# -*- coding: utf-8 -*-
"""
This module contains functions for turning a Python script into a .hex file
and flashing it onto a BBC micro:bit.
"""
import argparse
import sys
import os
import struct
import binascii
import ctypes
from subprocess import check_output


#: The magic start address in flash memory for a Python script.
_SCRIPT_ADDR = 0x3e000


#: The help text to be shown when requested.
_HELP_TEXT = """
Flash Python onto the BBC micro:bit or extract Python from a .hex file.

If no path to the micro:bit is provided uflash will attempt to autodetect the
correct path to the device. If no path to the Python script is provided uflash
will flash the unmodified MicroPython firmware onto the device. Use the -e flag
to recover a Python script from a hex file.

Documentation can be found here: http://uflash.readthedocs.org/en/latest/
"""


#: MAJOR, MINOR, RELEASE, STATUS [alpha, beta, final], VERSION
_VERSION = (0, 9, 18, 'beta', 0)


def get_version():
    """
    Returns a string representation of the version information of this project.
    """
    return '.'.join([str(i) for i in _VERSION])


def hexlify(script):
    """
    Takes the byte content of a Python script and returns a hex encoded
    version of it.

    Based on the hexlify script in the microbit-micropython repository.
    """
    if not script:
        return ''
    # Convert line endings in case the file was created on Windows.
    script = script.replace(b'\r\n', b'\n')
    script = script.replace(b'\r', b'\n')
    # Add header, pad to multiple of 16 bytes.
    data = b'MP' + struct.pack('<H', len(script)) + script
    data = data + bytes(16 - len(data) % 16)
    assert len(data) <= 0x2000
    # Convert to .hex format.
    output = []
    addr = _SCRIPT_ADDR
    assert(_SCRIPT_ADDR >> 16 == 3)  # 0x0003 is hard coded in line below.
    output.append(':020000040003F7')  # extended linear address, 0x0003.
    for i in range(0, len(data), 16):
        chunk = data[i:min(i + 16, len(data))]
        chunk = struct.pack('>BHB', len(chunk), addr & 0xffff, 0) + chunk
        checksum = (-(sum(chunk))) & 0xff
        hexline = ':%s%02X' % (str(binascii.hexlify(chunk), 'utf8').upper(),
                               checksum)
        output.append(hexline)
        addr += 16
    return '\n'.join(output)


def unhexlify(blob):
    """
    Takes a hexlified script and turns it back into a string of Python code.
    """
    lines = blob.split('\n')[1:]
    output = []
    for line in lines:
        # Discard the address, length etc. and reverse the hexlification
        output.append(binascii.unhexlify(line[9:-2]))
    # Strip off "MP<size>" from the start
    output[0] = output[0][4:]
    # and strip any null bytes from the end
    output[-1] = output[-1].strip(b'\x00')
    script = b''.join(output)
    return script.decode('utf-8')


def embed_hex(runtime_hex, python_hex=None):
    """
    Given a string representing the MicroPython runtime hex, will embed a
    string representing a hex encoded Python script into it.

    Returns a string representation of the resulting combination.

    Will raise a ValueError if the runtime_hex is missing.

    If the python_hex is missing, it will return the unmodified runtime_hex.
    """
    if not runtime_hex:
        raise ValueError('MicroPython runtime hex required.')
    if not python_hex:
        return runtime_hex
    py_list = python_hex.split()
    runtime_list = runtime_hex.split()
    embedded_list = []
    # The embedded list should be the original runtime with the Python based
    # hex embedded two lines from the end.
    embedded_list.extend(runtime_list[:-2])
    embedded_list.extend(py_list)
    embedded_list.extend(runtime_list[-2:])
    return '\n'.join(embedded_list) + '\n'


def extract_script(embedded_hex):
    """
    Given a hex file containing the MicroPython runtime and an embedded Python
    script, will extract the original Python script.

    Returns a string containing the original embedded script.
    """
    hex_lines = embedded_hex.split('\n')
    # Find the marker in the hex that comes just before the script
    try:
        start_line = hex_lines.index(':08058000193901005D150000AE') + 1
    except ValueError as e:
        raise ValueError('Bad input hex file:', e)
    # Recombine the lines after that, but leave out the last 3 lines
    blob = '\n'.join(hex_lines[start_line:-3])
    if blob == '':
        # If the result is the empty string, there was no embedded script
        return ''
    # Pass the extracted hex through unhexlify
    return unhexlify(blob)


def find_microbit():
    """
    Returns a path on the filesystem that represents the plugged in BBC
    micro:bit that is to be flashed. If no micro:bit is found, it returns
    None.

    Works on Linux, OSX and Windows. Will raise a NotImplementedError
    exception if run on any other operating system.
    """
    # Check what sort of operating system we're on.
    if os.name == 'posix':
        # 'posix' means we're on Linux or OSX (Mac).
        # Call the unix "mount" command to list the mounted volumes.
        mount_output = check_output('mount').splitlines()
        mounted_volumes = [x.split()[2] for x in mount_output]
        for volume in mounted_volumes:
            if volume.endswith(b'MICROBIT'):
                return volume.decode('utf-8')  # Return a string not bytes.
    elif os.name == 'nt':
        # 'nt' means we're on Windows.

        def get_volume_name(disk_name):
            """
            Each disk or external device connected to windows has an attribute
            called "volume name". This function returns the volume name for
            the given disk/device.

            Code from http://stackoverflow.com/a/12056414
            """
            vol_name_buf = ctypes.create_unicode_buffer(1024)
            ctypes.windll.kernel32.GetVolumeInformationW(
                ctypes.c_wchar_p(disk_name), vol_name_buf,
                ctypes.sizeof(vol_name_buf), None, None, None, None, 0)
            return vol_name_buf.value

        for disk in 'ABCDEFGHIJKLMNOPQRSTUVWXYZ':
            path = '{}:\\'.format(disk)
            if os.path.exists(path) and get_volume_name(path) == 'MICROBIT':
                return path
    else:
        # No support for unknown operating systems.
        raise NotImplementedError('OS not supported.')


def save_hex(hex_file, path):
    """
    Given a string representation of a hex file, this function copies it to
    the specified path thus causing the device mounted at that point to be
    flashed.

    If the hex_file is empty it will raise a ValueError.

    If the filename at the end of the path does not end in '.hex' it will raise
    a ValueError.
    """
    if not hex_file:
        raise ValueError('Cannot flash an empty .hex file.')
    if not path.endswith('.hex'):
        raise ValueError('The path to flash must be for a .hex file.')
    with open(path, 'wb') as output:
        output.write(hex_file.encode('ascii'))


def flash(path_to_python=None, path_to_microbit=None):
    """
    Given a path to a Python file will attempt to create a hex file and then
    flash it onto the referenced BBC micro:bit.

    If the path_to_python is unspecified it will simply flash the unmodified
    MicroPython runtime onto the device.

    If the path_to_microbit is unspecified it will attempt to find the device's
    path on the filesystem automatically.

    If the automatic discovery fails, then it will raise an IOError.
    """
    # Check for the correct version of Python.
    if not (sys.version_info[0] == 3 and sys.version_info[1] >= 3):
        raise RuntimeError('Will only run on Python 3.3 or later.')
    # Grab the Python script (if needed).
    python_hex = ''
    if path_to_python:
        if not path_to_python.endswith('.py'):
            raise ValueError('Python files must end in ".py".')
        with open(path_to_python, 'rb') as python_script:
            python_hex = hexlify(python_script.read())
    # Generate the resulting hex file.
    micropython_hex = embed_hex(_RUNTIME, python_hex)
    # Find the micro:bit.
    if not path_to_microbit:
        path_to_microbit = find_microbit()
    # Attempt to write the hex file to the micro:bit.
    if path_to_microbit:
        hex_file = os.path.join(path_to_microbit, 'micropython.hex')
        print('Flashing Python to: {}'.format(hex_file))
        save_hex(micropython_hex, hex_file)
    else:
        raise IOError('Unable to find micro:bit. Is it plugged in?')


def extract(path_to_hex, output_path=None):
    """
    Given a path_to_hex file this function will attempt to extract the
    embedded script from it and save it either to output_path or stdout
    """
    with open(path_to_hex, 'r') as hex_file:
        python_script = extract_script(hex_file.read())
        if output_path is not None:
            with open(output_path, 'w') as output_file:
                output_file.write(python_script)
        else:
            print(python_script)


def main(argv=None):
    """
    Entry point for the command line tool 'uflash'.

    Will print help text if the optional first argument is "help". Otherwise
    it will ensure the optional first argument ends in ".py" (the source
    Python script).

    An optional second argument is used to reference the path to the micro:bit
    device. Any more arguments are ignored.

    Exceptions are caught and printed for the user.
    """
    if not argv:
        argv = sys.argv[1:]
    try:
        parser = argparse.ArgumentParser(description=_HELP_TEXT)
        parser.add_argument('source', nargs='?', default=None)
        parser.add_argument('target', nargs='?', default=None)
        parser.add_argument('-e', '--extract',
                            action='store_true',
                            help="""Extract python source from a hex file
                            instead of creating the hex file""",
                            )
        args = parser.parse_args(argv)

        if args.extract:
            extract(args.source, args.target)
        else:
            flash(args.source, args.target)
    except Exception as ex:
        # The exception of no return. Print the exception information.
        print(ex)


#: A string representation of the MicroPython runtime hex.
_RUNTIME = """:020000040000FA
:1000000000400020E91F01002520010027200100F9
:1000100000000000000000000000000000000000E0
:100020000000000000000000000000002920010086
:1000300000000000000000002B2001002D20010026
:100040002F2001002F200100DD1E01002F200100C4
:100050002F20010000000000314601002F20010088
:100060002F2001002F200100514B01002F20010003
:100070002F2001002F2001002F2001002F20010040
:100080002F200100BD1C01002F2001002F200100A6
:100090002F2001002F2001002F2001002F20010020
:1000A0002F2001002F2001000000000000000000B0
:1000B0000000000000000000000000000000000040
:1000C00008B50FF095F817F08BFC0A4B084A16F0AC
:1000D00051FE094A094B16F029FB17F0D3FC032304
:1000E000984302231843064BC01808BDC046C046BB
:1000F0000000000000806640182D4454FB21094098
:1001000000008080C046C04608B50FF071F817F0B7
:1001100067FC0A4B084A16F02DFE094A094B16F0F7
:1001200005FB17F0AFFC0323984302231843064B4B
:10013000C01808BDC046C046182D4454FB210940D4
:10014000000000000080664000008080C046C0467D
:10015000F7B5171C146801AA051C0E1C05F0D6F88B
:10016000402D05D1019B3C255A1EA4185B421C4022
:1001700023183B602A1C5A27B742BF413E3A5542DA
:100180006A417F42231CD2B2391C1EF0A8FB041C1A
:100190000D1C4F2E3DD0532E08D1201C23F0C6FF3E
:1001A0000022011C201C01F0ADFC32E0662E06D1BD
:1001B00003239C4302201A4B0443E01829E0642ED9
:1001C00009D1201C17F05EFC032398430224144B32
:1001D0002043C0181DE0002F0FD0104B0E4A1219FB
:1001E0006B41201C002B04D1002A02DB1FF0BDF95B
:1001F0000FE0291C1FF0AAF90BE0201C002905D1F3
:10020000084B9C4202D81FF0CBF902E0291C1FF0DA
:10021000B8F9FEBDC046C046000000400000000026
:1002200000008080FFFFFF3F38B5041C82070CD11F
:10023000114B02689A4208D107F01AF9211D051CDA
:10024000043020F02BFC281C11E0201C0EF06CFF69
:10025000C0231B06984204D1064905481FF076F9D1
:1002600005E0C317C018584040000123184338BDAB
:10027000000000400000000018520200C046C046C6
:10028000F7B5041C0191081C002114F0B9FF0028E7
:1002900005D0234923481FF051FA11F0EEFA2379D3
:1002A000D90702D4A079617901E00520011C09F089
:1002B000D9FA0026071C22790523D10700D4A37997
:1002C0009E4226DA002522790523D10700D4A3799E
:1002D0009D421CDA2A1C311C201C1FF049FD15F020
:1002E00057FE019915F094FB17F07AFB0B4B0A4A65
:1002F00015F0FAFE17F002FB0923082800DC031CA6
:100300002A1C381C311C1FF016FD0135DBE70136B5
:10031000D1E7381CFEBDC046000000000000E03FF1
:10032000EDB80200A859020010B5041C081C8A0789
:1003300003D1134B0A689A4202D00EF0F5FE09E091
:100340000EF056FF17F04CFB0C4B0B4A15F0CCFE91
:1003500017F0D4FA0B4B011C994205D90A490B48F6
:100360001FF0ECF911F089FA606813F0E3FD08481A
:1003700010BDC046C046C046000000000000E03F7F
:1003800030570200FF03000054BC0200A8590200CD
:10039000387D0200C046C046F0B541188BB0071C3E
:1003A00008920993029102998F4200D32EE1387886
:1003B0000CF000FF002801D00137F4E73B782B2B2D
:1003C00002D10137049005E004902D2B0ED10122BB
:1003D00001370492029B9F4208D3914A00213D1CA1
:1003E0000191069207910E1C002458E03A782023D0
:1003F0001A43692A2ED10299BA1C914200D8D6E03C
:100400007A781A436E2A00D0D1E0BA781A43662A65
:1004100000D0CCE0FA1DFD1C914200D8C3E0FA7870
:100420001A43692A00D0BEE03A791A436E2A00D0F6
:10043000B9E07A791A43692A00D0B4E0BA791A434C
:10044000742A00D0AFE0FA791343792B00D0AAE0E8
:100450000535A8E06E2AC0D10299BA1C914200D895
:10046000A5E07A781A43612A00D0A0E0BA78134355
:100470006E2B00D09BE0FD1C00266A4C9AE02B7886
:100480006A1C191C303903920591092932D8022EB1
:1004900009D1019A0A235343CB180193039D029B70
:1004A0009D42ECD354E0012E15D1059815F0CCFDFA
:1004B000069915F0ADFA011C201C14F059FF041C1C
:1004C000069817F08DFA554B534A16F053FC17F067
:1004D000D9FA0690E2E75449201C15F099FA041C59
:1004E000059815F0B1FD011C201C14F041FF0026F9
:1004F000041CD3E7002E02D12E2B02D126E0022EBF
:1005000019D020221A43652A15D1039B02998B42E8
:100510000BD26B782B2B02D10235039505E02D2BE6
:1005200003D10235012203950792039B02998B4266
:1005300065D00226B2E7089A0026B24209D02022EE
:1005400013436A2B05D1039D012602E00126A5E78E
:1005500000260799002902D0019A52420192019B7C
:100560000393039A002A08DD201C2F4915F050FA46
:100570000399041C01390391F3E70199CB43DB177D
:1005800099430191019B002B14D0201C17F028FAED
:10059000224B214A16F0EEFB17F074FA019A041C64
:1005A00001320192EEE7FF240026E40502E03D1C43
:1005B000002600240499002902D080221206A418E3
:1005C000BD421CD0029B9D4206D228780CF0F2FD61
:1005D000002814D00135F5E702998D420FD1002E85
:1005E00002D1099A002A02D01048114909E00323D8
:1005F0009C4302200F4B0443E0180BB0F0BD0B48A6
:100600000D491FF09BF810990DF0C2FD00210491D7
:10061000E3E6C046C046C0469A9999999999B93F70
:10062000CDCCCC3D0000C07F00002041A859020085
:10063000A1C0020000008080BEC00200C046C046CB
:1006400008B50B4B1B78002B01D111F071FB11F099
:1006500017FB064B044A14F01BFE4904C00B084369
:1006600008BDC046C046C04640420F000000000022
:10067000632E0020C046C0462F4B70B51B78061C69
:10068000002B01D111F054FB11F0FAFA254B244A4A
:1006900014F0FEFD4B04C00B002400251843CD0BC5
:1006A0000023321CA4185D4180231B06984205D903
:1006B000002E03DB1C4A1D4BA4185D41610CEB03AB
:1006C0000B43E2031A481B4980185941154B144A41
:1006D00014F0BEFD194D041C2B78194E002B02D0CE
:1006E000336898421BD011F0CBFA201A022802DCA2
:1006F00011F0C6FA841C2102124BA822D200090A6A
:1007000099502A783460002A09D101222A70D22116
:100710008022520289005A50C12189005A5070BD6E
:1007200040420F0000000000000000000100000037
:100730003F420F0000000000632E0020642E0020C6
:10074000B42800200010014073B58279061C93077D
:1007500040D401231A4206D181881A1C684612F03F
:100760007BFC234837E01E22B35E2422805EC01A41
:1007700017F0F8F8041C2223F05E1C22B35E0D1C57
:10078000C01A17F0EFF8021C0B1C201C291C18F0D3
:10079000BFFA124B104A16F0EDFA114A114B15F040
:1007A000C5FF17F06FF90021041C14F029FD002883
:1007B00004D0201C0F4914F0DBFD041C201C17F092
:1007C0000FF9021C0B1C0848084916F063FD17F0CE
:1007D00095F800E0084876BD000000000080664003
:1007E000EA2E4454FB2109400000000000807640BE
:1007F00014FCFFFF0000B44315FCFFFFC046C046D9
:1008000070B5041C04201BF0B7F8051C1648401BEB
:1008100015F01AFC17F0E4F8124B114A16F0AAFA78
:1008200000F026F80323061C281C9E431BF0AEF89C
:100830002368002B0AD1301C1BF09EF82060002892
:10084000F6D1203E002EF3D1084807E0B608B600E6
:100850009B19201C636022F03AFF002070BDC04647
:10086000666666666666EE3F0038002013FCFFFF92
:1008700038B50E4B0C4A041C0D1C17F0C3F90028A8
:1008800004D1201C291C17F039F838BD074B064A43
:10089000201C291C16F0FEFC17F030F880231B06E4
:1008A000C018F2E7C046C046000000000000E0416A
:1008B000F0B58BB0061C18F02BFE374D0023EB561D
:1008C000041C013336D0301C1AF05CFC002831D0F7
:1008D000301C324914F0A8FC071E2ED1301C3049C0
:1008E00014F08EFC002825D0042300932D4B301CDF
:1008F0000193089717F074F8224B214A6C46A261C5
:10090000E3610023EB5620616161A060E160022B8E
:100910002FD068461AF044FC00282AD0236A002B06
:1009200003D01AF0F9FC236A0360A069E16917F0AB
:10093000A9F8041C201C0BB0F0BD03230093194B35
:10094000301C01930023089317F04AF86C4620618D
:100950006161A060E1602978002904D10A4A0B4B4B
:10096000A261E361D5E70A4A0A4BA261E361022969
:10097000CFD11AF0D1FC22230360CFE7C046C04696
:100980000000000000000000000000E0FFFFEF4753
:10099000000000000000F07FEA0000208071B142FA
:1009A000B5F1CFC26C9B0200F0B58BB0041C0E1CDD
:1009B00018F0B0FE2A4F0023FB56051C013304D06B
:1009C000301C18F027F8002802D1281C0BB0F0BD0D
:1009D000201C18F01FF80028F7D0301C002114F05C
:1009E00009FC0028F1D0012300931E4B201C019329
:1009F0000023089316F0F4FF041C0D1C301C029415
:100A0000039516F0EDFF3E7804900591002E16D068
:100A100012491148021C0B1C15F088FE0690079124
:100A2000022E0ED11AF078FC21230360089B002BC4
:100A30000DD10698079917F025F8051CC5E706940F
:100A4000079568461AF0ACFB0028EFD1EAE71AF0E8
:100A500063FC089B0360ECE700000000000000005E
:100A6000EA000020749B020070B58AB0041C18F0E4
:100A7000D7FE354E0022B256051C031C01320CD0A5
:100A8000201C17F0C7FF2B1C002806D0201C0021BB
:100A900014F0CAFB2B1C002802D0181C0AB070BD31
:100AA0002A4B0890201C019316F09AFF3578049089
:100AB000059102900391002D2AD1204B1E4A0692E7
:100AC0000793201C002114F095FB002811D002236D
:100AD0000093022D26D068461AF062FB002821D030
:100AE000089B002B23D10698079916F0CBFF031C17
:100AF000D3E701230093022D0FD068461AF050FB74
:100B000000280AD0124800F0F7FC06900791E7E7AA
:100B10000B4A0C4B06920793D3E71AF0FDFB2123F7
:100B20000360EFE71AF0F8FB22230360D8E71AF01E
:100B3000F3FB089B0360D6E7000000E0FFFFEFC770
:100B4000000000000000F0FFEA0000207C9B020093
:100B5000809B0200C046C046F0B546464F46C0B432
:100B60008BB0051C0C1C18F0B9FFBB4E0023F356CC
:100B70008046071C013304D0201C17F04BFF0028CF
:100B800005D1381C0BB00CBC90469946F0BD281C12
:100B900017F040FF8146002833D1201C002114F0BB
:100BA00029FB0028EDD001230093AC4B4A46281CBA
:100BB0000193089216F014FF6F46B860F960201C8C
:100BC00016F00EFF9D4B9C4ABA61FB610023F35661
:100BD000386179615A1C0ED0022B0CD068461AF08D
:100BE000DFFA002800D1E5E03B6A002B03D01AF0C1
:100BF00093FB3B6A0360B869F96916F043FF071C71
:100C0000BFE7281C002114F0F5FA002832D0201C80
:100C1000002114F0EFFA8046002869D001230093E8
:100C20008E4B281C01930023089316F0D9FE6F46C3
:100C3000B860F960201C16F0D3FE814A814BBA617E
:100C4000FB610023F35638617961002B04D07B4BA4
:100C5000794ABA61FB61CEE768461AF0A1FA00282A
:100C600000D1ACE03B6A002BC5D01AF055FB3A6AC4
:100C70000260C0E740461AF085FA8146002867D036
:100C80004046002114F0B6FA4746002800D178E724
:100C9000281C1AF077FA4746002800D171E7201C7B
:100CA0001AF070FA002800D16BE7042300936B4B15
:100CB000281C01930023089316F092FE6F46B8603B
:100CC000F960201C16F08CFE5D4A5E4BBA61FB6138
:100CD0000023F35638617961022B7AD068461AF006
:100CE0005FFA002875D03B6A002B00D183E7BCE790
:100CF000201C1AF047FA002800D142E7201C0021EE
:100D000014F07EFA002800D13BE701230093534BF7
:100D1000281C01934346089316F062FE6F46B860A4
:100D2000F960201C16F05CFE386179613178002989
:100D30004AD0454A454BBA61FB61022934D11AF0C9
:100D4000EBFA212303603A6A002A00D153E74EE709
:100D5000281C1AF017FA002892D0201C1AF012FA58
:100D600000288DD0404617F055FE6F46002835D13B
:100D700001230093394B0890281C019316F030FE94
:100D8000B860F960201C16F02BFE34783861796168
:100D9000002C19D02A482B49021C0B1C15F0C6FC4C
:100DA000B861F961022CCAD068461AF0F9F9002836
:100DB000C9D1C4E71AF0B0FA2123036014E71AF08E
:100DC000ABFA212303604DE71D4A1E4BBA61FB615C
:100DD000EAE71AF0A1FA2223036084E703230093D1
:100DE0001E4B4A46281C0193089216F0F9FDB86084
:100DF000F960201C16F0F4FD0023F3563861796188
:100E0000002B2DD1124A134B281CBA61FB61002123
:100E100014F0F6F9002845D10023F356022B05D033
:100E200068461AF0BDF9002800D01BE71AF074FAE2
:100E30002223036016E7C046000000000000F03FD8
:100E40000000000000000000000000000000F0FFB3
:100E5000000000E0FFFFEF47EA000020849B020053
:100E60001E4B1D4A281CBA61FB61002114F0C8F911
:100E70000028D1D0FC21201C890514F0C9FD16F0F2
:100E8000AFFD041C0D1C1AF08DF9021C0B1C201C5C
:100E9000291C16F093FE0028BED1114A114BBA61ED
:100EA000FB61B9E7FC21201C890514F0B1FD16F0A7
:100EB00097FD041C0D1C1AF075F9021C0B1C201C5C
:100EC000291C16F07BFE0028A6D1074A074BBA6101
:100ED000FB61A1E7C046C046000000000000F07FB3
:100EE000000000000000F0FF000000E0FFFFEFC77F
:100EF00070B58AB0041C19F0FBFA274E0023F35694
:100F0000051C01330AD0201C17F084FD002805D0F1
:100F1000201C002114F074F9002802D1281C0AB00A
:100F200070BD012300931D4B201C019300230893E7
:100F300016F056FD34780490059102900391002C30
:100F400011D1144B124A0692079368461AF028F9F9
:100F5000002812D0089B002B14D10698079916F090
:100F600091FD051CDAE70B490948021C0B1C15F022
:100F7000DDFB06900791022CE7D11AF0CDF9212371
:100F80000360E7E71AF0C8F9089B0360E5E7C0468D
:100F90000000000000000000EA0000208C9B02001E
:100FA000F0B55F464D4644465646F0B4041C5042E8
:100FB0000D1C104359004908C00F8846014389465B
:100FC000774985B0161C1F1C9B46009401958C46E2
:100FD000894527D80198410049080390009889461F
:100FE000009940420843C00F49460143614519D862
:100FF0006C48C01810434BD0991702200840824615
:101000000198C10F5046084382460098494608435C
:1010100017D1504602285BD011DC002811DB201CC0
:10102000291C05E0301C391C221C2B1C15F05CF817
:1010300005B03CBC90469946A246AB46F0BD03289D
:1010400035D04046024305D10399002946DB3F498C
:101050003D48EDE7524B98451FD0514B99453AD04A
:1010600048464146431A1B153C2B23DD3749364879
:101070005346012B40D0022B33D0002BD8D0344A1A
:10108000344B16F007F9344A344B16F003F9CFE726
:10109000201C291C00F088F8CAE7C14535D050460D
:1010A000012842D03CDD022812D00328D5D12C489B
:1010B0002C49BDE75A46002A22DB321C3B1C201C6F
:1010C000291C15F033FB1AF053F800F06DF8CFE748
:1010D00021482249ACE7039A002AB8DA224823497A
:1010E000A6E71B4A1B4B16F0D5F8021C0B1C1A482E
:1010F0001A4916F0CFF89BE780242406091997E7D0
:101100003C33DADA1A481B49B2E75246012A17D0B3
:101110000EDD022A11D0032ADDD11748174987E7CF
:1011200000289AD11248134982E7154815497FE7EC
:10113000002AD0D1144815497AE71548154977E7B0
:101140001548164974E7C046182D4454FB21F93F51
:10115000075C143326A6A13C182D4454FB210940FA
:10116000182D4454FB2109C0182D4454FB21F9BF0C
:101170000000000000000000D221337F7CD902C0B3
:101180000000000000000080182D4454FB21E93FBE
:10119000D221337F7CD90240182D4454FB21E9BF72
:1011A0000000F07F000010C0F8B556464D4644469A
:1011B0005F46C54BF0B44E00814688468A467608A5
:1011C0009E420CDDC14B9E4200DDA7E000D1A2E0B3
:1011D0005046BF4A002800DCE3E0BE4BA6E0BE4B11
:1011E0009E4200DDB8E0BD4B9E4200DCA6E001243B
:1011F0006442A3464A4643464846414615F0BAFD76
:10120000061C0F1C321C3B1C15F0B4FD8F4B8E4A84
:10121000041C0D1C15F0AEFD8D4A8E4B14F064FFBE
:10122000221C2B1C15F0A6FD8B4A8C4B14F05CFF86
:10123000221C2B1C15F09EFD894A8A4B14F054FF8A
:10124000221C2B1C15F096FD874A884B14F04CFF8E
:10125000221C2B1C15F08EFD854A864B14F044FF92
:10126000321C3B1C15F086FD834A844B061C0F1C68
:10127000201C291C15F07EFD814A824B16F00AF8CD
:10128000221C2B1C15F076FD7F4A804B16F002F8CD
:10129000221C2B1C15F06EFD7D4A7E4B15F0FAFFCB
:1012A000221C2B1C15F066FD7B4A7C4B15F0F2FFCF
:1012B000221C2B1C15F05EFD021C58460B1C013035
:1012C00000D170E05946CC00301C391C14F00CFFE2
:1012D0004A46434615F04EFD814D0B1C81492D19A0
:1012E000021C0C19101C191C2268636815F0D2FF2F
:1012F0004A46434615F0CEFF021C0B1C286869685D
:1013000015F0C8FF021C50460B1C00280EDA802086
:1013100000060B180AE0002800D159E74A46434668
:101320004846414614F0E0FE021C0B1C101C191C20
:101330003CBC90469946A246AB46F8BD584A594B2C
:1013400014F0D2FE584A594B16F052FC002800D136
:101350004DE74A464346E9E719F00AFF624B041C91
:101360000D1C9E4230DC614B9E4256DC221C2B1C25
:1013700014F0BAFE4C4A4D4B15F08CFF4C4A4D4BC5
:10138000061C0F1C201C291C14F0AEFE021C0B1C9A
:10139000301C391C15F0CAF98846002181468B465D
:1013A00028E7534BC2E7301C391C14F09DFE4A4617
:1013B000434615F0DFFC021C0B1C4846414615F065
:1013C00069FF021C0B1CB1E74A4B9E421ADC3A4AE9
:1013D0003A4B15F05FFF384A384B061C0F1C201C97
:1013E000291C15F0C7FC304A304B14F07DFE021C5E
:1013F0000B1C301C391C15F099F9814602208846D7
:101400008346F7E62E482F49221C2B1C15F08EF937
:101410008846032181468B46ECE6234A234B15F090
:1014200039FF214A214B061C0F1C201C291C14F0DB
:101430005BFE0B1C021C391C301C15F077F90123D4
:10144000814688469B46D5E611DA22E33AAD903FC5
:10145000EB0D76244B7BA93F513DD0A0660DB13FEB
:101460006E204CC5CD45B73FFF8300922449C23F53
:101470000D5555555555D53F2F6C6A2C44B4A2BF18
:101480009AFDDE522DDEAD3F6D9A74AFF2B0B33FE0
:10149000711623FEC671BC3FC4EB98999999C93F58
:1014A0009C7500883CE4377E000000000000F03F9F
:1014B0000000000000000040000000000000F83FB5
:1014C000000000000000F0BFFFFF0F440000F07FAD
:1014D000182D4454FB21F93FFFFFDB3FFFFF1F3E68
:1014E0002047020000470200FFFFF23FFFFFE53FF9
:1014F000FB21F9BFFF7F0340024901487047C04606
:10150000000000000000F87F08B5064B06480333D2
:101510001B1A062B00D808BD044B002BFBD09847A4
:10152000F9E7C04600010020000100200000000093
:1015300008B50748074B1B1A9B10DA0FD318591030
:1015400000D108BD044A002AFBD09047F9E7C04605
:1015500000010020000100200000000010B5074C31
:101560002378002B09D1FFF7CFFF054B002B02D0CA
:10157000044800E000BF0123237010BD00010020DB
:10158000000000005404030008B5094B002B03D0F1
:101590000848094900E000BF08480368002B03D051
:1015A000074B002B00D09847FFF7C2FF08BDC0468D
:1015B000000000005404030004010020000100208A
:1015C00000000000144B002B00D1124B9D4640221E
:1015D00092029A1A924600218B460F461148124AEF
:1015E000121A22F0ADFC0D4B002B00D098470C4B8B
:1015F000002B00D098470020002104000D000B486C
:1016000022F078FB1AF042F92000290021F036FA86
:1016100019F088FE000008000040002000000000D3
:101620000000000000010020C82F00203DB601008E
:1016300008B50DF0DDFD034B184002231843024BA3
:10164000C01808BDFCFFFF7F0000808008B50DF0CA
:10165000CFFD17F0DFF9002801D1024800E0024871
:1016600008BDC046E07B0200247C020008B50DF0F6
:10167000BFFD17F0CFF9012801D1024800E0024870
:1016800008BDC046E07B0200247C020008B50DF0D6
:10169000AFFD17F0BFF9012801D9024800E0024868
:1016A00008BDC046E07B0200247C02001FB5002379
:1016B00001930DF09DFD01A917F01AFA0323021CF6
:1016C000084902209A43024352180292019A9A430F
:1016D000131C03435B1802A903930CF097FF05B09A
:1016E00000BDC0460000808038B50D1C0DF080FDA7
:1016F000041C281C0DF07CFD14F02AFC011C201C8D
:1017000017F0D2F90323984302231843014BC01862
:1017100038BDC046000080801FB5002301930DF046
:1017200067FD01A917F094F9032302249843074B9E
:101730002043C018029001981DF017FF02A90390E2
:10174000201C0CF063FF04B010BDC0460000808078
:1017500038B50D1C0DF04CFD041C281C0DF048FD87
:10176000011C201CFFF720F9032398430223184390
:10177000014BC01838BDC0460000808038B50D1C34
:101780000DF036FD041C281C0DF032FDC30F600067
:10179000DB0740081843032398430224014B2043EE
:1017A000C01838BD0000808038B50D1C0DF020FD3C
:1017B000041C281C0DF01CFD011C201C17F04CFB08
:1017C0000323984302231843014BC01838BDC04679
:1017D0000000808008B50DF00BFD16F01FFF0323FD
:1017E000984302231843014BC01808BD00008080B5
:1017F00008B50DF0FDFC17F0DFFA03239843022330
:101800001843014BC01808BD0000808008B50DF0DA
:10181000EFFC17F081FA0323984302231843014B8E
:10182000C01808BD0000808008B50DF0E1FC17F07D
:1018300049FA0323984302231843014BC01808BDFB
:101840000000808008B50DF0D3FC17F0FBF90323EE
:10185000984302231843014BC01808BD0000808044
:1018600008B50DF0C5FC17F047F803239843022391
:101870001843014BC01808BD0000808070B5061CDD
:1018800008680D1C0DF0B4FCFFF7EEF8041C012EE7
:1018900006D103239C430220094B0443E0180EE0C9
:1018A00068680DF0A5FCFFF7DFF8011C201C13F0A1
:1018B000CBFE032398430224014B2043C01870BD84
:1018C0000000808008B50DF093FCFEF7F1FF0323C4
:1018D000984302231843014BC01808BD00008080C4
:1018E00038B50D1C0DF084FC041C281C0DF080FC88
:1018F000011C201CFFF730F90323984302231843EF
:10190000014BC01838BDC0460000808008B50DF0FE
:101910006FFCFFF7EDFA0323984302231843014BB2
:10192000C01808BD00008080032210B502400123CA
:10193000002A03D1094904688C420CD0011C1940CB
:101940000123002907D10B1C002A04D10268044B93
:10195000D31A5A425341181C10BDC046E87B0200FE
:101960001852020010B5041CFFF7DEFF0123002807
:1019700009D103222240031C022A04D1034B1C403C
:10198000A31F5C1EA3410120184010BD070080FF6B
:1019900008B520F040F90349021C034806F0A4F9F9
:1019A0000FF06BFF1FA50200985E020010B5041C2B
:1019B0000C201FF0D7FB034B4460036000238360BF
:1019C00010BDC046184B0200F7B58A18019300926B
:1019D000041C0E1C0B1C002200998B420DD219789E
:1019E000272904D0223948424141C9B201E00021EF
:1019F000012201330029EFD002E02225002A00D184
:101A000027251F4F201C391C2A1C20F0E8FA0099BA
:101A10008E422FD23278AA4203D1201C19492A1CA7
:101A200024E05C2A02D1201C17491AE01F2A0AD997
:101A30007F2A19D0019B002B02D053B2002B0CDB64
:101A4000201C391C12E00A2A02D1201C0F4908E090
:101A50000D2A02D1201C0E4903E0092A04D10D49A8
:101A6000201C20F0F2F903E00B49201C20F0B7FA0B
:101A70000136CCE7391C2A1C201C20F0B0FAF7BD37
:101A80004CA502004BA502004FA5020052A5020082
:101A900055A5020058A502005BA50200184B70B5C1
:101AA000061C0C1C98420ED1886849680CF05EFC3C
:101AB000051E08D0201C1FF051FCED00002306205D
:101AC000236028431AE010201FF04CFB6168051CBE
:101AD00081600660A0680CF02DFC6168226801310D
:101AE0006860A068914201D01FF061FBE860E9687E
:101AF000AA6800238B54281CA360236070BDC046D5
:101B0000C855020038B5051C0C1C002A02D00CF088
:101B100063FC03E00CF02AFC002803D0C00006237D
:101B2000184304E00248291C221C1BF0F0FB38BDBE
:101B3000C855020008B5031C0A1C0248191C1BF0FA
:101B4000E6FB08BDA84B020008B50A4B0340062B74
:101B500001D1C0080DE0820709D1074B02689A4203
:101B600005D1C3688168181C0CF036FC01E0FFF752
:101B70000FFF08BD070080FFC855020008B5064BDF
:101B80000340062B03D1C0081FF022FF02E0836848
:101B9000C0680B6008BDC046070080FFF0B5002696
:101BA00089B00F1C051C1C1C081C0096111C03236B
:101BB000321C05F0A1FBB74238D0012F0ED104A88A
:101BC00002AA10210BF08CFA216802A8321C0DF039
:101BD000DBF9281C04A9FFF761FF28E0206804A9AD
:101BE00082071AD1134B02689A4216D1FFF7C6FF3B
:101BF000114B061C20680340062B04D1C0081FF0BF
:101C0000D8FE041C00E044681020049F1FF0AAFACC
:101C100005608760C660446009E001220DF04AFC5F
:101C2000059904980022FFF76DFF00E00E2009B02F
:101C3000F0BDC046A84B0200070080FFF0B58BB096
:101C4000049008680D1C069207930DF083F9041C9C
:101C500068680DF07FF9061EA64202D06868FFF79B
:101C600097FE08A92868FFF789FF09A9041C68687E
:101C7000FFF784FF089A0590A3180393049B271C81
:101C8000022B1BD9AB6820498B4207D00121009160
:101C9000301C211C04F0F4FD071C00E0271C049BF1
:101CA000032B0BD0EB68184A934207D00122009215
:101CB000301C211C089A04F0E3FD0390039B381CA0
:101CC000D91B069B059A0093099B1BF000FB011E84
:101CD0000AD1079B01204042002B12D00B490C482F
:101CE0001DF02CFD0FF0C9FD0A4B9E4205D1201CB2
:101CF0001FF043FC0121400002E0011B49000120CC
:101D000008430BB0F0BDC046387D020062A502005A
:101D1000A8590200C8550200F0B58DB0041C03910B
:101D20000DF018F904A9061C201CFFF727FF0290EC
:101D3000039882070BD10368314A934204D105A965
:101D400006AA1FF06DFE10E02E4A934208D02D48DF
:101D50000121C36800220193019C03ABA0470390BB
:101D6000039805A906AA1DF040FF0024251C059B29
:101D70009C421ED2069AA700D0590DF0EBF8B04253
:101D800005D0214921481DF0D9FC0FF076FD002C2B
:101D900001D0049BED18069A1D4BD0590340062B29
:101DA00003D1C0081FF00AFE00E080682D1801343E
:101DB000DDE7291C08A81FF0BEFA0A9C0025059A39
:101DC000954217D2002D06D0201C049A029922F0C9
:101DD00095F8049AA418069AAB00985807A9FFF73B
:101DE000CDFE079A011C201C22F088F8079B0135C4
:101DF000E418E4E7301C08A9FFF750FE0DB0F0BD71
:101E0000D08B02003063020076A50200985E0200CB
:101E1000070080FFF0B5071C87B008680C1C0DF0A8
:101E200099F804A9061C2068FFF7A8FE05A9051C5F
:101E30006068FFF7A3FE0390281C022F07D9012238
:101E40000092A368301C291C049A04F019FD059A1D
:101E5000451B049BAD189D4206D8039922F03FF81C
:101E6000002801D1024800E0024807B0F0BDC0469A
:101E7000E07B0200247C020073B50C1C061C086881
:101E80006946FFF77BFE01A9051C6068FFF776FE37
:101E9000011C022E02D908480BF018F9019A009B88
:101EA0009A4207D89B1AE81822F019F8002801D1A5
:101EB000024800E0024876BDBBA50200E07B0200BC
:101EC000247C0200F0B58FB0079010680C1C171C22
:101ED0000DF040F80690012C10D078680DF03AF81B
:101EE000069A031C7868934201D0FFF751FD0DA9B3
:101EF000FFF744FE0D9B0890099303E02D4B07224A
:101F00000992089338680DA9FFF738FE0D9A079BD0
:101F10000B900492012B04D1141C5B42013C0A93E8
:101F200002E001220A920024049B002505930395F8
:101F30002E1C059A002A22D00B9B08981A190123FF
:101F4000009309991BF0C3F9002812D1039A002AC3
:101F50000ED1079B002B03D1261C049C013C19E0E9
:101F6000079A012A15D00123251C261C039300E0A3
:101F7000251C059B0A9A013BA4180593D9E7039BEE
:101F8000002B08D10C4B069A0E209A420FD00B481A
:101F90000DE0039E251C049B0135AA1B9A4201D12A
:101FA000386804E00B9B069899191BF0B0F90FB044
:101FB000F0BDC04618A50200C855020078490200CD
:101FC000F0B589B0049008680D1C0CF0C3FF041C28
:101FD00068680CF0BFFF071EA74202D06868FFF7D1
:101FE000D7FC06A92868FFF7C9FD07A9061C686881
:101FF000FFF7C4FD069A049BB11805900391341CA9
:10200000022B1BD9AB6820498B4207D001210091DC
:10201000381C311C04F034FC041C00E0341C049A0D
:10202000032A0BD0EB6818498B4207D0012200929B
:10203000381C311C069A04F023FC0390079A002AEE
:1020400001D0002510E0039B201C191B1FF0A4FAEF
:1020500001304000012514E0201C059921F03FFFCC
:10206000002807D10135341C079A0399A6188E421F
:10207000F2D904E0201C1FF079FA061CF3E76D008A
:102080000120284309B0F0BD387D0200F0B58BB0C7
:102090000E1C071C03920CF05DFF041C301C0CF09E
:1020A00059FF844202D0301CFFF772FC05A9381C8E
:1020B000FFF764FD06A9051C301CFFF75FFD069BBA
:1020C000021C002B05D11A491A481DF037FB0FF0EE
:1020D000D4FB19498C4201D10E2100E01749079128
:1020E000089109910399002901DD079700E00997FC
:1020F0000399281C009105991BF0E9F8002811D0DC
:10210000471B3A1C291C201C1BF001F9069A059B51
:10211000B918DF1B07906918BA1A201C08961BF023
:10212000F6F8099007A903200CF070FA0BB0F0BD87
:10213000CDA50200A8590200C85502007849020046
:1021400008B5011C01481BF0F8F908BDB9150200DB
:1021500008B5011C01481BF0F0F908BDCD150200BF
:10216000F7B5061C081C01A9FFF708FD019A051C1C
:10217000002A01D1144826E0144B041C9E4201D1D0
:10218000002712E0124B9E42FAD0019A631B934241
:1021900018D22078B04701340028F6D1EAE7207839
:1021A0000BF014F8002805D10134019A631B934207
:1021B000F5D305E02078B0470028DBD00127F3E70E
:1021C000002FD7D00348FEBD247C020015D20000AA
:1021D0002DD20000E07B020008B5011C0148FFF78A
:1021E000BFFF08BDB5D1000008B5011C0148FFF7CD
:1021F000B7FF08BDCDD1000008B5011C0148FFF7AD
:10220000AFFF08BDE5D1000008B5011C0148FFF78C
:10221000A7FF08BD15D2000008B5011C0148FFF753
:102220009FFF08BD2DD20000F0B585B0051C0C1C29
:10223000171C0CF08FFE6946061C281CFFF79EFC3D
:10224000051C042F22D10099A20715D1114B226839
:102250009A4211D1081C01AA211C04F05DFF00283C
:1022600002D10D480AF032FF019B029AE918D21AF6
:10227000301C1BF04CF80AE00023301C221C0DF02F
:1022800031F8285C01234000184300E0002005B02D
:10229000F0BDC046787D0200DDA5020070B51C1CB3
:1022A00088B0002968D01868354D031C2B40062BD8
:1022B00005D082071ED1334B02689A421AD10239E7
:1022C000012953D804A9FFF759FC061C20680540D2
:1022D000062D04D1C0081FF06CFB041C00E044680C
:1022E0001020049D1EF03EFF274A85600260C660F4
:1022F000446042E0012939D8012210420AD044103A
:10230000211C04A81FF017F806980021221C21F0B8
:1023100017FE26E001A91FF094FC002805D0029AC0
:10232000019919481AF0F3FF27E020680DF01CF816
:10233000002802D104A8102101E0411004A81EF0D9
:10234000E3FF20680AF006F9041C201C0AF050F98B
:10235000002806D00CF0E8FEC1B204A81FF07AF8FD
:10236000F3E704A90848FFF799FB06E00749084886
:102370001DF0E4F90FF081FA064808B070BDC046C0
:10238000070080FFC8550200A84B02000EA60200FD
:10239000985E02007849020037B5041C081C01A9A8
:1023A000FFF7ECFB0549051C201C1FF04EFD291C06
:1023B000201C019A0123FFF707FB37BDF4D302006D
:1023C0001D4BF7B5021C051C0C1C1A401F1C062ACD
:1023D0000BD10B40062B03D1401A4442604128E048
:1023E000C0081FF0E6FA061C00E046682740062FEA
:1023F00003D1E0081FF0DDFA00E06068002E05D090
:10240000002803D0864201D0002013E0281C694632
:10241000FFF7B4FB01A9051C201CFFF7AFFB009AD6
:10242000019B011C9A42EFD1281C21F058FD434228
:102430005841C0B2FEBDC046070080FF084B07B53B
:102440000340062B06D0830708D103689A69054B21
:102450009A4203D101A9FFF791FB0EBDFFF798FA4D
:10246000070080FF9D2400000A4B13B503400C1C9D
:10247000062B06D083070AD103689A69064B9A4255
:1024800005D101A9FFF77AFB019B236016BDFFF779
:102490007FFAC046070080FF9D240000F0B5A1B080
:1024A000041C0D1C0D920A2800D0CFE103240792D2
:1024B000144010D11368B64A934206D1079810A968
:1024C0000FAA1FF0ADFA07940BE0B24A934202D173
:1024D0000F94109405E00DAB0F930123109300238C
:1024E00007930F9B109A11A9281C0A930892FFF7D3
:1024F00045FB14AA0B90102118A80AF0F1FD0B9AC5
:10250000119B0B9CD21806920027069B9C4200D37D
:1025100093E12178252903D018A81EF09BFF8AE1BA
:10252000069A651C954202D39B489C4916E0617847
:10253000252904D118A81EF08DFF2C1C7BE1002654
:10254000282919D1A01C051C00E001352B78292B66
:1025500008D0069B9D42F8D38F4891491DF0EEF8B4
:102560000FF08BF9291A0122FFF7CCFA011C07980A
:102570000BF086FD0135061C002220232C1C09923D
:102580000593151C069A944211D223782D2B01D164
:10259000012306E02B2B01D1022302E0202B02D1E4
:1025A00004231D430FE0232B0BD0302B05D0069ABC
:1025B00000231293944208D31FE040221543059351
:1025C00001E0102309930134DCE723782A2B0FD193
:1025D000089A3B1E934202D372487349BEE70A9A97
:1025E0009B0098580CF0A0FD01371290013404E0D4
:1025F000201C12A91AF054FE241801235B421393E5
:10260000069B9C4290D223782E2B20D1069B621CE5
:102610000C929A4288D263782A2B0CD1089A3B1EDE
:102620009342D9D20A9A9B0098580CF07DFD01374D
:102630001390023407E000230C9813A913931AF0A7
:102640002FFE0C9B1C18069A944200D36CE7002EB8
:1026500007D1089A3B1E9342BED20A9A9B009E580D
:1026600001372378672B0FD8652B6ED2582B00D1FA
:10267000C8E004D81A1C453A022A66D9D2E0632B76
:1026800012D0642B42D0CDE0732B07D8722B00D32D
:1026900094E0692B3AD06F2B67D0C3E0752B35D00F
:1026A000782B00D1AEE0BDE0404B3340062B05D087
:1026B000B30714D13E4B32689A4210D11CA9301C8A
:1026C000FFF7D2FE1C9A011C012A02D03548394975
:1026D00044E720230093129B14A801930FE0301CC1
:1026E000FFF722F900280ED0301C0CF01DFD129AC5
:1026F0001CA9202308700192009314A801222B1C0E
:102700000EF018FA97E027482B4927E703223240BA
:102710000023022A04D1254B3340063B5A1E934125
:10272000311C002B07D0FF23DB05F018032398434F
:1027300004F0DEFE011C059A129B0192139A00958B
:102740000392029314A80A221FE0301C0CF050FDE3
:10275000059B22780093129B011C0193139B14A8E4
:1027600002932B1C1FF0EDFB65E0099A002A02D0B2
:1027700084239B001D43059B129A0193139B029295
:102780000095039314A8311C0822612347E0C0463A
:10279000D08B020098800200A859020028A60200EF
:1027A0003AA60200985E020050A60200070080FFD1
:1027B000C855020077A6020090A602001CA81021AE
:1027C00016AA0AF08DFC227816A8723A53425A4192
:1027D000D2B2311C0CF0D8FB139A1D9B002A00DAF0
:1027E0001393139A1E999A4200D91A1C202300931E
:1027F000129B14A801932B1C0EF09CF91CA81EF030
:10280000ADFD18E0099A173B1543059A0095019212
:10281000129A14A80292139A311C039210220EF0FD
:10282000EBF908E00B9A4849A41A00941A1C47488F
:1028300005F05AFA94E6013467E6089A974202D006
:10284000434844498AE6444818A968E0081C0CF04B
:1028500081FB16A9061C281CFFF790F9071C0D9890
:10286000072C1CD118A90CF09DFC0025A84268D0AB
:102870001899A94205DC384B0E259E4261D0374D90
:102880005FE0169B1CA859431EF055FD1E9A381C8C
:1028900000920121169A189B1CF0E9FB3DE00CF018
:1028A00059FB864206D10D981CA9FFF767F91C9DBC
:1028B00006900DE02A4B00259E4242D10D981CA99E
:1028C00001221FF0BEF9A8423BD01C9B1D9D069320
:1028D0001D2C06D8192C26D2052C0DD0122C0BD06D
:1028E0002EE01F2C2CD101230093381C1699069A38
:1028F0002B1C1AF0ECFC1DE0169A1CA8A9181EF05F
:102900001AFD391C169A1E9821F0F8FA169A1E9B89
:10291000069998182A1C21F0F1FA301C1CA9FFF71F
:10292000BDF8051C0DE00095201C391C169A069B6D
:102930001CF0D1FB002801D00A4D02E00A4D00E056
:102940000025281C21B0F0BDA1A60200A859020054
:10295000985E0200D6A60200C8550200784902001F
:10296000A84B0200E07B0200247C0200F0B59FB07F
:102970000D9109680E900591081C10A90F92FFF7A0
:10298000FDF81021079012AA16A80AF0A9FB079AD1
:10299000109B0021D21809920B910799099A914234
:1029A00000D38FE0079A1178141C01347D2908D1D7
:1029B000099B9C4202D251787D2910D0B348B4497A
:1029C00034E07B2903D016A81EF044FD76E0099977
:1029D000261E8E4236D2079A51787B2904D116A83A
:1029E0001EF038FD079469E07D2915D0212913D008
:1029F0003A2911D01EF0BDFC041C31787D290CD081
:102A000021290AD03A2908D0201C1EF023FD099B59
:102A100001369E42F1D115E000243378212B57D1A5
:102A20000999731C994205D898489A491CF086FE6A
:102A30000EF023FF75782B1C723B012BF4D8023665
:102A40008E4246D391489449F0E70A981EF09CFCC8
:102A5000069A002A00D17EE1002F00D120270C9A8F
:102A6000002A00D082E1069B3D2B00D189E15E2B3C
:102A700000D188E13C2B01D101231D43301CFEF71E
:102A800053FF002800D1CAE1632C00D190E100D9A6
:102A900082E1472C00D878E1582C00D1ACE1622CBF
:102AA00000D0B5E11199002302910095019703939D
:102AB00012A8311C022261230EF09EF8079B0133FD
:102AC00007936AE716A97548FEF7E8FF1FB0F0BD47
:102AD0000025337800220A923A2B18D1731C0793F1
:102AE00073787D2B0ED01EF044FC079E0A90099946
:102AF0008E42A7D231787D2909D00A9801361EF07E
:102B0000A9FCF4E7079A099B9A4201D39AE7079632
:102B100007990B787D2B02D05C48614986E7002C31
:102B200048D00023201C1A931EF081FC061C00785C
:102B30000AF058FB371C00281CD00B9A002A02DD33
:102B40005248584972E7301C1AA91AF0A9FB0E9A8C
:102B50001A9B013A3718934237D201330D999B00E3
:102B60005E5801235B420B931AE02E2B05D05B2BA2
:102B700003D001373B78002BF7D1B91B301C012261
:102B8000FEF7C0FF061C311C0F98002203F024F949
:102B9000002804D1311C44481CF0C9FD48E74668B0
:102BA0003B78002B02D041480AF090FA201C1EF01E
:102BB000EBFB13E00B9A002A02DA34483C4935E774
:102BC0000E9B0B99013B994202D33A483A492DE7B3
:102BD0000B9B0D9901339A0056580B930A9A002AC1
:102BE00003D1002D00D18AE101E0002D11D014AAFB
:102BF0001AA81021733D0AF073FA6A1E9541311C20
:102C0000EAB214A80CF0C0F924481AA9FEF746FF4E
:102C1000061C01235B42119314930A9B002B00D1E5
:102C200095E0181C1EF003FC0778041C0020874266
:102C300005D02248391C21F063FA431E9841002830
:102C400003D006970134002711E00690002F0ED024
:102C500061780691002904D0184821F051FA431EEA
:102C60009841002801D0023401E00690071C227828
:102C70000C922B2A05D02D2A05D00425202A1FD1FD
:102C800002E0022500E0002501341BE0A859020003
:102C90000BA7020033A702004CA70200C855020090
:102CA00064A7020088A70200885F0200EBA7020069
:102CB00008A80200045B0200D2A7020052A802008A
:102CC00000250C952378232B02D110231D430134BA
:102CD0002378302B07D1069B002B01D13D21069193
:102CE000002F00D13027201C11A91AF0D9FA201882
:102CF000037808902C2B04D1021C202301321D43A1
:102D0000089208990B782E2B07D10C1C0134201C3B
:102D100014A91AF0C5FA20180890089A002014780F
:102D2000844205D07748211C21F0EAF9431E9841DE
:102D3000002803D0089B0133089300E0041C089985
:102D40000B78002B00D180E66F4870496EE60A9D33
:102D50002C1C2F1C0C95301CFEF704FE3C23069304
:102D6000002800D178E63E21069175E6732C02D149
:102D7000654867495AE6632C00D074E662486549A5
:102D800054E6402379E6802377E6452C47D2002C91
:102D900019D0252C43D03BE0672C02D8652C12D3E8
:102DA0003DE06F2C19D0782C26D06E2C30D10AE063
:102DB000301C0CF0B9F9119A1AA908700192009709
:102DC00012A801228DE0119B009502930023019728
:102DD000039312A8311C0A226DE6E90602D580236E
:102DE0009B001D43119A00230292009501970393C3
:102DF00012A8311C08225EE611990022231C0291C0
:102E00000392173B0095019712A8311C102253E63C
:102E1000301C1EF000FF4049031C3B486BE0301C97
:102E2000FEF7A0FD002838D0002C1FD06E2C1DD03E
:102E3000472C15D8452C1AD2252C27D1301C0CF044
:102E4000D7F9364912F0E4FD119A80230192149AC1
:102E50005B00011C02922B43009712A8662212E02D
:102E6000231C653BDBB2022B10D800E06724301C2A
:102E70000CF0BEF9119A149B011C01920293009769
:102E800012A8221C2B1C1FF05CF817E6301C1EF049
:102E9000C2FE2349031C1C482DE0069B3D2B02D19A
:102EA00019482049C2E5002C02D0732C06D01CE042
:102EB00012A8311C221C0CF067F8FFE51AA9301C7F
:102EC000FFF7D2FA149B011C1A9A002B00DA149215
:102ED000149B9A4200D91A93119A009701921A9A58
:102EE00012A82B1C0DF026FEE8E5301C1EF093FE08
:102EF0000D49031C0448221C04F0F6FE98E57325D6
:102F000075E6C04657A80200A859020067A802004B
:102F100080A80200ACA80200DFA802000000C8429E
:102F200010A9020044A9020079A90200F0B5071C0B
:102F300087B008680D1C0CF00DF80090012F07D920
:102F40006C68022F05D0A8680CF0EEF8071C02E0B0
:102F5000444C01277F420020011C1CF02EFE04A9D6
:102F600001902868FEF70AFE049A3E4B051C86185D
:102F70009C4238D1B54229D228780AF01BF90028A2
:102F800024D00135F6E7002F23D02C1C20780AF03E
:102F900011F9002802D10134B442F7D1291C621B77
:102FA00000981AF0B4F9011C019806F02DF8B4420B
:102FB00054D220780AF0FEF8002802D00134B4423E
:102FC000F7D1FB17DB1BDB0FFF1A251CB542DAD349
:102FD00044E0291C721B00981AF099F9011C019811
:102FE00006F012F83AE0201C0BF0B4FF009A0290B1
:102FF000904202D0201CFEF7CBFC201C05A9FFF755
:1030000033FA059B0390002B22D1174917481CF077
:1030100095FB0EF032FC201C039920F060FF002885
:1030200005D00134009AA3189E42F4D2341C291C06
:10303000621B02981AF06BF9011C019805F0E4FF7D
:10304000B4420BD2059BE518FB17DB1BDB0FFF1A05
:10305000002FEBD0059A2C1C0092E3E7019807B0F3
:10306000F0BDC046387D0200CDA50200A85902007F
:10307000F0B50C1C8BB0022802D8FFF757FF7AE09E
:1030800008680BF067FF08A9059020686568FEF7DF
:1030900075FD0090A0680CF047F8411C0691041CD7
:1030A000081C00211CF089FD344B061C9D4202D1F6
:1030B00033480AF00BF8281C09A9FFF7D5F9099A3B
:1030C0000790002A05D12F492F481CF037FB0EF03E
:1030D000D4FB009B0899A2005B1802930392271C63
:1030E000099B0193002C0DD00299CD1A009A9542AC
:1030F00008D3281C0799019A20F0F1FE002821D05E
:10310000013DF3E7F368BC0002991D19009B059887
:10311000CA1A191C1AF0FBF82860002F10D0069963
:10312000F068CD1BAF0001193A1C20F0F0FE736867
:10313000F1685A1BC8199200002120F001FFB56008
:10314000301C18E0039BF2680598D2180492029B89
:10315000019A013FA9185A1B019BD21A1AF0D7F8FD
:10316000E317039A1B1B0499DB0F043A0860E41A67
:1031700003920295B4E70BB0F0BDC046387D020063
:10318000ABA90200CDA50200A859020010B5041C8D
:1031900008201DF0E7FF024B4460036010BDC046ED
:1031A000F04B0200F8B503780021041C8B4200D1DB
:1031B00099E0402B01D1012026E04C491AF098FA01
:1031C0000028F8D1201C4A491AF092FA0028F2D1BE
:1031D000201C48491AF08CFA0028ECD1201C4649E2
:1031E0001AF086FA0028E6D1201C44491AF080FA29
:1031F0000028E0D1201C42491AF07AFA0028DAD1DE
:10320000201C40491AF074FA00231D1C1E1C1F1CB0
:103210002278002A51D0272A10D1002B01D0032B6D
:1032200008D16278272A05D1A278272A02D1023450
:10323000032216E00122012B3DD812E0222A12D1EE
:103240000422191C914309D16178222904D1A17863
:10325000222901D1023404E0002B01D0022B2AD113
:103260000222D31A27E05C2A09D16178272901D0EC
:10327000222904D11A1C511E8A41A4181BE0002BDC
:1032800019D15B2A12D006D8282A0DD0293A5142EA
:103290004A41BF1A0FE07B2A0AD07D2A0AD05D3A44
:1032A00051424A41B61A06E0013704E0013602E015
:1032B000013500E0013D0134AAE70121002F12DCB5
:1032C000002E10DC002D0EDC033B8B420BD9013CA1
:1032D00023785C2B07D00840111C002803D00A3B40
:1032E000591E8B41D9B2081CF8BDC0465ED70200FA
:1032F000BAA90200C0A90200C4A902007DC8020048
:1033000032040300BFBB0200F0B541188BB0051CAE
:103310000592079302910C1C0494013CA5420FD81E
:10332000207809F053FF0028F6D1207809F05AFFE1
:103330000028F1D123785F2BEED02E2BECD000E0CB
:1033400004957A4B1E68049C029884420AD3049A1E
:10335000029BA21A03929C4209D30024271C251C1D
:10336000029451E023782E2BF1D00134ECE70025B4
:10337000B26895421ED2F268EF00D059002803D0FF
:10338000031F5A1E934100E0031CDA0714D509A954
:10339000FFF76AF8039B011C099883420CD104983B
:1033A0001A1C20F0CAFE002806D1F368DF197868DD
:1033B000002803D10020B6E00135D9E783070AD100
:1033C00003685B4A934203D11CF020F9061C0DE010
:1033D000584A934201D00BF0BDFD866B002EE9D018
:1033E000B007E7D1544B32689A42E3D101340494D8
:1033F000A9E7F268E3009858002809D0031F5A1E75
:103400009341DA0706D40134B0688442F1D328E04E
:10341000031CF6E709A9FFF727F8099B0190039819
:1034200006939842EFD804980199039A20F085FEFC
:103430000028E8D1002D0CD0039BBB420DD8069A82
:1034400093420AD80198E95CC25C914204D10133ED
:10345000F3E7069F019D00E01F1C029B01330293CE
:10346000D1E7029A002AA5D0012A06D0039B9F42E9
:1034700003D800200290402413E0039A0798AB1869
:103480000360B81A4FE0029AD300F26898580028F7
:103490000CD0031F5A1E9341DA0709D4029A013255
:1034A0000292029BB0688342EDD336E0031CF3E73F
:1034B00009A9FEF7D9FF099F039B0190BB42EDD8F4
:1034C000049801991A1C20F038FE0028E6D1231C2C
:1034D0000F33DD172D0FED182D112D012D1B012D93
:1034E00000DC10356319DF19402F0FD8002705982D
:1034F000AF4204DA11491EF0A8FC0137F7E7019941
:103500001EF0A3FC099824186419C7E705980C4914
:10351000019A1EF064FD099CC0E7059809491EF058
:1035200094FC012040420BB0F0BDC046902E00201C
:10353000E4570200C87402009880020059B80200E3
:10354000C8A902009BB00200F0B5041C91B08069CC
:103550000B9109908968151C0B986268C0680493E8
:103560008B185A1C6260A0609A1C19786260DA1C81
:103570005F7862609A78201C0A921A1D6260DB787C
:1035800003910693231C1833E360099B0021033346
:103590009B00E31804332361099B1C309B001A1C19
:1035A000059320F0CDFC169809990A9AAB00C31830
:1035B000C91B08938B1A05339B00E3180D911E1D40
:1035C00001220398BD420FD9104203D1884889498E
:1035D0003A1C2EE0E81B169DB90069181E1C0BF062
:1035E00015F83D1C706029E0104202D01E1C824B71
:1035F00073600499002921D1039A12071ED4069BF7
:10360000FA1A954213D3D91B0B98890041180791D8
:1036100005992B1C6018BB4210D29A00811A8C4667
:10362000079901338A18126961468A61F3E7704885
:1036300070492B1C04F058FB0EF01FF9059A00236B
:1036400012199446AB4207D016999A0088586146E1
:103650008A1A90610133F5E7049D002D03D1039D83
:103660002D0700D49BE0039D02231D400C950025EF
:1036700005950C9D002D04D004981EF027F90590A7
:103680003060A56800260795089D0435049B9E427E
:1036900029D02B1F196800230A98C219934215D20A
:1036A00007989A00825891420ED1099A013AD31A8A
:1036B0009B00E318DA69002A03D0CA084C484F4936
:1036C0006AE02868D8610BE00133E5E70C9A002A2C
:1036D00002D147484A4967E005982A681EF02EF94A
:1036E00001360835D2E70D9B069806339B00E31898
:1036F00003300B9D043380002818191C0022069DFE
:10370000954209D00D68002D03D195006D424559B1
:103710000D6004310132F2E7069DAA009B18099A58
:1037200006329200A2180432934209D20433191FC0
:1037300009680029F3D1D21A92102D4831492BE0A3
:103740000D9E079D0536B600BB00EB18A619043682
:103750000493002510E0069B0B9904339B005858F6
:10376000049BA9000430595802F036FB00280CD005
:10377000406830600135043E0A998D421ED232689D
:10378000002AF7D103980007E5D40798ED19AD009A
:103790002A581D491648D20804F0A6FA4CE70A9D9B
:1037A000002D04D0124819491BF0C8FF44E7039DBF
:1037B000AD0703D50A981EF089F8306065680FA838
:1037C00025600F9519F0B1FF2D1801356B1E1B7880
:1037D000FF2B09D0099E013EF61AB600A619F06922
:1037E000FFF7D4FCF061F0E7656011B0F0BDC046B2
:1037F000985E0200CCA90200588C020005AA0200C3
:1038000034AA02005DAA02008FAA0200BFAA020029
:1038100008B50B1C4179C26A012904D1101C191C7E
:103820001BF0D8FC03E0006B01491BF00DFD08BD47
:10383000F496020008B50B1C4179C26A012904D133
:10384000101C191C1BF0E6FC03E0006B01491BF087
:10385000FBFC08BDE496020008B50B1C4179C26A66
:10386000012904D1101C191C1BF0D4FC03E0006BCF
:1038700001491BF0E9FC08BD0497020008B53F228E
:10388000014B19F0E5FF08BD43E2010008B59122A4
:10389000014B19F0DDFF08BD3D48000038B58368D5
:1038A000041C0D1C002B09D1111C05481BF046FF00
:1038B000A060201C0C30291C19F0E4FF38BDC04664
:1038C000105F0200F0B50123041C4271E162036144
:1038D0000B788BB00D1C0092012B02D00021844A82
:1038E00088E00099012906D9836B2A1C1E68231CD5
:1038F000406B0833B047A86802901BF0C1FA6379A7
:103900000290032B0FD107900C2107A81BF0D1FACE
:10391000A36B021C9B68606B07999847A268688339
:10392000002A00D0DDE002981BF0AAFA02901BF0FA
:10393000A7FA5A21029002A81BF0BBFA029D01903F
:103940004CE0281C03A91BF0A5FA0378061C912B58
:103950004DD11BF095FA039B984248D1301C03A926
:103960001BF098FA0378071C0A3B0F2B3FD81BF07B
:1039700087FA0399061E8E4239D00378A02B36D1E0
:103980001BF07EFA039A904231D104A9381C19F039
:10399000E4FE301C1BF079FA9B21059005A81BF072
:1039A00088FA011C05981BF05FFA049B061C2D2B5E
:1039B00036D1012821D1059803780A3B0F2B1CD85A
:1039C0002669731C2361009B012B1AD8A16800296A
:1039D00000D086E0281C1BF053FA051C019A954282
:1039E00075D002952B78432BF4D0392BA9D00299AE
:1039F000404A201CFFF752FF78E0201C02993E4A03
:103A0000F8E707A919F0A9FEA36B606BDB68311C0E
:103A1000079A98470028D9D1201C0299374AE9E72C
:103A20002E2B15D1012803D105980378032B03D041
:103A3000201C0299324ADDE700990129C6D9A36BFF
:103A4000666B1F691BF00AFA011C301CB847BDE702
:103A50002F2B27D1012803D905980378032B03D0F6
:103A6000201C0299274AC5E7009A012AAED906A967
:103A70001BF0E4F90127059005980378032B03D088
:103A8000201C0299204AB5E707A91BF0D7F9A36BC0
:103A900005905B69606B0699079A01379847B742B2
:103AA000EAD193E7009B012B90D903289FD8059872
:103AB00007901BF0E5F908901BF0E2F9A36B099061
:103AC0009F69606B0499321C07ABB8477EE7637946
:103AD000012B03D9A36B606B5B689847A368002B2D
:103AE00004D0201C0C30029919F0CCFE0BB0F0BDB4
:103AF000F1AA020015AB020038AB020054AB020081
:103B000064AB020080AB0200A5AB020008B5024A1C
:103B1000FFF7C4FE08BDC046C7AB020030B50B7846
:103B2000041C85B00D1C481C002B78D0032B09D138
:103B3000081C03A91BF082F90399051C206B1EF0D9
:103B40001AFC49E0012B07D14978052902D0206BE6
:103B50000DF030FEA81C62E0042B07D189786B7849
:103B60000902206B19431EF04DFC16E0052B18D1FD
:103B70006379042B02D0206B2A490CE088784B78BB
:103B80000002184303A91DF023FF0399246BFDF7DE
:103B9000D1FF011C201C1EF041FC281C1BF070F9F9
:103BA0003DE01A1C0A3A081C0F2A08D803A919F08C
:103BB000D4FD0399051C201CFFF72AFE0CE0082BFE
:103BC0000CD103A91BF030F90399236A8A00051C64
:103BD000D158206B1EF022FC281C20E002AA03AB67
:103BE00001A91BF07EF90299051C206B0DF098FDD0
:103BF000019B201C9A000C4B291CD358002B03D18D
:103C00000A4AFFF74BFE09E0039A9847A16800298A
:103C100004D0E268002A01D1029BE360039805B05A
:103C200030BDC046387D0200604C0200E4AB0200AB
:103C3000F0B587B00593151C0A1C531E9A410291DA
:103C4000061C0599281C04921BF00EF9049B039096
:103C5000029C002B09D023780024842B05D1211C41
:103C6000306B039A1EF0BAFD029C039A2F1C013A96
:103C70000192059A97421DD03B78842B12D1002CDB
:103C80000AD10499039B019A0139C918891A306B2A
:103C90001EF0A4FD3C1C05E0301C391C1E4AFFF739
:103CA000FDFD36E0381C1BF0EBF8019B071C013BC7
:103CB0000193DEE7002C05D1039B049A306B991821
:103CC0001EF080FD049B002B1CD0029AA24205D15D
:103CD000201C1BF0DAF8011C301C01E00299301C9A
:103CE000002200F01BF80DE0A5420FD1281C1BF0AC
:103CF000CCF8011C301C002200F010F8281C1BF02E
:103D0000BFF8051C059B9D42EED102E0301C291C2A
:103D1000F1E707B0F0BDC046FCAB0200F0B5041CF3
:103D200085B00D1C161C2B781A1C0A3A0F2A0FD8C6
:103D300003A9281C19F011FD0399201C002E01D0A5
:103D4000022E02D1FFF776FDDFE0FFF761FDDCE038
:103D5000192B03D8201C291C6D4AD4E01A3B7C2B5C
:103D60007CD004D8252B75D0772B06D0C8E07E2BCD
:103D700000D186E0912B6DD0C2E0281C02A91BF077
:103D800089F8071C022E03D0201C391CFFF7C6FE41
:103D9000381C1BF075F80299071C19F0D6FC002896
:103DA00000D0ADE03B78922B14D1381C03A91BF056
:103DB00071F8071C381C1BF063F8039A01909042BD
:103DC00008D2022E01D1019FF4E7201C391CFFF715
:103DD000A5FEF8E73B78A12B19D1022E04D1206B68
:103DE0001EF0ADFB206B0FE0381C1BF04EF8011CE1
:103DF000201CFFF793FE206B012E05D11EF073FBF4
:103E0000206B1EF043FB1CE01EF058FB19E0A22BB8
:103E100076D1381C1BF039F803A919F09EFC206BF1
:103E2000012E06D11EF055FB206B03991EF00CFBF2
:103E300007E0022E01D11EF06BFB206B03991EF0F0
:103E400030FB381C1BF01CF8029919F07EFC00288E
:103E50005BD155E0281C002E4ED13AE003A9281C66
:103E60001BF018F80399071C19F06FFC002847D1C4
:103E70003B789A2B03D1002E3ED13D1C18E03D1C0F
:103E800051E7002E38D1281C03A91BF003F8039931
:103E9000051C19F05AFC002802D0201C311C04E03B
:103EA0002B789A2B04D0201C291C321C331C20E0B8
:103EB00003A9281C1AF0EEFF061C1AF0E1FF037894
:103EC0009D2B04D10022201C311C131C11E09E2BC1
:103ED00007D103A91AF0DEFF311C021C039B201C32
:103EE00007E0BD2B0CD01AF0CBFF0021031C321CC5
:103EF000201CFFF79DFE08E0201C291C054A02E05B
:103F0000054A201C291CFFF7C9FC05B0F0BDC046BE
:103F100016AC020049AC02002EAC0200F0B50B78E2
:103F200091B00A3B041C019104920F2B00D9DCE0F4
:103F3000081C1AF0A5FF0378912B00D0D5E001985A
:103F40001AF09EFF0DA91AF0A5FF037842780A3BEC
:103F50001B021343892B00D0C7E01AF091FF0378AE
:103F6000051CA02B00D0C0E01AF0CFFF002800D025
:103F7000BBE0281C1AF084FF0D9A904200D0B4E0F8
:103F8000281C1AF082FF9B210E900EA81AF091FFB8
:103F90000E9B061C0293029801230F931AF070FFE8
:103FA000071C0E90B04210D01AF06AFF0E90B0427B
:103FB0000ED00378032B00D097E00FA91AF03EFF34
:103FC0000E90B04200D090E002E0714A029F02924F
:103FD0000D9B181C05931AF053FF049A051C831AB5
:103FE0005A1E93415B421D400F9B26690693638BCB
:103FF000228B0A93731C63830793A38B0992E28B32
:10400000E383331D268323613B780B92B21C03921A
:10401000033BF21C08925A1E9341DBB20493002B1F
:1040200003D0201C391CFFF779FD0299201CFFF7F3
:1040300075FD206B08991EF097FA0399206B1EF00E
:1040400066F9206B1EF045FA0022201C0199FFF74B
:1040500065FE0599201CFFF761FD206B07991EF096
:1040600056F9206B06991EF086F9206B12211EF07E
:104070002EFB206B08991EF04AF9049B206B002B45
:1040800005D01EF030FA206B1EF042FA05E01EF05B
:1040900020FA201C391CFFF741FD069A206B002AEC
:1040A00001DB192100E01A211EF011FB039A206B9D
:1040B00001211EF065FA099B0A9A23830B9B6283F8
:1040C000E383002D03D0201C291CFFF727FD206B64
:1040D000311C1EF01CF9206B1EF00FFA049A002A06
:1040E00053D0206B1EF009FA4FE0238B256905930E
:1040F000E38B628B0793A38B6E1CE383254B0692A5
:104100002B432383EB1CAA1C236166830198029234
:104110001AF0B6FE011C201CFFF700FD071C206BE7
:104120001EF08AFA206B311C1EF0F1F8206B029908
:104130001EF08CFA201C01990022FFF7EFFD391CBC
:10414000201CFFF7EBFC071C206B1EF0D7F80028A3
:1041500003D1206B311C1EF007FA206B02991EF070
:10416000D6F8206B1EF07EFA059B069A23836283A5
:10417000079B049AE383974203D0201C391CFFF766
:10418000CDFC206B291C1EF0C2F811B0F0BDC0465A
:1041900025B102000080FFFFF0B5041C85B0081CAB
:1041A000171C0D1C1AF06CFE391C061C19F0CDFAF8
:1041B000019000281CD02379201C002B11D0E36A29
:1041C0001E78002E0DD11221FFF722FB291C201C86
:1041D000FFF7A4FC206B0121321C331C1EF03FFBB7
:1041E00002E0291CFFF79AFC206B1EF086F958E0CC
:1041F00033783B2B1BD1291C201C0122FFF78EFD9D
:10420000301C1AF042FE4378811C4E3BDBB218266C
:104210000A2B01D8244AD65C201CFFF77FFC206BB8
:10422000311C1EF054FA201C291C022237E03C2BC2
:104230002ED1301C03A91AF02DFE061C071C039B6F
:104240009F4205D0381C1AF01BFE0197071CF6E7A9
:104250000199201CFFF762FC206B1EF03AF9201C2C
:10426000291C0022FFF75AFD019B9E4219D0301CE9
:104270001AF006FE019B051E9D4202D0206B1EF027
:1042800028F9311C201C0022FFF748FD2E1CEBE70B
:10429000311C201CFFF742FC019A201C291CFFF74F
:1042A0003DFD05B0F0BDC046E6AA0200F0B589B0FC
:1042B000041C0D1C059104921F1C002924D1837934
:1042C000002B27D0C16A02950B78012B23D1052141
:1042D000FFF79EFAE36A188D854211DAD96AEA007F
:1042E0008A18567801210E4208D05288206B1DF0A2
:1042F00086FF0022206B0221131C9AE00135EBE7B8
:10430000201C00214D4A22E005A89B211AF0D1FD76
:10431000029000E002930022059D00920392161C79
:10432000019208E0281C1E431AF0AFFD0390281CE0
:104330001AF0A6FD051C029A954256D02B78B72B91
:1043400008D101231E42EDD03D4A201C291CFFF755
:10435000A5FA70E0B82B0CD102231E4203D0201C1A
:10436000291C384AF3E7281C1E431AF08EFD0090E2
:10437000DDE7B92B2CD1281C1AF087FD051C1AF09B
:104380007FFD0378BD2B09D1201C291C062219F0C2
:10439000B6FA281C01371AF073FDC9E72B780A3BDF
:1043A0000F2B03D9201C291C274AD0E7281C07A95A
:1043B00019F0D3F90799051C206B1EF023F8291C6E
:1043C000201CFFF7ABFB019B051C01330193B2E7F7
:1043D0000199201C002902D0291C1C4AB7E7291C7E
:1043E000FFF79CFB0137051CA5E7002E15D0039BAA
:1043F000002B03D1206B1EF01DF803E0201C039955
:10440000FFF78CFB0099002903D1206B1EF012F8F6
:1044100003E0201C0099FFF781FB049A206B391CF4
:10442000002A04D0019A331C1EF023FA03E0019AFB
:10443000331C1EF014FA09B0F0BDC04675AC020082
:1044400093AC0200AAAC0200C2AC0200E3AC0200D2
:10445000F7B50B78041C0E1C292B01D0312B02D18F
:104460000123E37163E02A2B61D0322B5FD01A1C49
:104470000A3A0F2A1CD9081C282B12D101A91AF0BC
:1044800009FD071C1AF0FCFC019A904211D01AF0A9
:10449000F7FC019A051C831A5A1E93415B421D408A
:1044A00008E01AF0F2FC071C1AF0EAFC051C01E017
:1044B0000F1C0025381C01A919F04FF9E379002DD4
:1044C00002D02A78002A0AD1002B30D1E38A002BAF
:1044D0002DD0201C311C164AFFF7E0F927E0002BF5
:1044E0001ED0A38A01339BB2A382012B0CD1E18A97
:1044F000206B002902D01EF00DF901E01DF09AFF9B
:10450000206B00211EF02DF9291C201CFFF706FB53
:10451000206B01991DF076FF206B1EF02EF906E04E
:10452000E38A201C0133E382291CFFF7F7FAF7BD69
:1045300005AD0200F0B5056987B003936B1C0293CB
:10454000AB1C041C03610E1C006B291C171C1EF005
:1045500050F8201C19F009F9311C201CFFF7DEFA75
:10456000206B1EF085F8206B02991DF0FDFF206B7B
:10457000291C1DF0CCFE206B1EF0C0F92669731CAF
:104580002361039B9F4200D191E0381C1AF07DFC0F
:10459000002305932369051C0193013323610378EC
:1045A000002B0FD11AF06CFC1AF06AFC039B9842A6
:1045B00023D0201C291C4B4AFFF770F9A38B013B29
:1045C000A3838CE0071C6A2B07D11AF05EFC071C42
:1045D0001AF056FC05A919F0C0F8206B1DF079FF00
:1045E000391C201CFFF79AFA206B21211EF06FF86E
:1045F000206B0021019A1DF0C3FF281C1AF040FC1B
:10460000071C206B1DF079FF0599002903D1206B51
:104610001DF073FF02E0201CFFF70CF9206B1DF06A
:104620006CFF059B0025AB4209D02569206B6B1CF4
:104630002361291C1DF0E9FF201C19F096F8391C94
:10464000201CFFF76BFA059B071C002B02D0206B88
:104650001EF00EF8206B1EF015F8059B002B19D0EC
:10466000206B0F210DF0A6F8206B291C1DF04FFECA
:10467000206B0F210DF09EF8201C0599FFF7DAF84A
:10468000201C0599FFF7E8F8A38B206B013BA3835F
:104690001DF0C7FF206B311C1DF066FF206B0199D8
:1046A0001DF035FE206B03211DF02DFE69E7A38B65
:1046B000206B013BA3831DF0B4FF206B1EF022F999
:1046C000206B02991DF023FE0C9B002B03D0201CB5
:1046D000191CFFF723FA206B311C1DF018FE07B0E0
:1046E000F0BDC04633AD0200F0B585B0019143790D
:1046F000041C012B3FD1C26A0D1C1378002B03D17F
:104700001E4AFFF7CBF836E001A843211AF0D1FB8F
:1047100000900198009B98422DD003A919F01DF834
:10472000039E6A4601900B32E06A311C18F083FF49
:104730006A46D37A071C002B06D10378042B03D0DA
:10474000201C291C0E4A0CE0E06A311C18F0A1FF65
:10475000002803D00378023B022B05D9094A201C0C
:10476000291CFFF79BF8D4E704233B70E06A311C57
:1047700018F0A0FFCDE705B0F0BDC04652AD020075
:1047800077AD020098AD0200F0B585B00191437994
:10479000041C012B2AD1009101A843211AF089FBA6
:1047A000071C0198B84221D003A918F0D6FF6D4626
:1047B000039E0B350190311CE06A2A1C18F03BFF68
:1047C0002B78002B08D10378012B05D0201C0099F1
:1047D000074AFFF763F8E4E701250570E06A311C3A
:1047E00018F04EFF0028DCD00570DAE705B0F0BD08
:1047F000B6AD020010B5438B041C002B02D1054A54
:10480000FFF74CF8A28BE38B206B618BD21A0CF074
:10481000EDFF10BDD5AD020010B5038B041C002BBD
:1048200002D1054AFFF73AF8A28BE38B206B218B6C
:10483000D21A0CF0DBFF10BDEDAD0200F7B50B781E
:10484000041C1A1C0A3A0D1C0F2A08D8081C01A9BE
:1048500018F083FF201C0199FEF7FEFF77E0912BF3
:104860003FD1081C69461AF015FB011C201CFFF7FC
:1048700055F90378061C922B10D101A91AF00AFBF6
:10488000061C301C1AF0FCFA019B071E9F4205D043
:10489000311C201CFFF742F93E1CF2E73378A12BB4
:1048A0000BD1301C1AF0F1FA011C201CFFF736F96D
:1048B000061C206B1DF04DFE0CE0A22B42D1301CDB
:1048C0001AF0E3FA01A918F048FF0199061C206BC1
:1048D0001DF028FE301C009918F037FF002831D059
:1048E00035E0962B2ED1081C1AF0CFFA0378051C60
:1048F0009A2B22D11AF0C9FA061C311C201CFFF792
:104900009DFF301C1AF0BCFA0378011C9D2B1ED0B1
:104910009E2B0ED101A91AF0BDFA019B051E9D42E6
:1049200015D0201C291CFFF789FF281C1AF0A8FAB3
:10493000F3E7201CBD2B05D001E0201C291CFFF74C
:104940007DFF04E0201C291C014AFEF7A7FFF7BDEC
:1049500002AE0200F7B50C1C002101912178051C64
:10496000081C0A380F2801D8201C05E01A32914291
:1049700012D1201C1AF089FA01A918F0EEFEEA798A
:10498000EB6A002A04D15A8B01325A83012633E0A4
:104990009A8B01329A83F9E71A33994220D1012781
:1049A000EF71201C1AF0B1FA0326002824D1201C34
:1049B0001AF06BFA0278EB6A0A3A0F2A04D81A7EC8
:1049C000201C17431F7605E01A7E201C17431F7614
:1049D0001AF05BFA1AF059FA01A918F0BEFE0BE0C2
:1049E000201C1AF052FA01A918F0B7FEEB6A022156
:1049F0001A7E05260A431A760199002911D06F46BE
:104A00000337E86A3A1C18F016FE3B78002B05D1F4
:104A1000281C211C034AFEF741FF02E00223037019
:104A20004670F7BD1AAE020038B50D1CC16A041CF1
:104A30000B78012B04D000210B4AFEF72FFF11E069
:104A4000281C111C18F081FE002804D0206B0F21B7
:104A50000CF0B0FE03E0201C291CFFF75FF8206B70
:104A60001DF012FF38BDC04633AE020038B50D1C34
:104A7000C16A041C0B78013B012B04D90021164AA2
:104A8000FEF70CFF26E0281C111C18F05EFE002823
:104A900004D0206B0F210CF08DFE18E02B78C12B79
:104AA00011D1281C1AF0F1F9011C201CFFF736F86F
:104AB000206B1DF0C1FD206B0F210CF07BFE206BE5
:104AC0001DF00CFF06E0201C291CFFF727F8206BC7
:104AD0001DF0F5FE38BDC0464DAE0200F7B5041C12
:104AE0000D1C081C111C18F030FE002804D0206B8F
:104AF00000211DF036FE50E02B78AF2B0BD1206B40
:104B000001211DF02EFE201C291CFFF707F8206B49
:104B10001DF033FE41E0AE2B3FD1281C1AF0B5F951
:104B2000051C1AF0ADF900900378B12B30D101A922
:104B30001AF0B0F9019B0090984203D06846982182
:104B40001AF0B7F901990098266B1AF08DF9411CFB
:104B5000301C1DF006FE291C201CFEF7DFFF206B19
:104B60001DF00BFE009E019B9E4216D0311C201CA6
:104B70003778FEF7D3FF061CAF2F05D0201C291C69
:104B8000064AFEF78BFE08E0206B1DF0F6FDEAE713
:104B9000201C291C042218F0B2FEF7BD66AE0200EC
:104BA0007FB5041C081C03A9161C1AF047F962798A
:104BB000051C012A05D10096201C03992B1C18F016
:104BC000DEFD281C1AF05CF9039A011C9300A26A0E
:104BD000201C9D580023E371A382E3820C22064B24
:104BE00018F036FEA368002B03D1201C291C19F0F5
:104BF0004BFA286904B070BD51440000F0B589B08B
:104C0000041C039103A807211AF053F9E26A0290E9
:104C10000023567E01930398029B98424BD005A92E
:104C20001AF038F94021039003A81AF042F906A9B6
:104C3000051C039818F091FD069A071C292A18D123
:104C4000A8420CD21AF01CF9A84208D1381C07A9B6
:104C500018F083FD079B2A2B07D02C2B07D0201C94
:104C60000021264AFEF71AFE22E0012620E0042653
:104C70001EE0019B201C013303990193FEF74EFFB8
:104C800003900398A84208D007A918F066FD079979
:104C90000390206B1DF0D8FBF3E7281C059918F052
:104CA00054FD002804D1A071291C201CFEF736FFFA
:104CB000059A0392AFE7181C1AF0E7F8029A0390DE
:104CC0001378011C321C201C242B04D1FFF768FF31
:104CD000061C019D02E019F03EF8F9E7002D07DD02
:104CE0000022206B0121131C1DF0B9FD013DF5E7E9
:104CF000201C311CFEF79EFD09B0F0BD89AE0200FC
:104D0000F0B50123041C0D1C427187B0E162036100
:104D1000111C006B2A1C0CF03BFC6379012B02D1A7
:104D200000236B84AB84AE6833781E2B07D1301C14
:104D30001AF0ABF8011C201CFEF7F0FEDBE02B782C
:104D4000002B04D1201C311CFEF7E8FE99E0012B5A
:104D50001ED1301C1AF094F86379051C012B07D181
:104D60000023E371201C291C0C22674B18F070FDF6
:104D7000281C1AF085F81AF083F8011C201CFEF795
:104D8000CDFE206B1DF0BAFA002800D0B6E078E026
:104D9000022B19D16379012B07D10023E371201C69
:104DA000311C1422594B18F053FD301C1AF068F8CE
:104DB000011C201CFEF7B2FE2B7E5A0700D49AE09D
:104DC000206B1DF09AFB5CE0033B032B5BD8301C8F
:104DD0001AF056F805A91AF05DF81AF051F867793B
:104DE0000390012F08D16A46E06A391C133218F08B
:104DF00022FC022303706F832B78032B04D1206BDA
:104E000000211DF094FC05E0042B03D1206B002150
:104E10001DF0A7FC2769201C7B1C0293BB1C23618F
:104E20000121FEF7F5FC206B02991DF070FA206B52
:104E3000391C1DF00BFC03990022201CFEF76EFFAD
:104E400003981AF01DF81AF01BF8059A011C831A32
:104E50005A1E93415B4219400023321C0093201CD0
:104E6000029B19F0B8FA206B02991DF07DFB206BB4
:104E7000391C1DF04CFA206B1DF0F4FB2B78062B2F
:104E800039D1206B2FE06379012B06D1281C052135
:104E900005AA18F0D0FB0223037005A9A86818F032
:104EA0005CFC201C0D21FEF7B3FC201C0C21FEF73E
:104EB000C1FC206B29691DF0A5FA1021201CFEF70A
:104EC000B9FCA86819F0DCFF19F0DAFF011C201CFE
:104ED000FEF724FE281C052118F09DFB0278031C18
:104EE000206B022A03D10F210CF064FC03E05A88E6
:104EF00005211DF084F9206B1DF0C6FC206B0CF021
:104F0000D5FB07B0F0BDC0467BDF01006FDF0100BD
:104F10007FB5041C081C03A919F090FF6379051CD8
:104F2000012B08D1E26A201C537E039900930222D0
:104F30002B1C18F024FC039A201C9300A26A291C45
:104F40009E580022E271A282E282064B142218F0DF
:104F50007FFCA368002B03D1201C311C19F094F8AE
:104F60007FBDC04651440000F0B59BB00BAC071CA0
:104F7000151C06913C220021201C1E1C1EF0E0FF87
:104F8000069879680B9038682162267119F078FFCD
:104F900019F064FF606280001CF0F6F80021A06246
:104FA0000095201C0A1C3B6818F0E9FB1DF090F9E5
:104FB00000250990206306950026331C606A86420E
:104FC00003D3002BF8D105932DE0A1680029F8D177
:104FD000A06AB2001558002D16D06969002913D1B6
:104FE0001CF00DFB6B7E6861291C201C0122042B28
:104FF00002D1FEF767FC01E0FFF782FE2369069D00
:105000009D4200D2069301230136D7E70D98002870
:1050100000D0B4E0059C159BA200D358002B07D10B
:10502000059E01360596059814998842EED3A6E0B0
:105030001A7ED50727D51C8D021CA04223D08F4E87
:10504000DD6AA119091AC90069184D78AE0713D590
:10505000002A18D010785478558808900494039545
:105060000E1C506830CE30C2089E049A039C0E700D
:105070004A704C80486006E0002A02D1012D00D120
:105080000A1C0130D9E7002119841D8DAC46A942C4
:105090001CDADD6A1878CA00AA18072802D15668F7
:1050A000052E11D00138052804D81078002801D128
:1050B000012010701078022802D05078C40703D560
:1050C000188C441C1C8450800131DEE700226245AC
:1050D0000EDADE6AD10071180878032806D1487804
:1050E000C40703D4188C4880013018840132EEE7DD
:1050F0005C68002C94D0258D002107950A1C079D23
:10510000A94220DAE06ACE008619307800250338FB
:10511000012816D804950498604512DA049DE80029
:10512000DD6A281803900078042807D10398756871
:105130004068854202D1039842800132049D0135C6
:10514000E8E70131DBE7002A00D169E7002161458A
:105150000DDADE6AC80030180478042C02D14478D5
:10516000E50702D54488141944800131EFE7598BD3
:1051700092B251185983198C52181A8450E7099821
:1051800006991DF0AAF80026351C149B9E420FD3E9
:105190000D9C002C49D0169B0EA8996818F072FB44
:1051A000169B0D981B690B990E9A02F00BFE3CE0C2
:1051B0000D980028ECD1159AB3009C58002C32D0E1
:1051C000637E042B18D1002D03D106981AF02FFB13
:1051D000051C002317932A4B0BA8211C03221993AB
:1051E0001895FEF76FFB0D9B002B1CD10BA8211C03
:1051F0000422FEF767FB16E00998211C1790022293
:105200000BA8FFF77DFD0D99002904D10BA8211CE7
:105210000322FFF775FD0D9A002A04D10BA8211C6B
:105220000422FFF76DFD0136AFE709981DF05DF828
:10523000002D02D0281C1AF00BFB381C19F06FFE51
:10524000159B00241B685D69149915988C4207D240
:10525000A2008058002801D018F0D4F90134F3E7F7
:105260001BF0B6FF0D9A002A02D0101C0CF005FBB3
:10527000281C111C1CF0CEF91BB0F0BDFFFFFF1F56
:105280001060020008B540681DF031FF002801D011
:10529000014800E0014808BDE07B0200247C0200D8
:1052A00008B540680DF052FE004808BD387D020088
:1052B00008B540681DF01FFF002801D0014800E03C
:1052C000014808BDE07B0200247C020008B540686C
:1052D0001DF015FF004808BD387D0200F8B5094DE6
:1052E0002B78002B0CD1084C2778FFB2002F07D168
:1052F00000680126036826705B68984727702E7047
:10530000F8BDC0461A2E00201B2E00203E2803D0D8
:10531000402809D03C280ED14239C9B22F290AD8D9
:10532000084B585C012308E0712904D8064B585CEF
:10533000064B5B5601E001230020002A00D01360D9
:105340007047C0468BAF0200A7AE020019AF020043
:1053500008B5512836D00FD8492827D006D842287A
:105360001CD048281FD000284BD117E04F2840D030
:1053700042D84C281AD044E0682811D007D86428B5
:105380002AD0662825D062283BD188563AE06C287E
:1053900032D071280FD0692833D12DE0885C31E0FC
:1053A0005200505E2EE05200505A2BE092005058AE
:1053B0001AF0F6F829E0D2008918086849681AF04E
:1053C000C5F822E0D2008918086849681AF0D9F8AF
:1053D0001BE09200505805E0D2008918086849681F
:1053E00012F050FB0323984302231843074BC018C5
:1053F0000BE09200505808E0920050581AF0B5F8AF
:1054000003E0002040000123184308BD0000808015
:10541000F0B587B0151C03AA071C0E1C01931C686D
:10542000FFF774FF0090402F05D1039B3C275A1EC5
:10543000A4185B421C40009A3E3FA318019A1360D7
:10544000642E09D0662E02D04F2E22D141E0281CB6
:1054500009F0CEFE051C3CE0281C09F0C9FE12F044
:10546000BFFA7D427D41EDB204900591AB0006AAE2
:10547000D318083B1B68291C221C042019F055FA7C
:1054800001235D40AD0006AB5D19083D04342D6875
:105490001FE0AA070CD1154B2A689A4208D179421D
:1054A0007941C9B2281C009A231C1AF03DF81BE070
:1054B000281C09F039FE009B051C042B09D95A2E23
:1054C00007D9002805DA1A1C201D043AFF211EF016
:1054D00037FD0098042800D9042079427941C9B2E7
:1054E000221C2B1C19F021FA07B0F0BD1852020043
:1054F00070B5061C0D1C141C181C642E0CD0662ED6
:1055000004D04F2E11D19400635127E094000D195F
:1055100009F06EFE286021E0D4000D1909F068FE44
:1055200012F05EFA2860696018E020233343712B83
:105530000CD10321014009D1094B02689A4205D1DF
:10554000E4002B19082219F0EFFF07E009F0ECFD49
:10555000291C031C221C301C19F0FDF970BDC0462B
:105560001852020008B502480DF024F9014808BDA0
:10557000D4280020387D020008B509F0D5FD0028A8
:1055800001DD0AF0ADF8014808BDC046387D0200D3
:1055900008B509F0C9FD011C02480DF02BF919F0FE
:1055A000E4FF08BDD428002008B503480DF0B6F983
:1055B00001234000184308BDD428002010B5031C67
:1055C000064C02D1201C191C04E0086809F0ACFD4F
:1055D000011C201C0DF0A8F9014810BDD4280020A2
:1055E000387D020000487047387D020010B588B051
:1055F00001AA6946041C02F01DFC009A022A2AD95D
:1056000004A8322102AA07F06BFD019B13495A68D6
:1056100002A81CF0E4FC201C09F09CFC104BC268A2
:105620009A4210D1236802A85A680E491CF0D7FC90
:10563000E368002B07D05A68002A04D0996802A8B2
:10564000002209F0A1FC04A81BF0F1FE0AF03AF8D0
:1056500004A81BF083FE08B010BDC046BBAF02001B
:10566000D17B0000C4AF020070B5031C0A1C90B0CF
:10567000191C0B20002305F077FA051E03D11848EA
:1056800016F09EFB29E004A80CF0DCF8041E19D1EA
:105690002E6801A8291C012200F0C2FD221C231C37
:1056A000311C01A8FFF760FC041C032009F08EFFE9
:1056B000201C1BF095FD0120404209F087FF0CF0F3
:1056C000D7F80AE00120404209F080FF054805991B
:1056D00009F07EFC0598FFF789FF10B070BDC04649
:1056E000C8AF0200F095020013B51F4BE12001AADC
:1056F000C0001A6005F034FC1C4B1D48C1180AF0AC
:1057000037F906F023FD09F03FFF03F023FA00F01C
:10571000BBFFF8239B021988164A174C914204D10B
:1057200059881648FFF7A0FF09E02278012A06D120
:1057300018201349FF3007F0FFFB1BF07BFD237897
:10574000002B0ED100F0C6F80028F8D00D481CF050
:10575000A7FA00210C220C481EF0F2FB1BF03CFDC6
:1057600013BD00F011F9EFE7782700205C26000058
:105770001C0100204D500000D200002004E0030076
:10578000588C0200F5AF0200F82E002007B50AF091
:1057900073F9054B01A81968091A89080AF02AF952
:1057A0000AF07EF907BDC04678270020F0B585B025
:1057B00003900526039809F093FF0125B54224DAEA
:1057C0000024144F211C381C2A1C08F03DFAC3B2D7
:1057D0000190002B13D06A1E381C211C029208F085
:1057E00033FA031E0BD1381C211C2A1C08F0F2F9D5
:1057F000019A381CD3B2211C029A08F0EBF901344B
:10580000052CDED10135EDB2D8E7013E002ED1D115
:1058100005B0F0BD2400002008B5C820FFF7C6FF82
:10582000004808BD387D0200F0B593B0061C06A8FC
:105830000F1C141C0CF006F8051E22D13368311C15
:1058400003A83A1C0126019300F0EAFCA3082A1CD5
:105850003340019903A8FFF787FB051C032009F0DB
:10586000B5FE281C1BF0BCFC704209F0AFFE0BF02B
:10587000FFFF344203D01448311C09F0DBFE012540
:1058800018E00120404209F0A1FE01210C4202D0A3
:105890000D4809F0CFFE079809F05CFB0B4905F0B5
:1058A00019FF051E04D10799094809F091FB01E091
:1058B00080256D0001210C4202D0034809F0BAFE98
:1058C000281C13B0F0BDC0462EB00200C85A02001A
:1058D000F09502001FB5202168461BF015FD2448F5
:1058E0001CF0DEF968461BF05CFD22481CF0D8F97C
:1058F00009F088FE0128F2D002280AD11E481CF0C7
:10590000CFF968461BF02AFD1C4B01221A700020BB
:105910002CE0032803D168461BF043FDE8E7042888
:1059200004D0C1B268461BF095FDE1E714481CF0B5
:10593000B7F9019A002A08D10F481CF0B1F968465E
:105940001BF00CFD8020400010E0FB20029900239A
:1059500005F00AF9002803D10A4816F0DBF9C1E77F
:1059600001210A1CFFF760FFC305BBD505B000BDD0
:1059700003B0020086B302009AB00200D2000020F9
:105980001EB0020021B0020030B587B002A820216D
:105990001BF0BAFC44481CF083F944481CF080F921
:1059A00002A81BF0FEFC02A841491AF028F80128C1
:1059B00009D140481CF074F902A81BF0CFFC3E4B03
:1059C000002018706DE0022803D13A481CF068F9F5
:1059D000E0E703281AD0042808D136481CF060F903
:1059E00002A81BF0BBFC802040005AE0052825D10E
:1059F00032481CF055F902A81BF0D3FC09F002FE56
:105A00006C46C1B207342170032901D12948C5E78A
:105A1000042904D127481CF043F9012427E002A8F7
:105A20001BF018FD23780D2B03D125481CF038F905
:105A3000E4E7201C012109F0FDFDDFE702A81BF0CF
:105A4000C3FC0028ACD002A81BF0F1FCFDF7AAFBB8
:105A500000280BD002A80A211BF0FCFC02A819495F
:105A600019F0CDFF0328D1D00428ECD1002402A8DE
:105A70001BF0A3FC051C02A81BF0A6FC291C021CA1
:105A80000023FB2005F070F8002803D10E4816F023
:105A900097F985E7211C0622FFF7C6FEC30500D44F
:105AA0007EE707B030BDC04630B0020077B00200DC
:105AB0009DB002009AB00200D2000020A2B0020005
:105AC000D2B00200D9B002001BC402007FB54B68FF
:105AD0000E1C5C106846211C1BF02DFC029D002151
:105AE000281C221C1EF02CFA30680121014004D130
:105AF000221C2B1C19F018FD08E0042C00D90424EA
:105B000043100021201C2A1C18F00FFF6946024890
:105B1000FBF7C4FF04B070BDA84B0200F0B500262F
:105B200085B00D1C1F1C081C0096111C0223321C82
:105B300001F0E2FBB54242D03C68201C012D2FD180
:105B40002C423DD103232340B34203D11D4A216897
:105B5000914235D01C4A2240062A06D0002B0CD197
:105B600023689A69194B9A4207D103A9201CFCF7B4
:105B70007BFC00220399131C1EE00323221C1A4005
:105B8000022A06D1FF22D205A018984301F0B0FCEA
:105B900016E0201C09F0C8FA0123400018430FE06A
:105BA00003A9FCF761FC051C7868039C09F0BCFAAA
:105BB000211C021C331C281C08F0FCFA00E0012008
:105BC00005B0F0BD18520200070080FF9D240000C0
:105BD000F0B58DB0099214AA1278051C0B9215AA83
:105BE00012780E1C0892D90706D5181C09F09CFAE9
:105BF000041E1BDB00221BE0990710D1574A1968CD
:105C000091420CD1129A1399009201910B9A089922
:105C100002920391099A311C19F05DFC9CE02A68FC
:105C200000230999137028680B6095E044422D22E7
:105C3000129B0021023B079205911E2B1DD8484B59
:105C4000129A2020995C0FF019FA089BC0B20690B6
:105C5000059F002B04D0013003210FF00FFA071C21
:105C60001399002903D0081C1EF060FA00E0139875
:105C7000069B0333DF193F180597059A33689A424C
:105C800005D9101C1BF06EFA0599286031602A684E
:105C9000059B0692D618771E00233B709C4203D1C9
:105CA000023E302333702EE00A97201C12990FF029
:105CB00089FA201C0E1C12990FF02EFA331C041CBA
:105CC0003033092E02DD0B9B0A3BF31808997E1E28
:105CD0003370002912D0002C15D0069A964212D9A2
:105CE0000A998B1B032B01D0371CDEE7089A069B11
:105CF000BE1E32709E4206D90A96F5E706998E427C
:105D000001D9002CF0D1139A002A0ED0101C1EF0DD
:105D10000DFA069B301A984207D900231399CA5CE2
:105D2000002A14D0C2540133F8E7079A002A05D09C
:105D3000069B9E4202D90799013E31702F68059A51
:105D4000099BBF18BF1B013F1F60301C04E007996F
:105D5000061C0029EFD1F1E70DB0F0BD185202008A
:105D600004B1020038B50D1C111C144A914202D135
:105D7000291C012204E0124A914204D1291C032269
:105D800006F076FC19E0072816D10E4A0A40062ACA
:105D90000FD000208B0710D10C680B4A944208D01A
:105DA0000A4A944205D00A4A944202D0094A9442CF
:105DB00003D107202A1CE3E7002038BD247C020021
:105DC000E07B0200070080FFC8550200A84B0200DC
:105DD000D08B020030630200F0B5037887B00192E7
:105DE000DA07D20FD2B2041C0D1C0392002A0FD086
:105DF000714A0A40062A0BD003220A4003D16F4998
:105E00002868884203D00199012901D0CEE003928D
:105E10005A074CD5980703D50199002900D0C5E051
:105E20002268A668D708FF00F719BE4211D2306871
:105E3000A84204D1019B022B00D08DE08EE0039993
:105E4000002904D1291C09F01DF90028F2D10836D7
:105E5000EBE7019A012A00D0A8E023686068D9081E
:105E6000814210D104316160A068C9001BF09FF924
:105E70002168A060CB086168CA1ADB00D200C01894
:105E800000211EF05DF823680721DE08721CD20095
:105E90000B401343A2682360F600474B9619356008
:105EA0001D40062D58D02378012293432FE06368CC
:105EB000002B05D10198012878D1201C00F080F832
:105EC000291C022006F0F2F96168401005900FF0DD
:105ED00019F90027029104910299A268CE0096193F
:105EE0003068002815D1019B012B5FD12368072161
:105EF000DA080132D2000B40134323602E4B356089
:105F000070601D40062D27D02378019883432370AD
:105F100022E0042803D1002F22D1371C20E0A84220
:105F200003D10199022917D108E0039A002A17D159
:105F3000291C09F0A7F8002812D0F2E7236802987C
:105F4000083B2360013061680FF0DCF8A368C900EA
:105F5000CB58002B02D13360301C2AE00423FAE72F
:105F60000298616801300FF0CDF8049B02919942CC
:105F7000B2D10198012819D1002F0DD02368083320
:105F8000236000237B600C4B3D601D40062D0FD02D
:105F90002378834323700BE0201C00F011F8059850
:105FA00061680FF0AFF80291049195E7002000E0DE
:105FB000381C07B0F0BDC046070080FFC85502007E
:105FC000F7B542688768111C041C01920131002357
:105FD000164A9A588A4205D204335C2BF8D1012024
:105FE000084300E0101C22680723134001222360AD
:105FF000134360602370C0001BF0C6F83D1CA06016
:106000000026019A96420DD02968002907D004295C
:1060100005D0201C0122FFF7DFFE6B6843600136CC
:106020000835EEE7381C1BF0D3F8F7BD78520200B4
:1060300013B5036A09059C6B044B890CCA580023ED
:106040000093211C18F006FE13BDC046D452020076
:10605000F0B587B002931B7803921A1C6B3A041CAC
:106060000F1C022A29D88568666868180378032BF4
:1060700000D0ACE004A918F0E1FEAB19984200D1C1
:106080009FE00378032B00D0A1E005A918F0D6FE0D
:1060900002990B786B2B03D1049B059A13430AE0FA
:1060A0006C2B03D1049B05994B4004E06D2BE4D18C
:1060B000059B049A13400493DFE76E2B04D0022261
:1060C000191C9143702965D1A2686368D0190193A6
:1060D00003780092032B7AD104A918F0AFFE061CB6
:1060E000009A019953189E426BD0B378B01C757812
:1060F000032B6CD105A918F0A1FE061C372D0FD17A
:10610000059B1F2B63DC4549049A19418A425EDCDA
:10611000C021090619418A4259DB9A40131C09E043
:10612000392D09D105991F2901DD1F230593049BF2
:10613000059A1341049328E02F2D03D10499059A61
:106140008B18F7E7302D03D10499059A8B1AF1E7E4
:10615000312D09D10498059902F0CEFE002836D1E0
:10616000059B04994B43E5E7332D30D00599352D38
:1061700005D100292BD0049819F04BFC04E000292C
:1061800025D0049819F054FC0490049B5A00534005
:10619000A6D51CE0752B1AD18268D0198378457872
:1061A000032B14D1023018F059FE2F2D08D0302DBA
:1061B00005D1404243000490584002D507E0C04357
:1061C00004906760201C049918F074FD23E0636854
:1061D000039DDB1B00930022561CED0901D0321CED
:1061E000FAE7009B0135DB09FCD102325219201C71
:1061F000391C1BF044F90299041C0B78039A1A33DA
:10620000311C03700136013018F0D0FCA019291C94
:10621000009A18F0CBFC07B0F0BDC046FFFFFF3F6F
:10622000F0B597B00990C0200AAC0025402380004B
:106230000F1C161C25706360A5601AF0A0FF256175
:10624000E0606561A561E5612762E562A84202D16F
:10625000BF48C049C1E1002E04D00423022E02D061
:10626000012300E0331CBC4A00259B0000959A588E
:10627000201CB96B2B1C18F0EDFC10201AF072FFDB
:106280001021041C1BF040F800260AADAB68002B5F
:1062900000D17EE12A78002A00D07AE1013B0C226D
:1062A000AB605343EA68D318D978AB4A18688900C1
:1062B00089585D6802029B68120A0593039108924F
:1062C00049780F23069119400491002D01D162688D
:1062D0000592069830230340102B02D0202B39D092
:1062E000F2E0002D11D0002ECED00EE003996E000A
:1062F0008B195B881A0B012A1AD13A1C403212788A
:106300001B051B0D9A4204D00135049A9542EDD32A
:106310001EE00AA8211C18F003FD0028B4D13B1C84
:1063200040331B78062B00D04BE18C488C4954E15C
:10633000049A6B1C934206D2059808990090039A20
:106340000AA818F087FC03998E193AE0012DE6D8C7
:1063500001269AE7002E22D003986B001B5A1B0BD4
:10636000032BF3D1201C01211BF04FF800230370F5
:1063700015E03B1C40331B78D2B2934231D1082B3D
:1063800007D1B96CF86C08F027F8011C201C18F034
:1063900057FC002D1AD0381C1BF037FC013504992E
:1063A0008D4221D203996E008E197288130B012B36
:1063B000DFD005986B1C009008990AA8039A18F082
:1063C00049FC71880AA8FFF733FE5DE7039A53780A
:1063D0007F2BE0D90E99201C01310E9118F06AFC38
:1063E000D9E7002DB4D09AE700231E1C04998B42F4
:1063F0000CD203985A0082185288110B012903D13C
:10640000D2B2072A00D901260133EFE7A268059B23
:106410000021D0180691A36861685A18904206D2EC
:10642000069A01210132069218F0E0FBF3E7039887
:1064300002781F2A01D02E2A00D1012603994A781A
:106440004021114048424141494252B20E40002A87
:1064500000DA0126059A00259818049507950699F3
:106460008D420FD00499037801310491002B04D0A0
:10647000079A0023013207920493012118F0B6FB1A
:106480000135ECE7002E02D1079A012A04D0201C26
:1064900004991BF028F875E0A36805981D18069B61
:1064A0009E4200D1F0E62B78002B06D1A268201C7A
:1064B000A91A01221BF025F804E0281C012118F07C
:1064C00095FB051C0136EAE7002E20D0049802282F
:1064D00004D1012D00D13BE7002344E0012D00D180
:1064E00036E701232A1C1A403CD0049903293AD0EC
:1064F00015E73A1C4032079812780105090D8A42C7
:1065000017D1002B10D0381C1BF07FFB0135069AE9
:10651000012313402B4003985A0082185288079297
:10652000120B012AE5D006E00AA8211C18F0F8FB9E
:10653000ECE70135CAE705990AA800916B1C089998
:10654000039A18F087FB0AA80799FFF771FD9CE6EC
:10655000285A02002EB10200D4520200905C0200C0
:1065600056B10200131C06986A1EC00705D5039891
:106570008188090B012900D16A08012A02D1002B68
:1065800000D181E6201C0599089A039BFFF760FD66
:106590007AE62B78002B00D05AE63B1C40331E785D
:1065A000002E00D0BBE66168002900D1B7E629695A
:1065B000201C013118F07EFBA468EA696C62AA62B3
:1065C00010E0022B02D11548154906E00B3B154897
:1065D000012B01D8144900E0144919F0AFF8002349
:1065E000061C13930D981AF0F3FD002E0BD0301CEF
:1065F0003968BA6B002301F0E5FB381C1BF092FAF6
:10660000301C0BF03AF9381C1BF08CFA099A13ABCA
:1066100013CB13C2099817B0F0BDC046905C0200BE
:1066200068B10200105F02009CB10200C3B1020019
:1066300073B5161C0C4A30CA012804D94D682C1CAD
:10664000022800D08C68086801A9FBF70DFF019AA9
:10665000011C0023FA2004F087FA311C2A1C231C99
:1066600006F0E8FC76BDC046902E002008B5054B2C
:1066700008221B68D96C0A43DA6404F045FCFFF772
:1066800033F8FCE7A82C002008B507F0F3FA05481A
:10669000054B083083610023C36204491CF0A8F94C
:1066A00008BDC046D4280020B16600007017000065
:1066B000124B10B51A68124C0632201C1A601CF0DE
:1066C0001AFD002803D00F4B1B78002B11D00E4A67
:1066D00000230E4C13700E4A201C13700CF03CF972
:1066E000201C28300CF038F907F0EEF802F0C4F85E
:1066F00010BD201C0CF034FCE9E7C046B82C00208B
:10670000C82A00201B2E00201A2E0020402A00201C
:106710001F2E002010B5041C0C201AF023FD034B83
:10672000446003600023836010BDC0468C550200A6
:1067300013B5041C081C01A9FBF720FA002C07D094
:10674000012C0AD101991AF027FF4000204307E0ED
:10675000019B002B03D0034802E0002000E0024828
:1067600016BDC046E07B0200247C0200F0B585B077
:10677000041C081C03A9151CFBF700FA039A061C4D
:10678000002D05D1201C3349331C1BF028FC5EE092
:1067900082180192031C002201998B420DD21978B4
:1067A000272904D0223948424141C9B201E00021E1
:1067B000012201330029EFD002E02227002A00D174
:1067C0002727254D201C291C3A1C1BF008FC019B87
:1067D0009E4237D2301C1AF0AEFE051C301C1AF057
:1067E000C5FE061CBD4202D1201C1C49ECE75C2DF5
:1067F00002D1201C1A4914E02B1C203B5E2B02D82E
:10680000201C15491CE00A2D02D1201C154908E066
:106810000D2D02D1201C144903E0092D04D1134988
:10682000201C1BF012FBD2E7FF2D02D8201C1049C0
:1068300006E0104B201C9D4201D80F4900E00F4993
:106840002A1CC2E7201C04493A1C1BF0C8FB05B0F7
:10685000F0BDC046D2B102004CA502004BA502001B
:106860004FA5020052A5020055A5020058A502003E
:106870005BA50200FFFF0000D7B10200DEB10200FD
:10688000F7B51D1C08AB0C1C171C1E78EB0702D5B6
:106890006D1001950EE0281C01A908F083FC00286A
:1068A00008D1281C1BF0B7F91B49021C1B4801F03A
:1068B0001BFA0DE0019BE019002B17DA0138A0420A
:1068C00008D20193002E25D11548164901F00CFA83
:1068D0000AF0D3FF02783F218A43803A511E8A4151
:1068E0009B180138002BEAD1013014E0002B11D0A5
:1068F000844203D30193002E0DD1E5E722783F2196
:106900008A43802A01D10134F8E7002B02D00134F8
:10691000013BEDE7201CFEBDE5B10200985E0200E0
:10692000045B02000DB20200F0B587B0041C0D1C20
:10693000171C08F00FFB02A9061C201CFBF71EF910
:10694000041C042F4ED1AA0735D1284B2A689A423D
:1069500031D105AB281C03A904AA1AF048FE059BF7
:10696000234FBB4204D0032B02D0224806F0AEFBDB
:10697000039BBB4208D001220092301C211C029ACA
:10698000FFF77EFF051C00E0251C049B029ABB421A
:1069900007D001210091301C211CFFF771FF041C5E
:1069A00000E0A4180E20AC421DD3621B301C291C31
:1069B00016F0ADFC17E000230093211C029A2B1C5B
:1069C000301CFFF75DFF0278012153B2002B05DA7E
:1069D00040231A4202D001315B08FAE70122FBF79B
:1069E00091F800E0002007B0F0BDC046787D0200BD
:1069F000387D0200DDA50200F0B589B006930EAB2C
:106A0000019001CB04911B78062A10D8012A04D9E1
:106A10003F230B700131049101E0002A02D0049958
:106A200000230B70012090429241504211E20199E3
:106A3000049C002907DA04982D2303704B005B089F
:106A40000134019304E0002B02D004980134037058
:106A5000019EFF21C905301C08402023884219D11E
:106A600006994E220B40E01C710208D15A40492180
:106A700062704622594053402170A37005E04121C5
:106A80001A434B4022706370A27000230370049B72
:106A9000C01ADEE10E98002801DA06210E91069850
:106AA00018430390672806D10E99002900D0C8E149
:106AB00001230E93C5E1002E0CD1039A652A00D163
:106AC000B4E1662A00D0F3E00E9D009201350296F3
:106AD000371C01E10498013A031BD3180093B94B0A
:106AE0009E4200D980E000262027351CB64B019934
:106AF000F0580EF099FB002806D0B44B0198F158DD
:106B00000EF086FFED19019004367F10182EEDD19E
:106B1000FE21019889052F1C0EF072FB002812D06F
:106B20000198AB490EF08AFB00280CD03123012DCF
:106B300002DC002D10D03023FE2189052D222F1CD0
:106B4000019102920EE00198A2490EF061FF2D23FF
:106B50006F1C0190029304E0FE2080052B21019020
:106B600002913023039A662A03D0672A2FD1042F7B
:106B70002DDC0E9800992370C3198B4202DBCB1BCE
:106B8000013B0E93039A672A03D10E987B1EC0180F
:106B90000E900E99002907D10126662201340D1CA2
:106BA00002917642009297E02E230E9D6370A31C03
:106BB000013F1C1C002F5FD0002D04D030221A7022
:106BC000013D0133F4E701260295764251E0009B36
:106BD0000E98053B834200DD2EE10399672950D0D2
:106BE000009A063A0E924EE0002520262F1C774B85
:106BF0000199E8580EF00EFB002806D0724B019860
:106C0000E9580EF005FFBF19019004357610182DD4
:106C1000EDD1039B662B0FD1009887420FDA0E99B6
:106C20007B18013383421EDBC31B1A1C023A0E92EF
:106C300019D5013B0E9316E0039B652B09D1009BF0
:106C40000E98053B834200DDE9E0009906390E917C
:106C5000E5E0039A672A19D10E9B9F4222DA0E982B
:106C6000FB43C0180E900E990022CD1901353E1C31
:106C70000292662300930FE0012602977642662077
:106C8000D2E003990E930091002504E0039A2B2390
:106C90000092002502932E1C0E98C343DB17184068
:106CA0000E900AE003992B220091029200260DE03B
:106CB000039B351C009302962F1C009B652B02D171
:106CC0000E9D013508E00098672805D10E990D1E2C
:106CD00002D101220E92151C00230593059B0198F9
:106CE000AB421FDA0FF034F9059A031C611C3033F4
:106CF00007912370964206D10E9B002B03D0A11C56
:106D00002E23079163700FF043F9011C01980EF0D8
:106D1000A9FF30490EF07CFE059A019001320592E0
:106D2000079CDBE72C490EF089FA621E00283CD054
:106D30001178131C2E2901D1013AF9E7081C3038CB
:106D4000092801D9013309E0392902D00131117034
:106D500004E00498302111708242EDD11A78302A73
:106D600018D159782E290AD10098662807D01970B1
:106D700002995A702D2901D1013F00E001370134F9
:106D8000221C9A4204D9511E087810700A1CF8E798
:106D900031221A700B4B019A9A4206D8009B0E982A
:106DA000663B5A425341C01A0E900399672918D185
:106DB0000E9A002A15DD631E1A78302A0ED11C1C8B
:106DC000F9E7C046FFFF7F3F185702000057020057
:106DD000F8FF7F3F000020410000A0402E2A00D194
:106DE0001C1C029B002B15D0069820234522034033
:106DF0000299134323706170381C0A210EF08CF93C
:106E00003030A0700A21381C0EF0DCF9251D30311D
:106E1000E1702C1C049A00232370A01A19E00025AD
:106E20002B2302932E1C6520009035E703992B221B
:106E300000910292371C43E70398002500902E1C16
:106E40003BE7002E00D045E6672100910296371CF3
:106E50003CE709B0F0BDC046FF22D20510B58C1842
:106E600003229443031C201C934215D0042B0AD008
:106E7000002B01D0002012E000210EF0BBF9002809
:106E80000CD107480BE080231B06E4189443022032
:106E9000044A2043801802E0081C00E0024810BDAC
:106EA000E07B020000008080247C020010B5FF23FC
:106EB000DB05041CC818032386B0984307230093FE
:106EC0000023019302A910226723FFF795FD02A971
:106ED000201C1AF0BAFF02A82E211DF011F900287B
:106EE0000FD102A865211DF00BF9002809D102A8D5
:106EF0006E211DF005F9002803D1201C02491AF06B
:106F0000A4FF06B010BDC04630BF020030B50C1C57
:106F100085B0111C00221D1C0092201C012300F0D2
:106F2000EBF9002C21D02868114B0340062B06D02A
:106F3000032318420DD10F4A0168914209D103A9D8
:106F4000FBF792FA0023009303991A1CF9F724FA2D
:106F50000CE00340022B09D008F04AF903239843C0
:106F6000054A02231843801800E0044805B030BDEC
:106F7000070080FFC855020000008080020080806A
:106F800070B5051C86B0101C019108F031F9041C85
:106F90000390681F182800D9AFE00EF051F80D10CB
:106FA000161B2C37696EAEAEAEAEAE0D10161B2C96
:106FB00037698A8F94999E000198211C55E00198A9
:106FC000211C0EF04FFE01908FE00198211C0EF065
:106FD0001FFDF8E7201C00210EF00CF9002805D059
:106FE0004849494818F0AAFB0AF047FC01A803A940
:106FF00017F0C3FF79E0201C00210EF0FBF80028F9
:10700000EED10198211C0EF01FFBDCE7201C0021B3
:107010000EF0F0F80028E3D1211C0198F9F7C4FC28
:107020000021041C01900EF0E5F8002807D0039918
:107030000023002901DA80231B06019355E000217B
:10704000201C0EF0DDF8039E431E984140420125AE
:1070500005400021301C0EF0D3F8431E98414540F6
:10706000EDB2002D41D0201C311C0EF081F9AAE7B1
:107070000198211CF9F770FDA5E7201C00210EF0F6
:10708000B9F80028ACD101A803A917F076FF019A3E
:1070900003231E499A430220024352180492039A82
:1070A0009A43131C03435B1804A9059307F0AEFA37
:1070B00026E00198211C0EF0A3F812E00198211C93
:1070C0000EF0B2F80DE00198211C0EF093F808E0E4
:1070D0000198211C0EF09EF803E00198211C0EF08F
:1070E000ADF800280BD10A480AE00199032399431F
:1070F0000220064A0843801802E0002000E005480C
:1071000006B070BD27B20200045E0200000080805D
:10711000247C0200E07B020030B585B003AB041C88
:10712000151C081C02AA01A91AF061FA019B174A52
:10713000934201D05B1000E000230298411090427E
:1071400000D1211C002B04DA1B19D843C0170340BF
:1071500002E0A34200D9231C002901DA091902E048
:10716000A14200D9211C2B60994200DA191C039B13
:107170006960934205D0032B03D05B10AB60002005
:1071800001E00120A86005B030BDC046387D020096
:10719000F0B587B0061C151C0C9C1B2803D1A2421D
:1071A00012D0002041E0192808D01C280CD1251C41
:1071B000141C0A1C1D26191C131C05E0251C141C7C
:1071C0000A1C1A26191C131C0394AC4200D90395FF
:1071D000002202911F1C0192019A039B9A421DD02A
:1071E000029B05971A1C01CA02CF0493029207F072
:1071F00049FF002803D0019B01330193ECE71B2ECC
:10720000CFD0049A059B1168301C1A6805F030FA3B
:10721000074BC01A43425841C0B206E0A54201D014
:1072200002D2BEE71A2EBCD0012007B0F0BDC04686
:10723000E07B0200F0B585B0039018681E1C029236
:107240000D1C07F087FE7268029B071C0192002448
:10725000022B11D9B268291C012308F043F8029AC5
:10726000041C032A08D0291CF268381C012308F0EA
:1072700039F8051C00E00134AC420CD2039AA3009B
:10728000D058019907F0FEFE0028F4D064000120D8
:10729000204305B0F0BD0349034818F04FFA0AF047
:1072A000ECFAC04638B20200A8590200F0B5002638
:1072B00085B00D1C071C0393081C0E4B111C009677
:1072C000321C00F019F8A81C800019F04BFF041CB8
:1072D00007604560AE420AD0039BB700DB59E7194F
:1072E000181C029305F036F90136B860F2E7201C4D
:1072F00005B0F0BDFFFF000010B5041C02A8007827
:10730000002906D0002804D10F49104818F016FAB9
:1073100008E09A4208D1944214D00C480C49231C2E
:1073200000F0E2FC0AF0A9FA944205D2121B0949C6
:10733000064800F0D9FCF5E79C4203D9034806490A
:107340001A1CECE710BDC04634AA0200985E020089
:10735000CCA902004FB2020081B20200F0B587B0A2
:1073600000250C9C0D9E03900491171C059302951B
:107370000195059A954239D0039A954209D26368DE
:107380009B0537D4019AAB0001320192049AD05880
:1073900019E022680621D3001943381C0022FEF7A9
:1073A0001BFD00280BD16368DB0505D52268194950
:1073B000194800F099FC21E0A268326012E0029BBB
:1073C0004068013302932379012B03D107F0F2FFC8
:1073D000307007E0022B02D107F0A6FE01E0032B7C
:1073E00000D1306001350C340436C2E7019B039AAA
:1073F000934205D20848094918F0A0F90AF03DFA6D
:107400003B68029ADB089A4202D203480449F3E738
:1074100007B0F0BDB0B20200985E0200C7B2020031
:10742000E8B2020070B5061C00290BDB032905D861
:10743000081C00240DF004FE070709098C1E012317
:107440009C4302E00024F22500E0FE25B52109025C
:107450002943301C17F074FF002C04D00349301C62
:10746000214317F06DFFF561346270BD80B00000FC
:1074700010B5102019F076FE034A041C04C019F060
:10748000BEF9201C10BDC0461852020038B50C1CB5
:10749000052804D80DF0D4FD05030C24131B00208F
:1074A00021E0081D19F0D8FA00281BD10E481AE077
:1074B000081D19F0EDFC01234000184313E0FFF70D
:1074C000D7FF211D051C043019F0F3FA06E0FFF781
:1074D000CFFF211D051C043019F0FBFA281C02E027
:1074E000081C00E0014838BDE07B0200247C02005B
:1074F00038B5041C11F08EFA012802D10F4810494A
:1075000003E0002805D10F480F4900F0EDFB0AF019
:10751000B4F9201C17F0DBFA002806D1201C0EF06D
:1075200017FD01254000284307E0FFF7A1FF211CBC
:10753000051C043019F0E2F9281C38BDD45E0200A5
:1075400006B30200A85902001FB3020007B5C30723
:1075500001D540100DE0043001A904F03FFC0028E3
:1075600001D0019805E00349034818F0E7F80AF054
:1075700084F90EBD38B30200D45E0200F0B50124D8
:107580008DB001900D1C171C0C4007D04B1003A8A8
:1075900002A9022219F072F903AE09E003230B409D
:1075A00000D043E1A34A0968914200D039E12E1D81
:1075B000FA0707D57B1003A802A9022219F05EF989
:1075C00003AD24E003231F4205D19A4A3968914252
:1075D00001D13D1D1BE03A1C1A400023022A04D1B0
:1075E000954B3B40063B5A1E9341002B08D0301C64
:1075F00019F09FFC3A1C011C0198FFF7C1FC04E044
:107600000198291C3A1CFEF7ADFB041C0EE1019AFF
:10761000092A01D0162A16D1281C19F01DFA0028B3
:107620003CD1301C19F085FC041C281C19F081FC8D
:10763000011C201C0EF008F80323984302247F4B02
:107640000443E418F2E00199182900D9CAE0FFF7D1
:107650000FFF041C01980DF0F3FC747A6E80800D0E
:1076600010161CE64B989E747A6E80800D10161CC6
:10767000E64B9800201D311C59E0201D311C2A1CAE
:1076800019F0FAFAD2E0201D311C2A1C19F038FB3F
:10769000CCE0281C19F0E0F9002802D068486949BC
:1076A00062E006A8271D19F0AAF8321C2B1C381C12
:1076B00006A904F03FFA32782B78D207DB07D20F05
:1076C000DB0FD2B2DBB29A420ED006A819F0C4F991
:1076D000002809D1012109A8494219F0C5F8381C30
:1076E000391C09AA19F08CFA06A819F094F89DE043
:1076F000281C19F0B1F90028D0D109A8271D19F0CC
:107700007EF8321C2B1C09A8391C04F013FA09A8B6
:1077100019F081F832782B78D207DB07D20FDB0F14
:10772000D2B2DBB29A4200D180E0381C391C2A1C4C
:1077300019F066FA7AE0201D311C2A1C04F0BEF80C
:1077400074E0201D311C2A1C04F048F96EE0201D55
:10775000311C2A1C04F09CF968E0381CFFF7F6FE87
:10776000021E05DA3848394917F0E8FF0AF085F8B3
:10777000019B201D311C032B01D0102B02D104F0E2
:1077800031F853E019F0DDF950E0201D311C2A1CBE
:1077900019F03CFB4AE0281C19F05EF9002800D0E3
:1077A0007CE7FFF765FE271D0190321C2B1C04307F
:1077B000391C04F0BFF932782B78D207DB07D20FDF
:1077C000DB0FD2B2DBB29A4204D0381C391C2A1C1F
:1077D00019F016FA01990220099109A90A9406F0F4
:1077E00015FF12E7301C291C19F03BF9031C019806
:1077F00000241938042819D80DF022FC03060F09BB
:107800000C00002B0BDA10E0002B0EDC07E0002B45
:1078100005DC0AE0002B08DA01E0002B05D00C4C57
:1078200004E01C1C02E0002400E00A4C201C0DB007
:10783000F0BDC04618520200070080FF00008080A3
:10784000045E020027B20200A859020065B30200DC
:10785000247C0200E07B020008B54A6801491AF066
:10786000BEFB08BD7AB3020070B5141C12680D1C73
:107870008368002A0AD1CD000621181D2943FEF78E
:10788000ABFA00281FD0406820601CE01A79181C51
:1078900091070BD50C4A934215D10C4E336C002B3B
:1078A00003D101201AF012F83064306C6268ED00E8
:1078B00006212943002A02D11AF04AF801E01AF001
:1078C0003DF80023236070BDB4940200902E002088
:1078D000F8B5C30006261E43071C311C0C480122C4
:1078E000FEF77AFA051C4068002810D10C2019F028
:1078F00039FC084B041C03604760012019F0E6FFC7
:107900006E21A060321C1AF019F86C60201CF8BDC2
:10791000B02E0020E457020008B50248032117F0FA
:1079200002F908BDB02E002008B5024817F01AF978
:1079300008BDC046B02E002010B5C0000C1C0621AA
:10794000014301220248FEF747FA446010BDC046D9
:10795000B02E002073B5C30006261E43051C311C43
:1079600010480022FEF738FA041E17D1221C0E48D8
:10797000311CFEF731FA041E12D0406808216A4615
:1079800004F06AFD009B002B08D00020011C6A4611
:1079900019F035FC281C6168FFF7CEFF6068FFE72F
:1079A00076BDC046B02E002020580200F0B589B048
:1079B00002AF051CFA603B600E1C03F0E3FAA968F5
:1079C000381C1430796115F0B0FE7860381C143022
:1079D00015F0ABFE032358437A6880188000B86026
:1079E0002C280AD8BB6869462A33DB08DB00C91A91
:1079F0008D46002202ACBA6005E0B8681C3019F070
:107A0000BEFB041EEED0AA687969201C8B1A636045
:107A100039687B68321CA3610091FB68291CFBF765
:107A200093FD154E6D687268201C626100217560BF
:107A300002F010FA6369F8607360002807D002282A
:107A400008D17B6805339B00E3185D6805E0E368B7
:107A50001D6802E00022094DFA60BB68002B02D0CD
:107A6000201C19F0B5FBF968281C002901D009F089
:107A700004FFBD4607B0F0BD902E0020387D020007
:107A80001FB50123041C184001D060104EE0284AA5
:107A900094424BD0274A944248D0274A944244D03B
:107AA0000323234007D1254A2168914203D1201C9A
:107AB00017F098FD3AE0224A2240062A05D0002B12
:107AC00008D1204B22689A4204D1201C01A9FAF760
:107AD000CBFC2BE0201C07F03DFA1B4B984207D152
:107AE000FF23DB05E018032398430EF031FA1DE075
:107AF000164B984205D1201C694601AA19F090FF47
:107B000011E0134B984205D1201C694601AA18F0D8
:107B10006CF808E0201C01A902221AF092F8031C5C
:107B2000201C002B02D0019800E0181C04B010BDEE
:107B3000387D0200247C0200E07B02001852020023
:107B4000070080FFC855020030570200D08B0200AA
:107B500030630200F7B5051C0F1C0092019300284A
:107B600001D0466800E0061C381C431E98413018BE
:107B70000430800019F0F6FA0C4B041C03600C4B27
:107B80005B684360009B8360019BC360002D05D050
:107B9000291CB200083110301CF0B0F9002F02D0BF
:107BA0000436B6003751201CFEBDC04624590200E1
:107BB000902E002038B5051C0C200C1C19F0D2FAB0
:107BC000024B45600360846038BDC046AC5802007B
:107BD000F7B51F1C00230093061C0D1C081C111C6C
:107BE0001A1C0B4BFFF788FB102019F0C8FA041E73
:107BF00004D1084C084B1034E36004E0281C391C05
:107C000006F004FDE06000232660201CA360FEBD9A
:107C1000FFFF0000902E0020588C020010B50138A4
:107C200010C906F0F3FCE060004810BD387D02008A
:107C3000F8B57F23171C151C041C0E1C1F409A430B
:107C40000AD17B1E012B0ED80B68586819F0BBFEB9
:107C5000011C201C1AF0F9F8022F04D1201C104935
:107C60001AF0F3F802E07D231D4212D1F368002BD5
:107C700002D05A68002A04D1201C0A491AF0E5F8FB
:107C80000CE0012A05D19968201C002207F07CF93C
:107C900004E0F168201C2A1C06F04EFCF8BDC0462A
:107CA00092BA02002FB00200C3685A68002A01D0BD
:107CB000986800E000487047387D020010B5141C39
:107CC0001268002A0CD15A2901D1C06807E0054B7F
:107CD00002689A4204D1972902D1FFF7E5FF20609C
:107CE00010BDC046545C02000EB4F0B5061C86B050
:107CF00010200B9D19F043FA041E07D11B4B1C4AA0
:107D00001C1C1E619861DA61103429E000210660B4
:107D10008160012006F07AFC061CE060002D1FD077
:107D2000281C25211CF0ECF9071E09D1281C1CF089
:107D3000FDF93A1C011C281CF9F7E4FEB0600FE0C5
:107D400002A8102119F0E0FA0CAA291C02A801923D
:107D500005F026FA074802A9E568F9F79FFEA86032
:107D6000201C06B0F0BC08BC03B01847902E0020C1
:107D7000588C0200C855020008B5820707D1074B8E
:107D800002689A4203D1064BC2689A4203D0054961
:107D900003F0A0FC00E0012008BDC046C87402004A
:107DA000D17B0000145D020010B5041C07F0D2F86E
:107DB000034BC2689A4200D024690023A36010BD1F
:107DC000D17B0000F7B5161C0193041C0F1C07F0B3
:107DD000C1F8174BC2689A4200D02469A568002DEB
:107DE00009D10C2019F0CBF9A06000281ED0032384
:107DF000A380E58010E0E388A18802338B420BDB8F
:107E000003318900281C012219F0DEF900280DD069
:107E1000A388A0600333A380E288A16893000332A3
:107E2000E280019ACB181F605E609A60F7BDC04681
:107E3000D17B000070B5151C041C0E1C07F08AF8DD
:107E4000064BC2689A4200D02469A368002B01D176
:107E5000336001E0E28832602B6070BDD17B0000AE
:107E6000F8B5051C10781F1C0A38C3B20E1C0F2B66
:107E700005D853780002184319F0A5FD00E0164814
:107E8000164C0178221C543263788B4218D1437807
:107E90009C46A3789C4513D183789C46E378634540
:107EA0000ED1002B09D12078B84214D90C49321CCC
:107EB0003B1C0C48FFF718FF0AE0C378002BF2D0F8
:107EC00004349442E0D107480749321CFFF70CFF05
:107ED000AB6818600020F8BD2FB00200BFB50200EB
:107EE000EEB30200105F020007B402007FB5137802
:107EF000041C0D1C992B46D1101C01A916F0CAFFB9
:107F0000019B021E9A423ED00378191C0A390F29A0
:107F100007D8201C291C0F23FFF7A2FF012686404B
:107F20002FE0AE2B2FD116F0B0FF061C16F0A8FFE5
:107F300002900378B12B26D1321C0F23291C201C60
:107F4000FFF78EFF0126864003A9029816F0A2FFD4
:107F5000039B0290984203D002A8982116F0A9FF33
:107F6000029A039B9A420CD0291C0F23201CFFF776
:107F700077FF0123834002981E4316F081FF029091
:107F8000EEE7301C07E0054805492A1CFFF7ACFE68
:107F9000A3681860002004B070BDC046105F0200E6
:107FA0001FB4020073B51E1C1378041C0D1C032B98
:107FB00005D00C492A1C0C48FFF796FE0DE0101C5A
:107FC00016F04CFF021CB243031C002A08D0009696
:107FD000054806492A1CFFF787FEA368186000239E
:107FE000181C76BD3AB40200105F020052B40200C1
:107FF00038B5041C1078131C0A38C2B20D1C0F2AA5
:1080000008D92A1C11481249FFF76EFEA368002503
:10801000186019E05B7802021A43E3680020984276
:1080200008D0256981004959914201D1051C0BE016
:108030000130F4E723880025042B05D103480549C6
:10804000FFF752FEA3681860281C38BD105F0200BD
:108050007EB4020093B40200F7B5061C0C1C01921A
:108060000025019B9C4228D06B1C0093052B03D15B
:10807000B4681348134907E020780A38C3B20F2BBD
:1080800007D9B4680E48104917F058FB206000204B
:1080900014E063780002184319F095FC0234071CC1
:1080A0001CF044F80228ECD13B78722BE9D17B78A4
:1080B0003035AB42E5D1009DD3E7281CFEBDC0465C
:1080C000105F0200AAB40200DDB40200F0B587B070
:1080D000051C081C04A901921E1C19F079FC041C43
:1080E000019800281BD1201CCC491CF015F8002851
:1080F00003D1BF216869090258E2201CC8491CF05D
:108100000BF8002808D0019BC648C749221CFFF77E
:10811000EBFDAB6818604BE26869C44946E201991F
:10812000012900D0ACE0201CC1491BF0F5FF00285C
:1081300009D1211C3268281CFFF75AFF011C68690D
:1081400017F051F90EE0201CBA491BF0E5FF00289A
:1081500012D1211C3268281CFFF74AFF011C6869F4
:1081600017F098F9002800D022E2AE48B249AC6876
:1081700017F0E4FA20601BE2201CB0491BF0CCFF92
:1081800000280AD1211C0F233268281CFFF768FE43
:108190008E216B69C000C90106E22378622B32D1BF
:1081A000049B032B07D0052B2DD1E3785F2B2AD11D
:1081B00023796E2B27D1A24A01276178531C7F4275
:1081C0002B321878884206D1A078844658788445A6
:1081D00001D1581E077803339342F2D1791C92D013
:1081E0003268211C281CFFF703FF0499021C00239E
:1081F0006869052903D12379773B59424B41391CE2
:1082000017F00DF9AEE7201C8E491BF085FF002802
:1082100002D168698C49C9E1201C8C491BF07CFFA4
:10822000002802D168698A49C0E1201C89491BF0F5
:1082300073FF00280DD13268281C211CFFF756FE61
:10824000FF221202031C104200D05CE76869B421CF
:1082500013E0201C80491BF05FFF002800D052E78C
:108260003268281C211CFFF741FEFF221202031C6A
:10827000104200D047E76869BC210902194395E123
:10828000019A022A00D01FE1706874490378201C0B
:108290000A3B0F2B4DD81BF03FFF002812D1211CA9
:1082A0003268281C0F23FFF7DBFD7268071C211CB6
:1082B000281C0F23FFF7D4FD391C021C686917F036
:1082C0007DF875E1201C66491BF026FF0027B842A7
:1082D00019D18027FF01211C3268281C0723FFF7D2
:1082E000BFFD72680190211C281C0723FFF7B8FD11
:1082F000391C031C019A686917F059F858E10137D5
:108300000F2F00D1FFE65749BA00013102928918B8
:10831000201C03221BF011FF0028F0D1E378002B72
:10832000EDD102984F498027435CFF011B011F4399
:10833000D1E71BF0F1FE8027002806D0201C4A4917
:108340001BF0EAFE002814D1A027211C3268072365
:10835000281CFFF785FD211C0190FF237268281C53
:10836000FFF720FE019CBF01210201436B693943E5
:108370001BE1201C3D491BF0CFFE002801D1C02786
:10838000E3E7201C3A491BF0C7FE002801D1E02793
:10839000DBE700273749F800023102900918201C5A
:1083A0001BF0BAFE002800D089E00299314A072369
:1083B000895A281C02913268211CFFF751FD76680A
:1083C00003903378982B57D1301C16F09EFD00286F
:1083D00052D1301C16F059FD03789A2B4CD105A9C7
:1083E00016F058FD0599071C16F03EFD022843D1F2
:1083F000381C16F045FD3A1C061C211C281C0723BE
:10840000FFF72EFD029A071CD2043DD5281C211C23
:10841000321C1F23FFF7C6FD46E0C0460FB5020021
:1084200013B50200105F020017B5020030BF000054
:10843000F4D302004CB50200ABB502004FB5020008
:10844000C4B3020052B5020072B6000058B5020073
:1084500062B600005EB5020082C7020063B502008A
:1084600067B5020088B302006CB502003DC8020087
:1084700070B50200BAA402004E484F49221CFFF713
:1084800033FCAB6818603EE60298211CC30B321C1B
:10849000281C002B04D03E23FFF784FD401003E08E
:1084A0007C23FFF77FFD80100399029CF822214373
:1084B000FF008001D2006B693943104074E001373E
:1084C000062F00D066E71EE60198032800D01AE6C2
:1084D000201C3A491BF020FE071E07D0201C3849FB
:1084E0001BF01AFE00281DD180273F01211C326895
:1084F0000723281CFFF7B4FC211C01907268072396
:10850000281CFFF7ADFC211C0290B2681F23281C19
:10851000FFF748FD0199029C3943E2006B69114362
:10852000800141E0201C27491BF0F6FD002802D104
:1085300080277F01DAE7201C23491BF0EDFDC027CF
:10854000002807D0201C21491BF0E6FDD027002879
:1085500000D0D8E5211C32680723281CFFF780FCD7
:10856000726801900723281C211CFFF779FCB26870
:108570007F01137802900A3B0F2B05D8281C211C81
:108580000723FFF76DFC07E08023DB001F43281C57
:10859000211C0723FFF706FD029C6B69E100019C8B
:1085A000800121430F43391C0143181C16F0C8FEFB
:1085B00007B0F0BD105F020074B502009FB5020065
:1085C000A3B50200A7B502003DC8020070B50200C5
:1085D000F0B58DB0019008680E1CF9F72FFF0390DD
:1085E00003A817F042F90090306817F066F94410BC
:1085F000211C08A818F09FFE0A98221C0021049054
:108600001BF09EFC0124019A94423FD2039A01255B
:10861000107804F0E7FD002803D003A817F037F91D
:10862000051C039A1378732B03D06419A700F7195C
:108630001BE0671CA400A05905A9012206F03AFF1F
:10864000069B2C1E9C4200D91C1C221C05990498D8
:108650001BF054FC049B2A1B181900211BF070FC12
:10866000049A3C1C551904950CE0002D0AD0039B7C
:1086700000981978AB005B42FA5804ABFCF7C8FECF
:10868000013DF2E7039B01330393BCE708A90248CD
:10869000F9F704FA0DB0F0BDA84B020008B54A681E
:1086A000014919F09CFC08BD4CBE0200044B782225
:1086B0001A80042203485A801A715A717047C046C2
:1086C000C4000020387D020013B5074C208816F046
:1086D0004CFF0090608816F048FF69460190022028
:1086E00005F094FF16BDC046C400002008B5002860
:1086F00003D0086803F0F2FB00E0044800210BF00F
:1087000019FC034B002203481A7008BD1C2B0020E3
:108710001C2E0020387D02001FB50A4B02AC0093CE
:1087200001940223FEF71AFE029B002B01D0064A99
:1087300053806368002B01D0034A1380034804B0C0
:1087400010BDC04618620200C4000020387D02003F
:1087500030B5244B89B004AC009301940423FEF798
:10876000FDFDFFF7A3FF04981F4B0340062B06D027
:1087700081072FD103689A691C4B9A422AD10123A1
:1087800002930394606803F0A9FB1949194B0D6823
:10879000194900220D601A70257B18490D7018497F
:1087A000029D0D8017490A80174A03991160174AE4
:1087B000106001221A70227A002A10D01A78002A3A
:1087C0000DD0134AD26A002AF8D0002119700BF09C
:1087D000B1FB04E002A903AA06F04EFDD2E70D4862
:1087E00009B030BD54620200070080FF9D240000E4
:1087F000B82C00201C2E0020802700201D2E0020D9
:108800000E2E00200C2E0020842700207C27002024
:10881000902E0020387D0200F0B5144B87B002ACDA
:10882000009301940423FEF799FDA0686668029FF7
:1088300003F054FB8021051C247B0BF07BFB391CCF
:108840000B480CF01BFC011C281C0BF0FBFB002E42
:1088500008DB002C06D0301C06F042FF281C00214B
:108860000BF068FB034807B0F0BDC046B4620200DD
:1088700040420F00387D0200F0B56C4C87B0237881
:10888000002B00D1CFE06A4D6A4E296830682F1C5A
:10889000884200D2C7E02378022B0AD1664B002120
:1088A00018680BF047FB33680A332B6001232370F1
:1088B000B9E05E4E3378012B00D0B4E05F4B604AE4
:1088C00019881288914208D35E4A1278002A02D091
:1088D00000221A8001E02270A5E01A885A4B92000B
:1088E0001B68554CD058594B98420DD10021206837
:1088F0000BF020FB564B574819880CF00DFC3860E4
:108900004A4F01233B708EE005A9F9F7ADFD2468BD
:10891000059E051C8021201C019600940BF00AFB8B
:108920002F784B4E1F231F407B1E31884948DCB2F5
:108930000CF0F2FB71880CF0EFFBB446019E029044
:10894000012E10D96B78232B09D0622B0BD1002C70
:1089500004D0023FFCB2012C08D000E00624022320
:108960000122002105E001230022FAE70223221C54
:10897000FF21019FBB4208D2E85C3A2805D00F26B0
:108980003040013366463071DBB267463F79019E65
:108990000397B34217D2E85C3A2814D1581CC0B2EE
:1089A000B04210D22E5C0F20674606407E71023323
:1089B000019FDBB2BB4206D20A277E43EF5C384000
:1089C000361860464671092C14D8039B6700043B97
:1089D00059184BB2002A01D01F4A00E01F4AD15B50
:1089E000002B05DA5B42994000980BF02BFB05E069
:1089F0001941F9E7009800210BF09CFA144A029EF5
:108A00005279F3B253430A3B092B00DC0A23094F86
:108A10003A689B18064A1360084B1A8801321A807C
:108A2000024B02221A7007B0F0BDC0461C2E002077
:108A300080270020B82C00207C2700200C2E00204E
:108A40000E2E00201D2E002084270020387D0200DD
:108A5000C400002060EA0000F8A40200EAA40200BA
:108A6000F7B501911249041C161C19F0EEF9002506
:108A700073689D4216D2002D03D0201C0D4919F0B9
:108A8000E4F9019BAF00DB590B491A1C201CF719B4
:108A9000009319F0A4FAB968201C012206F074FAB8
:108AA0000135E5E7201C054919F0CFF9F7BDC046AF
:108AB0002BBF020013B6020016B60200BED8020099
:108AC000F8B5224D2C68616801293DD9A0684B1E7C
:108AD000C25C0A2A38D1002B04DDC218013A127890
:108AE0000A2A01D11A1C05E0013BF4E7865C202E1E
:108AF00002D101328A42F9D3002B0BDD561C8E4283
:108B000008D15E1E002E05D0013E875D0A2F1BD0C6
:108B1000202FF7D0411802390978D61A3A39B60809
:108B20004B4259417618002E0ED0094F201C391C9B
:108B3000042218F0C8FB381C042106F07BFD2B69C9
:108B4000013E04332B61EEE7F8BDC04688270020C4
:108B500056B8020008B50348002120221BF0F0F9A6
:108B600008BDC046D42E002008B5094B42681860E5
:108B700000209860187501204042D860081C5A6097
:108B80001A61996119F08CF8FFF79AFF08BDC04689
:108B900088270020F8B50378041C002B1ED0104E47
:108BA000706C002804D0211C1BF0B6FA002815D0E8
:108BB000201C1BF0BBFA471C381C18F0E0FA051EFD
:108BC0000CD0211C3A1C1BF099F90023F218D16D2E
:108BD000043B11661A1C1C32F8D17564F8BDC046FE
:108BE000902E0020F0B5BB4B051C186885B0466878
:108BF0001C1C01969E68002E00D0C2E06B1E042B48
:108C00001BD818F0E1FB6168884200D160E1012DBA
:108C100000D106E1022D0AD00FE09A60412D37D035
:108C2000422D2ED0432D19D0442D00D0E8E02269EA
:108C300063689A4200D958E154E1032D00D147E11D
:108C4000042D06D1206821694568A94200D3E0E0DF
:108C5000FBE0052D00D1EEE0062D06D12368266944
:108C60005D68AE42AD416D4225E10B2D07D1019DFE
:108C700026692068A91B18F036FC002500E10E2D9E
:108C800004D1E368002B00DB9FE02BE1102D04D121
:108C9000E368062B00DC8AE024E1152D0AD1616827
:108CA000236920685A1A18F02CFC256961686E1A2D
:108CB0000025A3E00D2D0AD1874818F0F1FF2068A8
:108CC00018F0B5FB6368C018FFF764FF11E11B2DB6
:108CD00002D10123A36005E1082D01D07F2D19D118
:108CE00021696268914200D8FCE02068131C9D1A3B
:108CF0008B4205D08668F55C202D04D10133F6E760
:108D00000426032D00DC0126891B321C18F0F9FB18
:108D10000127ECE0092D28D1236861689868226951
:108D2000401803AB511A6D4AFAF7EEFA061E00D14D
:108D3000D8E00025431C0BD1A06918F0B1FF2368CF
:108D40006168986826694018711A06F073FC97E00C
:108D5000039B22692068A9185A1C03921A780135CE
:108D600018F0AFFBB542F3D18AE02B1C203B5E2B01
:108D700000D9B7E02A1C2068216918F0ABFB012557
:108D80007EE00022012E07D14F2D03D05B2D6BD149
:108D9000022269E0042267E0022E36D1291C303914
:108DA000092900D939E703229A601D759AE04C49D8
:108DB0005A1C11339B00CB185968002900D191E04F
:108DC00020686368E260436010E02068626846687B
:108DD000013BB11AE36018F086FBE368002B07DB68
:108DE00010333F4A9B00D3185968206818F03BFBAA
:108DF000636825692268EE1A5568ED1A012735E087
:108E0000482D0ED0462D6DD115E0032E26D17E2D96
:108E100002D000252F1C1DE01B7D312B01D0372BEC
:108E200005D12169626800258E1A2F1C13E0342BAE
:108E300001D0382B06D1236800275D6823693E1CCA
:108E4000ED1A08E0332BE4D1FCE6012218F059FBBF
:108E5000002501272E1C0023A36007E0042E03D168
:108E6000462DE8D0482DDCD09A603BE0002E05DD91
:108E7000301C06F003FC21698E1B2661002F1AD0DE
:108E80002368019E5B68B34203D22169701A06F021
:108E900005FC2268236996685168F018C91A06F023
:108EA000C9FB236821695868401A401B06F0E6FB9D
:108EB0002269AD180AE0002D14DD2368291C98688A
:108EC0002369C01806F0B6FB2669AD19256109E0D3
:108ED0002E1C0EE0882700209AB00200F0950200B8
:108EE000902E00200126764203E00027012600256F
:108EF000BEE7301C05B0F0BD70B5061C0D1C002887
:108F000011DD002906DD15480CF006F90124864222
:108F100013DC11E0C0200006311C0CF0FDF8012428
:108F200085420ADB08E0002909DDC02000060CF0BC
:108F3000F3F80124864200DB0024E4B20BE00024B5
:108F4000A04208D00548311C0CF0E6F80123854208
:108F500000DB231CDCB2201C70BDC046FFFFFF3FBE
:108F600008B503480349044A19F039F8034808BD15
:108F7000F0950200C9A902001AB60200387D02006D
:108F800008B503480349044A19F029F8034808BD05
:108F9000F0950200C9A9020096B60200387D0200D1
:108FA000002805D0012808D18B685B00184307E032
:108FB0008B68002B03D0034802E0002000E0024849
:108FC0007047C046E07B0200247C02008268F0B556
:108FD000D60FB61876100023B3420EDAC1689D0092
:108FE0004D1907492F685418E41AC168A40009599B
:108FF00001332960C1680F51EEE70248F0BDC04659
:10900000FFFFFF3F387D020038B50D1C83684168C3
:10901000041C8B4212D3C900C06818F0C8F86168FC
:10902000A3684A0009496260D21A013352189B00B2
:10903000E0609200C01800211AF082FFA368E26885
:10904000591C9B00A16002489D5038BDFFFFFF3FA7
:10905000387D0200F7B58368051C01924C1003D5DA
:10906000E418E243D21714409C4200D91C1C0C4F58
:10907000281C391CFFF7C8FFA9680A4B4A1EC918EB
:109080008900381C0F1FEB68A24204DDDE59013A4B
:109090005E50391CF6E7019EA4001E51FEBDC0467D
:1090A000387D0200FFFFFF3F38B50025041C8560B6
:1090B0001021C06818F07BF80423291CE06063606D
:1090C00010221AF03DFF014838BDC046387D02002D
:1090D0007FB5124B02AD0C1C009304310223013802
:1090E0000195FEF73BF923680D4C9968012912D9C7
:1090F000D8680C4BC918029B89001A1B561EB24136
:1091000052421A402B794118002B01D0064B00E047
:10911000064B16F0AAFC201C04B070BD24640200AB
:10912000387D0200FFFFFF3F247C0200E07B02004D
:1091300070B50C68021CA368002B05D11A491B48A6
:1091400016F0FCFA08F099FB2068012A01D04A6861
:1091500001E001225242191C002306F0C3F8E36823
:10916000A26881005E18013A35680431A260121AC3
:1091700059189200301C1AF0CAFEA368E06800215A
:109180009A001150616804290BD95B00994208D9F3
:1091900049088900E06818F00AF86268E06053083E
:1091A0006360281C70BDC0466DB70200045B0200FE
:1091B00007B5009001910220694616F0B9FC694696
:1091C00001900220FFF7B4FF00480EBD387D020079
:1091D00070B50E1C0D49051C18F037FE0024B3684D
:1091E0009C420ED2002C03D0281C094918F02DFEF9
:1091F000F268A3009958281C012205F0C5FE01342D
:10920000EDE7281C034918F020FE70BDBDFF0200E9
:1092100013B602004604030070B50326041C0D1C9F
:109220000E4028D1174B0968994224D1AA68836857
:10923000D1184268914210D904318900C06817F0F2
:10924000B6FFA968A268E0608B181A1D9B006260D7
:10925000C018311C10221AF073FEA368E168980050
:10926000AB6808189A00E9681AF048FEAB68A16874
:10927000CB18A36003E0201C291C16F062FC0248F6
:1092800070BDC04630630200387D020010B5041C7A
:109290000C2017F067FF034B4460036000238360DA
:1092A00010BDC046E863020038B50B4B051C0360D7
:1092B0000C1C081E042800D204206860AC608000EA
:1092C00017F050FF6A68E860121BA40092000019B2
:1092D00000211AF035FE38BD306302007FB50D1C49
:1092E000141C122828D004D8052807D0072829D014
:1092F00057E0031C193B042B40D952E003201040D7
:109300004FD1294B12689A424CD18A68A3689818A9
:1093100016F030FCAB68061C9A00E968C0681AF0C9
:10932000EDFDA868F268A36880001018E1689A0053
:109330001AF0E4FD301C35E0081C111CFFF76CFF2F
:10934000281C2FE0101C03A905F02CFF031C002093
:10935000834227D0039C844200DA0390039AA868D2
:10936000504316F007FC041CE368E8680093AA6801
:109370000421039B15F07BFE201C13E0A20701D003
:109380000A480FE0084B22689A42F9D1E368A468C2
:10939000C968AA680094FDF7FBFE0028F0D00448D5
:1093A00000E0002004B070BD30630200247C0200A5
:1093B000E07B0200F0B50B1C85B0041C151C0327D4
:1093C000002A2BD10F4022D15C4A086890421ED15E
:1093D00001AAA068FDF7A0FE029A0198E368851A29
:1093E0009100800059181818A3689A1A92001AF070
:1093F0008EFDA168E36868186A4280009200181820
:10940000391C1AF09DFDA0684519A56092E001A9DC
:10941000022001940293FFF78BFE8BE0042A2DD1EA
:1094200081683B4221D1454A186890421DD1081CF1
:1094300001AA191CFDF770FE002805D1A068E1689B
:1094400001AA15F027FE76E001990298401A16F05D
:1094500091FB8368051C0198E1689A008300C91894
:10946000E8681AF04BFD281C65E01A1C20680023F0
:1094700005F038FFE3688000C0585CE00F4054D12D
:109480002E4A0968914250D1191C01AA8068FDF743
:1094900043FEAA68019B02989E18361AE068002EC7
:1094A00021DDA2686368B118994206D9890017F0D6
:1094B0007EFEE060A06833186360019AE368B0182C
:1094C0009100800059181818A3689A1A92001AF08F
:1094D0001EFD0199E268AB6888001018E9689A00DF
:1094E0001AF00CFD1DE09B00C0189200E9681AF00C
:1094F00005FD0199A868029AE36840188000910070
:1095000059181818A3689A1A92001AF000FDA16859
:10951000E36870187242800092001818391C1AF023
:109520000FFDA0688619A66004E0201C191C2A1CE7
:1095300016F062FB024805B0F0BDC046787D02001F
:10954000387D020070B5061C081C17F070FF051C62
:1095500015F047FA041E06D108492A1C0848FEF7F0
:10956000C3FB08F08AF9301C16F050F8031C0121E7
:10957000201C1A1C03F05EFD70BDC04681B70200BE
:10958000505D020010B5041C17F051FF15F02BFAC6
:10959000031C012083420CD00649201C17F063FFF6
:1095A000201C17F044FF15F01EFA023843425841C0
:1095B000400010BDD2B70200F0B59DB000AF0C68FE
:1095C000032807D9CA6800257A60042805D00D69E8
:1095D0006D1002E0954B00257B60391C201C1C316E
:1095E000F8F742FF3861002D56D0914C6E2160682B
:1095F00004F046FD061C606818F0B3F900228E21C5
:10960000FCF7EAFB391C3031041C301CF8F72CFF46
:109610003A6B013D011C8318002C0CD18B420AD9F6
:10962000013B1A782E2AF9D105E08B4203D9013B80
:109630001A782E2AF9D1013DF7D2FE695C1A251C51
:10964000002E01D0751C2D192B1C0E33DB086A4629
:10965000DB00D21A95467A61101C221C1AF04EFCCF
:10966000002E08D07A692E23135501341019396958
:10967000321C1AF043FC7869291C04F0ADFE012865
:1096800004D16C496C4816F059F855E07B69C0006C
:1096900006240443FD613B61201CF8F755FAFEF7F0
:1096A00059F9041E14D038692E211AF029FD00281A
:1096B00000D1B6E05D4B7A689A4200D0B1E03B69D8
:1096C000C11A181C04F088FEFEF744F9041CA8E037
:1096D000381C3A1C20304021303217F034FE01266D
:1096E000251C3C607C6104E03A69935D2E2B05D01B
:1096F0000136FB699E4200D98EE0F5D13869311CF4
:1097000004F06AFEF860381C203017F05DFE002877
:1097100014D1381C39692030321C17F0D4FD381CA4
:109720002030FFF72FFFB860BB68002B12D14248F2
:109730004249FA68FEF7D8FA08F09FF8381C203042
:109740002F2103F0D9FC7A693B69381C9918203025
:10975000B21AE2E7F868FEF7FDF8041E47D1F86890
:10976000FEF7B6F8FA69041C964208D1344B7A68C1
:109770009A4204D180686E215E2218F0DFF8BB683F
:10978000012B2FD1381C203017F017FEB860381C81
:10979000203017F019FE0022011CB868F8F7B2F962
:1097A0001121021C201C02F0B1FE381C20302F2198
:1097B00003F0A2FC381C2030224917F054FE381C5C
:1097C000203017F034FE15F00EF9022804D1391CB0
:1097D000201C2031FFF7B6FE381C20300C2117F07A
:1097E00082FE04E0391C201C2031FFF7ABFE002D67
:1097F0000AD03A697B69D018F11A04F0EDFD221CF9
:10980000011C281C02F082FE3A68002A00D13C604C
:10981000731C7B61251C6BE7044B7A689A4200D16C
:109820003C68201CBD461DB0F0BDC046387D02001E
:10983000902E002096B70200505D0200B5B70200DE
:10984000247C0200CAB7020038B5051C0C200C1C91
:1098500017F088FC024B45600360846038BDC04649
:10986000B864020038B5051C081C6843013040107C
:1098700008300C1C17F076FC044B012203600379BE
:10988000857193430371447138BDC046746502000D
:1098900010B5041C0C2017F065FC034B4460A46851
:1098A0000360846010BDC046BC68020013B5041C90
:1098B0000749684619F0FEFE1F2C02D9019B9C4205
:1098C00000DD3F24203C05206043009B181816BD96
:1098D000D429002038B5051C182017F043FC114B83
:1098E000041C0360104B8360002303756B68EA68F7
:1098F000C36042602A7CA9688275581820610029DB
:109900000AD01878E075002A08D1FFF7CFFF16F0CB
:10991000DFF90130607503E02023E37505236375EB
:10992000201C38BDF464020060650200F8B50C68C4
:109930000E1C2379D90702D51A481B490DE070681F
:1099400005F0F2FB051CB06805F0EEFB071C002DCE
:1099500001DB002805DA1548154915F0EFFE07F080
:109960008CFFF06805F0E0FB031E092B02D90F48BD
:109970001049F2E72279D10704D4A279954206DA98
:10998000627902E0042D02DC0522974202DB0748DF
:109990000949E2E7201C291C3A1C16F0CCF90748BB
:1099A000F8BDC046985E0200D6B70200A859020072
:1099B0000BB8020024B802003EB80200387D020055
:1099C00070B5051C081C161C05F0AEFB041C301CF1
:1099D00005F0AAFB021C002C01DB002802DA0F486C
:1099E0000F490EE02B79D90704D4AB799C4206DAF3
:1099F0006B7902E0042C02DC05239A4205DB074860
:109A0000084915F09BFE07F038FF281C211C16F0B2
:109A1000AFF901234000184370BDC046A8590200A9
:109A20000BB802003EB80200F7B50D1C2949041C12
:109A3000019218F0D4FA0199002903D1201C26497B
:109A400018F0CDFA254F201C391C18F0C8FA002652
:109A50002A790523D10700D46B799E4225DA0027A5
:109A60002A790523D10700D4AB799F420CDA391C3F
:109A7000321C281C16F07CF9194B1A491A5C201C60
:109A800018F0ADFA0137EBE7201C174918F0A7FAD8
:109A9000019B002B07D12A790523D10700D46B79CC
:109AA000013B9E4211DB0136D2E7201C0B4918F026
:109AB00096FA019B002B03D1201C0C4918F08FFA59
:109AC000201C0B4918F08BFAF7BD201C094918F02F
:109AD00086FAE8E74EB8020055B8020061B8020005
:109AE00063B802004CA5020055FE02009BB00200C4
:109AF000BED802005BB80200F0B51E1C8BB000237C
:109B00000F1C0093081C111C1A1C0323FDF7F4FB07
:109B1000032F56D8381C0BF093FA570210103068F8
:109B2000674B0340062B51D0810700D0C3E0654B43
:109B300002689A4200D0BEE048E0306805F0F4FACE
:109B4000041C706805F0F0FA02900299201CFFF7DF
:109B500089FE051C022F02D116F0FFF82FE0B06835
:109B600007A9012205F0A6FC002C09DB029B002BB3
:109B700006DB63430898834202D10026039619E06E
:109B80005148524915F0DAFD07F077FE039A07991C
:109B90008B18DA5D0923082A00DC131C391C281CE9
:109BA000321C16F0C8F80137A742EFD1039B0136EB
:109BB0001B1903930298864201D00027F4E7281C62
:109BC0007CE043484349DDE7434877E007A9F8F7DD
:109BD0004BFC079902900591012904D1029B18784A
:109BE00016F025FB6AE00023029A1D1C1F1C029838
:109BF000111A0598814214DA11780A2901D03A29FC
:109C000005D19F4200DA1F1C0135002307E0013314
:109C1000202904D0392902D92B483049B2E7013232
:109C2000E5E7002B03D001359F4200DA1F1C291CF9
:109C3000381CFFF717FE0299002603900491341C8C
:109C400004980299059A431A934226DA049A1378E3
:109C50000A2B01D03A2B0CD1BC4207DA211C039805
:109C6000321C002316F067F80134F5E701360024B2
:109C70000FE0202B04D10398211C321C002305E0A7
:109C8000392B06D80398303B211C321C16F053F8B0
:109C90000134049B01330493D2E7AE4201DB039805
:109CA0000CE0BC42FBDA211C0398321C002316F0A6
:109CB00042F80134F5E70648094963E70BB0F0BD07
:109CC000070080FFC8550200A859020098B802009A
:109CD000985E0200B5B80200606502006EB802002E
:109CE000D4B80200F0B587B002910179061CC9070B
:109CF000C90FC9B20592002902D14379827901E0E6
:109D000005231A1C029C05272079C40701D4029C54
:109D100067799F4208D105240194002901D1B479C3
:109D20000194019C944205D01B491C4815F006FD86
:109D300007F0A3FD0198391CFFF794FD0024039060
:109D4000019B9C4224DA0025BD421FDA211C2A1CFB
:109D5000301C16F00DF82A1C0490211C029816F0F5
:109D600007F8059A002A05D0049A1318082B06DD77
:109D7000092304E0049A131ADA43D21713402A1C69
:109D80000398211C15F0D7FF0135DDE70134D7E733
:109D9000039807B0F0BDC04619B90200A8590200E7
:109DA000F8B5061C081C0D1C141C05F0D3F8164F42
:109DB000B84226D1053E042E23D8301C0BF040F9C2
:109DC000141403210700201C05F012FA07E0201CE0
:109DD00005F00EFA011CFE2080050BF035FC011C7D
:109DE000281CF6F74DFA0DE0201C05F0B3F8B84238
:109DF00007D172427241D2B2281C211CFFF772FFB8
:109E000000E00020F8BDC04674650200F8B5071CEC
:109E100014200E1C151C1C1C17F0A4F9034B4760E2
:109E20008660C56003600461F8BDC046B06502008D
:109E3000F8B5071C14200E1C151C1C1C17F092F9F9
:109E4000034B47608660C56003600474F8BDC0467C
:109E500080680200F0B583699FB008900D91581E8C
:109E600008995A1D06339B00CB1892008A180433B8
:109E700004320B930B690A9201216A4619403F3262
:109E80001170032293430C90109312A807F0DAFC90
:109E9000031E01D000F058FD089A5568D4680D9A49
:109EA000002A26D02A785E2A23D00D980D9300F040
:109EB0008AFCAB786A781B021343B749EB185B182E
:109EC0006360EB78083423602368590600D1A4E26C
:109ED000109A013B5268900700D49AE2221C08C2F3
:109EE00005236360109B141C1F68109B0C3B109390
:109EF0003D1C089B6F1C5D602B78181C10385A287D
:109F000001D900F0CFFC0BF0A5F85B005D0062000A
:109F1000CD046400CD04720080008700CD04890068
:109F20009E00AF00BD00CD00DB00EA00EE00F600B1
:109F3000060119012801370153015B016E018601F9
:109F40009301CD04CD04CD04CD04A001A201E3040E
:109F5000A901AF01B901C101CE01DB01E601CD04C8
:109F6000CD04CD04F60122028F028F02AB02C202A1
:109F7000C602D902D902D4FFE402CD04CD04CD0437
:109F8000CD04CD04CD04CD04CD04EB02FD020E03BF
:109F90001F032D033603CD04CD044B036F03810350
:109FA0002E044C0473046104CD049803A403B0038D
:109FB000BA03CA03E403F9031304A804B804C804E9
:109FC000764B00E0764B6360043400F0B1FC754BD7
:109FD000F9E76B785B06DB173A78D9017F231340EA
:109FE00052B20B430137002AF6DB00F05EFC00237F
:109FF0003A78D9017F23134052B25B180137002A07
:10A00000F6DBDB0006221343DDE7FD1C03239D4343
:10A010002F1D2D686560D7E70023D4E700233A7829
:10A02000D9017F23134052B25B180137002AF6DBB7
:10A030009B005B420A995858002800D03CE25A48DD
:10A040005A4900F029FD00233A78D9017F231340B3
:10A0500052B25B180137002AF6DB0A9A9B005B427A
:10A06000985813F041FBE7E700203B78C2017F20BE
:10A0700018405BB280180137002BF6DB251D02F07B
:10A08000B5F80CE000203B78C2017F2018405BB29D
:10A0900080180137002BF6DB251D02F075F8606093
:10A0A00000F02AFC00213B78CA017F2119405BB2F5
:10A0B00089180137002BF6DB206817F0B0F81FE293
:10A0C00000213B78CA017F2119405BB28918013712
:10A0D000002BF6DB2068221C02F0F0F974E7251D46
:10A0E00002F09CF8DBE7251F21682868042205F0B0
:10A0F000ADF900F000FC00233A78D9017F2313402A
:10A1000052B25B180137002AF6DB9B0021680A98DF
:10A110005B421950DCE300233A78D9017F231340D6
:10A1200052B25B180137002AF6DB0A9A9B005B42A9
:10A1300098582168251F13F0D9FADDE300203B78F9
:10A14000C2017F2018405BB280180137002BF6DB7C
:10A150002168251F02F076F8CEE300203B78C2018B
:10A160007F2018405BB280180137002BF6DB216896
:10A17000251F02F081F8BFE300213B78CA017F214F
:10A1800019405BB289180137002BF6DB231F1A68D0
:10A19000206802F0BBF901E20380FFFF247C02008B
:10A1A000387D0200E07B0200945B020037B90200B8
:10A1B000231F1868043B1A68216805F047F931E14C
:10A1C00000233A78D9017F23134052B25B1801373C
:10A1D000002AF6DB0A989B00C31A1968002900D1EF
:10A1E0002DE700223EE000253B78EA017F251D4057
:10A1F0005BB2AD180137002BF6DB0A9AAD00551B98
:10A20000286813F071FA002800D118E728680021A7
:10A2100013F06CFA8CE300203B78C2017F201840D9
:10A220005BB280180137002BF6DB02F019F87FE3F0
:10A2300000203B78C2017F2018405BB280180137B4
:10A24000002BF6DB02F026F872E32368BBE62068F9
:10A25000231FA0601B686360083469E3231F19682B
:10A26000226821601A6063E3221F1368216823605B
:10A27000231C083B18681060196059E3AB786A78B2
:10A280001B021343D349ED186F1851E3AA782068D5
:10A290006E78079205F08EF8EF1C251F2C1C002805
:10A2A00000D145E321E0AA7820686E78079205F096
:10A2B00081F8EF1C251F2C1C002800D038E314E087
:10A2C000AA7820686E780792EF1C05F073F80028D2
:10A2D00000D1FDE209E0AA7820686E780792EF1CB1
:10A2E00005F068F8002800D0F2E20798BA490302A6
:10A2F0001E437618DEE02768261C381C1621221C17
:10A30000083602F0DBF8381C1521321C02F0D6F8B2
:10A310000020011C321C16F072FFAA786B78120222
:10A320001A43109BEF1C0C331093109BBA181A6041
:10A330006B463F33109A197802252943251D29437E
:10A340005160109900228A601A70A0600DE02568A3
:10A35000A24A261C083E954209D16560A5600320EB
:10A360000021321C16F04BFF3560341CE0E2012165
:10A3700029402CD06D10231F012D10D1186897494A
:10A38000251C0C3D19600790216061602A1C032088
:10A39000002116F034FF079A03232A6015E019689C
:10A3A00030688E4A251C103D326007901A60099172
:10A3B0002260032000212A1C16F021FF079B099828
:10A3C0002B60231C0C3B186005233360E6E03368E8
:10A3D0003560251C103D23602A1C032016F00FFF5A
:10A3E00004F0E8FF00280CD07C49109B29605A68D3
:10A3F00001231A406B463F331A70109B0C3B10939D
:10A400007AE22068231C2860043C24680C3B1C6012
:10A41000ABE7109A0C3A109257E5221F1768002BF1
:10A4200000D1BBE00C3C83E2AA786B7812021A439D
:10A43000109BEF1C0C331093109BBA181A602978EC
:10A44000109A40394B4259416B463F3318784900C6
:10A45000014321435160109900228A601A7067E21B
:10A460002068FDF789FC251F002804D007F000FABA
:10A470002D68139568E22368584A2C1C934200D13A
:10A4800056E25B10DBB2012B00D01DE56BE12068CA
:10A4900002F060F834E0089BAA786E78DC602068EF
:10A4A0000792EF1C02F07EF8002805D10798043CC3
:10A4B00003021E43BF193BE2606085E5109B5A68AA
:10A4C00001231A406B463F331A70109B0C3B1093CC
:10A4D0002EE2434B2168994200D1424B236027E290
:10A4E00000203B78C2017F2018405BB28018013702
:10A4F000002BF6DB8300E41A0434211C04F086F8F8
:10A50000206015E200203B78C2017F2018405BB23A
:10A5100080180137002BF6DB8300E41A0434211C79
:10A5200015F04BFBECE700233A78D9017F23134069
:10A5300052B25B180137002AF6DB9B005B421859C8
:10A540002168FEF761FDC3E100203B78C2017F2056
:10A5500018405BB280180137002BF6DB251D17F081
:10A56000B5F99CE5251C2168083D043C2268286853
:10A5700017F0E4F9C0E100233A78D9017F231340B2
:10A5800052B25B180137002AF6DB01339B005B42B5
:10A590001859231F1A68216817F0D0F9083CC7E141
:10A5A00000233A78D9017F23134052B25B18013758
:10A5B000002AF6DB2268251F022B05D1111C286812
:10A5C000064A02F07FFE96E1083C2968206802F006
:10A5D00079FE95E70380FFFF0080FFFF387D0200D2
:10A5E000E07B0200247C020000253B78EA017F2505
:10A5F0001D405BB2AD180137002BF6DB291C221C75
:10A60000206802F019FBC44AAD1813E000253B781E
:10A61000EA017F251D405BB2AD180137002BF6DB48
:10A62000291C221C206802F05FFB2A0AFF231A4023
:10A630002B40D518AD0064197AE1FD1C03239D431E
:10A64000002128680A1C16F0E5FF2F1D261D6060FA
:10A650008BE6FD1C03239D43261F28682268316872
:10A6600016F0D8FF2F1D30607FE6FD1C03239D43AD
:10A6700029796F1D8B00E41A043428680BE0FD1C57
:10A6800003239D432B798021DA43920049002868F7
:10A690006F1DA4181943221C16F0D6FF30E70025C1
:10A6A0003B78EA017F251D405BB2AD180137002BD6
:10A6B000F6DBFF22E809291C5300114003405B1818
:10A6C0009B00E41A231C2D0A01CB2A4001F04EFE08
:10A6D00016E700213B78CA017F2119405BB2891837
:10A6E0000137002BF6DBFF23CA095B001340CAB217
:10A6F0009B189B00E41A083C00202DE000233A78C8
:10A70000D9017F23134052B25B180137002AF6DBD0
:10A71000FF22181C1040DE0955003540411C491924
:10A720008900641A190A1140221C16F068FDE7E638
:10A7300000213B78CA017F2119405BB2891801379B
:10A74000002BF6DBFF23CA095B001340CAB29B183B
:10A750009B00E41A0C3C0120221C02F049F9CFE6D0
:10A76000109B0C3B1093109B0B998B4213D3109BA7
:10A770005B689807F4D5109B24685B6803229343B9
:10A780005C609A601C1C109B08341F68109B0C3B7B
:10A790001093FFF7ADFB07F06BF8089A0020D46028
:10A7A0007EE16B78022B01D1043C0BE0002B09D138
:10A7B000109B0B98834200D26CE19868002802D16C
:10A7C0000C3BF6E7206802F099FB67E10D9E2168DB
:10A7D000231F002E02D000210D9E0D911868321CFF
:10A7E00011AB02F01DFB01280FD1119A2F1C226022
:10A7F00007F03EF86B463F33109A1B7808991343D5
:10A800004F60CC600B6101204AE1002806D1119B0A
:10A81000043C002B00D1414B23600CE002281BD1EB
:10A8200011983F4914F094FF002810D01198FDF7BB
:10A830003BFA043C2060002E7AD0301C394914F0D9
:10A8400087FF002874D007F013F813967CE007F018
:10A850000FF8119B139377E0043C00203B78C20172
:10A860007F2018405BB280180137002BF6DB251FD4
:10A8700021682A6802F060FB3DE000213B78CA01B4
:10A880007F2119405BB289180137002BF6DB251CAC
:10A8900001CD02F063FBFFF702FC2068251F16F0D4
:10A8A000C9FC29E0AF2B04D8803B5B000122FFF7F5
:10A8B000AAFBBF2B04D8B022D31A9B00FFF7BAFB28
:10A8C000CF2B07D8C022D31A20680A9A9B00985031
:10A8D000043C2DE0D52B05D8181C2168D03801F098
:10A8E000E5FC0DE6F92B09D8251F181CD63822687F
:10A8F000296801F0BDFE28602C1C19E00A490B48AC
:10A9000014F01CFF041C06F0B3FF0C9B08990633DF
:10A910009B00CB185C60BBE0FFFFFF3F387D02006F
:10A92000545C02004C5F020063B90200405E02000A
:10A930005C4BDA6A002A01D1FFF7DAFA0022DC6AFE
:10A94000DA6206F095FF1394139804F003FB56495E
:10A9500000F0C0FE002827D0089A5368002B23D0AF
:10A960001A78432A0ED1987859780002DA1C031C11
:10A9700008980B43C168D31843600B1C043BC360A9
:10A98000FFF783FA5E2A0FD1089A1398D468231D23
:10A99000D360FDF789F9089B60605B6808980593B0
:10A9A00001334360FFF771FA139814F0CBFE0028CF
:10A9B0003CD0139B3D4A934238D03D4A934235D018
:10A9C000089911A80968119112F0AFFE041C11A892
:10A9D00012F0ABFE051C11A812F0A7FE089A089B06
:10A9E00052681B68011C0293D31A1B1B0122119C85
:10A9F0002078002812D0C60904D11F260640013451
:10AA0000400908E00F26E0270640FF00000107404C
:10AA10006078023438431194B34204D213982B1C4B
:10AA2000FDF7D0F902E09B1B1218E0E76B463F33BD
:10AA30001A78002A08D0109A516801220A401A7028
:10AA4000109B0C3B1093F1E7109A0B98824218D39D
:10AA500001221A70109B08991B68139A4B60109B77
:10AA60005C6803239C43109B9A60124B63601398AD
:10AA7000A06004F06FFA089BE0600C34DC60FFF724
:10AA800004FA0C9B089806339B001399C31859606D
:10AA9000022005E00848094914F050FE041C50E764
:10AAA0001FB0F0BD902E0020545C0200645A0200DA
:10AAB000C45F0200387D0200E45902007DB9020043
:10AAC000094A38B51378002B0CD1084C2578EDB223
:10AAD000002D07D1006801231370237003685B68A1
:10AAE0009847257038BDC0461F2E00201E2E00201E
:10AAF00010B5041C00F02AFA074B021C0833DB6F68
:10AB00000649074817F06BFA05F02EFA012C01D11F
:10AB100005F048FA034810BD902E00209CB90200B1
:10AB2000F0950200387D020010B586B0041C03A920
:10AB300002A804AA05AB03F09FFC049B07480093FE
:10AB4000059B07490193029A039B17F048FA012CD1
:10AB500001D103F0CFFC034806B010BDF095020010
:10AB6000B1B90200387D0200F8B5051C10200C1C9C
:10AB7000161C1F1C16F003FB011E0AD044608460E3
:10AB8000A4190760C460034A281C034B16F0DDFFBC
:10AB9000FFE7F8BD190302002F030200F0B5456876
:10ABA00087B00F1CA96805A805910292039312F0C3
:10ABB000BCFD061C05A812F0B8FD03225043331C4F
:10ABC00009331818800016F0CDFA6A6805994260BA
:10ABD000084BAA6803608B1AC360039B0662041CBF
:10ABE00000930830291C3A1C029BF8F7ADFC201C8E
:10ABF00007B0F0BD606A020038B5051C88680C1CFF
:10AC000014F080FD0349021C231C281C17F0E7F9EF
:10AC100038BDC046F9B9020010B5041C082016F072
:10AC2000A1FA024B4460036010BDC046186A0200DE
:10AC3000F8B5041CC0681D1C002801D118602FE065
:10AC4000201C63692030834208D1164B994206D0FC
:10AC50001549164814F072FD06F00FFE1960144EE7
:10AC60006368201C0830111C77687360FFF7F2F8E6
:10AC70007760012807D00023E36002280AD06369C7
:10AC80001B682B600CE063691B682B60002B07D1ED
:10AC9000E36005E0236A07339B00E41864682C60D6
:10ACA000F8BDC046387D020017BA0200985E020067
:10ACB000902E002013B501AB141CFFF7B9FF01283B
:10ACC0000DD0019B174C02281BD0A34228D0002B8B
:10ACD00026D0012101AA144814F01DFD0DE0002C1E
:10ACE0000DD0201C04F036F9104900F0F3FC0028C8
:10ACF00005D00F480F4914F021FD06F0BEFD019864
:10AD00000FE0181C04F026F9074900F0E3FC0028C6
:10AD100001D10198F1E70198FCF7C6FFA042F8D1F4
:10AD2000002016BD387D0200545C02004C5F02001A
:10AD3000E45902004DBA020010B50C1C022801D1E2
:10AD4000486800E0886802F0D9F80649021C2068CB
:10AD5000FFF7B0FF002804D1034814F0E2FC06F02E
:10AD60008CFD10BD387D0200545C020008B5002245
:10AD7000FFF7A0FF002804D1024814F0D2FC06F02F
:10AD80007CFD08BD545C020008B502490022FFF7B3
:10AD900091FF08BD387D020013B5124C124A211CE8
:10ADA00001ABFFF745FF012802D0022805D017E0CC
:10ADB0000E490F4814F0C2FC10E0019804F0CAF8E4
:10ADC0000C4900F087FC00280AD1019804F0C2F871
:10ADD000094900F07FFC002802D1019806F04DFDE2
:10ADE000201C16BD387D0200645A02004DBA0200D4
:10ADF000E45902004C5F0200545C0200F0B5061CEE
:10AE00008BB00024184B1948E158F5F739FA03AF15
:10AE1000E05104341C2CF5D1142373430024019316
:10AE200000257959124816F067FC0435301C04F0EF
:10AE300057FC1C2DF5D10625AB000D48F95816F02E
:10AE40005BFC301C04F04CFC013DF5D20134082CB5
:10AE500005D0E307E4D4019804F042FCE0E702F0F7
:10AE600095FE0BB0F0BDC046E86A020030790200E2
:10AE70002400002008B51920FFF7C0FF004808BDD6
:10AE8000387D0200826801231340836000487047C8
:10AE9000387D0200826801210A4201D0034B00E0A4
:10AEA000034B8A438260181C7047C046E07B020057
:10AEB000247C020008B5406818F043F8002801D04F
:10AEC000014800E0014808BDE07B0200247C02004C
:10AED00082B0000C012804D1034B9A68023210435F
:10AEE000986002B07047C0460400002082B0000C99
:10AEF000012804D1034B9A6802321043986002B0D3
:10AF00007047C0461000002037B5084CC02501210D
:10AF100000950A1C201C064B07F066FE0095201CBD
:10AF200002210122034B07F05FFE37BDBC29002040
:10AF3000D1AE0000EDAE0000034B82B001AA043395
:10AF4000DA6702B07047C046902E0020034B82B0F3
:10AF50000433D86F01ABC01A02B07047902E0020A6
:10AF6000014B0833D8677047902E002008B503497D
:10AF7000034814F0DCFB06F080FCC0469E0700008E
:10AF8000E459020007B5064B1A1D0833D16FDB6F79
:10AF900001AA8A1A9A4201D3FFF7E8FF07BDC0460B
:10AFA000902E002073B5041C0D1CA368002B0AD042
:10AFB000354AE868904206D0EB58002B03D0E3688E
:10AFC00004221A605EE0A86B00281FD016F0C9FCAE
:10AFD00061680022CB0006211943FAF7FDFE002824
:10AFE00014D0267C4268E36821680020002E0AD134
:10AFF000081E07D02449EC688C4203D023498D42B7
:10B0000000D00069291C01F0EDF93BE02368002B1A
:10B0100003D1686B002814D134E0227C002AF8D1D7
:10B02000194AE8689042F4D0184A9542F1D018695C
:10B030006168E26801F010FAE3681B68002BE8D051
:10B0400020E0694601AA16F0EBFC0099002919D00E
:10B05000002500990D4B481E019A85420CD2A9008B
:10B060005158994206D0201CFFF79CFFE3681B68EB
:10B07000002B07D10135ECE7054809188900555820
:10B080009D4292D173BDC0466DB300006C57020063
:10B09000FFFFFF3FF0B515688BB0071C0191161C30
:10B0A000002D21D14368586B00281DD004AA03A9A4
:10B0B00016F0B6FCBF68019A05AC05976260A56002
:10B0C000E6602574039A95420AD2049AAB00995817
:10B0D000201CFFF767FF3368002B05D10135F1E72E
:10B0E000201C0249FFF75EFF0BB0F0BD6C57020059
:10B0F00008B54A68014916F072FF08BD6DBA020032
:10B1000070B58AB0051C0E1C141C002105A8142261
:10B110000091019118F014FF2023079300AB0893CE
:10B12000059529681B23002C02D0042C06D1192375
:10B1300005A80693FFF736FF022105E01A2305A8AC
:10B140000693FFF72FFF03210098042805D12869F3
:10B15000311C221C04F07AF90BE0002809D00022EF
:10B1600002AB02950396049401F000F9042C00D080
:10B1700001480AB070BDC046387D0200F0B5204BD2
:10B1800082008BB0D25805AD0023019003AF05912A
:10B190006A600E1C1422281C096803937B60AA6055
:10B1A000EF602B74FFF7FEFE039C042C05D1316980
:10B1B000019801F07BF8041C1EE0002C0DD0201C2F
:10B1C000311C16F014F8019B041C022B14D103F05F
:10B1D000D7FF0124400004430EE0019B022B0BD15A
:10B1E0002523281C31686B60FFF7DCFE3B68002BD1
:10B1F00002D1760001243443201C0BB0F0BDC046C0
:10B200004C760200F0B5131C0C1C161C1F215A1E94
:10B21000934189B0C91A03AD04910821002301AA02
:10B220000591071C2168281C019302932B74039439
:10B230000692FFF7B7FE019B002B08D1002E06D126
:10B240001E23281C21686B60AE60FFF7ABFE0198DF
:10B25000042819D1206903F07DFE164BC2689A427A
:10B260000ED1002E07D02368586816F0ACFB011CE5
:10B27000381C16F0EAFD802221693243381C0BE0AD
:10B280002169381C321C07E0002808D0211C15F069
:10B29000AEFF0022011C381C03F076FE08E0201CE3
:10B2A00016F0B9FC0449021C231C381C16F097FE4A
:10B2B00009B0F0BDD17B00007ABA020038B5041C99
:10B2C0000D1C0B4916F0C1FD6968201C002203F01B
:10B2D0005BFE201C074916F0B8FDA968201C00225F
:10B2E00003F052FE201C044916F0AFFD38BDC046E5
:10B2F0008CBA020013B6020086B3020010B5C4680F
:10B30000002C06D1426804490448FCF7EDFC06F025
:10B31000B4FAA04710BDC04695BA0200985E02007C
:10B3200073B50E1C01AA694616F07AFB00252C1C89
:10B33000009A954213D20199AB005B58094A934297
:10B340000BD0094AD968914202D03360013404E03D
:10B35000586B311CFFF7E4FF24180135E8E7201C87
:10B3600076BDC0466C5702006DB30000F0B58FB0DB
:10B370000493436B05900D1C029006A9181C0392C0
:10B380000193FFF7CDFF061DB600301C059F15F099
:10B39000E9FE0021041C80C013F0C5FB321C201CF8
:10B3A000103A1030002118F0CBFD012D04D1049B80
:10B3B0001B68042B00D183E009A809220023426006
:10B3C00007AF0C2202998260C760037407937B6009
:10B3D0000993FFF7E7FD0798042807D10698291C71
:10B3E000C668039A049BB047206123E0002821D05F
:10B3F000039A2A4305D1012105AB00F0B7FF041CD5
:10B4000018E0039B5C002C190134A400201C15F0EB
:10B41000A9FE059B061C221F08C0049918F06EFDAA
:10B420003868691C039A331C00F0A0FF041C301C10
:10B4300015F0CEFE201C03F08DFD059B98423FD1F8
:10B440000023082209A80299089307930B930994F3
:10B450000A92FFF7A7FD079B002B31D003992943E0
:10B4600005D1081C07AA15F0CAFE051C1BE0039BAA
:10B470005F00EF190237BF00381C15F073FE079B01
:10B480003A1C0360089B061C4360083A0499083084
:10B4900018F034FD281C0399321C15F0B0FE051C71
:10B4A000301C15F095FE084B9D4209D0281C16F063
:10B4B000B2FB0649021C0648FCF716FC06F0DDF953
:10B4C000201C0FB0F0BDC046387D0200B2BA0200A9
:10B4D000985E0200F8B5041C0F1C161C1D1C14F00D
:10B4E00075FF002809D1201C16F095FB0949021CA4
:10B4F0000948FCF7F9FB06F0C0F9042801D12069DE
:10B5000002E0211CFEF7A0F9391C321C2B1C00F0B4
:10B510002DFFF8BDDABA0200985E0200F0B5154BB7
:10B5200089B0161C8200D5580C1C0C220021071C67
:10B53000684618F005FD03A81823456083600025C0
:10B5400000AB2168C36005740394FFF72BFD0098DE
:10B55000042805D12169381C321C01F089F807E064
:10B56000002805D00120291C6A46029615F047FEE6
:10B5700009B0F0BD04750200F0B585B0071C0D1CC4
:10B58000081C161C01A902AA16F04AFA0199029891
:10B5900000238B420CD09A008258D468002C05D12D
:10B5A000526824492448FCF79FFB26E00133F0E76A
:10B5B0003C2015F0E9FD214B041C0360204B476043
:10B5C0008360204B4563C3601F4B866303611F4B41
:10B5D00003A943611E4B83611E4BC3611E4B036273
:10B5E0001E4B43621E4BC362281CFFF799FE0128C5
:10B5F00005D911481B4914F0A1F806F03EF9A06BDB
:10B6000016F0AFF94E210022FAF7E6FB051E0DD029
:10B61000436803221A4009D11B685B68D12B05D10E
:10B62000031D0121104814F05CFF6860201C05B068
:10B63000F0BDC046F6BA0200985E0200C87402006F
:10B6400005B200006DB30000D5B400007DB100006C
:10B650001DB500005704020001B100004D050200B5
:10B66000070502001FBB02000476020037B51C1C50
:10B6700000230D1C0093081C0323111C0122FBF75F
:10B680003BFE012D09D0032D0BD12068F6F75CFAA3
:10B690006168A268FFF770FF09E0206803F05AFCB8
:10B6A00005E00349034814F049F806F0E6F83EBD0A
:10B6B0004DBB0200985E020038B5051C0C200C1C26
:10B6C00015F050FD024B45600360846038BDC046F4
:10B6D0008C75020037B50D1CA84225D00324044008
:10B6E00001D0002021E0114B01689942F9D1406B53
:10B6F0000028F6D001AA694616F092F9009A002AAD
:10B70000EFD0009A019B511E8C4208D2A20098589B
:10B71000291CFFF7DFFF002806D10134F1E70449B7
:10B72000521892009858D7E701203EBDC874020015
:10B73000FFFFFF3F30B585B0051C0191081C8A074B
:10B7400011D10B68154A934204D10123029301AB36
:10B75000039306E0124A934205D102A903AA16F008
:10B760005FF9002411E00F490F4813F0E7FF06F0DE
:10B7700084F8039AA30099580C4B994209D0281CCD
:10B78000FFF7A8FF002804D10134029B9C42F0D3AC
:10B7900001E0074800E0074805B030BDC87402006A
:10B7A000D08B020069BB0200985E02006C57020059
:10B7B000E07B0200247C020008B5820703D1064B1F
:10B7C00002689A4205D00549054813F0B7FF06F014
:10B7D00054F8FFF7AFFF08BDC8740200A2BB020017
:10B7E000985E0200F0B50E1C496887B0041C151C59
:10B7F000002901D0002A04D1201C311C15F015F8B5
:10B8000058E0131C0F331B095918029314F077FFEB
:10B810000F22A768B06873682A4000D110220299ED
:10B82000CD182549491949008C4667440497224F91
:10B83000D9194900401884460498191C0390002027
:10B84000002913D067463F88013907431020801A2A
:10B850000197C740381C039F3880019F3804039F1D
:10B86000023F039702277F42BC44E9E7049F5B0045
:10B87000FB1A1027BA1AD040188002984700DB1B29
:10B880009F1C0D4BC2185200381C18F059FB002D9C
:10B8900007D06B00FB18023B1B88002B01D1013D38
:10B8A000F5E7217865600123327899431A400B1C33
:10B8B0001343237007B0F0BDFFFFFF7FF0B5141CEA
:10B8C00023780A78DB07D207D20FDB0FD2B2DBB2C4
:10B8D00085B0051C0E1C9A422DD1002A28D148683B
:10B8E0006268904201D2261C0C1C281C616814F06E
:10B8F00006FFB6686368A968A7680296181C00224C
:10B90000002807D0029EBC5AB65A013834408C52E7
:10B910000232F5E75B00CB18023B8B4204D20233C4
:10B92000591A491069604BE01A88002AF4D0F6E7EA
:10B93000284801F0CBFB002B01D1261C0C1C7168A0
:10B94000281C013114F0DBFE7268B168A6686468D7
:10B95000AF68141B012003943B1C0290002A13D0F3
:10B960000398824210D03488013AE443A0B2029C8A
:10B970008446201C0C8860440440000C1C8002900B
:10B98000023302310236E9E70193141C002C0DD07A
:10B99000029E1148013C30180E88039006401E801C
:10B9A000039E0233360C02960231EFE701985200F3
:10B9B0008218023ABA4209D20232D71B7F106F6056
:10B9C0002B78012293432B7005B0F0BD1388002B18
:10B9D000EFD0F1E7E6BB0200FFFF0000F0B5151C59
:10B9E00085B0061C0C1C8868926849686B6814F066
:10B9F000CCFE002802DA231C2C1C1D1C22782B787C
:10BA0000D207DB07D20FDB0FD2B2DBB26168301C8A
:10BA10009A4235D114F073FEAB6869686568A06816
:10BA20006D1AB26800900393AC46081C00230028EE
:10BA300008D0039F009DFF5AED5A01383D43D5526F
:10BA40000233F4E700984900471851186346081C70
:10BA5000002B05D03D88013B058002370230F7E717
:10BA600065466B00C9188A1A5210317872602278C4
:10BA7000012399431A400B1C1343337005B0F0BDEA
:10BA800014F03DFE014801F021FBC04604BC020059
:10BA9000F0B5151C85B0061C0C1C886892684968B6
:10BAA0006B6814F072FE002802DA231C2C1C1D1C8B
:10BAB00022782B78D207DB07D20FDB0FD2B2DBB2B2
:10BAC0006168301C9A422ED114F019FE6968A7688B
:10BAD0006468AB68641AB26803930194081C00237D
:10BAE000002807D0039CFD5AE45A01386540D5521E
:10BAF0000233F5E749007F18019B5118081C002B01
:10BB000005D03D88013B058002370230F7E7019DF3
:10BB100033786C0009198A1A52107260012293431B
:10BB2000337005B0F0BD14F0EAFD014801F0CEFA23
:10BB300021BC0200F0B595B00C935B68041C0D1C91
:10BB40000992002B02D143604B6042E10998002624
:10BB50004068011C0131201C14F0D1FD0999A06836
:10BB600049680A1C01325200002118F0E9F9099ACB
:10BB700066605268281C111C013114F0C0FD281C9D
:10BB8000099914F052FEAF6806970C9F0698BF689B
:10BB900007970C9F079A7F680A97A7680A9B0D97DB
:10BBA0006F68391C14F0F1FDB04205D10D9E0123E0
:10BBB000686033806360FCE0002801DA6660F8E0CA
:10BBC0000A988549079B421852009B1808931B88C6
:10BBD00019B20596002905DB059E5B0001369BB274
:10BBE000B6B2F5E7079E0232B44610929444331C75
:10BBF000002263450BD2198805980E1C86403243FB
:10BC00001A801022121A11418AB20233F1E7069A01
:10BC10007E000021013791530B976F60B71CD71935
:10BC20000E97131C0E9FBB420BD21888059A071C57
:10BC30009740394319801021891A084181B2023393
:10BC4000F0E7089F0B983F881397069FBE190A9F3D
:10BC5000C21B614862600D9F12185200BA180E9202
:10BC60006F680A980F97874261D9B71E30883B8862
:10BC7000000418431399119709F000FA0B901098DB
:10BC8000079F301A12900197021C0023B2421BD268
:10BC900001980B99078810884F43874202D2C11B35
:10BCA000994209D8381AC31858421080180C9BB210
:10BCB0005F1EBB411B1802E0CB1A138000230198C2
:10BCC000023202300190E1E73288934208D39A1A97
:10BCD0005342110C92B23380531E9A4153180BE019
:10BCE000D31A3380002307E032880B9889183180FB
:10BCF0000138090C5B1A0B90002B0ED00798129A92
:10BD00000021B242F0D21788BC460788023067444F
:10BD100079181180090C0232F3E70E9E0B9F0F9BDE
:10BD20003780013B023E0E966B60119E98E7002320
:10BD3000089F079EB7420DD3089E059F3288023E9A
:10BD4000111C39410B4373801023DB1B9A4093B2C3
:10BD50000896EDE70F9F2048069E3B185B00F318FE
:10BD60000022069EB34214D31988059F081C38414F
:10BD700002431A801022D21B91408AB2023BF0E7A4
:10BD8000154F0D9EDA195200925B002A0ED1013B2D
:10BD900063606368002BF3D108E00F4F069EDA1949
:10BDA0005200925B002A04D1013B6B606B68002B50
:10BDB000F3D1099F0C9E3A783378D207DB07D20F74
:10BDC000DB0FD2B2DBB29A4203D0237801221343B5
:10BDD000237015B0F0BDC046FFFFFF7F436830B54C
:10BDE00084685A00A2180023A24207D9084DAB422A
:10BDF0000BD8023A15881B042B43F5E70278D007CD
:10BE000000D55B420B60012000E0002030BDC04641
:10BE1000FF7F0000F8B51F1C8B1E151C00241E2B75
:10BE200014D80B4B4068595C000109F027F9061C37
:10BE3000A74204D00130032109F020F9041C281E78
:10BE400001D018F073F9033634192418201CF8BDFA
:10BE5000C5BB020010B54468081C03F065F9011C5D
:10BE6000201C17F02DFC014810BDC046387D020093
:10BE700010B54468081C03F057F9011C201C08F099
:10BE8000E1F8014810BDC046387D020008B54068A1
:10BE900008F0B6F8002801D0014800E0014808BDCC
:10BEA000E07B0200247C020010B5041C081C03F097
:10BEB0003BF9011C431005D00549064813F03EFC30
:10BEC00005F0DBFC606807F0D5FF034810BDC046F5
:10BED0003FBC0200A8590200387D020010B5041CC6
:10BEE00003F038F8084A904205D0084A904202D040
:10BEF000074A904201D1606810BD0649064813F018
:10BF00001DFC05F0BAFCC046F07702004477020041
:10BF10008C77020075BC0200985E0200F0B5002725
:10BF200085B00D1C03901E1C081C104B111C0097A3
:10BF30000222FBF7E1F9A81C800015F013F9039B1E
:10BF4000013D0360336803954560041C83603D1C1C
:10BF5000039B9D4207D20135AF00F05900F0FAFA79
:10BF6000E719B860F4E7201C05B0F0BDFFFF000042
:10BF7000F0B51C4B8BB005AC013800930431019433
:10BF80000523FBF7EBF9A068174DA84203D003F097
:10BF9000CBF8C6B200E000262069A8420ED003AA62
:10BFA000022103F08BF9039B1868FFF797FF039BAF
:10BFB000477B5868FFF792FF427B01E0022203278C
:10BFC00079B252B203A805F021FF03A8059905F044
:10BFD000F9FE03A86168E368321C05F075FF281CB0
:10BFE0000BB0F0BD5C7B0200387D020008B503F0A9
:10BFF000FDFA002801D0024800E0024808BDC04612
:10C00000E07B0200247C020000B50B79062805D8ED
:10C0100009F016F81104090906080D0000200DE0CA
:10C020005B4200E0DB435B000120184306E0002B8D
:10C0300003D0034802E0081C00E0024800BDC046EF
:10C04000247C0200E07B020008B50B79002B01D0B4
:10C05000024900E0024915F0F8FE08BDEEC40200F6
:10C06000E6C4020037B50C1C111C00221D1C0092F6
:10C07000201C0123FBF740F9002C06D0286803F0B0
:10C0800099F9002801D0024800E002483EBDC046B0
:10C09000E07B0200247C020030B5124B8BB003AC75
:10C0A00020C90138009301940323FBF757F906A830
:10C0B000616815F040F9237A6868089A009303993B
:10C0C000079B06F011FA021E05D007490748FBF747
:10C0D0000BFE05F0D2FB06A90548F5F7DFFC0BB017
:10C0E00030BDC0462C7C020085BC0200585B0200BB
:10C0F000A84B020030B5114B89B002AC20C9013801
:10C10000009301940323FBF729F9606805A9012234
:10C1100003F0D0F9227A6868069B00920299059A8A
:10C1200006F020FA021E05D005490648FBF7DCFDA3
:10C1300005F0A3FB044809B030BDC046647C020092
:10C14000A8BC0200585B0200387D020070B502F006
:10C1500003F9FEF7F1FE0B4C0026231C251C30359D
:10C1600088331E60E662FBF7D7FB281C012101F033
:10C170009BFF281C6E215E2215F0E0FB65602560A8
:10C18000266470BD902E002070B5144EC300051CAF
:10C19000062470681C4300220430211CF9F71CFEA1
:10C1A000021E18D1306C002807D00430211CF9F78A
:10C1B00013FE002801D040680EE000220848211C30
:10C1C000F9F70AFE021E06D106492A1C0648FBF7AB
:10C1D0008BFD05F052FB506870BDC046902E0020CC
:10C1E000B8940200CCBC0200945B02000A4B10B56C
:10C1F000041C18685B6898420AD0E30006210430EA
:10C2000019430022F9F7E8FD002801D0406802E058
:10C21000201CFFF7B9FF10BD902E002008B5074B7A
:10C22000186C002801D1064807E0043026210022BE
:10C23000F9F7D2FD0028F6D0406808BD902E002006
:10C24000F491020008B5054B0A1C1B68C0000621CA
:10C250000143181C15F072FB08BDC046902E00204B
:10C2600008B5044BC0001B6806210143181C15F0DB
:10C270006FFB08BD902E002008B5054B0A1C5B68BB
:10C28000C00006210143181C15F058FB08BDC0462C
:10C29000902E002008B5044BC0005B6806210143C6
:10C2A000181C15F055FB08BD902E0020012238B552
:10C2B000051C0C1C114219D04B10042808D005286D
:10C2C00010D0081C002D42D1002B3FD020483EE06A
:10C2D000C021090658428B4205D18020C00513F0C9
:10C2E00044F934E0D8434000104330E0022813D131
:10C2F000184B0B40062B08D08B070DD10B689A69A1
:10C30000154B9A4208D1486802E0C80815F051FB65
:10C310004000012420431AE0201C02F01BFE436968
:10C32000002B0DD10D4BAD00201CED5815F073FC0A
:10C330000B49031C2A1C0B48FBF7D6FC05F09DFAA1
:10C34000281C211C9847002801D1EBE7064838BD7E
:10C35000E07B0200070080FF9D2400004C76020075
:10C36000E5BC0200985E0200247C0200F8B5041CC3
:10C370001D1C0F1C161C02F0EDFD0369201C9C46C1
:10C38000002B04D0391C321C2B1CE047F8BD15F0E3
:10C3900042FC0349021C0348FBF7A6FC05F06DFABA
:10C3A000DABA0200985E0200F8B5061C0D1C171CD4
:10C3B0001C1C00290BD0186802F0CCFD7368984251
:10C3C00005D00649064813F0B9F905F056FAB068E9
:10C3D000291C3A1C231CFFF7C9FFF8BD03BD02004E
:10C3E000985E0200F8B5071C0E1C141C1D1C930758
:10C3F00010D11368134A934201D1646808E0124ACD
:10C40000934202D1646850C51BE0104A934201D1A7
:10C410002C6016E0201C02F023FE0028F8D0002F2C
:10C420000ED1201C02F096FD094B984208D10C2039
:10C4300014F098FE074B466003608460286000E0BB
:10C4400090C5F8BD04760200C8750200C8740200E9
:10C45000E8580200F07C0200F7B500231360536037
:10C46000141C061C019102F075FD019A051C0F2A8F
:10C4700005D1836A002B02D00F4B48C41BE0EF6943
:10C48000002F04D0301C0199221CB84713E0A86B80
:10C49000002810D015F065FA019A0621D30019433F
:10C4A0003A1CF9F799FC002805D04268291C301C79
:10C4B000231CFFF797FFF7BDA894020070B5161C68
:10C4C000041C0D1CFFF7C8FF3368002B15D10B4E61
:10C4D000A20707D10A4B22689A4203D16268301C36
:10C4E000084905E0201C15F096FB0749021C301C8A
:10C4F0002B1CFBF7F9FB05F0C0F970BDCC5C02000A
:10C50000C87402001BBD020042BD020073B5041CCA
:10C510000D1C161C02F01EFDC369002B09D004225D
:10C5200000920196201C291C6A469847009B002B0C
:10C530000AD0201C15F06FFB0449021C2B1C044878
:10C54000FBF7D2FB05F099F973BDC04642BD02006E
:10C55000CC5C020013B5041C02F0FCFC436A002B07
:10C560000BD1201C19216A46FFF776FF009B002B98
:10C5700008D0684603F0FAF80EE0201C984700281F
:10C580000AD1EEE7201C15F046FB0449021C0448C2
:10C59000FBF7AAFB05F071F916BDC04664BD0200A9
:10C5A000985E020037B5041C02F0D4FC856A201C9A
:10C5B000002D01D0A84716E00F216A46FFF74CFF77
:10C5C000009B002B05D0281C291C6A4614F017FE7E
:10C5D00009E0201C15F01FFB0349021C0348FBF770
:10C5E00083FB05F04AF93EBD80BD0200985E020063
:10C5F00030B5041C8FB0FEF7C5FC201C02F0AAFC6D
:10C60000856A201C002D01D0A84729E00F216A4629
:10C61000FFF722FF009B002B18D002A805F012F9AB
:10C62000011E07D16A4614F0EAFD051C05F020F949
:10C63000281C15E0039802F08DFC0A49FFF74AF820
:10C64000031C281C002B0BD1039807E0201C15F0BD
:10C65000E2FA0549021C0548FBF746FB05F00DF917
:10C660000FB030BD545C020080BD0200985E020035
:10C67000F0B585B002900F1C161C202802D1914203
:10C6800013D1A6E1029A1B2A01D01E2A0FD1381C11
:10C69000311C02F0F7FC002803D0029B1B2B04D1B5
:10C6A00097E1029A1B2A00D093E1B44892E1029BE1
:10C6B000212B2AD1301CFBF75FFB002807D0381C48
:10C6C000311C13F045F8002800D082E1EDE7032487
:10C6D000344000D065E1AA4B32689A4200D060E154
:10C6E00073689C42E1D2A300F3189D68281CFBF7F5
:10C6F00043FB002800D153E1381C291C13F028F813
:10C70000002800D065E10134EAE70123194200D195
:10C71000F9E04D10334000D1E1E0029A74101D2A77
:10C7200000D93EE1101C08F09FFC1E0021002400EF
:10C7300027003A00420044004600510059006E00B4
:10C740007700A6001E002100240027003A004200C6
:10C7500044004600510059006E007700BF00C3003E
:10C760003C01C700CB002F1C2743ADE02F1C6740C6
:10C77000AAE0271C2F40A7E0002C02DA814882495A
:10C7800024E11F2C71DC814B23419D426DDCC023D1
:10C790001B0623419D4268DB2F1CA74094E0002C20
:10C7A000ECDB1F2C00DD1F242F1C27418CE02F19F0
:10C7B0008AE02F1B88E0281C211CFCF79DFB002829
:10C7C00053D16C4301206400204303E1002C00D1CD
:10C7D000FAE0281C211C13F02BF91BE0002C00D1DF
:10C7E000F2E0281C09F0D4FB051C201C09F0D0FB4A
:10C7F000011C281C08F028FF032398430224644BE3
:10C800002043C018E6E0002C00D1DDE0281C211CEC
:10C8100013F0FFF8071C57E0002C02DB03950127FB
:10C8200017E0281C09F0B4FB032398430227584A59
:10C830000743BF1895E0E3070ED4012C44D00398BA
:10C840006410011CFCF758FB00280ED1039B5B43CE
:10C850000393002CEFD137E0381C0399FCF74CFB15
:10C86000002802D1039A5743E7E7E917281C12F082
:10C870006DFE071C75E0002C00D1A5E00021022010
:10C8800001F0C4FE211C061C281C13F0D1F801275E
:10C8900040003843B060211C281C13F0BAF8B8409F
:10C8A0000743F760301C95E0A54200DBFDE690E011
:10C8B000A54200DCF9E68CE0A54200DDF5E688E063
:10C8C000A54200DAF1E684E07B001A1C7A4002D42B
:10C8D000012018437EE0381C12F047FE7AE0032264
:10C8E0003240022A04D12B4B3340063B5A1E93415F
:10C8F000002B08D0281C09F04BFB321C011C0298AD
:10C90000FAF73EFB37E0029A1F2A2AD1301C02F0C8
:10C9100021FB8369041C002B07D1636A002B16D00E
:10C92000301CFFF717FE041C0BE00298311C3A1C68
:10C93000984700284ED1F0E7391C02F0A3FB0028ED
:10C9400047D1201CFFF754FE0028F5D1ADE6301C7E
:10C9500015F061F91049021C1048FBF7C5F904F005
:10C960008CFF381C02F0F6FA8369002B19D002986C
:10C97000391C321C984700282CD112E0247C02007C
:10C98000D08B0200A859020065B30200FFFFFF3FF1
:10C9900000008080070080FF64BD0200985E0200F6
:10C9A0002E1C029B381C9A000B4BD55815F033F9FE
:10C9B000041C301C15F02FF9084900902A1C231C78
:10C9C0000748FBF791F9CAE70648074912F0B6FE97
:10C9D000C5E7064805B0F0BD047502009FBD020022
:10C9E000985E0200045E020027B20200E07B0200B3
:10C9F000F0B515688DB00695002803D10432029277
:10CA0000051C03E0161C083655680296FF230C1C13
:10CA1000090A19404E001C4033190596029E9B00DE
:10CA2000F65804910396029EF3185E68002E0AD011
:10CA30000020B20708D17D4B32689A4204D1301CE5
:10CA400014F079FF00E0301C049B039AC718002AF9
:10CA500014D1631C7F00DF19B800009714F082FB2B
:10CA6000071C002D01D005600125A8003818A20080
:10CA700002992D1917F042FA019561E0039B9B077B
:10CA80002DD1039A13686A4A934202D0694A9342AD
:10CA900025D1039809A90AAA02F0EEFB099B7F00A1
:10CAA00001331B19DF19B800009714F05BFB071C5A
:10CAB000002D01D005600125A800A20002993818B8
:10CAC00017F01CFA099B281980009A0038180A9957
:10CAD00017F014FA099AA3185B19019330E0231D8B
:10CAE0007F00DF19B800009714F03CFB071C002DF5
:10CAF00001D0056001250195019A029995007819E8
:10CB0000A20017F0FBF90398FFF724FD07900798A0
:10CB1000FFF76EFD0390002812D0019B009A93420C
:10CB200007D3381CD10014F042FB009B071C5B00AC
:10CB30000093019A039B01327B5101920435E6E791
:10CB4000019DA100A800049D3818EA00029D691803
:10CB500017F0D4F9019D059AAC18002E57D0032583
:10CB60003540301C002D21D1304B32689A421DD106
:10CB700014F0F7FE436800932B1C009DAB4246D097
:10CB80008568D9006A58002A03D0151F6E1EB5416A
:10CB900000E0151CEE0707D5A5007A5182687D19C3
:10CBA00051184A6802346A600133E6E7A2210AAAF2
:10CBB000FFF784FC0020011C0AAA14F020FBFFF7F9
:10CBC000C9FCA50002900298FFF712FD061E1ED0B8
:10CBD000009A631C93420BD352000092032A01D89F
:10CBE00004230093009A381C910014F0E0FA071C0B
:10CBF00009AA301C022102F061FB099B02341B6868
:10CC00007B51099B5A687B195A600835DBE7019D07
:10CC10003B1C641B6208291C0698FFF7A7FB041C39
:10CC2000381C14F0D5FA201C0DB0F0BD988002001D
:10CC3000D08B02003063020073B50C1C151C8107F9
:10CC400020D10368224A934207D0224A934219D145
:10CC5000694601AA12F0C9FF03E0694601AA14F06F
:10CC6000DFFE009BA34227D32AD8019AA300D11844
:10CC70000023A3422BD09A00881A0438006801339D
:10CC8000A850F6E7FFF766FC0023061C0093009A05
:10CC9000301CA2420BD2FFF7ABFC00280CD0009B4B
:10CCA0000D49E21A5218920050510133EEE7FFF796
:10CCB0009FFC00280BD003E008480949009A02E0D5
:10CCC00006480849221CFBF70FF804F0D6FD73BD97
:10CCD000D08B020030630200FFFFFF3FA859020023
:10CCE000C4BD0200E7BD0200F0B5161C0A0AFF230E
:10CCF00085B00D1C141C1D4001921C40870741D1BA
:10CD00000768434A974203D0424A97423AD104E027
:10CD100002A903AA14F084FE09E0019F39431942D5
:10CD200001D1306071E002A903AA12F05EFF0298FF
:10CD30006319984262D303998300CB1801930023AF
:10CD40009A00A3420AD0019F0133BF1ABC460427B0
:10CD50007F42BC4467463F68B750F1E7AC00401BD8
:10CD60000919C01AB61812F028FF0399306001356E
:10CD70000C1900230133AB4247D09A00514261584D
:10CD8000B150F7E7FFF7E6FB0023071C0293029A76
:10CD9000AA420BD2381CFFF72BFC00282ED0029B96
:10CDA000EA1A1219920090510133EFE70020011C9A
:10CDB00012F003FF051C381CFFF71AFC031E04D0F9
:10CDC000281C191CFCF720F9F5E7A968A14215D326
:10CDD000A200B618091B5242356001928C00019BDB
:10CDE000984207D0EA68231AD7583318043B1F60CB
:10CDF0000438F4E7281C12F0FDFE06E00649029A0A
:10CE00000648FAF771FF04F038FD05B0F0BDC046E2
:10CE1000D08B020030630200C4BD0200A85902009A
:10CE2000F0B587B01D1C061C0C1C019202F092F894
:10CE30002F4B984206D1301C211C019A2B1CFDF768
:10CE4000F7FE52E0876A2B4B002F07D09C421CD183
:10CE5000301CB8472860002840D146E09C4214D1DD
:10CE6000301C0F2103AAFFF7F7FA039B002B08D110
:10CE7000301CAB2103AAFFF721FB05940120002100
:10CE800001E0381C391C03AA25E0002CF0D10198E0
:10CE9000002829D002F05EF81749FEF71BFC002895
:10CEA0000ED0301CAA2103AAFFF7D6FA039B002B51
:10CEB00006D0201C211C03AA14F0A1F9286013E05D
:10CEC000301CAC2103AAFFF7C7FA039B002B07D045
:10CED0000120002101AA14F092F92860012004E049
:10CEE000019B02202B6000E0201C07B0F0BDC04673
:10CEF000606A0200387D02004C5F020010B5041C1D
:10CF0000FAF73AFF002806D00021201C0A1C0B1C4F
:10CF1000FFF72CFA0AE0201C12F014FC031C201C62
:10CF2000002B03D10248034912F008FC10BDC04693
:10CF3000985E02000FBE02007FB50623C0001843B2
:10CF4000054B01900491052001A9029303930592DA
:10CF5000FCF732FB07B000BD387D0200F0B58BB0A6
:10CF600000AF3A1C0C32051C0C1CFFF775FA3A692D
:10CF7000002A06D02B49221C2B48FAF7B5FE04F0F4
:10CF80007CFCF868002849D1281C12F043FE0028D8
:10CF9000F0D03A1C0C32281C0D21FFF75DFA391C29
:10CFA0000831F868F5F760FA3860201CBD6814F0A5
:10CFB00005FD01352D182B1C0E33DB08DB006A46FE
:10CFC000D21ABE6895463968321C68467D6016F0F4
:10CFD00095FF6D462E23AB55201C14F0F4FC3860F1
:10CFE000201C14F0EBFC0136AE19021C3968301C11
:10CFF00016F084FF7968684601F0EEF90623C00058
:10D0000018430A4B391CBB61FB61094B78613B62D9
:10D010000520012314317B62FCF7CEFABD460BB02C
:10D02000F0BDC04639BE0200505D0200387D0200EE
:10D03000E07B0200F0B5174C0F1C616895B00391BE
:10D040002168061C08A804916260236004F0FAFBC2
:10D05000051E06D00399049B09986160236004F0C3
:10D060000CFC336805A8311C3A1C0193F9F7D8F879
:10D0700001992A1C2B1C05A8F7F776FF14F0B0F8CD
:10D08000051C04F0F5FB0399049B281C61602360D8
:10D0900015B0F0BD902E002010B5041C02F0A0FCCD
:10D0A000074B002804D0181C064912F047FB04E087
:10D0B000181C0549221CFAF717FE04F0DEFBC046D7
:10D0C000285A02004FBE020078BE0200011C08B5BB
:10D0D000024812F033FB04F0D0FBC046405E020071
:10D0E00038B5051C141C14F00FF9024B2560636061
:10D0F00038BDC046C712020010B50C1E7F2C06D8E2
:10D10000012114F082F9002845D0047043E0224B3D
:10D11000994210D8022114F078F900283BD040231E
:10D12000A2095B42134303703F231C4080235B42F0
:10D130001C4344702FE0194B994214D8032114F07A
:10D1400064F9002827D02023220B5B421343A10956
:10D150003F22037080235B42114014401943234354
:10D160004170837017E0042114F04FF9002812D0A9
:10D170001023A20C5B421343210B3F220370802338
:10D180005B42114019434170A109114014401943F9
:10D1900023438170C37010BDFF070000FFFF000034
:10D1A00007B5034B00906846019303F037FE07BDB7
:10D1B000C712020000237F2803D8034B1B5C9B0788
:10D1C000DB0F181C7047C046A6BE020000237F2854
:10D1D00003D8034B1B5C1B07DB0F181C7047C046B2
:10D1E000A6BE020000237F2803D8034B1B5C5B070D
:10D1F000DB0F181C7047C046A6BE020000237F2824
:10D2000003D8034B1B5C5B06DB0F181C7047C04642
:10D21000A6BE020000237F2803D8034B1B5CDB065D
:10D22000DB0F181C7047C046A6BE020000237F28F3
:10D2300003D8034B1B5C9B06DB0F181C7047C046D2
:10D24000A6BE0200002805D0022805D14900012011
:10D25000084302E0014800E000207047247C0200FF
:10D2600008B5024914F0F1FD08BDC046DFC4020054
:10D2700070B5041C0D1C104914F0E7FD6968201CF2
:10D28000012201F081FE0D4E201C311C14F0DDFD49
:10D29000A968201C012201F077FE311C201C14F02B
:10D2A000D4FDE968201C012201F06EFE201C044917
:10D2B00014F0CBFD70BDC04626BF020013B60200BD
:10D2C000BED8020070B5061C10200D1C141C13F0F3
:10D2D00049FF034B466085600360C46070BDC04673
:10D2E000787D020008B50348096801F071FE024824
:10D2F00008BDC046F0950200387D0200027830B5C6
:10D300000724A243022422430270039A7F24058843
:10D310001440044AE4002A402243028041608360B2
:10D3200030BDC04607FCFFFF10B5047807239C43BF
:10D3300019402143049B01707F2104881940094B47
:10D34000C90023400B43039C03806105064B04681E
:10D35000C90A23400B430360059C029B4260836023
:10D36000C46010BD07FCFFFFFF03E0FFF0B50D68D0
:10D3700087B02B681B6B002B02D01B68002B04D1DD
:10D380002D492E4812F0DAF930E0012808D94C680E
:10D390006410621C04D002A8211C13F0B5FF15E034
:10D3A00002A81021012413F0AFFF64420EE02B68A5
:10D3B000281C1B6B311C1F68012201ABB847431CA2
:10D3C00016D0002826D033780A2B27D0631C03D030
:10D3D000631E002C22D01C1C02A8012114F015F899
:10D3E000061EE4D116481749FAF77EFC04F045FA08
:10D3F00001990B2907D1039A012A0BD102A813F036
:10D40000ADFF114815E00123490019430B4812F004
:10D410008EF9EBE702A8012114F065F82B681B6B6D
:10D420001B7BDA0701D5094800E0094802A9F4F797
:10D4300035FB07B0F0BDC04633BF0200585B0200A9
:10D44000285A02004BBF0200387D0200C855020076
:10D45000A84B0200F0B5036887B01B6B061C002BBD
:10D4600002D01B68002B04D12649274812F066F928
:10D4700020E0802102A8490013F046FF8024049D8B
:10D48000640000273368301C1B6B291C1A6801AB31
:10D490009446221CE047431C0ED101990B2903D16D
:10D4A000002F20D119482AE04900012319431648CA
:10D4B00012F03DF904F0E1F9002814D03F18A04221
:10D4C00002D2241A2D18DDE7802102A8490013F0AA
:10D4D00082FF051E04D10E490B48FAF705FCE9E767
:10D4E00080246400CEE7336803971B6B1B7BDA074D
:10D4F00001D5084800E0084802A9F4F7CFFA07B0C0
:10D50000F0BDC04633BF0200585B0200387D020008
:10D5100059BF0200C8550200A84B0200F0B50E68C2
:10D5200089B033680D1C1B6B002B02D01B68002BCD
:10D5300004D15249524812F001F926E0012803D1E2
:10D540002868FFF787FF97E0486801F0EDFD041CAD
:10D55000421CF5D033681B6B1B7BDD0763D5051CB4
:10D56000211C04A813F0D0FE0022019201E0251C2A
:10D570000193002D78D0291C04A813F046FF011E4A
:10D5800005D140484049FAF7AFFB04F076F933681B
:10D59000301C1B6B2A1C1F6803ABB847071C431CBD
:10D5A0000DD1291C04A813F09EFF03990B294ED11D
:10D5B000059D002D58D104A813F0D0FE5BE0A842D1
:10D5C00002D3069805991FE0291A04A813F08BFFCF
:10D5D000002FF6D148E01F23151C9D43C02D1AD003
:10D5E0000F23151C9D43E02D17D007239A43131CCE
:10D5F000F03B5A1E93410433019D5B198B420ED8B8
:10D60000013C8B42B3D20193019D0123425D55B28F
:10D61000002DF1DADFE70223EEE70323ECE75D1EDE
:10D620006D1A2D19A5E704A8211C13F084FE336898
:10D63000221C1B6B301C1D68069903ABA847421CBB
:10D640000CD104A813F08AFE03990B2913D00123EF
:10D65000490019430A4812F06AF896E733680590C2
:10D660001B6B1B7BDD0701D5084800E0084804A9B7
:10D67000F4F714FA00E0074809B0F0BD33BF020028
:10D68000585B0200285A02004BBF0200C855020036
:10D69000A84B0200387D02007FB50C68061C236889
:10D6A0000D1C1B6B002B02D01B68002B04D11849EA
:10D6B000184812F043F821E04868022201A901F05D
:10D6C000F9FE029A022E07D9A86801F02DFD029BEF
:10D6D000021E9A4200D91A1C2368201C1B6B019958
:10D6E0001D686B46A847431C0AD100990B290BD033
:10D6F000490001231943074812F019F804F0BDF856
:10D7000040000123184300E0034804B070BDC04648
:10D7100033BF0200585B0200387D0200036813B576
:10D720001B6B002B02D05C68002C04D10C490D4807
:10D7300012F004F80CE001ABA047431C0AD1019998
:10D740000B290BD0490001231943064811F0EFFFC4
:10D7500004F093F840000123184300E0024816BD8E
:10D7600033BF0200585B0200387D02000A4A0023E2
:10D7700013600A4AFA211360094A89001370094AA2
:10D780001360094A1160094A9366D3661367084B10
:10D7900001221A707047C046A8270020A427002045
:10D7A000212E0020AC27002020000020902E0020F9
:10D7B000222E002010B500231A1CC418647F8C424E
:10D7C00002D301249C4022430133092BF5D1094B9C
:10D7D000D2431C780F21130121401943064BC9B2D3
:10D7E0001970438DD205D20E1A43044BD2B21A706F
:10D7F00010BDC0461005005004050050050500503E
:10D80000F8B5C61DF57F041C0135EFB2391CFFF7D2
:10D81000D1FF092D0ED0084A084B6D001868A95A8F
:10D82000074AF777C26100220262064A8461C26237
:10D8300015F0DEF8F8BDC04606A502005000002035
:10D8400001D80000E516020038B51A4B1A78F0230B
:10D850001A43194B1A70438D1F221A43174BD2B229
:10D860001A70438D5B004385031C0833DA7F013255
:10D87000D2B2032A01D0DA7703E00022DA7720223D
:10D880004285DA7F0E4B52009A18002106234B4343
:10D89000D418D35C05256B4364781B19094CE31835
:10D8A0001C79431801315C770929EFD1FFF782FF1A
:10D8B00038BDC04610050050040500500505005055
:10D8C0009CBF020024000020F7B5324E301CFFF749
:10D8D000BBFF314B31491A68096806321A608A4227
:10D8E00046D300221A602E4B1B78012B03D0022B4B
:10D8F0003ED1301C37E02B4B9D6E002D36D0DB6EB9
:10D90000002B33D0284F3868FEF772FE041E09D171
:10D91000264B1868002803D0FEF71CFE386027E06D
:10D92000281C20E001F016FB214B984202D1281C54
:10D93000211C15E01F4B2340062B05D0A20723D145
:10D940001D4B22689A421FD1201C01A9F4F78CFDBF
:10D95000019B012B18D1007812F069FC011C281CD6
:10D9600013F0CAFE04E0154913F0C6FEFFF7FEFEF1
:10D97000F31D0022DA77328DFF235B001A4207D0B5
:10D98000301CFFF73DFF03E00D4B01221A70EDE75D
:10D99000F7BDC04624000020AC2700202000002056
:10D9A000212E0020902E0020A4270020A827002050
:10D9B00074650200070080FFC85502006065020020
:10D9C000202E0020F0B585B002930AAB164C1B78D0
:10D9D0000025071C081C019203930E1CA566E56632
:10D9E0002567FEF7B7FD114B019A1860104BA7662B
:10D9F0001D70104BE0661A60039BAB4202D00E4BC9
:10DA000026671E600D4B00221A700D4A012111700D
:10DA1000029A002A06D01A78002A01D130BFFAE70C
:10DA200000221A7005B0F0BD902E0020A42700201F
:10DA3000202E002020000020A8270020222E0020D9
:10DA4000212E00207FB5214B00220D689A66DA66F0
:10DA50001A67061C1E4A48680C1C0240062A05D09C
:10DA6000830720D11B4A036893421CD103A9F4F712
:10DA7000FBFC039B002B26D0012B04D1007812F075
:10DA8000D6FB011C15E0032E04D1A06801F04CFB6D
:10DA9000021C01E0C8225200002361680093281C88
:10DAA000FFF790FF0FE001F055FA0B4B984204D1BD
:10DAB0006168281C13F020FE05E00849084811F0B1
:10DAC0003DFE03F0DAFE074804B070BD902E002042
:10DAD000070080FFC85502007465020067BF02009E
:10DAE000985E0200387D0200F0B5134B8BB004AC99
:10DAF00040C90138009301940623F9F72FFC049DD7
:10DB0000A368281C0393E76801F024FA0B4B9842A2
:10DB100006D1281C391C0522039BFCF777F9051C4C
:10DB2000217D6268237C301C0091291CFFF74AFF8D
:10DB300003480BB0F0BDC0465C7F02007465020074
:10DB4000387D020030B50F4B89B003AC20C90138D5
:10DB5000009301940523F9F701FC02A90398F4F757
:10DB600083FC237C0299039AFCF762F9011C207B59
:10DB70006268237A0090281CFFF724FF024809B04E
:10DB800030BDC046E07F0200387D0200094B002214
:10DB90001A70094A02211170084A1168084A0639A8
:10DBA00011601A78002A01D130BFFAE700221A70FA
:10DBB0007047C046222E0020212E00202000002089
:10DBC000AC27002008B5FFF7E1FF014808BDC046BB
:10DBD000387D020010B5042901D8042A02D90B4867
:10DBE0000B4903E0092B05D908480A4911F0A6FDA5
:10DBF00003F043FE052461438A1882181371012241
:10DC00009A40131C028D1343038510BDA8590200CE
:10DC100087BF020024B80200F8B548680C1C0F68E2
:10DC200001F082FA061CA06801F07EFA051CE0688B
:10DC300001F07AFA311C031C2A1C381CFFF7CAFFBA
:10DC40000048F8BD387D020008B5042901D8042A2F
:10DC500005D90649064811F071FD03F00EFE0523B3
:10DC600059438A188018007908BDC04687BF020052
:10DC7000A859020008B50423E02252009918A022F6
:10DC800089000320D20501338850112BF4D10248BA
:10DC900006F00CF808BDC046D4290020002806D0A4
:10DCA000012809D14B68DB085B00184307E04B688B
:10DCB000DB0803D0024802E0002000E00148704782
:10DCC000E07B0200247C020010B5041C0C2013F041
:10DCD00049FA034B446003600023037210BDC04641
:10DCE0001C82020010B5041C102013F03BFA044BF8
:10DCF0000360237A6468037100238460C36010BDED
:10DD0000B481020010B5041C0C2013F02BFA034B55
:10DD1000446003600023836010BDC046E0800200C1
:10DD200008B5043010F02DFF004808BD387D020012
:10DD3000F8B50A7A134B9200041C0D1CD15814F04C
:10DD400084F81149201C14F080F8281CFFF7CAFF42
:10DD50000126071C381C13F065FD051E0CD0002E93
:10DD600003D1201C094914F070F8201C291C012241
:10DD700001F00AF90026EDE7201C054914F065F8CA
:10DD8000F8BDC04638800200D2BF020013B60200C0
:10DD9000D5BF0200F7B50B681C4A041C0D1C93424A
:10DDA00003D05A681A4914F01AF9201C194914F0C2
:10DDB0004CF8002301930127281C01A913F011FD41
:10DDC000061E15D0002F03D1201C134914F03DF876
:10DDD0000122201C316801F0D7F81049201C14F0F2
:10DDE00034F87168201C012201F0CEF80027E3E727
:10DDF000201C0B4914F029F82B68044A934203D0E5
:10DE0000201C084914F021F8F7BDC0469880020094
:10DE1000D8BF0200DCBF020013B6020092BA0200B3
:10DE200038B40200BED8020038B5151C1A1C1C1CE0
:10DE3000F7F7D2FF002802D0416800290ED1291E31
:10DE400008D1022C05D10849084811F077FC03F0ED
:10DE500014FD0749012C05D1416003E0022C01D1DA
:10DE600000234360081C38BDDEBF0200885F02004B
:10DE7000387D020030B585B0002501A9041C01954C
:10DE800013F0AFFCA84205D10A490B4811F056FC2B
:10DE900003F0F3FC626802A9083A62600368042296
:10DEA00002934368039324C0022000F0AFFB05B047
:10DEB00030BDC046E6BF0200885F020073B50D1C8E
:10DEC000141C1B2809D01F2837D1081D111C002243
:10DED000F7F782FF00282ED131E00320014208D15C
:10DEE0000B68184A934204D1204002D1216899421C
:10DEF00026D00323234022D1134A206890421ED10A
:10DF00006A686068D108C208914218D10193281C40
:10DF100001A913F066FC061E0DD0201D31680022F9
:10DF2000F7F75AFF031E0AD07068596801F0AAF883
:10DF30000028ECD103E0054802E0002000E004489E
:10DF400076BDC0465C80020098800200E07B020043
:10DF5000247C0200F0B5141C126887B00F680D1CF9
:10DF6000D108012200920223061CF9F7C5F9022EFE
:10DF700022D168680323034016D10268D1682E4A73
:10DF8000914211D12A68904216D00593686805A97C
:10DF900013F027FC061E0FD03168381D0122F7F759
:10DFA0001BFF76684660F1E7FEF7D4FA039003980A
:10DFB000FEF71EFB002801D1002533E0FEF7CAFA68
:10DFC000051CFEF715FB0290281CFEF711FB061C32
:10DFD000281CFEF70DFB029B002B03D0002E01D066
:10DFE000002805D01549164811F0A8FB03F045FCA0
:10DFF000381D02990122F7F7EFFE4660D7E7A268C5
:10E00000EE009159002911D00B1F5A1E9341012295
:10E01000134206D0381DF7F7DFFEA3689E19766815
:10E020004660013562689542E9D301E00B1CEEE7DA
:10E03000044807B0F0BDC04601E1000005C0020081
:10E04000A8590200387D020010B5041C0C2013F002
:10E0500089F8034B446003600223037210BDC0467D
:10E060001C82020010B5041C0C2013F07BF8034B3B
:10E07000446003600123037210BDC0461C8202008D
:10E0800008B504300022F7F7A7FE002805D104499F
:10E09000044811F053FB03F0F0FB406808BDC04694
:10E0A000DEBF0200885F020008B5024B08C010F016
:10E0B0003AFD08BD9880020070B5061C48680C1C2B
:10E0C000FEF748FA051C01F04FF9022E01D9A668A7
:10E0D00000E00A4E002800D0401013F0F7FB041CAB
:10E0E000281CFEF785FA011E05D0201D0122F7F736
:10E0F00073FE4660F4E7201C70BDC046387D020008
:10E10000F0B5071C89B000201E1C0D1C019213F0F5
:10E11000DDFB0E4B041C07609F4203D103790422F0
:10E1200013430371019B2B430DD03368AA00B2182F
:10E1300005A801990394049310F007FD681C03A936
:10E1400005AAFFF707FF201C09B0F0BD5C800200A4
:10E1500008B5002A02D113F0FBFB11E0042A0DD10F
:10E1600004300022F7F738FE002805D1054906489B
:10E1700011F0E4FA03F081FB406802E013F0DEFBEB
:10E18000024808BDDEBF0200885F0200387D020041
:10E1900010B50B1C041C002906D0054A0968026052
:10E1A0009A6B0023F9F70EFE201C03F066FBC046B5
:10E1B000105F0200F0B5041C89B005920493661844
:10E1C000012A01D0242A0BD93B493C4811F0B6FA68
:10E1D00003F053FB2078FEF7EDFF002803D0013455
:10E1E000B442F7D30CE023782B2B02D101340190F9
:10E1F00008E001902D2B05D101220134019201E0AC
:10E2000000230193311B201C05AA12F0A2F8241848
:10E2100002940025B4420DD22778381CFEF7E2FFA5
:10E220000599002804D03A1C303A03928A420ED352
:10E23000102904D0019B002B17D06D4215E020233C
:10E240001F433B1C613B052BF4D8573F0397281C09
:10E25000FAF752FE059B002819D15D43039A551920
:10E260006A006A4013D40134D4E76D0001231D43D2
:10E27000029B9C4215D0B44206D22078FEF79AFF4A
:10E2800000280ED00134F6E7B44212D009E0029A19
:10E2900007A80792B11A019A11F08DF9079C051C85
:10E2A000E6E707490548059AF9F71EFD0499FFF7C7
:10E2B0006FFF281C09B0F0BD56C00200A85902002B
:10E2C00079C00200074BDB68002B09D05A689042E6
:10E2D00004D3821A04329200D05802E01B68F3E79C
:10E2E000181C7047902E002070B5114D041CEB686F
:10E2F0009868DB6883420FD30230C00012F032FF0F
:10E30000EA68D36856680260926899195200826080
:10E3100000224160C260E860EB68D96858684A1C16
:10E32000043189000138DA608018CC5070BDC046D5
:10E33000902E0020074B4118884205D25A01D3186D
:10E34000027801305340F7E7D8B2002800D101200D
:10E350007047C04605150000024B034ADA600022F0
:10E360005A677047902E00207C820200F0B585B07D
:10E37000071C0E1CFFF7DEFF164B0390DC68002C19
:10E3800024D0E368221C04339B001032E31802926D
:10E390000193151C019A954216D22868039A0378B6
:10E3A00093420FD14378B3420CD10230391C321C56
:10E3B00015F095FD002805D1029BE81A63688010CE
:10E3C000C01804E00435E5E72468D8E7201C05B050
:10E3D000F0BDC046902E0020F7B50E1C0190FFF74F
:10E3E000C5FF021E43D1234CF51C606F002812D0DC
:10E3F000E76FA16FEB198B420DD9691812F0E4FE9B
:10E40000071E05D1606FE16F12F0D1FE676702E071
:10E41000A26FAB18A367636F002B11D180277F2DEC
:10E4200000D92F1C381C12F0AAFE6067002804D106
:10E43000281C12F097FE2F1C60670023A767E36774
:10E44000E36F626FED18311C0198D718E567FFF78D
:10E4500071FF321C38707E700199B81C15F04EFDAA
:10E46000BE190023B370381CFFF73EFF021C101CBE
:10E47000FEBDC046902E0020F0B51D1C0023036099
:10E480000B6013602B60194B85B0DC68071C03918F
:10E49000161C002C24D0164B9C4221D03B680399BB
:10E4A00001333B600968E2688B1803990B60E268EE
:10E4B000231C043292001033A218934206D202CBDE
:10E4C00030684978033041183160F6E72A68201C2B
:10E4D000029201F061FC0299246843182B60D8E78E
:10E4E00033682A68D3182B6005B0F0BD902E002049
:10E4F0007C8202000C4B70B5DC68002C13D00B4BF7
:10E500009C4210D0E668251C0436B6001035A619CA
:10E51000B54206D204CD06490232064813F05FFD2B
:10E52000F6E72468E9E770BD902E00207C820200A7
:10E53000DEC00200F095020070B50E1C1049041CEC
:10E5400013F083FC002573689D420ED2002D03D08A
:10E55000201C0C4913F079FCAB00F3189968201CBF
:10E56000012200F011FD0135EDE7012B03D1201C44
:10E57000054913F06AFC201C044913F066FC70BDC9
:10E580002BBF020013B60200B7D60200BED80200AD
:10E5900070B50C1C01281CD0002804D002281CD106
:10E5A000104E002504E04B68002B18D00E4817E0F1
:10E5B00063689D4209D2AB00E31899680220FDF719
:10E5C00075FE401036180135F2E776000120304321
:10E5D00006E04B685B00184302E0002000E00348BF
:10E5E00070BDC046588C0200E07B0200247C020013
:10E5F00010B5041C0C2012F0B5FD034B4460036001
:10E600000023836010BDC0461C8C020070B5041C42
:10E610000D1C002812D0861CB600301C12F0A2FD82
:10E62000074B44600360002D09D0083E0023B3422D
:10E6300005D0EA58C1188A600433F8E7014870BD74
:10E64000D08B0200588C02007FB5061C0D1C141CD8
:10E6500007282AD002D8052805D063E0031C193BFF
:10E66000042B3FD95EE0101C00F074FC3049FDF72C
:10E6700031F8002858D062686B680021D018FFF785
:10E68000C5FF6B68291C061C9A000831083015F07C
:10E6900035FC6868636802308000211C083130183E
:10E6A0009A0015F02BFC311C3FE003A9101C00F070
:10E6B00079FD0021884238D00398884210DD6A68CD
:10E6C0005043FFF7A3FF041C231C0833281C0093AE
:10E6D000042108306A68039B10F0C9FC211C24E067
:10E6E000144922E0081C00F035FC201C00F032FC2C
:10E6F000114B426A9A4207D0201C0D4911F069FF64
:10E70000041E01D10D4910E0231C6468291C083146
:10E710006A6808330094301CF8F73AFD0028F1D0FD
:10E72000074902E0002100E0011C081C04B070BD94
:10E73000D08B0200588C0200F1E50000247C02001E
:10E74000E07B020030B50B1C85B0041C042A2CD1E0
:10E7500003250D4041681FD1154A186890421BD10E
:10E76000081C01AA191CF8F7D7FC002802D111488F
:10E77000FEF7ACFC019A0298291C801AFFF746FFAD
:10E780000199051C6B680231890008309A006118F4
:10E7900015F0B4FB281C09E01A1C2068002300F0C7
:10E7A000A1FD02308000005900E0002005B030BD1E
:10E7B000787D0200DDA50200F0B51D1C85B00023A8
:10E7C0000C1C0093081C111C1A1C0123F8F794FD63
:10E7D000002C2BD02868820703D1164B02689A427E
:10E7E00025D0102012F0BEFC041C2868FDF7B2FEF4
:10E7F0000025039004260398FDF7FAFE071E0BD0B0
:10E80000B54205D3F100201C12F0D1FC7600041CA7
:10E81000AB001F510135EEE7281C211CFFF7F6FE67
:10E82000051C201C12F0D4FC281C00E0024805B096
:10E83000F0BDC046D08B0200588C0200F7B5CD1C4D
:10E84000AD00071C281C0E1C019212F08BFC064B1D
:10E850002A1C47608660041C03600C3A01990C3046
:10E8600015F04CFB201CFEBD7C8C0200F0B5071C93
:10E87000443787B0041C381C019112F092FD002629
:10E880002069411C18D00A2804D1201C13F015F966
:10E890000126F5E7FEF78EFC002823D12369232B00
:10E8A00008D1201C13F009F92369581CE8D00A2B61
:10E8B000F7D1E5E75C2B07D0E369256A0199A363EB
:10E8C000E563002912D117E0201C13F0F6F8226945
:10E8D0000A2A07D0E369266AA363E6630423403467
:10E8E00023702BE3201C13F0E8F8C9E7012B03D1B8
:10E8F000012D01D00622B4E1636A002B04DA221C48
:10E900000721403211702FE0002B06D0221C062177
:10E9100040321170013B6362ECE1002E38D0A26AF4
:10E92000002A35D1231C052140331970BD4E626287
:10E93000226B606B91194900095A013D8D4200D14B
:10E94000D8E113D9E16A8A4207D30831490012F0AD
:10E950002EFCE36A60630833E362236B606B5A1C2E
:10E960005B0022631D52636A0133D4E7216BAD4E15
:10E970008A195200125A954205D2626A0139013A47
:10E9800021636262F2E7954200D1B3E102226AE1BB
:10E990002069411C1BD1226BA24E616B93195B0055
:10E9A0005A5A231C4033002A00D15CE105221A7018
:10E9B000002363629B48236B1A185200525A002AA4
:10E9C00000D197E1013B2363636A013BF1E727280C
:10E9D00004D0031C223B5A42534100E00123002B88
:10E9E00031D1752807D01023011C99430B1C623BC1
:10E9F0005A42534100E00123002B09D06369272BC1
:10EA000003D0223B5A42534100E00123002B1AD18C
:10EA10000023722803D16369623B5A425341002BA1
:10EA200007D1622803D16369723B5A425341002BDC
:10EA300031D0A369272B03D0223B5A42534100E037
:10EA40000123002B27D0251C4035752804D1201C1C
:10EA500013F033F800261CE062280ED1201C13F0BE
:10EA60002CF8206900260396722800D070E1201C43
:10EA7000012613F022F803966AE100260396722815
:10EA800000D069E1201C13F018F820696228EED04C
:10EA90000126039660E1FEF799FB0122131C002872
:10EAA00008D123695F2B04D07F229A429B415B42AD
:10EAB00000E0131C002B26D0231C082240331A70C0
:10EAC000217C381C12F0C6FC201C12F0F6FF2069D5
:10EAD000411C00D10EE1FEF779FB0122131C002836
:10EAE00008D123695F2B04D07F229A429B415B426D
:10EAF00000E0131C0120002B02D12069FEF772FBFD
:10EB0000C207DDD4F6E02069FEF76CFB002808D0D0
:10EB10002169251C40352E290CD10A232B70002693
:10EB200033E023692E2B55D16069FEF75BFB00288B
:10EB3000EED14FE009232B700026302925D16669DC
:10EB4000202333430126622B1FD06F2B1DD01E1CA8
:10EB5000783E73425E4118E02D2916D02069411C91
:10EB600000D1C7E0002E17D12023011C994345296D
:10EB700012D10A2365212B70381CFEF7BDFA201C28
:10EB800012F09BFF21692B29E6D1381CFEF7B4FA5D
:10EB9000201C12F092FFE1E7FEF718FB00280AD0D4
:10EBA00021692E2910D02023081C9843031C4A3BBE
:10EBB0005A42534109E02069FEF714FB0028EFD1C7
:10EBC00022692E2AECD095E00123002BDDD00A2308
:10EBD0002B70DAE721692E2902D00026124D30E091
:10EBE000381CFEF789FA201C12F067FF2269002307
:10EBF0002E2A03D163692E3B5A425341251C4035CE
:10EC0000002B13D0381C2E21FEF776FA2E21381C4B
:10EC1000FEF772FA201C12F050FF201C12F04DFF7C
:10EC20000D2304E0FFFFFF7FE4D602004A232B7090
:10EC300060E0B9420FD06B1C652F06D11D1C013658
:10EC400001352F78002FF4D105E0632FF6D0452F42
:10EC5000F5D1013EF2E7201C12F02FFF002F04D166
:10EC60000122231C40331A7044E00135371C2B78F5
:10EC7000652B0CD16B7820690137984205D1201C97
:10EC8000013512F01AFF3E1C01E00235EFE72B7848
:10EC9000452B09D16B7821690122994213D1201C9F
:10ECA00012F00BFF3E1C0CE0632B0AD16B7822693B
:10ECB00001379A4205D1201C12F0FFFE02353E1C9E
:10ECC000D5E79F4B9A5D231C40331A70231C4033B9
:10ECD0001B7804221E1C9643422E01D0442B02D1E5
:10ECE000A36A013305E0432E01D0452B02D1A36A6C
:10ECF000013BA362211C40310B78082B00D01DE1A1
:10ED0000E56CA46C00238F4A980080580022861876
:10ED1000A24203D132785042424106E0875CAE5CA9
:10ED2000B74201D10132F2E70022002A0CD0212B98
:10ED300007D1854B88331A680E23002A02D110238D
:10ED400000E00E330B70F9E00133222BDBD1F5E04C
:10ED50000C232B70012602E00B232B700026236965
:10ED60000596222B02D02726029600E00293201C53
:10ED700012F0A3FE2069029E0023B04203D1606915
:10ED8000831B5A42534101260496002B07D0201CB6
:10ED900012F093FE0326201C12F08FFE049600262C
:10EDA00020690190013000D1B2E00499012903D11A
:10EDB000019A0A2A00D1ABE0049B9E4200D3AEE048
:10EDC00001980299884204D1381C0136FEF794F963
:10EDD0009AE0019E5C2E00D090E0201C12F06DFEA7
:10EDE000039E2569002E02D0381C01996DE0622D2A
:10EDF00029D013D84E2D4ED008D8222D69D0272DDA
:10EE000067D000260A2D00D17EE047E05C2D60D05F
:10EE1000612D00D18EE0552D40D11CE0742D00D124
:10EE20008AE007D86E2D10D0722D12D0662D35D104
:10EE30000C2551E0762D0AD00DD30223782D16D063
:10EE4000681C60D02AE0082546E00A2544E00B252E
:10EE500042E00D2540E0059E002E04D0381C5C21C8
:10EE6000FEF74AF938E00823752D00D104231E1C53
:10EE70000025201C12F021FE2069013E0190FEF7C2
:10EE8000BDF9002850D0019812F0AAFB2D014519B8
:10EE9000002EEED11BE02D48FEF718F92B1C303B5D
:10EEA000072B10D81D1C03266369303B072B0ED897
:10EEB000013E002E0BD0201C12F0FFFD2369ED0057
:10EEC000303B5D19F0E7381C5C21FEF715F9691C31
:10EED00019D01F4B9D420CD8059E002E05D1381C21
:10EEE000291CFEF709F9059E0EE0FF2D01D8E9B2B5
:10EEF00006E0231C012240331A7004E0019EF1B2A7
:10EF0000381C12F0A7FA0026201C12F0D6FD47E7A5
:10EF10000498864203D2231C032240331A70381C03
:10EF2000311C12F0E0FAE5E6231C012240331A708E
:10EF3000051CCEE70725CFE70925CDE707B0F0BDD3
:10EF4000B9D60200B88C0200902E002026D702000D
:10EF5000FFFF1000C3070BD4074B0340062B09D05B
:10EF600003230340022B01D0006804E0034802E0C1
:10EF7000034800E003487047070080FF3057020055
:10EF800018520200C855020070B50D1C041C161C56
:10EF9000FBF7F8FF281CFFF7DDFF8368002B04D088
:10EFA000201C291C321C984704E042680249201C9E
:10EFB00013F015F870BDC0469CD7020008B5031CBD
:10EFC0000A1C0248191CFFF7DFFF08BDF09502007C
:10EFD000F7B5041C081C0E1C10F0B4FB00282AD046
:10EFE00001AA301C6946F8F725FF009A002A22D0B2
:10EFF000201C164912F029FF009D154BEF1EED183D
:10F00000AD00002F17DB019B201C5A595B195B6870
:10F01000104912F0E4FF019A201C53199A68002A43
:10F0200003D10D4912F011FF02E00C4912F0D7FF95
:10F03000033F0C3DE5E7311C201C0222FFF7A4FF33
:10F04000201C054912F001FFF7BDC046A1D7020000
:10F05000FDFFFF3FC5D702009BB00200DAD70200D8
:10F0600010B5041CFFF776FF054B0069984203D0EA
:10F07000431E9841C0B202E0201C11F08DFA10BD71
:10F08000D5B4000038B5051C0C1C884241D0224B79
:10F09000984201D100203DE09942FBD00123184263
:10F0A00003D01942F6D10D1C041C1C4B2A1C1A401B
:10F0B000062A05D0A90711D1194A296891420DD114
:10F0C0002340062B05D0A207E4D1154B21689942B5
:10F0D000E0D1281C211CF3F773F91BE02340062B19
:10F0E000D8D0A20703D10E4B21689942D2D0281C58
:10F0F000FFF730FF8369002BCCD01B20291C221C7A
:10F1000098470028C6D0074BC01A43425841C0B2A6
:10F1100000E0012038BDC046387D0200070080FFB6
:10F12000C8550200E07B020008B5104B984219D088
:10F130000F4A0123904217D0184201D0184114E021
:10F14000820706D10B4B02689A4202D1F8F7FEF90A
:10F150000BE012F060FD0849021C0848F8F7C4FDF6
:10F1600002F08BFB002000E0181C08BD247C02008C
:10F17000E07B020018520200E3D70200985E020012
:10F1800008B5C20705D4830706D1054B02689A4229
:10F1900002D110F027FA01E0FFF7C6FF08BDC04614
:10F1A0001852020038B50F4B0D1C0124984202D1B1
:10F1B00000230B6012E00C4B984201D10C600DE073
:10F1C000031C234001D0401007E0810707D1074A04
:10F1D0000168914203D1F8F7B9F92860231C181C83
:10F1E00038BDC046247C0200E07B020018520200B9
:10F1F00008B51B4B98422DD01A4B98422CD0C10712
:10F2000003D5401006F0C4FE28E00323184206D1BF
:10F21000154A0168914202D110F0EDF91EE0021C7E
:10F220001A400023022A04D1104B0340063B5A1E09
:10F230009341002B05D0FF22D20580180323984369
:10F240000CE012F0E8FC0A49021C0A48F8F74CFDF1
:10F2500002F013FB002001E0FE20800508BDC0463F
:10F26000247C0200E07B020018520200070080FFAD
:10F27000FBD70200985E020010B583070CD103682B
:10F280000A4CA34202D112F0CBFB0EE0084CA34281
:10F2900002D110F0AAFC08E012F0BDFC0549021CE6
:10F2A0000548F8F721FD02F0E8FA10BDD08B020006
:10F2B0003063020015D80200985E020013B50C1CE2
:10F2C00001A9FFF7D9FF019BA34206D00349221CE5
:10F2D0000348F8F709FD02F0D0FA13BD38D8020050
:10F2E000A8590200F7B5061C0C1C151C1F1CD307DF
:10F2F00002D55510019510E0101C01A9FFF752FF2F
:10F3000000280AD1281C746812F085FC1249031CDD
:10F31000221C1248F8F7E8FC19E0019B002B01DAE7
:10F32000E3180193019B002F08D0002B02DA002381
:10F3300001930EE0A3420CD901940AE0002B01DBFB
:10F34000A34206D3726806480649F8F7CDFC02F0DE
:10F3500094FA0198FEBDC04665D80200985E02008E
:10F36000045B020089D8020010B5041C820710D18A
:10F370000E4B02689A420CD10D4B0340062B03D171
:10F38000C00812F01BFB00E0806840000123184316
:10F390000AE0201CFFF7DEFD4369002B03D0211C8F
:10F3A0000120984700E0181C10BDC046A84B020081
:10F3B000070080FF174B70B5041E9C4227D0164DE6
:10F3C000A84201D1012023E0144B98421FD001260E
:10F3D000064004D04410601E8441E0B218E0FFF7FC
:10F3E000B9FD4369002B08D0301C211C9847002828
:10F3F00003D0401B4542684107E0201CFFF7B4FFE3
:10F400000028DFD00138431E9841C0B200E0002040
:10F4100070BDC046247C0200E07B0200387D020003
:10F4200010B5041CFFF7A0FF002809D1201C12F022
:10F43000F2FB0449021C0448F8F756FC02F01DFADE
:10F4400010BDC0469FD80200985E020070B5041C33
:10F450000D1C161CFFF77EFD036A002B05D0201C37
:10F46000291C321C984700281AD10E4D201C002E52
:10F4700005D112F0D0FB0C49021C281C06E0042E1A
:10F4800008D112F0C8FB0949021C281CF8F72CFC13
:10F4900002F0F3F912F0BFFB0549021C281CF5E746
:10F4A00070BDC046985E0200C0D80200EBD80200D2
:10F4B0000CD9020008B512F0C4FB002805D103499D
:10F4C000034810F03BF902F0D8F908BD39D9020021
:10F4D000985E0200024B0022FE3302481A857047F4
:10F4E000902E0020387D0200024B0122FE3302489C
:10F4F0001A857047902E0020387D0200044BFE33A1
:10F500001B8D002B01D0034800E003487047C04624
:10F51000902E0020E07B0200247C020008B5F6F764
:10F5200035F9014808BDC046387D020010B5104CC1
:10F53000201C13F026FB002818D0201C403013F0AC
:10F5400027FA0C4B1B68984203D10B4B5A6EDA62B8
:10F550000CE00A4B3F211A8801320A400849098809
:10F560008A4203D01988074C1A80605410BDC046E7
:10F5700024290020B0270020902E0020122E0020E9
:10F58000102E0020232E002008B5094B00221A80DF
:10F59000084B094809491A8013F0F8FA084B012270
:10F5A000524208481A6010F0BCF8074B586608BD74
:10F5B000122E0020102E0020242900202DF50000FE
:10F5C000B027002060590200902E002010B5041CC6
:10F5D000431C03D0034B586EF8F7E6FB024B1C604C
:10F5E00010BDC046902E0020B0270020034B188885
:10F5F000034B1B88C01A431E98417047102E0020F1
:10F60000122E0020084B094A19881288914201D114
:10F6100030BFF7E71A880649885C1A883F21013213
:10F620000A401A807047C046102E0020122E00207B
:10F63000232E002038B5041C4518AC4205D0217893
:10F64000024813F09AF90134F7E738BD6429002025
:10F6500070B5041C4618B4420DD02378064D0A2B11
:10F6600003D1281C0D2113F088F92178281C13F0F0
:10F6700084F90134EFE770BD6429002010B5041C43
:10F68000002C08D0211E082900D908210248641A3C
:10F69000FFF7D0FFF4E710BD5ED9020038B5051CB6
:10F6A000041C002C08D0211E082900D90821044878
:10F6B000641AFFF7BFFFF4E7281CFFF7DFFF38BD30
:10F6C00067D9020010B5041C14F030FD211C021C87
:10F6D0000023024812F060F810BDC046240000204C
:10F6E00070B5051E13D00A4E301C03F017F94519EA
:10F6F000041C854205D230BF301C03F00FF9A04234
:10F70000F9D830BF301C03F009F9A842F9D370BD15
:10F71000D428002030B58DB0041C684602F092F861
:10F72000011E0FD1221D012011F069FDE268051CA8
:10F730005310013301225B001343E36002F098F899
:10F74000281C0DE00198FFF705FC064A031C002069
:10F75000934205D0044A934202D0019802F08DF8FA
:10F760000DB030BD545C0200045B020010B5041CF7
:10F77000102011F0F7FC044B0360236843606468B9
:10F7800001238460C36010BDDC8D0200F7B5002842
:10F7900005D13949394A3A4812F021FC6AE00D682E
:10F7A000281CFFF7D7FB061C4068CE2804D16D68E3
:10F7B000281CFFF7CFFB061C00233249DA00505803
:10F7C000854203D18A1851682D480AE00133592B2C
:10F7D000F3D12B4C2C4B201C9D4201D09E4203D1D7
:10F7E0002A4912F032FB45E0294912F0F8FB281CA7
:10F7F0000021FFF7E3FB201C2649726812F0EFFBA3
:10F80000254B9E4203D1281C0FF000FF0CE0234B38
:10F810009E4200D12E1CB06B00282BD0820729D12C
:10F820001F4B02689A4225D112F09BF8061E21D088
:10F830000025726895421DD2B068EB00C3181F689E
:10F84000002F15D05B681749201C019312F0C7FBED
:10F85000381C0021FFF7B2FB1349201C12F0BFFB3C
:10F8600001980021FFF7AAFB201C104912F0B7FBFA
:10F870000135DEE70E48FEBDC9A9020070D90200BD
:10F88000F0950200188E0200506902007EDD020031
:10F890009ADD0200A2DD0200E4570200C8740200F3
:10F8A0009880020058B80200B2DD02009BB002004E
:10F8B000387D0200F7B52D4B191CFC31181C4A6A23
:10F8C000A0301C1C824250D9043A1068231C8C338F
:10F8D0001E684A62431C9A08B75C1D1C032215402F
:10F8E0006D002F41191A3A400133022AF3D09434A3
:10F8F00023680001181889000029DCD0026813076A
:10F9000030D11A4B1C1C94342468A2422AD31D1CEB
:10F9100098352D68954225D9121B1C1C8C342468FF
:10F9200016099209A41827780194351C0324254050
:10F930006D00AC4662463D1C15412540012D11D19C
:10F940009440019A27431C1C1770FC3490277F00B9
:10F95000626AFF18BA4203D2131D6362166001E0A7
:10F960009C331D6001390430C6E7F7BD902E00209E
:10F9700070B50F230E1C9E43051C4121301A05F063
:10F980007DFB0E4C8101231C90331860231C8C33AB
:10F990001D60231C711A94331960231C021C9833B8
:10F9A000281C00211E6014F0CBFA221C0023FE3418
:10F9B000FC32D362E3840123238570BD902E0020A6
:10F9C000024BFE33DA8C0132DA847047902E00202D
:10F9D000024BFE33DA8C013ADA847047902E002015
:10F9E000034BFE33D88C431E9841C0B27047C046CB
:10F9F000902E0020F7B5002400900191019DAC42AB
:10FA000037D0009DA300EA5811072ED1194B191CBD
:10FA100094310E68B24228D3191C9831096891427A
:10FA200023D9191C8C31921B0E6810099209B61843
:10FA3000011C03221140490037788C466546391C69
:10FA400029411140012910D1AA40174337701E1CCB
:10FA5000FC3690256D00726A5F19BA4203D2131DFD
:10FA60007362106001E09C331960FFF723FF0134DB
:10FA7000C4E7F7BD902E002008B5FFF7A1FF0748A7
:10FA80000022031C9C331A60031C021CFC33A032AE
:10FA900020215A62FFF7AEFF08BDC046902E00201D
:10FAA000F8B52C4C0025221C9C321368AB4222D0A6
:10FAB0001560231C221CFC33A0325A62231C903395
:10FAC0001B689B009D42ECD2221C8C321268AB0852
:10FAD000D15C03232A1C1A40520011410B40032B16
:10FAE00007D1221CFC32536A191D51621D60FFF7B9
:10FAF000E1FE0135E2E7191C221C903212689200E7
:10FB0000934221D2221C8C321268980810180327C5
:10FB100005781E1C3E4076002A1C32413A40022ADB
:10FB200005D0BA4209D0012A0CD1111C01E00029EC
:10FB300008D0B740BD43057004E00222B2409543AF
:10FB4000057000210133D7E70023FC34E362FFF79F
:10FB50003FFFF8BD902E0020274AF0B5111C131C62
:10FB60009831943309681B68CB1A111C90310D68C9
:10FB70008C3203601668002343608360C3600361B6
:10FB80004361AD00191CA9422ED08A08B75C03243A
:10FB90000A1C2240520017413A1C2240012A12D866
:10FBA000012B03D1C4680134C46004E0022B02D1EC
:10FBB0000469013404614469A34200D94361012A04
:10FBC0000CD0002A06D0022A0CD14268013301323F
:10FBD000426007E083680133836002E043680133D9
:10FBE0004360131C0131CEE742688468130143600F
:10FBF00023018360F0BDC046902E0020F7B5424F30
:10FC0000051C3B1CFE33DC8C0F35061C2D09002C1B
:10FC100001D0002077E0002DFBD0188D43425841E1
:10FC2000394A111C131C90318C32FC33096812685C
:10FC3000DB6A01910092019A934229D20099CA5C31
:10FC4000910704D10134AC4202D39B0026E000248A
:10FC50000C210A4205D10134AC4203D39B0001338D
:10FC60001CE0002430210A4205D10134AC4203D308
:10FC70009B00023312E000243F218A4305D1013466
:10FC8000AC4203D39B00033308E000240133D2E7E6
:10FC90000028BED1F5F77AFD0120C1E71A1B551CDB
:10FCA000012C04D118485C1CA408FC30C462009CE0
:10FCB000A808211803202840400001248440201C6B
:10FCC0000C780232204308709A420FD8381C8C30CE
:10FCD000006891084118032010404000022484402D
:10FCE000201C0C78013220430870EDE794373C6803
:10FCF0002A010133A4185A1B1201921BA0190021DA
:10FD000014F01EF9201CFEBD902E002070B5214A73
:10FD1000131CFE33DB8C002B3AD1010738D1131CA6
:10FD200094331B68984233D3111C9831096881427F
:10FD30002ED9111C8C31C01A0968030980090D5C89
:10FD40001C1C03210C4064002541294001291FD1BE
:10FD5000111CFC31CC6AA04200D2C862101C8C304D
:10FD6000056803211E1C9C080E402C1976000D1CF2
:10FD7000B5402E1C25780133B543257000689C08DA
:10FD8000045D181C08404000044121400229E5D0D0
:10FD900070BDC046902E0020031C0F2070B5184087
:10FDA00027D115490A1C94321268934222D30C1CA5
:10FDB000983424689C421DD98C319B1A0C681A090E
:10FDC0009B09E55C111C0323194049000D412B40A0
:10FDD000012B0FD1531C9908665C1D1C03210D409B
:10FDE0006D002E41981A314001330229F3D00001F1
:10FDF00000E0002070BDC046902E0020F0B50E1C23
:10FE0000584987B00B1C0392FE33DB8C041C002B7B
:10FE100000D09DE0002804D1301C211CFFF7EEFE2D
:10FE20009DE0002E00D18FE00F20204000D091E017
:10FE30000B1C94331A68944200D290E00B1C983348
:10FE40001B68A34200D88AE00D1C8C352D68A21ACD
:10FE500013099209AF5C029503221D1C15406D0029
:10FE60002F413D1C1540012D79D190310968321C7C
:10FE700089000F3204911209591C8446049881426A
:10FE800017D2029F8808385C03270F407F00384153
:10FE9000071C03200740022F01D1013507E0002F86
:10FEA00007D10127BC4467467819904201D201313D
:10FEB000E4E7AA421AD01BD29A185D19111C294BEB
:10FEC000A9420DD08C331B688808181803260B1C18
:10FED00033405B009E4003780131B3430370EEE78B
:10FEE000FC33D96A92088A4200D2DA62201C36E0DA
:10FEF0006746E9198A421AD8ED1899188D420FD22F
:10FF00001848A9088C3000680227411803202840AF
:10FF100040008740381C0F78013538430870ECE703
:10FF20001201921BA019002114F00AF8DEE70398D1
:10FF3000002811D0301C0021FFF760FE061E0DD0F6
:10FF40002A01211C13F0DAFF201CFFF7DFFE05E079
:10FF5000002004E0181C02E0039800E0301C07B009
:10FF6000F0BDC046902E002010B588B002A8FFF763
:10FF7000F3FD094C0499029A0091039B201C074948
:10FF800012F02DF80799059A0091069B201C044950
:10FF900012F025F808B010BDF0950200E5FD020052
:10FFA00008FE0200F7B5444D444E2B1C94331A68EA
:10FFB000301C434912F013F800242B1C90331B68AB
:10FFC0009B009C4226D2A00634D12A1C8C32126897
:10FFD000271C00920099BA088A5C391C94460322B7
:10FFE0001140490060460841104202D101379F424A
:10FFF000F0D33A1B7F2A12D99209301C314911F0F3
:020000040001F9
:10000000EEFF3C1C3F239C432B1C90331B689B0042
:100010009C4204D3301C2C4911F017FFF7BD2B1C58
:1000200094331B6822019A181203120B301C2749C3
:1000300011F0D5FF2A1C8C321268A308D15C032270
:10004000231C13405B0019410B1C1340022B21D0D1
:1000500093421DD0012B01D02E2226E02B1C94337D
:100060001B682201D3581A4A934215D0194A934269
:1000700014D0194A934213D0184A934212D0184A06
:10008000934211D0174968228B420ED14D220CE0C9
:100090006D220AE0742208E0542206E04C2204E0BB
:1000A000442202E0462200E04222301C0E4911F0B8
:1000B00096FF013481E7C046902E0020F0950200A3
:1000C0003CFE020057FE02009BB0020073FE0200DD
:1000D000D08B02003063020098800200305702008B
:1000E00024590200E45702004CA50200014B186895
:1000F0007047C046902E0020014B58687047C0469C
:10010000902E0020F0B51A4D87B02B68071C0020F8
:100110000C1C009311F0DAFB28600190206811F0AC
:100120005FF8009B061C2B60022F04D0A068FEF72E
:1001300011FF051C00E00F4D6368211C0831B81E3B
:100140000393FEF763FA019B04900593281C03AB0D
:1001500003210022FCF70AF9074B041C9E4203D03E
:10016000301C211C0DF0C2FA201C07B0F0BDC046A7
:10017000902E0020C8740200387D0200032270B562
:100180000240041C0023022A04D1104B0340063B0A
:100190005A1E9341002B13D0FF23DB05E6180325DD
:1001A000AE43301C002105F02BF800280CD0802332
:1001B0001B06F618AE430220054B3043C01804E07E
:1001C000201CF0F731F800E0201C70BD070080FF14
:1001D0000000808010B5FCF7BDF9041C201CFCF762
:1001E00007FA002805D0FFF7E5F80028F6D1024805
:1001F00000E0024810BDC046247C0200E07B020003
:1002000010B5FCF7A7F9041C201CFCF7F1F9002835
:1002100005D0FFF7CFF80028F6D0024800E00248EA
:1002200010BDC046E07B0200247C020007B5044BF1
:1002300001906946022000220093F2F797FB0EBD61
:10024000EE02000008B5FEF70BFF002801D00248BF
:1002500000E0024808BDC046E07B0200247C0200AA
:1002600037B5FEF761FF01AB7F2802D81870012176
:100270003FE0224A840990420BD840225242144364
:100280003F2210408022524210431C7058700221BD
:100290002FE01B49020B88420ED8202149420A4315
:1002A0001A703F2180220C405242084014430243FE
:1002B0005C709A7003211CE01249884213D8102107
:1002C000850C494229431970151C3F218022524256
:1002D0000D400C4008401543144302435D709C7070
:1002E000DA70042105E0084908480FF027FA01F008
:1002F000C4FA181C0122F1F705FC3EBDFF070000FF
:10030000FFFF0000FFFF10007BFE0200A859020063
:1003100008B5021C02490A20FCF7AAF908BDC0462C
:10032000A603000008B5021C02490A20FCF7A0F948
:1003300008BDC0461E040000F0B585B002900D1C3B
:10034000101C2E4900220393F5F746FD002800D02B
:100350004068029B0090012B03D00024271C0194CD
:1003600035E02868FCF7F6F800240190271C019876
:10037000FCF73EF9051E18D0009B002B05D0181C79
:10038000291C10F034FF061C00E02E1C002C09D0A4
:100390000398311C3A1CFCF76BF9194B984201D0B9
:1003A000251C3E1C2C1C371CE1E7201E23D11549BF
:1003B00015480FF0C3F901F060FA009B002B0AD139
:1003C0002E68002F0DD12F68019601340435029B51
:1003D0009C42F2D10EE00098296810F008FF061C3C
:1003E000EFE70398311C019AFCF742F9044B98425D
:1003F000EBD1E8E7381C05B0F0BDC046C6050000EB
:10040000E07B02009CFE0200A859020037B501A95A
:10041000051CF2F729F81E4B041C2B400199062BF2
:1004200005D0AB072AD12A681A4B9A4226D1201C44
:1004300011F0B2F80190012822D123785AB2002A93
:1004400004DB207801234000184320E07F2018407F
:1004500001344023184202D098435B10FAE7237816
:100460003F22191C9143802905D18101181C10409D
:1004700001340843F3E70FF078F808E00129E0D0F1
:100480000549019A0548F7F72FFC01F0F6F93EBD42
:10049000070080FFC8550200B5FE0200985E02000A
:1004A000F0B587B0141C02900391101C244900225F
:1004B000F5F792FC2349051C0022201CF5F78CFC63
:1004C0000123041C04930593002D08D068681E4B7B
:1004D000984204D004A9F1F7C7FF071C00E01B4FA6
:1004E000002C08D06068184B984204D005A9F1F799
:1004F000BBFF051C00E0164D0024029B154E9C42DC
:1005000012D0002C07D0002300930193301C391C1B
:10051000049A00F00FFB039AA300D158301C00226C
:10052000FEF732FD0134E8E7002300930193301C0D
:10053000291C059A00F0FEFA034807B0F0BDC0463A
:10054000D6040000DE040000387D020059B8020025
:100550009BB00200F09502007FB50D4D041EAC4229
:1005600012D00C4E0122301C211CFEF70DFD0A4951
:10057000301C11F06AFC04230293084B03940848D2
:10058000032102AADB699847281C04B070BDC0464D
:10059000387D0200F09502009BB00200E457020093
:1005A000EC90020010B586B0041C6A4602A8102127
:1005B000FCF796FD6846211C0122FEF7E5FC02A926
:1005C0000248F1F76BFA06B010BDC046C8550200EC
:1005D00070B50C68231CE2074BD4A50703D1264A4B
:1005E0002568954245D001281FD94868FEF79CFD33
:1005F000061C201CFEF7FCFD051C301C05F0C8FC89
:10060000011C1E48F0F7A8FA041C211C281C05F048
:10061000FFF908F08BFA211C05F016F80323984324
:10062000174A022303439B1823E0201CFEF7E0FD3A
:10063000061C08F07BFA051C05F08AFC291C041C2A
:10064000301C05F00FFBFC218905051C04F0D2FDD0
:10065000002801D0013406E0BF21281C090604F05F
:10066000C9FD002801D001239C43201C0EF07DFF12
:10067000031C181C70BDC046185202000000204127
:100680000000808007B5C9086A46FBF7E5FE009BBD
:10069000002B01D0014800E001480EBDE07B0200C4
:1006A000247C020037B50024022800D98C684868F1
:1006B0000D68F1F749FA011C002C01D1084B00E04C
:1006C000084B281C6A4698470098002805D00199D5
:1006D000002903D0F9F7B8F800E0201C3EBDC04661
:1006E000BDC4000059C4000038B5051C081C141C0A
:1006F000F1F72AFA221C011C281CFBF707FF01480E
:1007000038BDC046387D020070B5002802D11F4BAD
:100710001C681DE0086882070AD103681C4A9342DE
:1007200003D10EF073FF041C12E01A4A934201D069
:10073000FEF710FC846B002C0AD0A30707D12268B7
:10074000154BD31A5A4253415B421C4000E000242F
:100750000020011C0FF031FA0025061CAC4213D01A
:10076000A3689D4210D2E268EB009958002903D09B
:100770000B1F5A1E934100E00B1CDA0702D5301CF8
:10078000F8F742FC0135EBE7301C70BD902E0020DD
:10079000E4570200C87402009880020008B5FBF715
:1007A00001FF002804D103480EF0BBFF01F065F8FB
:1007B00008BDC046545C020030B50B1C85B0141C4B
:1007C000012805D90A490B480EF0B8FF01F055F889
:1007D00009480121C2680192019D0022A84703A98E
:1007E0000390221C0120F8F773FC039805B030BD7C
:1007F000EFFE0200985E020030630200F0B587B0A1
:1008000000AFFA60061CC26BF8680C1C08181D1CAF
:100810007861904205D02C497B692C48F7F764FA3F
:1008200033E079698C4247D08A00131C0E33DB0811
:10083000DB006846C01A85466B4600213B6113F019
:100840007FFBA2000023934204D0E9583869C150CD
:100850000433F8E7F8687A69ED181218FA6003E0D3
:100860002A1F126802341A60FA68944223D2286858
:10087000F1F76AF9F16B021CB9600023B868834292
:1008800005D112481249F7F72FFA00F0F6FF980049
:1008900078608019016C914201D00133EEE7013399
:1008A000EFD03969786808350B1819680029D7D056
:1008B00006480849E7E73D697869291CFDF7A6FE67
:1008C000BD46066007B0F0BDCCA90200985E0200EC
:1008D0001AFF020005AA020038B50B680C1C5A6802
:1008E0000549051C11F07BFB2168281C4031221CA6
:1008F000F8F7B6F838BDC0464CBE0200F0B585B07A
:100900000C1CF1F721F90325071C254003D1204BCE
:1009100022689A4205D01F491F480EF00FFF00F0D1
:10092000ACFF201C02A903AA0FF05FF9029E039BF3
:10093000301C10308000019310F014FC291C3C2264
:10094000041C13F0FDFA154B67602360144BE6633B
:10095000A360144BE360144B6361144BA361144B0D
:10096000E361144B2362144B6362144B6363B5421F
:100970000AD0019AAF00D259E719101C0092F1F782
:10098000E3F801353864F2E7201C05B0F0BDC0463D
:10099000306302003BFF0200985E0200C874020050
:1009A000D9080100FD07010091E5000049E60000BB
:1009B000C109010045E70000F1E5000024950200AF
:1009C000136870B5002B11D10468E56BAB4213D0EE
:1009D0009E00A619366C8E4201D00133F6E7591CF1
:1009E0000AD002339B001B58136005E003490448FA
:1009F0000EF0A4FE00F041FF70BDC04649FF0200AA
:100A0000CC5C020013B5041CA068FBF7F1FD01905B
:100A100000280ED06368074A934205D0181C0121B4
:100A2000002201ABFBF7A2FCFEF7C4FC0028EBD0D0
:100A3000019816BD387D020010B5041C081C11F089
:100A4000ACF9002C04D0012C06D14000204306E074
:100A5000002803DD024802E0002000E0014810BD4C
:100A6000E07B0200247C020070B54568C66884689B
:100A7000102010F077FB034B4560C6600360846074
:100A800070BDC046B495020038B50D1C6A680849AF
:100A9000AB68041C11F0A3FAEA68201C012A03D1F8
:100AA000044911F0D2F902E0034911F098FA38BD77
:100AB0005DFF0200BED802006AFF020030B5041CD0
:100AC00085B00D1C0020042A2DD1201C11F065F9E1
:100AD000011CAA071BD1154B2A689A4217D1291C61
:100AE00001AAF6F719FB102010F03CFB104B019AFD
:100AF0000360E36861685A4352180299426059439F
:100B000062688A188260039A5343C3600BE02A1C10
:100B100000232068FEF7E6FBE26863685043C018D4
:100B200040000123184305B030BDC046787D020067
:100B300078950200F0B587B0051C0D980392841AD1
:100B40000CAA12780591101C2021884306D0302A67
:100B500009D1274910220491019208E0254810216B
:100B60000490019103E00CAA0120049201908022DC
:100B70001A4005D0E30F1B195B10E71A1C1C03E099
:100B800001210B4012D11F1C002C12DD261C0199E3
:100B900002968E4200DD029128680499029A6B68E1
:100BA00098470298361A002EF1DC03E0271C141C2B
:100BB00000E000240399002906D028680599039ACB
:100BC0006B68984703982418002F0DDDE4190199EC
:100BD0003E1E8E4200DD0E1C28680499321C6B6894
:100BE0009847BF1B002FF2DC201C07B0F0BDC046A9
:100BF00082FF020093FF0200F0B593B01F1C18ABF8
:100C000010CB0D1C1B780590161C0693E9070BD41E
:100C1000AA0703D17F4B2968994205D0281CFEF70B
:100C200083FA01254000054381231C4209D1069A1D
:100C3000302A06D11A9B1B998B4200DA1A910022A6
:100C40001B92281C0EF075FC0AAB00280BD0A107E4
:100C500003D52B221A70013305E0620703D5202249
:100C60001A706B462933E10618D5022E03D13022C3
:100C70001A707A1C10E0082E08D130221A70A205D2
:100C800001D401330AE03A1C0E3205E0102E05D1E2
:100C900030221A703A1C17325A7002330AA9591AB4
:100CA00000220491A106C9171A702C230B400EA92B
:100CB0000B9110210C911B990D92012901DD40210E
:100CC0000C43272169440A70402222400792079969
:100CD000FAB20096002915D00021019102920393E7
:100CE0000BA82B1C0CA90DAAF4F772FF0378061CA5
:100CF0002D2B12D127226A4413700D9B0136013B24
:100D00000D930AE00AA90191029203930BA80CA982
:100D10000DAA2B1CF4F75CFF061C1B9B012B2DDD81
:100D20000D9B1B9F9F4200DA1F1C0799002907D0CB
:100D30006B4627331B785A1E9341049AFF18BF183D
:100D40001A9B9F4207DA01252540DF1B002D04D0A6
:100D50003D1C002701E000252F1C01239C43002F90
:100D60000FD020230022009301972B490598131CD4
:100D7000FFF7E0FE3021071C069104E000252F1C40
:100D800001E030220692630620D5694627310B78B0
:100D9000002B0AD000230122009301920598FFF74F
:100DA000C9FE1A993F1801391A91049A002A0DD0E8
:100DB00000230122009301920AA90598049AFFF7E3
:100DC000B9FE1A9B04993F185B1A1A931B9A012AC1
:100DD00000DD1A92069B1A99009301910598311C27
:100DE0000D9A231CFFF7A6FE3F18002D09D02023E3
:100DF00000220093019505980749131CFFF79AFEFE
:100E00003F180B980EAB984201D010F0E1F9381C56
:100E100013B0F0BD185202002FB00200F0B58DB033
:100E2000071C069200240D1C2B78002B09D18D4243
:100E30000BD96E1A3868321C7B689847A419291C94
:100E400003E0252BF3D00135EEE70B78002B00D122
:100E50003AE10131049120210991002604990B788F
:100E6000002B12D02D2B01D1012302E02B2B02D11C
:100E700002231E430FE0202B01D10423F9E7212B8D
:100E800001D10823F5E7302B02D00022079206E0BB
:100E9000402216430993049B01330493DEE704992F
:100EA0000B781A1C303A092A09D807990A224A43B2
:100EB000D318049A303B013207930492EFE72E2BAC
:100EC00025D14B782A2B04D00131002204910892BD
:100ED0000BE00699049B096802330493CB43069DFB
:100EE000DB1719400435089115E004990B781A1C9A
:100EF000303A092A09D808990A224A43D318049A91
:100F0000303B013208930492EFE7069D03E0012392
:100F10005B42069D0893049A049913786C3B5A42ED
:100F20005341C9180A7804910592002A00D1CBE0F8
:100F3000642A00D189E015D8502A00D193E005D861
:100F4000131C453B022B00D89DE0B3E0059B622BB0
:100F50001BD033D8582B00D0ACE0291D069141237B
:100F6000296884E00599712934D005D8672900D80B
:100F700089E0702977D09DE0059A752A58D0782AA3
:100F800071D0732A00D095E036E02B1D06932B68B4
:100F9000002B07D00999079A00910192381C4C49FF
:100FA000042206E00799099B01914A490093381CE5
:100FB0000522331CFFF7BEFD241882E02B682A1D92
:100FC0000BA90B700692099B079A00930192381C9B
:100FD0000122EEE72B1D0BA92868069310F0F8FC00
:100FE000089A011C013201D10B9B0893099A079BB7
:100FF00000920193381C11E0291D2D680691002DE7
:101000000ED0089A013203D1281C13F08FF80890F3
:101010000799099B01910093381C291C089AC8E77D
:10102000099A079B00920193381C2B490622C0E7BE
:10103000291D6123099A069129680093079B029252
:1010400001960393381C00220BE0291D6123099AA5
:10105000069129680093079B029201960393381C1E
:1010600001220A230CE0291D069129686123099AAF
:101070000093079B029203930196381C00221023D1
:1010800010F0F1FE98E7072307359D43291C08312E
:1010900006912868696806F0F5FC099A079B00929A
:1010A000089A011C01930292381C059A331C10F017
:1010B00048FF81E73868049901227B68984701342A
:1010C000069504990131AEE6201C0DB0F0BDC04676
:1010D00070FF020075FF02007BFF0200002805D0B0
:1010E000012808D18B685B00184307E08B68002B50
:1010F00003D0034802E0002000E002487047C046E9
:10110000E07B0200247C02007FB5041C0122081C45
:1011100001A9FEF7CFF9002221794020F4F7F6F873
:10112000061C311C029803F0A9FF6368051C1A0A0B
:10113000824208D2A368C1187143E06810F037F802
:101140002379E06003E0121A1202DBB21343A068B5
:1011500063607043E368321C6A431818019912F007
:10116000CDFEA36802485D19A56004B070BDC046FD
:10117000387D0200F8B54368041C0F1C1D0A1CD101
:1011800001792A1C4020F4F7C1F82279A168802354
:101190001B0113430831061C41436360E06810F0F3
:1011A00006F86368E0601A0AA368013A01337243E3
:1011B0005E43291C801912F0C3FEA2682079531CDB
:1011C000A360E1683B1CF4F793F963680248013BB4
:1011D000FF3B6360F8BDC046387D020010B5041CBB
:1011E00010200FF0D1FF024B4460036010BDC046D9
:1011F000209602000A7970B5041C0D1C002A09D142
:10120000194910F022FEE968AA68201C0123F0F7B2
:10121000DBFB23E0154910F0E2FEAB68002B1DD08C
:10122000201C134910F011FE0026AB689E4211D21B
:10123000002E03D0201C0F4910F007FE321CE96875
:101240002879F4F785F80122011C201CFDF79CFE8B
:101250000136EAE7201C084910F0F7FD201C074979
:1012600010F0F3FD70BDC046A4FF0200B0FF020005
:10127000BBFF020013B6020046040300BED8020002
:10128000F8B5051C0F1C4020291C0022F4F73EF87D
:10129000061E05D10C490D480EF050FA00F0EDFA8B
:1012A00010200FF05FFF041C002D01D1084B00E05F
:1012B000084B2360381CEBB2A760704363600FF0EB
:1012C00051FFE060201CF8BDBFFF0200A8590200DA
:1012D000989602005C960200F0B5051C89B00C1CC3
:1012E000161C12282ED01B2832D00020052D48D1E4
:1012F00002AD081C0122291C10F07DFE301C05A93E
:101300000122FEF7D7F80022297A4020F3F7FEFFEA
:10131000071C391C069803F0B1FEA168061C711861
:10132000287AFFF7ADFF0299041C6A68C06812F0C2
:10133000E5FD6868E3683A1C18187243059912F0D5
:10134000DDFD03E0081C111CFFF7DEFE201C18E089
:10135000081C012202A910F04EFE301C05A9012232
:1013600010F06FFC00280BD0069B039A0093281CFA
:101370000299059B0DF0AFFE002801D0024800E065
:10138000024809B0F0BDC046E07B0200247C0200A8
:10139000F0B5041C87B00E1C002808D08A0724D1A1
:1013A0000B68274A934202D0264A93421DD1301C33
:1013B00003A9012210F045FC002816D00022211CB0
:1013C0004020F3F7A3FF071C391C049803F056FED6
:1013D000061C311C201CFFF753FF3A1C051C7243EE
:1013E0000399C06812F08AFD26E0301CFDF7BCFFAF
:1013F000002801D0471000E0071C391C201CFFF713
:101400003FFF051C301CFBF7A5F800260090009854
:10141000FBF7EEF8031E0FD0002F04D1281C191C77
:10142000FFF7A8FEF3E7721C0192201C321CE9684A
:10143000F4F75EF8019EEAE7281C07B0F0BDC0464D
:10144000A84B0200989602007FB5041C0B1C151EC9
:101450003ED003260E40816827D11F4A186890426B
:1014600023D1081C01AA191CF5F756FE002802D149
:101470001A48FBF72BFE321C042D2AD1217940207B
:10148000F3F744FF029A019B061CD11A2079FFF75B
:10149000F7FE0199029A051C521A72434E43E16805
:1014A000C068891912F02AFD12E01A1C2068002376
:1014B000FDF718FFE168021C2079042D03D1F3F732
:1014C00047FF021C05E02B1CF4F712F8044A00E069
:1014D0002A1C101C04B070BD787D0200DDA502003E
:1014E000387D020037B50C1C111C00221D1C009217
:1014F000201C0123F5F700FF002C04D1201C211C27
:10150000FFF7BEFE1BE02968CA0705D48B0713D17D
:101510000B4B0A689A420FD1081CFDF705FE051C0B
:10152000291C0020FFF7ACFE0021041C2A1CC06807
:1015300012F006FD201C02E00020FFF729FF3EBD4F
:101540001852020038B5151C041C10F0E4FD2A1CCA
:10155000201C024910F08DFD38BDC046F720020066
:1015600038B503780D1C0024032B06D9416A074CBB
:101570009200641A81695358E418032110F0BBFDEE
:10158000447024120570847038BDC046FD7F000091
:10159000F8B50023041C217043604370A260C3604F
:1015A00001230E1C151C0361032905D8406959420B
:1015B0008200A06912F0C4FC00236362E3612A8CFC
:1015C0006B8CD218002A00D10122374F201C391C05
:1015D00010F04FFDAA8C201C391C10F04AFDA268A7
:1015E000201C117E10F080FDA368201C997E10F055
:1015F0007BFDA068017F201C10F076FDA268201CF6
:10160000917F10F071FD042E07D1E069236A391C27
:101610001A1A201C10F02DFD03E0201C022110F0EE
:1016200056FD391C201C2A6910F023FD391C201C92
:10163000EA6810F01EFD00272B8D9F420BDAE96A45
:10164000FB00CB181A78032A03D19978201C10F0DC
:1016500062FD0137F0E7201CFF2110F05CFD042E35
:1016600020D1AB8B6E8BF6180023B3421ADA288D8B
:101670000022844662450CDAEF6AD10079184F786F
:10168000F80704D54F889F4201D14A6802E0013231
:10169000F0E70222D2000620276B99000243CA51CC
:1016A0000133E2E7F8BDC046CF20020073B50378EE
:1016B000041C012B2ED04268002A03D0164817497B
:1016C00010F08DFC201C002110F00EFD2378032B60
:1016D00013D1E269606A03329A43E2612262A06236
:1016E00010180FF051FDA368E062588B9B8BC01857
:1016F00080000FF049FD20630CE0042B0AD1A36A9F
:10170000A568266AE16A9A19236B2C7E68690094A1
:10171000FBF7F4FD73BDC046F0950200CCFF02005C
:10172000F7B5224B041C88331B680191022B3CD86F
:101730000569A94239D9426AC3684D1BD61A331CC0
:101740002B432ED00096062D10D81F2E01D91F2214
:1017500000922F1E032F00D90327201C012110F017
:10176000B6FC009A7B011343037016E00F2E01D9DB
:101770000F2300930E4B2F1E9F4200D91F1C0221E6
:10178000201C10F0A4FC009B802252421A4339090D
:1017900070230B40134303704770009AED1BB61A79
:1017A000CDE7636A019AE3602261F7BD902E0020C5
:1017B000FF07000038B5041C0D1C012110F079FC56
:1017C000201C0F2D05D0102D05D010210E2D06D177
:1017D00002E0112100E0122110F09DFC03E017212E
:1017E000014A10F035FD38BDEC600200F8B5041C6C
:1017F0000D1C161C124F11D1111C10F05AFC802325
:101800001B021D4203D0201C322110F084FC2A1C34
:101810003A40201C3521FFF7A3FE0FE00A1C3A4096
:101820004621FFF79DFE80231B021D40691E8D414E
:10183000E9010E43F1B2201C10F06DFCF8BDC0466A
:10184000FF7FFFFFC4600561466187614146C1615A
:101850004946016251464162594681626946C16208
:1018600071468160124B1A68026018600020704750
:101870000F4B1A6812681A6070470D4B1A68002ADD
:1018800001D10DF0B2F8506010681860D468156985
:1018900056699769D1698846116A8946516A8A46AC
:1018A000916A8B46D16A8D4691688E4601207047B9
:1018B000982E0020074B10B51A1C08323C33041C2C
:1018C00002604360406909F09BFD201C00F0A2F912
:1018D000201C10BDF043020008B4024B9C460438A3
:1018E00008BC6047B518010008B4024B9C46043898
:1018F00008BC6047692902001FB5041C00F0ACF960
:101900000B4B01A81A1C3C3363600832002363614F
:1019100022600849221C0AF0ADFB074901A809F022
:10192000DFFE606111F0B9F8201C04B010BDC046A4
:10193000F0430200F8FF0200FCFF020010B5054B67
:10194000041C0833036011F042F8201C00F0CEFBA9
:10195000201C10BD38440200074B083303600023ED
:10196000064A9958814201D10021995080220433BE
:1019700052009342F4D1704750440200B427002033
:1019800008B5054B1B68002B04D104481821192207
:1019900000F03CFA08BDC046BC280020BC2F002047
:1019A000F0B50F1C85B02F49051C12F0B5FB041EC5
:1019B00002D1FFF7E5FF51E0281C2B4912F0ACFBE8
:1019C000002803D1FFF7DCFF012447E0281C27494A
:1019D00012F0A2FB0024A04206D1FFF7D1FF02249F
:1019E0003CE00134402C0ED0214BA600F258002AD6
:1019F000F7D10BE002A8291C11F058F802A811F049
:101A00009FF800280CD10124644227E02B783A2B60
:101A1000F0D1281C174902AA0AF04EFB029818E0E0
:101A200002A811F078F8002803D002A811F07DF880
:101A30000FE002A811F067F8051EE4D0036802A8C1
:101A40009B68019311F052F83A1C011C019B281C61
:101A500098470028D7D0064B03349851201C05B076
:101A6000F0BDC046FFFF02000E00030006000300A9
:101A7000B4270020F8FF020008B5002302280DDD7E
:101A8000C11E074A890088588B50984204D00368C9
:101A90005B689847031C01E001235B42181C08BDEA
:101AA000B427002070B50C1C151C022810DC0F4B4D
:101AB0001B68002B01D1FFF763FF6619B44205D004
:101AC00021780B4800F082FA0134F7E7281C0BE07C
:101AD0000338084B8000C058002803D003681B68F7
:101AE000984701E00120404270BDC046BC2800205C
:101AF000BC2F0020B427002010B50C1C02280BDCE2
:101B00000C4B1B68002B01D1FFF73AFF0A4811F07C
:101B10002BF9207001200BE00338084B8000C058DF
:101B2000002803D003689B68984701E001204042E9
:101B300010BDC046BC280020BC2F0020B4270020C8
:101B400008B5031C0120022B0BDD033B054A9B005B
:101B50009858002803D00368DB68984701E001200B
:101B6000404208BDB427002008B5031C0020022B0A
:101B70000BDD033B05489B001858002803D0036881
:101B80001B69984701E00120404208BDB4270020AE
:101B9000074A13681818EFF30881884205D3054BEC
:101BA0000C2201201A60404201E01060181C7047AE
:101BB00054000020C42F0020014B03607047C04632
:101BC0008844020010B5034B041C036012F08CF82B
:101BD000201C10BD8844020038B50C4B051D036065
:101BE000002343608360C360036243628363962380
:101BF0009B01041CC363281C00F008F9281C04493D
:101C0000221C00F091F9201C38BDC0468844020017
:101C10004B2B0200074B10B51A1C08323433041C3E
:101C200002604360043000F003FA201CFFF794FECA
:101C3000201C10BD9044020008B4024B9C4604389E
:101C400008BC6047151C010008B4024B9C460438D0
:101C500008BC6047CD2B0200074B10B50022041CC6
:101C600008C000F0FFF9054B201C1A1C0832343361
:101C70002260636010BDC0465844020090440200D8
:101C80000A490B4A88680B4B002808D018680130B5
:101C90001860002088600220D221814050500649FF
:101CA0001B6852581806190A10437047FC1001406F
:101CB00000100140B828002004050000174B70B543
:101CC0009A68002A0AD0164A022011680131116070
:101CD00000229A601349D222824088505B6C114CDA
:101CE000002B19D0104D2B78002B15D00F4B1E68F0
:101CF000FFF7C6FF361A002E0EDC084B0021596490
:101D0000D22280235B029200A3502970C221890055
:101D10006350A35000F0FAF970BDC046FC100140BA
:101D2000B828002000100140642E0020B4280020B4
:101D300038B5124C2278002A1FD1114BA121C900BD
:101D40005A500222D22191405A50C12191405A50FA
:101D50000C4AC421890055580B482840C0252D0243
:101D6000284350508021C020890240000125115095
:101D700011601D6010F0E5FF257038BD632E002056
:101D80000010014000E100E0FF00FFFF074B1A7860
:101D9000002A0AD0064A8021C22049028000115040
:101DA000D2208000115000221A707047642E00204B
:101DB00000100140024B00229A605A647047C046EE
:101DC000FC100140962210B50123D200914203DCA1
:101DD0009E210268C90212E00A4ADC00A458A1420E
:101DE00007DA013BDB00D21801685268064BCA5083
:101DF00007E00133112BEFD1802102684905024B26
:101E0000D15010BD1497020024050000F8B5274BEF
:101E1000274C0360A023DB050F1C161C01211A5957
:101E2000B9400A431A511959802212060A431A511D
:101E30001A590121B1408A431A511A599621520068
:101E40005208051C1A518901FFF7BCFF2B6819497C
:101E500000225A50A021C900042058500121996045
:101E60001960191CFC31CA6013495A50A1216A60DB
:101E7000C9001F225A5011495F50A221C9005A506F
:101E80001E517B1C03D0381C032110F0F3FF711C82
:101E900003D0301C032110F0EDFF094B01221A6022
:101EA000291C0822074812F029F8F8BD002000403C
:101EB000140500006C0500001C0500000C05000066
:101EC000BC280020BC2F00200168034B002A00D052
:101ED0000E22CA507047C0466C05000008B50E4A75
:101EE000C1239B00D158080603D50C49096A002973
:101EF00008D1D3585A070DD5084B0021DB68002BB9
:101F000001D107E00121064B1868002802D0054BDB
:101F10001B68984708BDC04600200040FC200040D8
:101F2000C0280020C4280020034B19604168034BDF
:101F30008900CA507047C046C4280020C02800202D
:101F400030B503681E4C1819444260414000002A15
:101F50001BD0002903D0012905D1802100E00421F4
:101F6000C12292009950174BC022920040B29C5857
:101F7000C100FF258D40AC43C0258D40291C214365
:101F80009950012282401A6018E0002908D00129E6
:101F900014D1C222920080249C509B589B0806E0DA
:101FA000C2229200042199509B580121DB099943D8
:101FB00004D001238340181C034BD86730BDC046B2
:101FC00000E0FFBF00E100E004E100E003681A1C4C
:101FD000FC32106A0128FAD100201062014AC9B20D
:101FE000995070471C0500000848026803210A4305
:101FF00002600749074A084B9B1A03DD043BC85897
:10200000D050FBDC054880470548004724050040C8
:102010008804030000000020000100204D21010081
:10202000C5150000FEE7FEE7FEE7FEE7FEE7FEE778
:102030000A4B826808330360002A0DD0084A1368EF
:10204000834202D14368136006E05A68824201D09D
:10205000131CFAE742685A607047C046D044020039
:10206000C8280020064B81600833036000234360CA
:102070000273994203D0034B1A681860426070479C
:10208000D0440200C8280020F8B50C4B071C1C687F
:102090000E1C002C10D0A568002D0BD0281C391C5C
:1020A000321C12F04AF8002804D1281C12F03EF825
:1020B000B04201D06468ECE7201CF8BDC8280020BD
:1020C000084B10B508330360002343608360C3608E
:1020D000041C00F017F80449206110F0C8FD201C12
:1020E00010BDC046E0440200A72D020010B5044B0D
:1020F000041C0833036010F063FE201C10BDC046B2
:10210000E044020000487047B097020008B502485A
:1021100010F0B6FD08BDC046B097020001704B1C20
:102120000AD001238B404360044BC360044B03611E
:10213000044B4361044B83607047C0460805005060
:102140000C0500501005005014050050234B10B52D
:102150001A78181C012A12D1214B1B6819070ED1BD
:10216000204BF0221B68E024191C1140234204D1AB
:102170001D4B1B68134202D120E03029F8D00378B0
:10218000012B0DD1164A1268110709D1154A1168A1
:10219000F0221140402903D113490968114215D09A
:1021A0008022A3230021D205DB00D1500F4B996080
:1021B000012191609A68002AFCD00DE00C490D4A7B
:1021C000116080210C4A09021160D8E7C1228021E8
:1021D000D200C9058B50E3E710BDC046E00F00F008
:1021E000E40F00F0E80F00F0EC0F00F0FC000040FE
:1021F000DFFF07C004050040186C0040014B03607E
:102200007047C04600450200014B03607047C0465E
:1022100000450200014B03607047C04600450200C4
:1022200010B5034B041C036001F060FF201C10BDBF
:102230000045020010B5034B041C036001F056FF7B
:10224000201C10BD0045020010B5034B041C0360A8
:1022500001F04CFF201C10BD0045020010B5034BDF
:10226000041C0360FFF76AFB201C10BD90460200AF
:10227000074B10B51A1C036018324C33041C02645F
:1022800043644030FFF716FB024B201C236010BD57
:10229000A84602008844020008B4024B9C46443819
:1022A00008BC60477122010008B4024B9C464038CC
:1022B00008BC60477122010010B5041CFFF7D8FF6D
:1022C000201C01F013FF201C10BD08B4024B9C46DB
:1022D000443808BC6047C046B922010008B4024B2C
:1022E0009C46403808BC6047B922010010B5064B37
:1022F000041C1A1C183203604C3302644364FFF759
:10230000B7FF201C10BDC0466045020008B4024B58
:102310009C46443808BC6047ED22010008B4024BDB
:102320009C46403808BC6047ED22010010B5041CF3
:10233000FFF7DCFF201C01F0D9FE201C10BD08B403
:10234000024B9C46443808BC6047C0462D23010020
:1023500008B4024B9C46403808BC60472D2301005E
:102360000D4B10B5041C0360683010F0FBFF201CFF
:10237000603010F0F7FF201C583010F03AFF201C9E
:10238000503010F036FF201C1030FFF767FF034B72
:10239000201C236010BDC0466046020000450200BC
:1023A00038B52F4DDA239B00C550D6239B00C5506E
:1023B000D2239B00C550CE239B00C550CA239B004F
:1023C000C550C6239B00C550C2239B00C550BE23E9
:1023D0009B00C550BA239B00C550B6239B00C55037
:1023E000B2239B00C550AE239B00C550AA239B007F
:1023F000C550A6239B00C550A2239B00C5509E2319
:102400009B00C5509A239B00C55096239B00C55046
:1024100092239B00C5508D239B00C550FA235B007F
:10242000C550E4235B00C550DE235B00C550CA23C2
:102430005B00C550B6235B00041CC5500130FF3063
:10244000FFF78EFF231CE833201C1D605030FFF780
:102450004DFF201C0830FFF771FA201C38BDC04624
:102460000045020010B50D4C0321201C11F01FFB8C
:102470000B49201C11F020FB01F008FE00F06CFE5F
:10248000084C201C00F010FA6421201C00F09EF97A
:10249000F4F7ECF800F09AFFFEE7C046542C002059
:1024A0004D260100D428002038B50A4D281C00F024
:1024B000D9F8094C281C221C084911F00EFC084DC3
:1024C0001321281C01F0B0FF281C0649221C11F022
:1024D00004FC38BDD428002000000020A123010006
:1024E000542C002011440100F0B585B01F1C0AAB2C
:1024F0001B78041C039300933B1C0D1C161C11F04D
:1025000035FB002826D0237D082B21D82368002204
:10251000191CFC318A62A021C9005A500F495A5037
:1025200010F0CEFC23680D4901225A50A02105224B
:10253000C9005A5002F040F8039B201C0093291C4C
:102540003B1C321C11F012FB237D01332375D8E7AD
:10255000034800E0207505B0F0BDC046FC0F000048
:102560000EFCFFFFF0B585B01F1C0AAB1B78041CE6
:10257000039300933B1C0D1C161C11F0DFFA00287E
:1025800026D0237D082B21D823680022191CFC317A
:102590008A62A021C9005A500F495A5010F090FC8D
:1025A00023680D4901225A50A0210522C9005A5022
:1025B00002F002F8039B201C0093291C3B1C321CD8
:1025C00011F0BCFA237D01332375D8E7034800E0FE
:1025D000207505B0F0BDC046FC0F00000EFCFFFFEB
:1025E00038B5144B051C5B68DA0701D500F0EEFD29
:1025F00000242B19D0331868002816D003689B6874
:102600009847002811D00C4B01211A780A431A7000
:1026100000242B19A8331868002802D00268126819
:1026200090470434282CF4D138BD0434182CE0D160
:10263000EEE7C046D4280020652E002008B5011C16
:10264000014801F03DFB08BDD4290020BFF34F8FA6
:10265000024A034BDA60BFF34F8FFEE70400FA052E
:1026600000ED00E030B5002591B0041C4560083055
:10267000FFF726FD394B201CA3602A1C25626563E9
:102680001E21383010F02FFC201C18211922503048
:1026900001F0E6FC201CE83000F000FA0522601C86
:1026A000131C0621FF3001F0E5F9B6235B00E018AA
:1026B00000952B1C0121112200F0B0F9CA235B0008
:1026C000E01800952B1C02211A2200F0A7F9DE2346
:1026D0005B00E0181A210122022301F0CBFDE42364
:1026E0005B00E01804213A2200F078FFFA235B0037
:1026F000E0181D22052100F0CDFB8D239B00E01882
:10270000072100F0DDFF92239B00E0180A230093CD
:102710000B2301930C2302930D2303930E230493A5
:102720000F23059310230693112307931223089375
:102730001323099314230A9315230B9316230C9345
:1027400017230D9318230E9319230F9307210822A3
:10275000092310F07DFD201C11B030BD4044020063
:10276000F0B589B001A81149192211F0C7FB8023E7
:102770005B055F6E002405260125381C311C02F024
:10278000C1FC081C291C02F079FC05235E435D4353
:1027900063433F1A064A181801A90B5C121B013447
:1027A000D374052CE9D109B0F0BDC0461600030072
:1027B000D3000020BFF34F8F024A034BDA60BFF310
:1027C0004F8FFEE70400FA0500ED00E010B5002988
:1027D0000CDB446801231C40081C002C03D000F0D3
:1027E000D1FD002003E010F03BFAFAE7004810BDED
:1027F00017FCFFFFF0B500291BDD036801390C1C35
:1028000000229E09DF0F77405F401E0977405D0878
:102810009E083B1C73406B40DB072B435500012295
:102820001A402A436408ECD18A42E8D80360101C9D
:1028300000E00148F0BDC04617FCFFFF0023036025
:102840000C4B012230B51A60016804230A4A0024A7
:102850005460151C6C68074A002CFBD0A124E400CE
:1028600014590902013B2143002BEFD101230160E0
:10287000536030BD00D00040FCD0004038B5051C8E
:1028800000242B19D0331868002802D0026852683F
:1028900090470434182CF4D1024B01211A788A4352
:1028A0001A7038BD652E002038B5184DE121041C82
:1028B0004902281C10F05DF9291CB031201C10F0D1
:1028C00024FBBC235B00E918201C10F02CFBD22356
:1028D0005B00E918201C10F026FB291C9831201CF5
:1028E00010F021FB201CFFF7A9FF201CFFF738FF89
:1028F000074B201C63620023A362064B24626363C0
:102900000830054910F074F838BDC046242900206D
:10291000E1250100F72E020070170000014B186836
:102920007047C046B82C002008B5024801F0C8F92D
:1029300008BDC046D4290020014B03607047C04643
:102940000045020010B5034B041C036001F0CEFBF0
:10295000201C10BD0045020030B5C369C1681B686A
:1029600085B0041C451D19424BD0EB7F002B01D0D4
:10297000013BEB77EB7F082B0DD9A27901231A429B
:1029800009D11A43A271A1881A1C02A800F064FBA5
:102990001F4B1B682362EB7F012B1DD8A2790123FB
:1029A0001A4219D00022A271A1886846022200F0C2
:1029B00053FBA31DDB7F012B0ED1154AA1881068A4
:1029C000226A801A134A904202D902A8042201E026
:1029D00002A8032200F040FBA27903231340012B3D
:1029E00014D10B490868216A401A0B4988420DD955
:1029F00002210A43A271A18802A8052200F02CFB43
:102A000004E0EB7F0B2BB5D80133B2E705B030BD46
:102A1000B82C0020E7030000DB050000F0B585B00E
:102A200002930AAB1B78071C0393124B0025083353
:102A30000837041C161C0360019185808571291CD0
:102A4000381C182211F07CFA381C311C039A10F043
:102A5000DDF9019AA31DA280029AE671DA77631D5F
:102A60002562211CDD77044810F04FFA201C05B0C8
:102A7000F0BDC046B8450200D4280020014B0360D9
:102A80007047C0460045020010B5034B041C0360AC
:102A900001F02CFB201C10BD00450200054A00235C
:102AA00008328380837102608360C3600361C382E4
:102AB0007047C046D8450200F7B584680D1C0192E6
:102AC0000126002C2AD023882A889A4201D0002B84
:102AD00022D163886A889A4201D0002B1CD1A28837
:102AE000C0231340C03B019F59424B41BB4212D10E
:102AF00013B2002B0FDB231C1033291C81C981C3A7
:102B0000500603D5201C10F024FA05E0211C0448CF
:102B100000F06CFC00E00026E469D2E7301CFEBD4A
:102B2000532F0200F8B5061C0C1E4BD08568002DF3
:102B300018D0A2880023910702D5AB889B07DB0F32
:102B40002A6821688A4248D1002B06D0A868A1686B
:102B500010F05FFE002837D13FE0AA68A3689A42D0
:102B60003BD131E0B068002825D02188051C031C2A
:102B70001A888A4205D2DA69002A0ED01D1C131C5D
:102B8000F6E71A1C2B1C08E015888D4207D15788E0
:102B90006588AF4203D2131CD269002AF4D1834264
:102BA0000BD11A88914205D38A4206D1598862888E
:102BB000914202D9E361B46002E0D969E161DC616C
:102BC00000200CE006480AE0AB881AB2002A02DABC
:102BD0005B045B0CAB80034801E0ED69A7E7F8BD3F
:102BE00017FCFFFF16FCFFFFF0B585B01D1C0AABFC
:102BF0001B88061C0F1C02920393002D1AD0202064
:102C000001F050FA029B041C9AB2039BB9B20093E4
:102C10002B1C10F0A6FD301C211CFFF783FF0028A1
:102C20000BD0002C08D0201C10F0B1FD201C01F0AE
:102C30005DFA01E0024800E0024805B0F0BDC04680
:102C400017FCFFFF13FCFFFF70B50D1E26D0846834
:102C50000026002C1ED0AA88A188022351401942C8
:102C600016D11A4203D1AB889A0707D510E0A068A5
:102C7000A96810F0CEFD002804D1F4E7A368AA6883
:102C8000934205D12B88002B0AD022889A4207D084
:102C9000E469DEE7002E01D0201C0DE007480BE0C0
:102CA0006B88002B02D062889A42F1D1A388044A33
:102CB00001361343A380EBE770BDC04617FCFFFF4E
:102CC0000080FFFF10B5041C8AB0002B0FD010202D
:102CD00092B289B2009002A810F043FD02A9201C14
:102CE000FFF7B2FF02A810F052FD002000E00148FB
:102CF0000AB010BD17FCFFFF014B03607047C046D0
:102D00000045020010B5034B041C036001F0EEF90E
:102D1000201C10BD004502001FB503AB5A7019708E
:102D200000220189009203481A1C0223FFF71AFCB3
:102D300005B000BD0C290020F0B585B0151C6A4611
:102D40000F32071C1C1C1170002D16D0002B14DD37
:102D50000B4E012301890093301CFFF703FC002870
:102D600001D008480AE039892A1C0090231C301C35
:102D7000FFF7BAFB002801D0F3E7034805B0F0BD28
:102D80000C2900200EFCFFFF17FCFFFF7FB5114D43
:102D900003AC217000230189061C0093281C221C0F
:102DA0000123FFF7DFFB002801D00B480FE0207064
:102DB000607031890090221C281C0223FFF794FBCD
:102DC0000028F2D1207863780002184300B204B0E2
:102DD00070BDC0460C2900200EFCFFFF13B5002378
:102DE0006C46E3710734221C0123FFF7A5FF00287E
:102DF00001D1207800E0014816BDC0460EFCFFFF5F
:102E0000F8B510210022041CFFF786FF1E4E002893
:102E100036D1201C0821FFF7E1FFB04230D0032556
:102E2000054028D16389194AFA2189005943131CA6
:102E30005033101C08381E1C1F681A1C8F4203D305
:102E4000083B161C8342F7D1FA213068890002F052
:102E500015F911216081A022201CFFF75DFF0028D9
:102E60000ED1337901221A43201C1021FFF754FFA1
:102E7000002806D004E064210548FFF7A7FCC8E756
:102E8000014D281CF8BDC0460EFCFFFFB89702009C
:102E9000D4280020F7B51A4B061C00250833283625
:102EA000041C0F1C85808571036005824582858224
:102EB000C582058345838583C583058445848584D0
:102EC000C584291C0192301C182211F039F8301CDD
:102ED0001D210FF096FF019901266423A78021810F
:102EE000A671E5606381201CFFF78AFFA3790822A1
:102EF000B343A371034B201C59680A435A60FEBDBB
:102F0000F8450200D4280020F7B5837902251E1C5D
:102F1000041C2E4016D1071C2B4322378371391C09
:102F20000622103010F0EAFF201C391C0622163051
:102F300010F0E4FFA18868462A1C012300F08CF8F9
:102F4000301C00E00048FEBD15FCFFFF08B5034B38
:102F50001B68C360FFF7D8FF08BDC046B82C00202F
:102F6000C36B37B51B68C16A041C194250D00121DC
:102F7000FFF70CFF03216084201CFFF707FF0521EA
:102F8000A084201CFFF702FFA37980B2E084990798
:102F900038D52223E25E1025635F934200DD131CC7
:102FA00023822421635E1225615F994200DD191C92
:102FB00061821421655E00B2011EA94200DD291C58
:102FC000A1821625615F914200DA111CE18218216D
:102FD000625E9A4200DA1A1C22831A22A35E984289
:102FE00000DA181CE3686083002B11D0094A0A4DEF
:102FF00012685B199A420BD90023E360201C10F081
:103000004EF805E0A18868460422012300F024F868
:1030100037BDC046B82C00201027000000230380D5
:103020004380024B1B6843607047C046B82C0020A9
:1030300008B5031C012904D1064806CB10F002F89C
:1030400006E0022904D10348191C0022FFF734FDD1
:1030500008BDC046BC29002010B54280054A041CAA
:10306000126801804260002B02D0191CFFF7E0FFBC
:10307000201C10BDB82C0020F0B5214B85B0061CDB
:103080001C680290039185B2360C0027002C2AD0D0
:10309000626DA36C1B4901929AB21B0C8D4211D137
:1030A00019498A420ED1002B01D0B34219D1002F09
:1030B00017D1201C10F049F8201C144910F032F8E8
:1030C00001270EE0002A01D0AA420AD1002B01D02C
:1030D000B34206D1201C10F038F8201C0B4910F028
:1030E00021F8019CD2E70A4AAB18012B05D90948FF
:1030F000291C321C084BFFF7E5FD05B0F0BDC046AA
:10310000BC2C0020FE030000FF030000A42C0020C4
:1031100002FCFFFFBC2900207930010010B572B617
:103120000B4B1C68002C03D0201C10F00EF808E09C
:1031300062B65C2000F0B6FF00215C22041C10F097
:10314000FFFE0023E364034B201CE36310BDC04675
:10315000B02C00200040002073B5FFF7DFFF124BBA
:10316000124918600FF0DEFFFFF7D8FF104B114D2A
:103170001860114B114C4363114BC02683631149F6
:103180002B1C0096201C0022FFF72EFD2B1C009606
:10319000201C0D49E83C0022FFF726FD6268012350
:1031A0001343636073BDC046A82C0020A42C0020EC
:1031B000AC2C002079300100FC3F0020BC2900200D
:1031C000E7310200FF030000FE0300000C4B70B566
:1031D0001C680C4B1A681D1C06321A60002C0DD09E
:1031E0002A68A36C666D9A4206D3201C0FF0ADFFCF
:1031F000201C05490FF096FF341CEFE770BDC04658
:10320000B42C0020B82C0020A42C0020F7B5061CFC
:103210000D1C171C0193002801D1002016E0002985
:10322000FBD0FFF77BFF041EF7D0094B066043631A
:10323000019B45608760002B01D0064B00E0064BE8
:10324000201CA36305490FF06DFF201CFEBDC04686
:10325000FC3F0020D1310200BB310200A42C002031
:10326000024B1868434258417047C046A42C0020C6
:1032700010B50A4C201CFFF701FB094B1B68002B03
:103280000AD1DE239B00E358002B04D018680368A2
:103290009B6A984700E030BF10BDC046D42800208C
:1032A000A42C0020F8B5304E01213468351CE36CA5
:1032B0000B4217D02D4F022538682B43E364C16CB5
:1032C000646B04230B43C364C4630FF05DFF386871
:1032D000416C00F068FF3068C26C2A4242D000F0B6
:1032E0009CFF3FE0224F234E3A68002A03D0224839
:1032F0000078084201D0316806E0216DB94205D15D
:10330000616D002900D1111C296000E02A602A6843
:1033100031688A420CD11A070AD52C60FFF7A8FF42
:103320003B68002BFAD0144A1278D107F6D42B60F0
:103330002968A14216D03368994204D10F4B4B63E0
:103340000F4B8B6305E09C4203D100204B6C021CA9
:1033500006E0201C0FF018FF2968626C4B6C201CE3
:1033600000F0E0FEF8BDC046A82C0020C02C0020D4
:10337000A42C0020AC2C0020652E0020FC3F002057
:10338000E731020038B50D4B051C1C68E36CDB0708
:1033900006D5FFF7C3FE0A4A1060002800D0041CBF
:1033A000084B201C1B68ED18A5640FF0CEFE201CF6
:1033B00005490FF0B7FEFFF775FF38BDA82C0020B8
:1033C000C02C0020B82C0020B42C002010B5054CD7
:1033D00020680FF0BAFE206803490FF0A3FEFFF744
:1033E00061FF10BDA82C0020B02C0020F7B5051CF3
:1033F0000F1C002828D0164C07262068C16C0E40F0
:1034000006D0281C391C134A0FF0B6FE00261CE01B
:1034100000F0EBFE23680221DA6C1140019103D029
:1034200003218A43DA6410E001263243DA64381C4F
:10343000A8472268D36C191CB143D164019E5A0776
:1034400003D5FFF7C3FF00E0034E301CFEBDC046AE
:10345000A82C0020C931020017FCFFFF014B0360BC
:103460007047C0461098020010B50548054C206012
:1034700010F0E2F9201C0449044A10F02EFC10BDA3
:1034800010980200C42C0020F3310200000000203C
:10349000014B03607047C0460045020010B5034B66
:1034A000041C036000F022FE201C10BD0045020039
:1034B0001FB503AB5A7019700022018900920348AE
:1034C0001A1C0223FFF74EF805B000BD0C2900209E
:1034D00070B52A4A4389FA2189005943131C041CF8
:1034E0003833101C08381E1C1D681A1C8D4203D36B
:1034F000083B161C8342F7D1237B214D082B05D8AE
:10350000042B03D8022B02D9023500E00435FA213E
:103510003068890001F0B2FD60812B78201C237394
:103520002A210022FFF7C4FF002801D0154824E01B
:10353000201C2B211022FFF7BBFF0028F6D1201CF6
:103540002D210122FFF7B4FF0028EFD1201C2E21EE
:103550000122FFF7ADFF0028E8D16A78201C0E2178
:10356000FFF7A6FF0028E1D1337901221A43201C7E
:103570002A21FFF79DFF0028D8D170BD18980200BE
:103580002F0003000EFCFFFFF0B585B0151C6A4646
:103590000F32071C1C1C1170002D16D0002B14DDDF
:1035A0000B4E012301890093301CFEF7DBFF00283E
:1035B00001D008480AE039892A1C0090231C301CDD
:1035C000FEF792FF002801D0F3E7034805B0F0BDF5
:1035D0000C2900200EFCFFFF17FCFFFFF8B5134B72
:1035E000051C083314350F1C0021041C0360818066
:1035F0008171C18101824182161C281C182210F0A1
:103600009FFC281C1C210FF0FCFB02251423A78023
:10361000268163812573201CFFF75AFF002803D100
:10362000034B5A6815435D60201CF8BD1846020024
:10363000D42800207FB501216A460623041CFFF729
:10364000A3FF051E1CD16B4602216E460020595671
:10365000305604229A56C900237BC00092B24942D8
:1036600040425843594353430122DB00E081218209
:103670006382A18802A8131CFFF7EEFC281C00E05F
:10368000014804B070BDC0460EFCFFFF034B1A6832
:10369000836800209A4240417047C046B82C002001
:1036A000014B03607047C0460045020010B5034B54
:1036B000041C036000F01AFD201C10BD0045020030
:1036C000084A10B508320260FA22041C0023920056
:1036D00083718180C2608360211C03480FF023FC4A
:1036E000201C10BD38460200D42800201FB5DE2360
:1036F000154A9B00D358041C002B03D001A80FF0DF
:10370000A5FD0EE0114B01221A60114B5A68002AE8
:10371000FBD000225A600F4B01221B6801930B4B18
:103720005A60019BA188DA17920FD3189B1023824D
:10373000094BE2681B6802A8D3180122A360131C7E
:10374000FFF78AFC1FBDC046D428002000C00040FF
:10375000FCC0004008C50040B82C002008B5044B50
:1037600082681B68934201D3FFF7C0FF08BDC046C3
:10377000B82C0020014B03607047C04658980200E7
:10378000F0B5071C85B00C1C1D1C002922DD002B88
:1037900020D0066873880391994200DD0393B388B3
:1037A00002929A4200DD0293002206360192019AAB
:1037B000029B9A420CDA301C291C039A10F09EFBE3
:1037C0003A682D195388F618019B01330193EEE7EF
:1037D000002000E0014805B0F0BDC04617FCFFFF27
:1037E000F8B5041C0E1C151C1F1C002901DB002A47
:1037F00002DA0D4B236015E0101C4843063000F040
:1038000051FC206010F015F82368201C5E809D801C
:10381000002F05D0311C2A1C3B1CFFF7B1FF01E033
:103820000FF0ADFDF8BDC04658980200F0B589B064
:10383000041C0F1C06A8214901921E1C0FF03AFF20
:103840002368019D5A88954207DA9B889E4204DAD4
:103850001F2F02D90798874201DD19482CE0203F2D
:1038600005237B4306980293039000230399029D4E
:1038700098194A19D25C8446049200212268019D5D
:1038800057884819B84202DA9588AC4507DB013100
:103890000529F3D10133052BE8D100200CE0654662
:1038A0006F431218049D102008412840D219471E6A
:1038B000B84140429071EAE709B0F0BDD429002038
:1038C00017FCFFFFF7B50368061C9C1D5B880D1CE9
:1038D0005A1A019200291BDD994201DA002702E001
:1038E0000FF04DFD12E0326893889F420EDA6119A5
:1038F000019A201C10F002FB019B291CE0180FF01C
:1039000038FD326801375388E418ECE7002000E006
:103910000048FEBD17FCFFFF10B50548054C2060B0
:103920000FF08AFF201C0449044A10F0D6F910BD9C
:1039300058980200C82C00206533020000000020C7
:10394000054B1A78F0231A43044B1A70C37A1F22CE
:103950001A43034B1A7070471005005004050050BD
:1039600005050050F0B5826E87B00632067B0392E3
:10397000C779041C7B000493457A364B0295827B01
:1039800000210592807A019140001818037842784E
:10399000012E04D17D1EAD1A1A1C2B1C16E0022E1E
:1039A00009D17D1EEB1A257AAC4601256D42AC4447
:1039B0006546AA1A0AE0032E08D1257AAC460125ED
:1039C0006D42AC446546ED1A131C2A1C049D6A43E3
:1039D000039DEB189B5C029A934200DD131C059D2E
:1039E0001D4204D0019A01238B401A4301920131F8
:1039F00006300929CAD1019B0F22DD43164B1978E5
:103A00002B010A401A43154BD2B21A70E37AED0526
:103A1000ED0E1D43124B1D70E37B072B18D8A27BC4
:103A200010495200A2735A1CE2730F4A9B00985827
:103A300001F0EEFF01F04EFC0C4B011CE362002391
:103A400023630B4B201CA462E36310300EF0D0FF05
:103A500007B0F0BD3500030010050050040500500C
:103A60000505005000247449609802006539010082
:103A7000AD340200F7B51F1C254B00250833041C8C
:103A80000360858085711030161C0191FEF718FBCC
:103A9000204B201C2361A562E563403000F01CFC34
:103AA000201C5030FFF7DAFC201C5830FFF7D6FC02
:103AB000201C6030FFF75EFE201C683071003AB2B7
:103AC0000FF066FC0423E02252009918A02289001E
:103AD0000320D20501338850112BF4D12022E27249
:103AE0000122019BA273FF226272221CA380483232
:103AF0000023E6712772A3722373E3736373137059
:103B0000054B04225968201C0A435A60FEBDC0467A
:103B10005846020090460200D4280020F0B5437AAF
:103B200085B0041C002B72D0836E057B0633029394
:103B3000C679384B77000397877A00217F00DF1919
:103B40000197081C06224A43019FBB5CBA185278B1
:103B5000012D04D1771EBF1A1A1C3B1C16E0022D42
:103B600009D1771EFB1A277ABC4601277F42BC4445
:103B70006746BA1A0AE0032D08D1277ABC46012706
:103B80007F42BC446746FF1A131C3A1C039F7A43CA
:103B9000029FFB189B5C002B02D001238B40184333
:103BA00001310929CED11C4BC04319780F220301E2
:103BB0000A401A43194BD2B21A70E37AC005C00EFC
:103BC0001843174B1870607AC31EDBB2FB2B18D852
:103BD000144BA462E36200232363134BE36302F0FC
:103BE00033FA124901F030FD114901F011FF11497A
:103BF00001F00EFF01F06EFB011C201C10300EF0D6
:103C0000F7FE637A022B02D8201CFFF799FE05B05D
:103C1000F0BDC046350003001005005004050050FB
:103C20000505005041390100AD34020000007F431A
:103C3000A69BC43B0024744907B501228188131C4C
:103C40006846FFF709FA6846024902220123FFF796
:103C500003FA07BDFE030000134B10B55B68041C9C
:103C60005A071FD5C37A5B00C372837A0133DBB274
:103C7000032B01D0837203E0002383722023C372DD
:103C8000637B002B02D1201CFFF748FF637B012BD5
:103C900005D1A3730023E373201CFFF763FE201CF0
:103CA0000FF0D5FC10BDC046D4280020034B0421E2
:103CB0005A680A4201D08A435A607047D4280020CB
:103CC000F0B50C1C89B072B60025FF23291CA34255
:103CD00069414B421C40FFF7E9FF3E4B1022291C73
:103CE00004A81E6810F02CF93B4B201C642104939F
:103CF00001F012FA0A2101F065FA05271031794323
:103D000071180591201C0A2101F006FA0A2101F020
:103D100059FA1031794371180691201C0A2101F0DB
:103D200051FA10314F43F61907962C1C2026FA231E
:103D30005B000293032D01D120260025A3006A46D3
:103D400010339B58254903936B00CB180193002334
:103D50001A1C0620584301990F187F780399C95DF2
:103D6000019F385C102707410F4202D00120984084
:103D700002430133092BECD11948F0231F210370B2
:103D80000F1C184B3743D2431F7017011211FFB29B
:103D9000114007703143FA271970BF0012480FF025
:103DA0009BFE002801D1FEF751FC013F002FF5D109
:103DB000029F76000135013FF6B2EDB20297002F67
:103DC000B8D10134E30F0322A2427B415B421C4085
:103DD000ADE7C046580000206B000300350003002B
:103DE0000405005005050050542C002030B5044D4A
:103DF000002405608471818042730373846030BD48
:103E00002045020010B58379041CDA0702D58068CA
:103E100000F06CF9A3799A0702D5A06800F066F962
:103E2000A3795A0707D5A023114A0021DB00D150FE
:103E3000A06800F05BF9A3791A0709D5A0680FF014
:103E400026FE0D23E356834202D1A06800F0C2FA99
:103E5000A379DA0605D5A068002802D003681B699B
:103E600098470023A360A3797F229343A37110BDD9
:103E700000700040F7B5037B041C0F1CDA0725D542
:103E8000012925D8867902231E4015D1FFF7BAFFF4
:103E9000182000F007F9627B311C01921822051CE2
:103EA00010F04EF8019B281C59B20EF0CBFFA379FD
:103EB00002221343A560A371A3685A68002F03D0A0
:103EC000DB681A60002004E01B69FAE7014800E0A3
:103ED0000148FEBD16FCFFFF17FCFFFFF7B5037B93
:103EE0000127041C3B4220D086793E4015D1FFF7C4
:103EF00089FF182000F0D6F8637B311C1822051CBE
:103F0000019310F01DF8019B281C59B23A1C0EF0C9
:103F10007DFFA379A5603B43A371A3685A695868E4
:103F200012681040431E984100E00148FEBDC046A3
:103F300016FCFFFF70B5037B041C0E1C9A0720D5EE
:103F40001B4B99421FD883791A071ED580680FF042
:103F50009EFD0D23E356834217D1A0680FF097FD15
:103F60000D23E356002583421FD1301C02F010F8C8
:103F7000104901F069FBA468011C201C00F000FF3F
:103F800013E00D4D11E00D4D0FE0201CFFF73AFF3F
:103F90000D20FA2292002056012100F0D1F9A379D8
:103FA00008221343A060A371D7E7281C70BDC04648
:103FB000FF03000000C07F4416FCFFFF17FCFFFF5B
:103FC00070B5037B041C9A0715D5837904252B4211
:103FD0000DD1FFF717FF082000F064F80D2161569E
:103FE000061C00F04BFDA379A6601D43A571A068D7
:103FF00000F06CFD00E0014870BDC04616FCFFFFFC
:10400000F7B5037B041C5A0718D5877910252F4074
:1040100010D1FFF7F7FE282000F044F80D2201230D
:10402000A188A2560097061CFEF7F8FCA379A660AB
:104030001D43A571A0680EF084FF00E00048FEBD9E
:1040400016FCFFFF08B583791A0704D580680FF0C6
:1040500021FD002000E0014808BDC04616FCFFFF1E
:1040600010B50023041C00F039FA074BE1211A1C9B
:10407000236018324C33201C2264636449020EF022
:1040800078FD201C10BDC0466045020008B572B620
:104090000248ECF7B5FB62B6014808BDCC2C002005
:1040A00013FCFFFF38B5104D041C2B68002B04D007
:1040B000291C0FF015FB002812D1AB68002B08D18A
:1040C000201C07F059FC041E0BD11420FEF7B6FA91
:1040D00007E0291C0831201C0FF002FB0028EFD05C
:1040E000041C201C38BDC046CC2C002008B500287C
:1040F00015D00B4B1A68904202D95A68904208D3E7
:104100009A68904202D9DB68984202D307F03EFCDD
:1041100005E00438026880231B061343036008BDD2
:10412000CC2C0020002815D0006041608260C36064
:10413000046145618661C761444604624C4644623D
:10414000544684625C46C462644604636E464663B9
:1041500074468463002A06D0C46B043C043A256884
:104160001560B442F9D18C6BA6464E6BB546002B58
:1041700006D0CC6B043C043B1D682560B442F9D1E9
:104180000C6BA446CC6AA3468C6AA2464C6AA14634
:104190000C6AA046CF698E694D690C69CB688A6844
:1041A000086849687047006041608260C3600461CC
:1041B00045618661C761444604624C464462544688
:1041C00084625C46C462644604636E464663744619
:1041D0008463C46B043C043925680D60B442F9D192
:1041E000C7698669456904697047006041608260FB
:1041F000C360046145618661C761444604624C4600
:104200004462544684625C46C462644604636C46FD
:1042100044637446846304697047846BA646446BA8
:10422000A546046BA446C46AA346846AA246446AAF
:10423000A146046AA046C769866945690469C368DE
:10424000826800684168704708B5084A038893424D
:104250000AD0012B02D00020DA0706D404481E2120
:10426000FEF762FB002000E0012008BDFFFF000018
:10427000D4280020F0B585B003930F4B0F4F036097
:10428000039B0F4E00254381C023857181800281ED
:10429000041C0093111C331C2A1C381CFEF7A4FCC0
:1042A000C0230093381C03992A1C331CFEF79CFC86
:1042B000201C05B0F0BDC04640450200BC290020CE
:1042C000C542010007B5031C0A1C0248191C0FF067
:1042D00042FB07BD902A0020024B1B6803607E232F
:1042E000436070475800002030B5E0246400051991
:1042F000A023DB050124AD00EC50251C8D40291CBA
:104300000B4D844059515C510A4B00021843A223C3
:104310005B00D118084B8900C850C046C046C04653
:104320005132064BFF3292000021D15030BDC046C1
:104330000C050000030003000060004000A00040E6
:10434000F7B5224C061C256800910192204F002DE4
:1043500008D06168002904D0A3680225002B0FD182
:1043600000E0012503203D70FFF79CFEAD00071C17
:10437000311C009A019B0FF072FB6751381C23E03F
:104380003A7800239D0060598178C90709D5934286
:1043900007D03B70009B311C83700FF06DFB6059A0
:1043A00012E00133032BEDD19200A0580123827853
:1043B000134008D000998170311C0FF05DFB3B78F1
:1043C0009B00E05800E0181CFEBDC046DC2C00201D
:1043D000E900002070B502780B4B4532FF329200A5
:1043E0000024D450051C00F073FC0123AB70074E71
:1043F000A359AB4204D1281CFFF778FE0023A35138
:1044000004340C2CF3D170BD00600040DC2C002083
:1044100010B5044B041C083303601C3000F0B2F9E3
:10442000201C10BD784602000F4B70B50833051CE8
:1044300008C5041C0E1C281C002118220FF080FD4A
:104440000023201C311CE36123626363A363E364E4
:10445000064A231C1C3000F065F9281C311C0EF0A4
:10446000D0FC201C70BDC04678460200073B02000D
:1044700070B50E1C151C00211022041C0FF060FDED
:10448000054B201C2361311C2A1C00F04DFA034B04
:10449000201C1C6070BDC046A0860100E82C0020D6
:1044A00038B5054D041C2B68834203D0216900F008
:1044B000F5F92C6038BDC046E82C002008B4024B4A
:1044C0009C46403808BC60479D3B020008B4024B44
:1044D0009C46403808BC6047A53B020038B5041C28
:1044E0001D1CFDF779FB201C291C4030FDF704FA48
:1044F000054B201C1A1C083222601A1C203254332F
:104500002264636438BDC046A0460200F7B5A0230C
:10451000264FDB00F95800220091A024FA50244ACB
:10452000E023E405DB00E658E250EF23DB00E1582E
:1045300001250191E250A1238022DB00D205E25047
:104540000420E5500FF032FBA223DB00E258920F6B
:104550002A4202D0E3582B4216D11324013C002CEE
:1045600014D0144BA025ED050127EF5004200FF0C7
:104570001DFBA123DB00EF5004200FF017FBA2234B
:10458000DB00EB585A00E9D5012000E0201CA023F5
:10459000E022DB05D2009E500199EF22D200995013
:1045A0000099024AA023DB00D150FEBD004000402C
:1045B0000D0600000C050000154AA023E021DB05D4
:1045C000C90010B55A50EF21C9005A50114B0022B2
:1045D000191CFC31CA600A62A121C9005A500E4A56
:1045E0001E2098500D4ACC20400498500C4C0D4A87
:1045F000A220C00014500C4C0C4814500120505004
:10460000A0220521D2009950FFF780FF10BDC046BF
:104610000C060000004000400C05000024050000CE
:104620003841004000F001401C40004014050000EB
:1046300037B5A223A022D205DB00D358BE220193B6
:10464000314B5200995800295CD0C121890059583A
:10465000002957DA00249C502C4BA500E85800286C
:104660004DD02B4BE35C002B30D0019B0121E3406C
:104670000B4212D0E0235B00E218A0239200DB057E
:10468000D3589B039B0F032B07D0224B1B68E3409F
:104690000B4202D0204B1B6817E0019A0123E24035
:1046A0001A4213D1E0225200A118A0228900D2059B
:1046B0008A589203920F032A08D1184A1268E240DE
:1046C0001A4203D0144B02211B689847A023DB0534
:1046D000EA18E023DB00C021D058890208420ED03E
:1046E000D5580F482840D0500198E040C50701D563
:1046F000D05802E08021D05889020143D1500134C2
:104700001F2CA9D137BDC04600600040F02C00200E
:10471000662E00206C2D0020EC2C0020702D002037
:10472000FFFFFCFF30B54C1C1DD0104C0160226017
:104730000F4CBE2252000020A0500E4A8D00AB50FC
:104740000D4B01225A54C122802392001B06A35014
:104750000A4B0B499C582140C02424042143995002
:1047600040221A6000E0081C30BDC046EC2C00203E
:1047700000600040F02C0020662E002000E100E0E8
:10478000FFFF00FF0268024B92000021D1507047EA
:10479000F02C0020036870B5A024E40598000019EF
:1047A000E024E4000659204D354005511F4C0125F9
:1047B000002A0ED0A94204D12268994011432160F9
:1047C00015E0022913D11A4A9D4011680D43156066
:1047D0000DE0012904D1226899408A43226006E055
:1047E000022904D1124A9D401168A9431160216831
:1047F0000122D940114204D10D490968D940114222
:1048000011D0A222A021C905D2008A58DA40131C77
:10481000E022D2008158DC0701D5C02300E08023CC
:104820009B020B43835070BDFFFFFCFF6C2D0020EB
:10483000702D0020084B0068C150084B021CFC3250
:10484000116A002904D1013B002BF7D1012001E0BE
:10485000002010627047C0461C050000A1860100C0
:1048600010B50368002A03D00220802282409850AD
:1048700001221A62084A1C1CFC34E068002804D19A
:10488000013A002AF7D1012005E00020A322E060D0
:10489000D2009B580B7010BDA186010010B50B4CC7
:1048A00002680B4BA14204DC0A498160CC21490417
:1048B0000AE0094CA14203DC08498160802102E042
:1048C00007498160CD21C904D15010BD8FD00300AC
:1048D00024050000A08601007F1A060090D0030086
:1048E000801A0600F8B5E0256D00041C5619A020BA
:1048F000C025E027C005ED007F00B6003550CE1979
:10490000B60035502068A125ED004251054A81507E
:10491000191C201CFFF7C2FF2268A0230521DB0021
:10492000D150F8BD0C050000F8B50E1C151C041C78
:10493000FFF742FE274B19781A1CC9B2012909D189
:104940005F78F0B2874205D19878EBB2984201D1F6
:10495000617316E0204908780B1C012807D14F78B5
:10496000F0B2874203D18878E9B2884214D0117836
:10497000002908D10123F1B213705170E9B291708E
:104980006373164B10E01A78002A09D101221A70BD
:10499000F2B25A70EAB29A7002236373104B03E0CA
:1049A00010480EF01CF90023191C0022FC31236072
:1049B000657126718A62A021C9005A500A49201CDB
:1049C0005A5001225A50311C2A1C084BFFF78AFF0B
:1049D000F8BDC046852E0020892E00200030004002
:1049E000004000404F020300FC0F0000A0860100C1
:1049F00008B503680022191CFC318A62A021C90095
:104A00005A5006495A5001225A5004210522415653
:104A100082568368FFF766FF08BDC046FC0F0000A2
:104A2000036800211A1CFC3210B591600121596104
:104A3000074B9168002904D1013B002BF9D10120DB
:104A400004E000240473FFF7D3FF201C10BDC04610
:104A5000A1860100036830B5191CFC318A6A002068
:104A6000012A08D1044C1C5988625A610220A5070A
:104A700000D40120404230BDC404000070B5104E87
:104A8000041C0D1C081C311C00F0CAFA331C2060E9
:104A900000229A56511C05D0AA4201D19B6802E01F
:104AA0000C33F5E70023074AA0210120C900237138
:104AB00050501B026A210B430349535070BDC0463E
:104AC0008098020000700040040500000C4B0D4A65
:104AD00010B50D499C582140995001799C58090204
:104AE0002143995001221A608022D2009A58D1079E
:104AF000FAD4034AA123DB00D05880B210BDC046CF
:104B00000070004004050000FF00FFFF02780D4B1D
:104B10009200D218A223DB0010B58020D4584003A5
:104B20002043D050002902D0D158074806E0D05881
:104B300006490140D150D058802149020143D1504B
:104B400010BDC0460060004003000300FFFFFCFFF3
:104B5000114A00211165114A114B1188114A9950CF
:104B6000114A1178002904D010490888A821C900E9
:104B700058505178002903D00C4948880C495850A6
:104B80009278002A04D0094A9188A922D20099502B
:104B900001221A607047C046FCA00040CA000020F5
:104BA00000A000404C0500008D2E0020CC0000200D
:104BB00044050000164B002210B55A60904210D1F7
:104BC000144A012198509950134A06219850A12265
:104BD000D2009850A222D2009950104A1188104A4F
:104BE0009950104A410051308A5AFF3080001A50C3
:104BF000C2210D4A890054580C4820408024E40307
:104C0000204350508021C900116001221A6010BD5C
:104C100000A00040FC0F000004050000CA000020B6
:104C20004C050000CC00002000E100E0FFFF00FF89
:104C3000E0235B0030B5A022C418D2050123A400F4
:104C4000A3501D1C0A4C854015510A4A8900891839
:104C5000094CA222D2008C50C046C046C0460B6010
:104C6000064B000218438850C046C046C04630BDBF
:104C70000C05000000600040031F02000300030059
:104C800010B5002A02D0FFF741FF17E002780C4B65
:104C90009200D218A223DB00D4580A482040D050FA
:104CA000002902D0D158084806E0D05807490140F1
:104CB000D150D058802189020143D15010BDC04647
:104CC00000600040FFFFEFFF03000300FFFFFCFF59
:104CD000F7B50378234A0021D154234B00220578ED
:104CE000224E1A6501239D407360214B21491F8884
:104CF000695A041C381C019101F04AF9002100F0A6
:104D000087FE00F0E7FA1C4B1A4982B2EA526A5257
:104D1000002A04D10121E952201C111C14E0BA42DE
:104D200006D1013A201C0021EA52FFF7EFFE0DE008
:104D3000019A002A01D0BA4208D1019B201CDA1B3B
:104D400053425A41D2B20121FFF79AFF8022C12378
:104D500012039B00F250094A80239B00F25001236A
:104D60003360F7BD8D2E0020FCA0004000A0004065
:104D7000CA000020142E0020CC00002008080000EB
:104D80002C4BF7B52C4C00221A650123061C0D1C78
:104D9000081C6360002100F033FA002809D1FE21CD
:104DA000281C890500F040FA002803D0FE25AD0537
:104DB00000E00025214B347821491F886400615AA6
:104DC000381C019101F0E4F8011C281C00F020FEC1
:104DD00000F080FA1B4B1A4982B2E2526252002A5A
:104DE00004D10121E152301C111C14E0BA4206D159
:104DF000013A301C0021E252FFF788FE0DE0019AD3
:104E0000002A01D0BA4208D1019B301CDA1B57425C
:104E10007A41D2B20121FFF733FF07498022C12333
:104E200012039B00CA50084A80239B00CA500123EA
:104E30000B60F7BDFCA0004000A00040CA000020AD
:104E4000142E0020CC00002008080000CB17104AC8
:104E50009B0F0020106559180E480F4B01225A6015
:104E600089100E4A814202D90121494202E00429F7
:104E700000D8052111808021C12209039200995098
:104E8000074980229200995001221A607047C0465B
:104E9000FCA00040FFFF000000A00040CA0000206E
:104EA00008080000F7B5041C0E1C081C4D4900F052
:104EB000B7F84D4BC5B2C0B2195C012200290FD022
:104EC0005978002902D15A70151C0AE099780029F6
:104ED00002D19A70022504E044480DF080FE00E003
:104EE0001A54301C6670291C2570FFF7A1FE40493A
:104EF0006A00D2B23F4BAF007F18561C3D49D0002C
:104F0000C018B4463C4BF6007618C750F7503B4BE0
:104F1000AF00FF18A223DB00C7503948F050081C2F
:104F2000A021C9004658012301961F1C6646B740C0
:104F3000BC461F1C97403A1C6646019F32433A43C9
:104F40004250002D02D18022D2059367281CFFF722
:104F500031FE201C2B49FFF779FF257801222A4BCF
:104F60002A4E954000211965AE5B294B294F7A6086
:104F700001961E88301C01F00BF8002100F048FD5E
:104F800000F0A8F9244B214982B2EA526A52002A61
:104F900004D10126EE52201C111C14E0B24206D1AD
:104FA000013A201C0021EA52FFF7B0FD0DE0019903
:104FB000002901D0B14208D1019B201C9A1B564206
:104FC0007241D2B20121FFF75BFE8022C12312039E
:104FD0009B00FA50114A80239B00FA5001233B604A
:104FE000F7BDC046D49802008D2E00206002030059
:104FF0000060004000F001401405000040A10040A6
:105000004CA10040204E0000FCA00040142E0020C7
:10501000CA00002000A00040CC00002008080000CA
:1050200010B5041C431C07D00EF04BFE041C431C9F
:1050300002D102480DF0D3FD201C10BDC4020300B4
:1050400002B4714649084900095C49008E4402BC1B
:105050007047C04603B47146490840004900095EE4
:1050600049008E4403BC704703B4714649084000B0
:105070004900095A49008E4403BC7047002934D0C6
:105080000123002210B488422CD301242407A1421A
:1050900004D2814202D209011B01F8E7E400A142D7
:1050A00004D2814202D249005B00F8E7884201D372
:1050B000401A1A434C08A04202D3001B5C0822434A
:1050C0008C08A04202D3001B9C082243CC08A042BB
:1050D00002D3001BDC082243002803D01B0901D0A7
:1050E0000909E3E7101C10BC7047002801D000201C
:1050F000C04307B4024802A14018029003BDC04655
:10510000D90000000029F0D003B5FFF7B9FF0EBCAD
:105110004243891A1847C046002941D010B4041CE4
:105120004C40A44601230022002900D54942002812
:1051300000D5404288422CD301242407A14204D246
:10514000814202D209011B01F8E7E400A14204D226
:10515000814202D249005B00F8E7884201D3401A3D
:105160001A434C08A04202D3001B5C0822438C085F
:10517000A04202D3001B9C082243CC08A04202D3C9
:10518000001BDC082243002803D01B0901D00909B9
:10519000E3E7101C6446002C00D5404210BC704769
:1051A000002806D003DB0020C043400801E0802037
:1051B000000607B4024802A14018029003BDC04691
:1051C000190000000029EBD003B5FFF7A7FF0EBCC4
:1051D0004243891A1847C0467047C0468446081C97
:1051E0006146FFE71FB500F0C7FB002801D400218E
:1051F000C8421FBD10B500F04DFB4042013010BD4C
:1052000010B500F0B9FB002801DB002010BD012023
:1052100010BDC04610B500F0AFFB002801DD002036
:1052200010BD012010BDC04610B500F05DFB002888
:1052300001DC002010BD012010BDC04610B500F0FB
:1052400053FB002801DA002010BD012010BDC0462C
:10525000002B11D1002A0FD1002900D1002802D043
:105260000021C943081C07B4024802A1401802905B
:1052700003BDC04665FFFFFF03B4684601B5029851
:1052800000F05CF8019B9E4602B00CBC7047C04623
:105290009C460304F0B51B0C17043F0C150C1E1C98
:1052A000041C000C7E436B4347434543FB18300C02
:1052B0001818874202D980235B02ED18030CED1801
:1052C00063465C434A433604360CA1180004801937
:1052D0004919F0BD9E2110B5C905041CFFF7AEFFAA
:1052E000002803D1201C00F033FE10BD9E21C9050B
:1052F000201C00F0B7FC00F02BFE80231B06C0181A
:10530000F3E7C046F0B583B0161C1F1C0090019156
:1053100002F0A0FC041C0D1C221C2B1C301C391C90
:10532000FFF7B6FF009A019B121A8B410899201CC7
:105330000A604B60291C03B0F0BDC046F0B583B0D5
:10534000141C1D1C0090019102F060FE221C2B1CFD
:10535000061C0F1CFFF79CFF009A019B121A8B4141
:105360000899301C0A604B60391C03B0F0BDC04680
:10537000F8B543024400C50F4E024800240E2A1C13
:105380009B09000EC90FB6098D425BD0221A002A74
:1053900000DC89E000281DD1002E00D075E0580700
:1053A00004D00F221A40042A00D004338021C904FB
:1053B00019402A1C00293AD00134FF2C00D17FE08B
:1053C0009B015B0A5B02E4B2E405580AD207204362
:1053D0001043F8BDFF2CE2D08021C9040E431B2AE4
:1053E00000DD2DE1311C2020D140821A9640721E32
:1053F00096410E439B1B5801D1D59B019F09381C38
:1054000002F00AFC421F974094425BDC141B1F23EE
:105410001B1B3A1C9F40611C3B1CCA405F1EBB41CA
:1054200013430024BBE7131EB9D100230022DB087D
:10543000FF2C04D1002B43D08020C00303435B0228
:105440005B0ABFE7211A002940DD002823D0FF2C8A
:10545000A5D08020C00406431B2900DDEEE0301CEF
:105460002027C840791A8E40711E8E4106439B1931
:10547000590100D493E70134FF2C55D07149012222
:105480001A400B405B08134389E7013A002AB1D068
:10549000FF2CA4D183E7002E00D180E70139002939
:1054A000E5D0FF2CD8D17AE7002A1BD1621CD2B2FA
:1054B000012A4BDD9F1B7A0123D5F71A0D1C9EE7AD
:1054C00000237FE75F4BA41A3B4068E7002946D1E1
:1054D000611CC8B2012829DDFF2924D0F3185B081C
:1054E0000C1C5CE7002C13D0FF2818D08024E404A7
:1054F000524223431B2A4DDD0123F31A041C0D1CC9
:1055000079E7002F00D07AE70023002200248EE7FD
:10551000002B3BD0D243002AEFD0FF28EAD1331C26
:10552000FF240D1C3BE7FF24002380E7002C5CD107
:10553000002B00D180E0002E00D130E79B195801EC
:1055400000D42CE73F4A0124134028E7002C15D152
:10555000002B40D1002E63D0331C0D1C1FE7002C04
:1055600021D1002B54D0C943002904D0FF284CD0AE
:105570001B2958DD01239B19041C79E7002B19D145
:10558000002E48D0331C0D1CFF2408E7331C041CDC
:105590000D1C04E71C1C2025D440AA1A93405A1E57
:1055A00093412343A9E7FF282FD08024E4044942F4
:1055B0002343DDE7FF24002E00D1F0E68022DB0844
:1055C000D203134204D0F608164201D1331C0D1C3D
:1055D000DB00FF24E3E6002E00D1E0E69A1B500139
:1055E00000D420E7F31A0D1CD9E6002B0DD0FF24C0
:1055F000002E00D1D3E68022DB08D2031342E7D08D
:10560000F6081642E4D1331CE2E7331CFF24C6E659
:10561000331C041CC3E6802300229B04FF2406E7FE
:10562000231C002203E71C1C2027CC40791A8B4046
:10563000591E8B4123439EE7331CB0E6012616E733
:105640000126D7E6FFFFFFFBF0B55F4656464D4605
:105650004446F0B446024500C00F85B00F1C760AE0
:105660002D0E804641D0FF2D26D080242404002119
:105670002643F6007F3D89468B46F90F7C02780071
:10568000640A000E00918A463CD0FF2834D0802363
:105690001B041C430023E4007F380193009F434612
:1056A000019A7B4049469C4611430F2900D971E07D
:1056B000764F89007F58BF46002E3ED10822022334
:1056C00091469B46D9E75A46341CC246019201993D
:1056D000022937D0032900D1CFE0012900D0ABE067
:1056E00053460B400022002632E0002E19D104213F
:1056F000012289469346C0E7221C531E9A4102327A
:105700000192CBE701270197002CC7D0201C02F0A3
:1057100083FA431F9C4076235B420021181A0191B3
:10572000BCE7301C02F078FA7625431F9E406D429C
:1057300000232D1A99469B469FE70C230321994687
:105740008B469AE7D446012367463B40FF2200265A
:105750007602D205700ADB071043184305B03CBC43
:1057600090469946A246AB46F0BD80260023F6033C
:10577000FF22EDE700220026EAE78020C003064270
:105780003BD0044239D1061C26437602760A009BA0
:10579000FF22DDE7281A039076016401A64239D37F
:1057A000361B1A2201230120311C5B0076000029E0
:1057B00001DBB44201D8361B0343013A002AF3DC73
:1057C000741EA641341C1C43039A7F32002A27DD35
:1057D000630704D00F232340042B00D00434270197
:1057E00003D52B4B039A1C408032FE2A0BDD01238C
:1057F00061460B40FF220026AAE706437602760A9E
:105800004346FF22A4E7A40101236746660AD2B2F9
:105810003B409DE7039F1B22013F03970023C2E704
:105820007E23039F5B42DB1B1B2B07DD01236146AD
:105830000B40002200268BE7D446C5E7221CDA4045
:10584000039B9E339C40231C5C1EA34113435A07B9
:1058500004D00F221A40042A00D004335F0105D57A
:10586000012361460B400122002671E79E0162463A
:1058700001231340760A00226AE78026F6032643B6
:105880007602760A5346FF2262E7C0463C9A02003F
:10589000FFFFFFF74A02430270B55C0A550A430056
:1058A0004A001B0EC60F120EC90FFF2B05D0FF2A90
:1058B00008D0012093420BD070BD0120002CFBD1F9
:1058C000FF2AF6D10120002DF6D101209342F3D119
:1058D000AC42F1D18E4205D0002BEDD1201C441EEC
:1058E000A041E9E70020E7E74A024302F0B55C0A7D
:1058F000550A43004A001B0EC60F120EC90FFF2B9C
:1059000031D0FF2A34D0002B16D16042604184464A
:10591000002A14D0002820D18E4217D1934215DCE2
:1059200004DBAC4212D80020AC4212D2704270416B
:105930004042012318430CE0002AEDD194466F4207
:105940006F416046002805D1002FE5D07042012349
:105950001843F0BD0020002FFBD14842484140428F
:1059600001231843F5E7002CCBD002204042F0E79A
:10597000002DC8D0F9E7C0464A024302F0B55C0AE0
:10598000550A43004A001B0EC60F120EC90FFF2B0B
:1059900027D0FF2A29D0002B10D0002A15D19446F9
:1059A0006F426F416046002815D00020002F04D1BF
:1059B00048424841404201231843F0BD60426041E3
:1059C0008446002AECD00028F2D18E4211D07042D9
:1059D00001231843F1E7002FF7D070420123184349
:1059E000EBE70220002CE8D1D3E70220002DE4D120
:1059F000D1E79342EBDC04DBAC42E8D80020AC42B8
:105A0000DBD270427041404201231843D5E7C046C3
:105A1000F0B55F4656464D464446F0B44402460053
:105A200083B00F1C640A360EC50F002E41D0FF2E26
:105A300022D080231B0400201C43E4007F3E8246CA
:105A40008046391C4B007F02C90F7F0A1B0E8B4614
:105A50003BD0FF2B34D0802212041743FF007F3B42
:105A600000215A466A40019252460A430F2A63D8DF
:105A70007A48920082589746002C3FD10822022390
:105A800092469846DDE70195404602282AD1019AC0
:105A900001251540FF2300246402DB05600AED07A1
:105AA0001843284303B03CBC90469946A246AB46F7
:105AB000F0BD002C27D10420012282469046C0E789
:105AC000391C4A1E91410231CBE70121002FC8D079
:105AD000381C02F0A1F8431F9F4076235B421B1A3B
:105AE0000021BEE7032800D1AEE001284FD1019884
:105AF00042461040C5B200230024CDE70C2303200A
:105B00009A4680469DE7201C02F086F87626431FC1
:105B10009C4076420023361A9A46984691E78024A4
:105B20000025E403FF23B7E75B463C1C019388464E
:105B3000AAE73C1C8846A7E7250C24043A0C240C51
:105B40003F04F6183F0C211C231C794353436F4339
:105B50005543FB180A0C9B18B1469F4202D980227C
:105B60005202AD1809041A04090C521894011B0CB6
:105B7000611E8C41920EED181443AD012C4323019C
:105B800005D5012263080120144081441C434B4683
:105B90007F33002B2DDD600704D00F222240042A22
:105BA00000D00434220103D52D4B1C404B468033DA
:105BB000FE2B17DD019B01251D400024FF236BE711
:105BC0008020C003044208D0074206D1041C3C4395
:105BD0006402640A5D46FF235EE704436402640ACC
:105BE000FF2359E70198A4010125640ADBB20540AF
:105BF00052E77E235B424A469B1A1B2B05DD019B25
:105C000001251D400024002346E7221CDA404B46B4
:105C10009E339C40231C5C1EA3411343580704D0B1
:105C20000F221A40042A00D004335A0105D5019BE3
:105C300001251D40002401232EE701989C01012528
:105C4000640A0540002327E78027FF03019B3C43AC
:105C5000640201251D40640AFF231DE77C9A0200AF
:105C6000FFFFFFF7F8B5C20F430244004D024800A2
:105C7000240E161C9B09000EC90FAD09FF2800D188
:105C800083E0012779408A425CD0221A002A00DC96
:105C90008EE000281ED1002D00D07AE0580704D0F5
:105CA0000F221A40042A00D004338021C9040122A3
:105CB0001940324000293AD00134FF2C00D183E052
:105CC0009B015B0A5B02E4B2E405580AD207204359
:105CD0001043F8BDFF2CE1D08021C9040D431B2ADD
:105CE00000DD31E1291C2020D140821A95406A1E36
:105CF00095410D435B1B5801D0D59B019F09381C72
:105D000001F08AFF421F974094425FDC141B1F235F
:105D10001B1B3A1C9F40611C3B1CCA405F1EBB41C1
:105D200013430024BAE7131EB8D100230022DB0876
:105D3000FF2C04D1002B47D08020C00303435B021B
:105D40005B0ABFE7211A002944DD002827D0FF2C79
:105D5000A4D08020C00405431B2900DDF2E0281CEC
:105D60002027C840791A8D40691E8D4105435B1973
:105D7000590100D492E70134FF2C59D07349012214
:105D80001A400B405B08134388E7002D00D07AE7E8
:105D900077E7013A002AADD0FF2CA0D17EE7002D95
:105DA00000D17BE701390029E1D0FF2CD4D175E780
:105DB000002A1BD1621CD2B2012A4BDD5F1B7A0183
:105DC00023D5EF1A0E1C9AE700237BE75F4BA41A3A
:105DD0003B4063E7002946D1611CC8B2012829DD98
:105DE000FF2924D0EB185B080C1C57E7002C13D0BC
:105DF000FF2818D08024E404524223431B2A4DDD9F
:105E00000123EB1A041C0E1C75E7002F00D076E767
:105E10000023002200248AE7002B3BD0D243002A33
:105E2000EFD0FF28EAD12B1CFF240E1C36E7FF24FD
:105E300000237CE7002C5CD1002B00D180E0002DFA
:105E400000D12BE75B19580100D427E73F4A012412
:105E5000134023E7002C15D1002B40D1002D63D037
:105E60002B1C0E1C1AE7002C21D1002B54D0C94347
:105E7000002904D0FF284CD01B2958DD01235B19D1
:105E8000041C75E7002B19D1002D48D02B1C0E1CCB
:105E9000FF2403E72B1C041C0E1CFFE61C1C202601
:105EA000D440B21A93405A1E93412343A9E7FF28D6
:105EB0002FD08024E40449422343DDE7FF24002D52
:105EC00000D1EBE68022DB08D203134204D0ED08B8
:105ED000154201D12B1C0E1CDB00FF24DEE6002D39
:105EE00000D1DBE65A1B500100D41CE7EB1A0E1C54
:105EF000D4E6002B0DD0FF24002D00D1CEE6802269
:105F0000DB08D2031342E7D0ED081542E4D12B1C85
:105F1000E2E72B1CFF24C1E62B1C041CBEE68023F9
:105F200000229B04FF2402E7231C0022FFE61C1C26
:105F30002027CC40791A8B40591E8B4123439EE782
:105F40002B1CABE6012512E70125D3E6FFFFFFFB83
:105F50004302590A4300C20F1B0E00207E2B0DDDA9
:105F60009D2B0CDC802000040143952B0ADC96203D
:105F7000C31AD9404842002A00D1081C7047034B7D
:105F8000D018FBE7963B9940F4E7C046FFFFFF7F40
:105F900070B5041E3CD0C60F00D04442201C01F056
:105FA0003BFE9E23251C1B1A962B0CDC08388440D4
:105FB0006402640ADBB2321C6402DB05600AD207A9
:105FC0001843104370BD992B0ADD0522121A211CBB
:105FD000D1400A1C011C1B318D40691E8D411543A7
:105FE000052801DD421F9540164C2C406A0704D05D
:105FF0000F221540042D00D0043461010CD59F23DD
:10600000181AFF281AD0A401640AC3B2321CD3E7BD
:10601000002200230024CFE7E408FF2B04D0640211
:10602000640ADBB2321CC7E7002C04D08020C00316
:1060300004436402640A321CFF23BDE7321CFF23C1
:106040000024B9E7FFFFFFFB10B5041E33D001F0B9
:10605000E3FD9E231B1A962B09DC0838844064025A
:10606000640ADBB26402DB05600A184310BD992B99
:106070000ADD0522121A211CD1400A1C011C1B3109
:106080008C40611E8C411443052801DD421F944061
:10609000144A2240610704D00F210C40042C00D088
:1060A000043251010AD59F23181AFF2816D09401F3
:1060B000640AC3B2D6E700230024D3E7D208FF2B3B
:1060C00003D05402640ADBB2CCE7002A06D0802455
:1060D000E40314436402640AFF23C3E7FF2300249C
:1060E000C0E7C046FFFFFFFBF8B55F465646444693
:1060F0004D46F0B40C034D00CE0F610A440F21430E
:10610000C400180380465800400D8246D80F8446CC
:106110004046400A530F0343D0006D0D371C8346A1
:106120005246664500D1A4E0AF1A002F00DC09E119
:10613000002A3BD1184300D0EAE0630700D187E092
:106140000F232340042B00D182E0221DA242A44150
:106150006442802309191B040B40371C141C002BBC
:1061600000D17CE0CE4B01359D4200D105E1CD4B05
:10617000E40819404807490204430B0B00200021A2
:106180001B031A0B0B0D6D051B0513436A08C64D47
:10619000FF071D4015436D006D08291C3943201C65
:1061A0003CBC90469946A246AB46F8BDBC488542E9
:1061B000C3D0802000040343382F00DDF0E01F2F00
:1061C00000DD24E12020C01B1A1C81468240584675
:1061D000F8400243944658464A469040421E904139
:1061E000FB40624602431F1CA21A9442A44164422F
:1061F000C91B091B141C0B029FD549024F0A002F13
:1062000000D1C8E0381C01F007FD021C083A1F2A23
:1062100000DDB5E02821091A201C9740C84007433B
:106220009440954200DDB2E0551B691C1F2900DD3A
:10623000DCE01F22551B3B1C221CAB40CA40AC407B
:10624000651EAC411343CF401C43391C002574E745
:1062500080231B040B40371C002B00D082E7904B9F
:106260004807E4080443C9089D4248D009030B0BC2
:1062700084E7AA1A9446002A00DC98E050460028D9
:1062800052D08748854200D157E78020000403435D
:106290006246382A00DDFCE01F2A00DD4AE12022A8
:1062A0006046101A1A1C8240824691465846624641
:1062B000D0404A4602439046584652469040421EBD
:1062C0009041424602436046C3401219A242A44193
:1062D000644259180919141C080200D42DE7704BA8
:1062E00001359D4200D122E16E4B60081940012327
:1062F00023401C1C0443CB071C4349081DE7231CF7
:106300000B433AD080231B030B431B031B0B35E7C6
:10631000013F002F65D15846221A9442A44164429D
:10632000C91A091B141C66E75846184300D104E734
:106330000122524294446046002800D0C5E05846ED
:106340000219C3E7002F73D1681C4005400D0128D6
:1063500000DCDEE05A46A21A9442BF41C81A7F42CE
:10636000C71B380200D489E05A46141BA34592414A
:10637000591A52428F1A664641E700230024FDE66F
:10638000271C283887400024954200DC4CE745490B
:10639000AD1A3940D1E6201C01F03EFC203034E734
:1063A0005A461A43531E9A41D2B200271CE7002ACC
:1063B00000D0DCE0681C4205520D012A00DC8DE0B3
:1063C000374DA84200D1F3E05D462A19A242A4410C
:1063D000644259180919CC07520814434908051C8E
:1063E000ABE62F48854200D0E6E6A6E62B1C1F3B15
:1063F0003A1CDA40131C20296CD03F22551BAF40B9
:106400003C43601E84411C430021002595E6381C56
:1064100020381A1CC240101C202F5DD04022D71BF0
:10642000BB405A461A43531E9A4102430027DBE6FB
:10643000002D3BD01A4DAA4500D193E080252D04B4
:106440007F422943382F00DDACE01F2F00DD29E11A
:106450002025ED1B081C261CA840FE40AC4006432E
:10646000651EAC413443F9405D462C1BA345924167
:106470005B1A5242991A55466646BCE6131C3B43CA
:10648000141C002B00D0BAE60027002100250024B0
:10649000E5E65A461A43531E9A41D2B2002314E746
:1064A000FF070000FFFF7FFFFFFF0F800D1C25434C
:1064B00058D0FF43002F51D1041BA3459241591AD4
:1064C0005242891A5546664695E69648854200D05E
:1064D000DEE632E6002793E70023A2E7081C20430C
:1064E000002D00D0C4E0002800D1F7E05846184342
:1064F00000D122E658460219A242A441644259182A
:106500000919141C0A0200D417E6874B012519400B
:1065100013E6081C2043002D39D1002871D15946BB
:10652000194303D0191C5C46664606E60027002185
:10653000002494E6604620381A1CC240604691460A
:10654000202800D1ACE04022121A93405A461A4348
:10655000531E9A414B461A430023B6E6714DAA4595
:1065600000D06FE7191C5C4655466646E5E5002DF0
:1065700022D10D1C254377D0D543002D71D15C4429
:106580005C4592415918524289185546A4E60028A4
:106590004DD15946194300D194E0191C5C4666461A
:1065A000604DCAE50C43611E8C41E4B200215BE7FB
:1065B000051C0021002452E65A4DAA4554D05542EC
:1065C000802210040143382D00DD81E01F2D00DD05
:1065D00092E02022501B0A1C84468240201CE84086
:1065E0000243904662469440601E844142461443F2
:1065F000E9405C445C459241CB185242991855469B
:106600006AE65846184300D197E55846271ABC4217
:106610009241C81A5242801A020266D55846041B9B
:10662000A3459241591A5242891A664685E5584651
:10663000184333D04807E40804438020C908000306
:10664000014208D0DD08054205D15946CA085C0759
:106650001443291C6646630FC9001943E400314DF9
:106660006BE5304A9245AED1191C5C46554664E54F
:10667000002836D05846184310D080254807E40833
:10668000C9082D0304432942E5D0D8082842E2D1A5
:106690005D46EA085C071443011CDCE7214D4CE52C
:1066A000002353E73D1C203D0A1CEA40151C202F07
:1066B00034D04026F71BB9400C43611E8C412C435B
:1066C0000021D1E680210027C903164D0024C6E52C
:1066D0000C43611E8C41E4B200218AE7191C5C4620
:1066E0002BE5191C5C460F4D27E5031C3B4300D1ED
:1066F0001CE7011C3C1C20E52020404240190A1CDC
:10670000C2409046202D0BD04020451BA9400C4391
:10671000611E8C4145462C4300216AE70021CBE7EE
:106720000021F4E7FF070000FFFF7FFFF0B55646AA
:1067300044465F464D46F0B41F1C0B031B0B9846A6
:106740004B0087B0041C81465B0DC80F161C9A468F
:106750000090002B51D06A4B9A4531D0802241469F
:1067600052030A43630FD2001A43664B904600253A
:10677000E20091469A44002402953B031B0B9B4682
:10678000FD0F7B00311C5B0D019560D05C4A93428C
:1067900054D08021584649030143720FC900114368
:1067A000584A8B469B18F1000020009A04436A4027
:1067B00003920F2C00D9ADE0534EA4003459A746E4
:1067C000404604436ED100210225082488468946AC
:1067D0000295D2E7009C0298C346494601940228DC
:1067E00064D0032800D1ABE2012800D038E2019A3E
:1067F000002402400025A14660E0434623434AD0DE
:106800004046002800D1C0E101F006FA031E272B04
:1068100000DDB3E128210D1A211C083B4246E94066
:106820009A400D1C1543221C9A40A8469146374BAE
:1068300000251B1A9A46002402959EE75A461643E5
:106840000320002EB1D1B34600210220ADE75A4605
:1068500032431BD05B46002B00D18AE1584601F041
:10686000DBF9272800DD7DE12822171A011C321CE4
:1068700008395B46FA408B40171C1F43331C8B4082
:10688000BB46191C214B1B1A00208EE70027BB4674
:106890000021012089E7002001250424804681464B
:1068A00002956AE703250C24029566E7019C039490
:1068B000039D01222A400024114DA1460020002101
:1068C0002403260B0C0D2405114B34432D052340C6
:1068D0002B435B005B08D207191C4846114307B0E5
:1068E0003CBC90469946A246AB46F0BD00228024AF
:1068F00024039146024DE1E700240025A146DDE78F
:10690000FF07000001FCFFFFBC9A02000DFCFFFF27
:10691000FFFF0F805546ED1A0495D84500D953E185
:1069200000D14EE1049C0025013C4E4604944746AC
:10693000A946584603020C0E1C430902250C2304E9
:106940001B0C0091381C291C0193FEF797FB019941
:1069500083464143381C8A46291CFEF7D3FB330C7F
:10696000090419438A450CD95B460919013B8C423D
:1069700000D947E18A4500D844E1022252429344BB
:1069800009195346CB1A181C291C9846FEF776FBAA
:10699000071C0198291C784382464046FEF7B2FB4B
:1069A00036040B04360C33439A4509D91B197A1E59
:1069B0009C4200D924E19A4500D821E1023F1B19ED
:1069C0005E4632041743380CBB46009E009F51467A
:1069D0003F0C32045B1A5946BA46120C0F043F0CA6
:1069E000904651467A434F43414641435646704391
:1069F000CF19160CBE19B14202D980277F02C019E7
:106A0000310C12043604120C4018B618834200D21E
:106A1000C4E000D1BEE0191A4846861BB145BF410B
:106A20007F42CF1BA74200D113E1291C381CFEF77F
:106A300025FB019902904143381C8946291CFEF729
:106A400061FB330C0904194389450CD9029B0919D0
:106A5000013B8C4200D9FFE0894500D8FCE0029F51
:106A60000919023F02974F46CF1B381C291C059776
:106A7000FEF704FB071C0198291C78438146059802
:106A8000FEF740FB36040904360C0E43B14509D924
:106A900036197B1EB44200D9E0E0B14500D8DDE0F4
:106AA000023F3619029D4946761A290439430B04E0
:106AB00057460A0C1B0C40464546584355437B43FA
:106AC0007A43EB18070CDB199D4202D980256D0231
:106AD00052191D0C00041B04000C52191B1896427D
:106AE00035D300D1FCE001231943049E994FF519D9
:106AF000002D00DCA1E0480709D00F230B40042B38
:106B000005D00B1D8B42894149428B44191C5A46C2
:106B1000D20107D5904B5C46049E80271C40FF00A5
:106B2000A346F5198D4B9D427ADD039C012222403C
:106B300000248B4DA146C1E680242403474627420A
:106B40004CD13C432403240B009A854DB6E63619FC
:106B5000481EB4425ED9011C9642C4D1009E9E429A
:106B6000C1D1C2E7031C283B311C99408B46002150
:106B700088E6301C01F050F8203072E6283B211CDA
:106B8000994000228846914651E6201C01F044F8C5
:106B900020303BE60021B14500D33DE7009F5A4637
:106BA000B944B945BF417F423F19FB18013A9C42A5
:106BB0001ED2984200D97EE000D1B5E0191A934662
:106BC0002AE7894500D8ADE648464646424677085A
:106BD000D3074608C0071E438146AAE6584620420E
:106BE00012D1044324032A1C240B89465C4D65E61C
:106BF000A342E3D1009F4F45DBD9211A93460BE70F
:106C0000171CDDE69B46BCE63C432403240B009A9C
:106C1000534D53E6B24259D800D18AE0011C62E7D5
:106C20005F46C9087B07039E0B437C026D0501226A
:106C30009946240B6D0D324040E64A4B049FDB1B06
:106C4000382B10DD039C0122224000240025A146A0
:106C500034E60121494248E7029304E71F1C21E77B
:106C6000019C039441E71F2B40DC3F48049F0C1C10
:106C70003A1858469140DC40904020430A1C511E6F
:106C80008A41011C11435A46DA40131C480709D0B7
:106C90000F220A40042A05D00A1D8A42894149422E
:106CA0005B18111C1A0234D5039C012222400024D7
:106CB0000125A14602E6009F02214942B9448B44C6
:106CC000B945894149420919CB18A4E6009D881E9F
:106CD0006900A942AD416D422C19361900913AE77D
:106CE000002B00D033E70024009437E71F4A049CB0
:106CF0005D46121BD5402A1C202B1FD01C4E5F4620
:106D0000A3199F403B1C19434B1E9941114300237B
:106D1000BCE75A07C9080A43039F91465B02012258
:106D20001C0B3A400025C9E54E45C4D893460021C6
:106D300072E6009F9F42C9D3011C0FE70023E2E7E0
:106D4000802424035F463C432403240B019A894694
:106D5000034DB3E5FF030000FFFFFFFEFE07000049
:106D6000FF07000002FCFFFF1E040000E2FBFFFF24
:106D70003E040000F0B5564644465F464D46F0B42A
:106D80001F1C0B031B0B9A464B0087B0041C80464C
:106D90005B0DC80F161C02938146002B68D0694B0F
:106DA0000299994232D08022534652031A43D200AC
:106DB000630F1A439246644AE000891880460291A4
:106DC000002400253B031B0B9B467800FB0F321C65
:106DD000400D039300D175E05A4B984269D0802250
:106DE000594652030A43730FD2001A43564B934637
:106DF000C018F200002303994E4671401C430F2C2B
:106E000000D9A9E0514EA4003459A74653461C436B
:106E100000D087E00025AA46A84608240225D1E72D
:106E20004946022D6CD0032D00D117E2012D00D070
:106E300058E10D40EDB20024A9460023A0460020F1
:106E4000002125030A0D1C052D0B1205404B2A437A
:106E5000134023435B004C465B08E207191C404685
:106E6000114307B03CBC90469946A246AB46F0BDE4
:106E70005346234350D05346002B00D184E1504663
:106E800000F0CAFE031E272B00DD76E128210D1A33
:106E9000211C083B5246E9409A400D1C1543221C18
:106EA0009A40AA4690462B4B00241B1A02930025B9
:106EB00088E75B461E430323002E9CD1B346002285
:106EC000022398E75B46334321D05846002800D17F
:106ED0004EE100F0A1FE272800DD42E128210F1A33
:106EE000021C311C083A5B46F94093400F1C1F43BB
:106EF000331C9340BB461A1C164B181A00237AE722
:106F000001230B4000249946A0460E4B97E700272B
:106F1000BB46002201236EE7002104248A468846EE
:106F200001254FE70C2403254CE700258024A946C2
:106F30002403A846034B82E7DA46904603991D1CBA
:106F40006FE7C046FF07000001FCFFFFFC9A02004C
:106F5000FFFF0F800DFCFFFF029F160C38180490F6
:106F60004046070C0004000C1204120C031C53438F
:106F7000041C3D1C7443554398463B1C73436419E1
:106F8000A44644460293230C63449D4204D9029DC7
:106F9000802464022D1902951D0C039545462C048E
:106FA0001B04240C1C1905945C46230C051C584337
:106FB0002404240C8446381C604365435F438146A7
:106FC000CC44280C6044BB46814502D980277F020F
:106FD000BB442D04070C2D0C000440195546BC463B
:106FE0002F04E3448446280C3D0C2F1C5743B8461D
:106FF0002F1C77434243B94647463F0C9144BA465B
:10700000D14446434A4502D980225202B6184F461F
:107010003A0CB6183A0447463F043F0CB8462F1CBA
:1070200067435D434443584365190190380C2D185C
:107030004244B846AC4204D9019880235B02C01890
:107040000190039C029F201C6044C0196045A4412C
:1070500047466442A4462B043C049946240C4C4405
:10706000A046D8448018C246E24490429241574616
:1070700052429146F219E245BF417F424B46BC461F
:10708000D845BF41D4187F4263461F432D0C7F195A
:10709000B24292414C45AD4152426D421543019E70
:1070A0007D19AB19E20D5B02059F134342023A437F
:1070B0009A46531E9A41C30D101C18436402204384
:1070C00080465046C0010DD5454601225646049CD7
:1070D0006B082A401A43F30701341A4376080494D4
:1070E0009046B246049E634FF319002B61DD404683
:1070F00040070BD00F2244462240042A06D04246C5
:107100000432424580414042824490465546ED015A
:1071100007D5594B5646049F80201E40C000B246FA
:107120003B18564A934200DDEAE644465546E208DB
:107130006807104301226C025B050A408046240B5D
:107140005B0D91467BE6DA4690461D1C69E680247D
:107150002403574627421CD13C432403240B484BAD
:107160006DE6031C283B311C99408B460022C3E688
:10717000301C00F051FD2030ADE6283B211C994029
:1071800000228A4690468EE6201C00F045FD203005
:1071900078E65846204207D1044303992403240B80
:1071A00089469046364B4AE63C432403240B344B35
:1071B00045E6344B049E9B1B382B06DD01230B4018
:1071C00000249946A046002339E61F2B25DC049CA9
:1071D0002D4D46466019524644468640DC4082406A
:1071E0005746301C2243DF40441EA04102433B1C53
:1071F000540709D00F201040042805D0101D9042DC
:10720000924152429B18021C1D021AD501230B40C9
:1072100000249946A046012311E61C48049C5546CB
:10722000001BC540281C202B16D0194E5746A2190A
:1072300097403A1C43461A43531E9A410243002387
:10724000D6E758075B02D2081C0B01230B40104302
:10725000994680460023F2E50022EBE780242403D0
:1072600050460123044319402403240B8946044B50
:10727000E5E5C046FF030000FFFFFFFEFE0700003C
:10728000FF07000002FCFFFF1E040000E2FBFFFFFF
:107290003E040000F8B55F46564644464D46F0B4FD
:1072A0000C034D00CF0F610A440F2143C4001803A3
:1072B000DE0F8046B44646465800760A530F3343E5
:1072C000D600D14A6D0DBA46400DB346904200D16A
:1072D000F5E06246012672409446674500D1ABE076
:1072E0002F1A002F00DC11E100283ED15846184328
:1072F00000D0F1E0600700D197E00F232340042B7A
:1073000000D122E1221DA242A44164428023091936
:107310001B04012750460B400740141C002B00D1D2
:1073200079E0B94B01359D4200D10BE1B74BE40840
:1073300019404807490204430B0B002000211B039E
:107340001A0B0B0D6D051B0513436A08B04DFF07A3
:107350001D4015436D006D08291C3943201C3CBCA1
:1073600090469946A246AB46F8BDA7488542C1D093
:10737000802000040343382F00DDFDE01F2F00DDD7
:1073800031E12020C01B1A1C5E468240FE40324381
:1073900094465A468240101C421E9041FB40624671
:1073A00002431F1CA21A9442A4416442C91B091B38
:1073B000141C0A029ED549024F0A002F00D1D6E0C4
:1073C000381C00F029FC021C083A1F2A00DDC3E02B
:1073D0002821231C091A9740CB401F439440954213
:1073E00000DDC0E0551B691C1F2900DDEAE01F22FB
:1073F000551B3B1C221CAB40CA40AC40651EAC4137
:107400001343CF401C43391C002573E780217E4D78
:107410000027C90300247C4B4807E4080443C9083B
:107420009D4250D009030B0B87E780231B040127E3
:1074300052460B40174071E72A1A9446002A00DC96
:10744000A1E0002854D07048854200D152E7802046
:10745000000403436046382800DD0EE11F2800DDEC
:1074600057E162462020801A1E1C8640B1465E46C7
:10747000D6404A4632435E4686409046301C421E05
:107480009041424602436046C3401219A242A441C1
:10749000644259180919141C080200D42AE75A4BEF
:1074A00001359D4200D131E1584B6008194001235C
:1074B00023401C1C0443CB071C4349081AE71E4306
:1074C00000D00AE705E7231C0B433BD080231B03B6
:1074D0000B431B031B0B30E7013F002F6DD15E46B2
:1074E000A21B9442A4416442C91A091B141C60E700
:1074F0005846184300D1FDE601267642B444604662
:10750000002800D0D0E05E463219BFE7002F00D03F
:1075100080E0681C4005400D012800DCE8E05A4688
:10752000A21A9442BF41C81A7F42C71B3E0200D430
:1075300098E05846041BA3459241591A52428F1AAB
:10754000E2463AE700230024F7E680231B040127E4
:1075500056460B403740E1E6271C28388740002478
:10756000954200DC3EE72949AD1A3940C2E6201CAD
:1075700000F052FB203026E75A461A43531E9A4128
:10758000D2B200270EE7002A00D0DEE0681C4605D4
:10759000760D012E00DC90E01B4DA84200D1F5E0F5
:1075A0005E463219A242A441644259180919CC0717
:1075B000520814434908051C9CE61348854200D034
:1075C000D9E697E62B1C1F3B3E1CDE40331C2029CE
:1075D0006FD03F22551BAF403C43601E84411C438B
:1075E0000021002586E6381C20381E1CC640301CB1
:1075F000202F60D04022D71BBB405A461A43531E4F
:107600009A4102430027CDE6FF070000FFFF7FFFFE
:10761000FFFF0F80002D37D0B64DA84200D18FE07C
:1076200080252D047F422943382F00DDA8E01F2F3D
:1076300000DD24E12025ED1B0E1CAE40B046261CCB
:10764000FE404246AC401643651EAC413443F9400F
:107650005A46141BA34592415B1A5242991A051CC3
:10766000E246A6E6131C3B43141C002B00D0A4E604
:107670000027002100250024CDE65A461A43531E58
:107680009A41D2B2002300E70D1C254358D0FF4396
:10769000002F51D15A46141BA3459241591A524208
:1076A000891A051CE24684E69248854200D0D1E65C
:1076B00020E6002790E700239FE7081C2043002DC9
:1076C00000D0C2E0002800D1EFE05846184300D1B6
:1076D00010E658460219A242A441644259180919F9
:1076E000141C0A0200D405E6834B0125194001E66B
:1076F000081C2043002D38D100286FD1594619436A
:1077000003D0191C5C46E246F4E500270021002462
:1077100081E6604620381A1CC2406646101C202EA6
:1077200000D1AAE04022921B93405A461A43531EAE
:107730009A4102430023A8E66E4DA84200D073E7A9
:10774000191C5C46051CE246D4E5002D22D10D1C17
:10775000254376D0D543002D70D15C445C459241E1
:10776000591852428918051C96E600284CD15946F2
:10777000194300D14AE6191C5C46E2465D4DB9E565
:107780000C43611E8C41E4B2002161E7051C00211D
:10779000002440E6574DA84253D05542802216049B
:1077A0003143382D7BDC1F2D00DD8CE02022561B61
:1077B0000A1CB446B240261CEE4032439046624654
:1077C0009440661EB44142461443E9405C445C4523
:1077D0009241CB1852429918051C5DE65846184351
:1077E00000D187E55E46A71BBC429241C81A5242AF
:1077F000801A060260D55846041BA3459241591AC7
:107800005242891AE24675E55846184333D0480774
:10781000E40804438020C9080003014208D0DD08C1
:10782000054205D15946CA085C071443291CE246A3
:10783000630FC9001943E4002E4D5BE52D4A9042C9
:10784000AFD1191C5C46051C54E5002830D05846C1
:10785000184310D080254807E408C9082D030443C5
:107860002942E5D0D8082842E2D15D46EA085C0703
:107870001443011CDCE71F4D3CE5002355E73D1C8C
:10788000203D0E1CEE40351C202F2ED04026F71B2D
:10789000B9400C43611E8C412C430021D8E60C43B7
:1078A000611E8C41E4B2002190E7191C5C4621E581
:1078B000191C5C460F4D1DE5031C3B4300D124E71A
:1078C000011C3C1C16E52026764276190A1CF24063
:1078D0009046202D0BD04026751BA9400C43611EFD
:1078E0008C4145462C43002170E70021D1E700215F
:1078F000F4E7C046FF070000FFFF7FFF70B50B1CD9
:10790000124C09030E0B5900021C490DDD0F00201B
:10791000A14211DD0E4881420FDC80204003064366
:107920000C48401A1F280BDD0B4A521AD640321C55
:107930005042002D00D1101C70BD084BE818FBE729
:10794000074BC240C9188E403243F1E7FE030000E6
:107950001D0400003304000013040000FFFFFF7F3C
:10796000EDFBFFFFF8B5041E31D0C70F00D0444235
:10797000201C00F051F9184D2D1A0A2819DD0B387A
:10798000844024036D05240B6D0D3A1C0026002055
:1079900000210B0D2403240B1B0523430F4C2D0545
:1079A0001C402C4364006408D307211C301C19437D
:1079B000F8BD061C1536231CB3401E1C0B23181AD9
:1079C000C44024036D05240B6D0D3A1CDFE7002233
:1079D000002500240026DAE71E040000FFFF0F80C8
:1079E00043001B0E5A1C4102D2B270B54C0AC50F9F
:1079F000012A17DDE02292006407090B9818002283
:107A000000231E0D221C34050C431B494005400871
:107A10002140014349004908ED070B1C2B43101C72
:107A2000191C70BD002B15D1002C1CD0201C00F09F
:107A3000F3F80A281ADC0B21091A231CCB40191C65
:107A4000031C15339C400D4B0903181A4005090B04
:107A5000400DD4E7002C03D06407090B0848CEE79B
:107A600007480021CBE700200021C8E7011C0B39A3
:107A70008C40211C0024E6E7FFFF0F8089030000F3
:107A8000FF070000F0B54B000D03420F5B0D6D0AC0
:107A900015435A1C5205CC0FC600520D012A27DD92
:107AA000394FDA19FE2A1ADC002A35DD8001ED0093
:107AB000431E98412843760F3043430704D00F23D9
:107AC0000340042B00D004308021C904014027D09A
:107AD0000132FF2A1DD083015B0AD1B201E0FF21F0
:107AE00000235802C905400AE40708432043F0BDBB
:107AF000002B06D1354311D10021002043025B0A3F
:107B0000EFE72E43EBD08020ED0080042843FF22D6
:107B1000D3E7FF210023E4E717320DDA0520002226
:107B2000C008D1B2FF2AE9D10028D9D08023DB03D5
:107B300003435B025B0AD4E7802214491204154315
:107B4000C91A1F290DDC124A371C9B18281C9F409C
:107B500098403B1C5A1E93411843CE4030430022AC
:107B6000ABE70C4F2A1CFF1AFA40171C202909D03A
:107B7000094A98188540281C3043461EB0413843B6
:107B800000229AE70020F7E780FCFFFF9E03000039
:107B900082FCFFFF7E030000A2FCFFFF8446101C56
:107BA00062468C46191C634600E0C0461FB500F0D3
:107BB000B7FC002801D40021C8421FBD10B500F059
:107BC000E7FB4042013010BD10B500F0A9FC0028D1
:107BD00001DB002010BD012010BDC04610B500F033
:107BE0009FFC002801DD002010BD012010BDC04613
:107BF00010B500F017FC002801DC002010BD0120AA
:107C000010BDC04610B500F00DFC002801DA0020C0
:107C100010BD012010BDC0461C2101231B04984249
:107C200001D3000C10391B0A984201D3000A08390D
:107C30001B09984201D30009043902A2105C4018C4
:107C40007047C04604030202010101010000000068
:107C500000000000F0B544465F4656464D46F0B47D
:107C60001C1C85B0002900DADBE00F1C0021061C7B
:107C70008A46101C191C002C00DAC9E001960090FD
:107C800089468046002951D1B84200D871E0FFF7FB
:107C9000C3FF002809D020234546311C1B1A85400C
:107CA0008740D940A8460F4386404246150C13042E
:107CB0001B0C291C381C9B46FDF7E0F95B4643432F
:107CC000041C291C381C9946FDF71CFA330C0804C7
:107CD0001843814509D94044631E804500D978E1A5
:107CE000814500D875E1023C40444946411A894625
:107CF000081C291CFDF7C2F95A464243071C291CDF
:107D000048469346FDF7FEF936040904360C0E4347
:107D1000B34507D946447B1EB04502D8023FB34560
:107D200000D81F1C24042743002403E0B94211D9C2
:107D3000002400275246381C211C002A03D03B1C7B
:107D400000215842A14105B03CBC90469946A2464C
:107D5000AB46F0BD081CFFF75FFF041E00D0BFE07C
:107D6000B94500D242E1019D0099071C8D4247416F
:107D7000E0E7002804D101200021FDF77FF98046CB
:107D80004046FFF749FF002852D1414644460B04C4
:107D90003C1B1B0CA3460D0C00930124291C5846C8
:107DA000FDF76CF9009F81464743291C5846FDF7B3
:107DB000A9F9330C090419438F4208D94B464144B1
:107DC000013B884502D88F4200D91AE19946C91B68
:107DD0008B46081C291CFDF751F9009B291C4343C5
:107DE000071C58460093FDF78DF93604009D0904E1
:107DF000360C0E43B54207D946447B1EB04502D827
:107E0000023FB54200D81F1C49460E04374391E794
:107E10005246D243031C0C1C924600215842A141F9
:107E20002CE7002746428F41012149428A4620E73C
:107E300020231B1A4246351C82403C1CDD40DC409E
:107E400087402B1C150C3B43291C8640201C0093AB
:107E500017049046FDF712F93F0C011C7943814647
:107E60008B46201C291CFDF74DF9009C0904230CAE
:107E700019438B450CD94B464144013B884500D9F9
:107E8000BDE08B4500D8BAE0022252429144414401
:107E90005C460C1B201C291C0194FDF7EFF8391CD3
:107EA0004143041C8B460198291CFDF72BF9009ACD
:107EB000090413041B0C19438B4509D94144631E63
:107EC000884500D997E08B4500D894E0023C4144B6
:107ED0005B46CB1A49469B460B041C4300975DE763
:107EE000009D20231B1A4A468240DD401543391C61
:107EF000009AD94082408846311C0092D9403A1CF1
:107F000082400B1C134301932F0C2B041B0C391CB8
:107F100040460293FDF7B2F8029A81464243391C6B
:107F200040469346FDF7EEF8019A0904130C1943F5
:107F30008B450AD94B464919013B8D425DD88B458B
:107F40005BD902235B42994449195A468A1A101C8C
:107F5000391C0392FDF792F8029B80464343391C7B
:107F600003989B46FDF7CEF8019A090413041B0CF5
:107F700019438B450AD943464919013B8D4238D8EC
:107F80008B4536D902235B42984449195D464D1B07
:107F9000AB464946009D0F04424617432A04120C83
:107FA0003B042D0C1B0C380C111C594342436B43F2
:107FB0006843D3180D0C5B198C469A4202D9802273
:107FC000520280181D0C401983450CD303D00024A5
:107FD000B0E61C1C89E665462A041B04120C9B189B
:107FE000A6409E42F3D2013F0024A3E600240127CD
:107FF000A0E69846CAE71C1C6AE79946A5E7994699
:1080000046E70222524291444144E0E6F0B55F4621
:1080100056464D464446F0B40D1C85B0061C9246AB
:1080200098460290019103921F1C141C8346A94696
:10803000002B59D1AA4269D9101CFFF7EDFD002889
:108040000AD020231B1A311CD94085400B1C2B431E
:10805000864084409946B346250C23041B0C291CFA
:1080600048469846FDF70AF84646071C4643291C31
:108070004846FDF747F85A460904130C19438E4247
:1080800009D909197B1E8C4200D957E18E4200D8CC
:1080900054E1023F0919891B8946081C291CFCF779
:1080A000EDFF43464343061C291C48469846FDF70E
:1080B00029F85A46130409041B0C1943884508D9AA
:1080C0000919731E8C4200D936E1023E884500D85A
:1080D00032E1380430430027391C05B03CBC9046DF
:1080E0009946A246AB46F0BD019A934262D8181C4D
:1080F000FFF792FD041E60D1019B9F4200D22CE14C
:10810000029F03998F4260410027E5E7002A04D1CE
:1081100001200021FCF7B2FF041C201CFFF77CFDAE
:10812000002800D0B9E023042D1B1B0CA946260C07
:1081300098460127311C4846FCF7A0FF41464143C1
:10814000051C8A464846311CFCF7DCFF5A460804E9
:10815000130C1843824507D900196B1E844202D8BC
:10816000824500D910E11D1C5346C31A181C311C4E
:108170009A46FCF783FF4146414381468846504674
:10818000311CFCF7BFFF5A46130409041B0C1943AA
:1081900088450BD94B460919013B8C4200D9CFE0E9
:1081A000884500D8CCE002235B4299442804494624
:1081B000084391E7002700208EE720231B1A424640
:1081C00057468240DF401743524682400192321C9C
:1081D000DA40291CD9408540131C2B4302933D0CE7
:1081E0003B041B0C8846081C291C9A46FCF746FFDA
:1081F000534643438146291C40469B46FCF782FF79
:10820000029A0904130C19438B4506D94B46C91928
:10821000013B8F4200D8ABE099465A468A1A101C9F
:10822000291C9346FCF72AFF53464343291C8046EA
:1082300058469A46FCF766FF029A090415042D0C6D
:1082400029438A4506D94346C919013B8F4200D8C4
:1082500086E098465746CF1BBA464946019F080418
:10826000424610433D042D0C03043F0C1B0C020C32
:10827000291C594355437B437A43EB180F0CDB19F8
:108280008C469D4202D980277F02D2191D0C5219BB
:1082900092455FD356D000271EE720231B1A311CBE
:1082A0002F1CD940DF4085400B1C84402B43864067
:1082B0000193B3462304260C1B0C381C311C984632
:1082C000FCF7DCFE42464243051C311C381C91463B
:1082D000FCF718FF019F09043B0C1943894507D996
:1082E00009196B1E8C424DD889454BD9023D09199D
:1082F0004A468A1A101C311C9246FCF7BFFE4346C0
:108300004343071C311C50469946FCF7FBFE019A7B
:10831000090413041B0C1943894507D909197B1E4D
:108320008C422DD889452BD9023F09194B46CB1ACF
:108330002D0499462F43FDE61E1CCAE61F1CAAE623
:10834000994633E761460A041B04120C9B18A640A9
:108350009E42A0D201380027BEE600270120BBE6DE
:108360008A4500D875E702235B429844C91971E732
:108370008B4500D850E702235B429944C9194CE76A
:108380001F1CD3E71D1CB3E7023D0019ECE6C046F5
:10839000F0B55F4656464D464446F0B40D1C041CED
:1083A0008046E80F814618030F03000B3F0B83B094
:1083B00084461B48009749005E00DF0F490D924636
:1083C000760DBB4681420CD01548864210D0012064
:1083D000B14215D003B03CBC90469946A246AB468C
:1083E000F0BD009F01202743F4D10D488642EED115
:1083F000604602430120002AECD10120B142E9D1BC
:10840000009B6345E6D1D045E4D1D94506D000298B
:10841000E0D11C43201C441EA041DBE70020D9E72B
:10842000FF070000F0B55F4656464D464446F0B49F
:10843000CD0FDE0FAC461D032D0BB146374E0F039B
:108440004C00AB465D0080463F0B640D92466D0DBF
:10845000B44232D0314EB54235D0002C0ED1384323
:1084600041424141081C002D0BD0002919D1CC45B7
:108470002DD0654668420123184318E0002DF6D13F
:10848000281C59460A4353425341002806D1002B69
:10849000EDD0634658420123184308E00020002B2A
:1084A00005D14A46504250414042012318433CBC4A
:1084B00090469946A246AB46F0BD3E1C0643C9D045
:1084C00002204042F3E75E461643C6D0F8E7AC42CE
:1084D00007DC0BDA61464842484140420123184319
:1084E000E5E76646704201231843E0E75F450AD896
:1084F0000ED000205F45DAD26546684268414042AE
:1085000001231843D3E76246504201231843CEE7C4
:10851000D045F8D80020D045EED3C8E7FF070000CB
:10852000F0B556464D4644465F46F0B40D1C83B048
:10853000041C0190E80F814618030F03000B3F0B4A
:1085400084463548009749005E00DF0F490D92468A
:10855000760DB846814234D02F48864236D0002965
:1085600018D0002E1FD1341C67463A435342534162
:10857000002C1FD00020002B05D142465042504114
:1085800040420123184303B03CBC90469946A246A2
:10859000AB46F0BD0098044360426041041C002ECD
:1085A000E2D00028E9D1C14515D04F4678420123D9
:1085B0001843E8E7002BF6D04B46584201231843F6
:1085C000E1E7009F02202743DDD1C5E7674602208F
:1085D0001743D8D1C3E7B14204DD4A4650420123D4
:1085E0001843D0E7B14207DB00986045E4D80AD0D1
:1085F000009F00206745C6D24F46784278414042EE
:1086000001231843BFE7019A5245D5D8019A0020AB
:108610005245F1D3B7E7C046FF070000F0B5794BEC
:108620004746450080B4041C061C6D089D420BDDC6
:10863000FF23DB059D4200DD75E0002800DCA1E0A2
:10864000714804BC9046F0BD704B9D427CDC704B81
:108650009D426CDD01235B429846211C201CFDF7E6
:10866000D7F9071C391CFDF7D3F96A49051CFDF73A
:10867000CFF96949FCF77CFE291CFDF7C9F9674968
:10868000FCF776FE291CFDF7C3F96549FCF770FE7F
:10869000291CFDF7BDF96349FCF76AFE291CFDF7AB
:1086A000B7F96149FCF764FE391CFDF7B1F95F4980
:1086B000071C281CFDF7ACF95D49FDF7D3FA291C0E
:1086C000FDF7A6F95B49FDF7CDFA291CFDF7A0F9E6
:1086D0005949FDF7C7FA291CFDF79AF95749FDF7E3
:1086E000C1FA291CFDF794F94346011C01334BD014
:1086F0004346381C9D00FCF73BFE211CFDF788F922
:108700004F4BE958FDF7AEFA211CFDF7ABFA4D4B84
:10871000011CE858FDF7A6FA002E00DB91E7802344
:108720001B06C0188DE7211CFCF722FE89E746498D
:10873000FCF71EFEFE218905FCF776FD031C201CBC
:10874000002B00D07DE785E700F014F93F4B041CB7
:108750009D4224DC3E4B9D4242DC211CFCF708FE7E
:10876000FE218905FDF77EFA8021051CC905201C24
:10877000FCF7FEFD011C281CFCF766FF0023041C0F
:1087800098466AE733485CE7381CFCF7F1FD211C8A
:10879000FDF73EF9011C201CFDF764FA51E72E4B52
:1087A0009D4215DCFF218905FDF75CFAFF21051CC0
:1087B0008905201CFDF72CF9FE218905FCF7D8FD61
:1087C000011C281CFCF740FF0223041C984644E7C8
:1087D000211C2248FCF738FF0323041C98463CE781
:1087E000FE218905FDF73EFAFE21051C8905201CA6
:1087F000FCF7BEFD011C281CFCF726FF0123041C0E
:1088000098462AE7FFFF7F50DB0FC93FFFFFDF3E9F
:10881000FFFFFF30D769853C59DA4B3D356B883D0A
:108820006E2EBA3D2549123EABAAAA3E21A215BD25
:108830006BF16E3D95879D3D388EE33DCDCC4C3E32
:108840003C9B02004C9B0200CAF24971FFFF973F1C
:10885000FFFF2F3FDB0FC9BFFFFF1B40000080BFA2
:10886000F0B54300474680B45F081B0E1E1C7F3ED8
:10887000041C162E1CDC8046002E22DB1B4F051C20
:108880003741074210D01A49FCF772FD0021FCF76E
:10889000CBFC002808D0002C04DD80231B043341CE
:1088A0001E19B0464546BD43281C04BC9046F0BD89
:1088B000104B051C9F42F7D9211CFCF759FD051CE4
:1088C000F2E70B49FCF754FD0021FCF7ADFC002852
:1088D00006D0002C06DB002F02D0FE25AD05E3E715
:1088E000251CE1E780252D06DEE7C046FFFF7F005F
:1088F000CAF24971FFFF7F7F00B51C4A430083B075
:10890000011C5B08934217DD194A934203DDFDF712
:10891000A9F903B000BD694601F06EFC03231840BD
:10892000012815D002280BD000281AD000980199F0
:10893000012202F063FAECE7002101F037FEE8E7DC
:108940000098019901F032FE80231B06C018E0E771
:1089500001990098012202F051FA80231B06C018E9
:10896000D7E70098019901F021FED2E7D80F493FDF
:10897000FFFF7F7F400040087047C046F0B54300CE
:10898000474680B45F081B0E1E1C7F3E041C162E3B
:1089900017DC8046002E1DDB1A4F051C37410742AD
:1089A0000BD01949FCF7E4FC0021FCF73DFC002842
:1089B00003D0002C1CDB4546BD43281C04BC90465C
:1089C000F0BD124B051C9F42F7D9211CFCF7D0FCCF
:1089D000051CF2E70C49FCF7CBFC0021FCF724FC5A
:1089E000002803D0002C09DB0025E6E7251CE4E77E
:1089F00080231B0433411E19B046DCE7002FF5D05D
:108A0000034DDAE7FFFF7F00CAF24971FFFF7F7F66
:108A1000000080BF43005B080220002B00D170479C
:108A2000074A04209918074A9142F8D9064A591E64
:108A300003209142F3D9054A9B1858425841EEE76A
:108A4000000080FFFFFFFF7EFEFF7F0000008080B0
:108A500038B50C1C0021216010494300051C5B083F
:108A6000021C8B4217DC002B15D00D4900228B42D3
:108A700008DC9821C905FCF7CBFF19224300051C2F
:108A80005B085242DB157E3B9A182260054A15406E
:108A9000FC2292052A43101C38BDC046FFFF7F7F91
:108AA000FFFF7F00FFFF7F8038B5041C0D1C02F024
:108AB00069FB002805D0201C0021FCF79BFB002847
:108AC00001D0201C38BD201C291C00F055F8041CC6
:108AD00002F058FB002805D0201C0021FCF78AFB7F
:108AE0000028EED002F018FC22230360E9E7C0461C
:108AF00008B543001B0E7F3B162B0DDC002B0FDB54
:108B0000094A1A41131C024206D0021C9A430A6009
:108B1000111CFDF7A7F802E00860C00FC00708BDF0
:108B2000C30FDB070B60FAE7FFFF7F0008B54300C8
:108B30001B0E7F3B021C162B0DDC002B12DB0D489D
:108B4000111C1841104204D08021C9031941891811
:108B50008143081C08BD011C802BFAD1FCF708FCDE
:108B6000011CF6E7C10FC9070133F2D1FE239B05B3
:108B70001943EEE7FFFF7F0070B5031C4400061C9D
:108B80000D1C60081A1C00280FD0274988420ED8F7
:108B9000264A904211D9240E6419FE2C2ADC002C9E
:108BA00019DD234BE2051E403243101C70BD181C1A
:108BB000191CFCF7DDFB021CF7E79821181CC905FE
:108BC000FCF726FF1B4A031C95421CDB4400240EC5
:108BD000061C193CE0E7221C163219DA164A9542A7
:108BE00008DC191C154802F0C7FA1449FCF710FFFD
:108BF000021CDAE7191C124802F0BEFA1049FCF711
:108C000007FF021CD1E70D49FCF702FF021CCCE76D
:108C1000074A201C19301640C005CC213043890575
:108C2000FCF7F6FE021CC0E7FFFF7F7FFFFF7F001F
:108C3000FFFF7F80B03CFFFF50C300006042A20DE9
:108C4000CAF2497100B51D4A430083B0011C5B089C
:108C5000934219DD1A4A934203DDFDF703F803B08E
:108C600000BD694601F0C8FA03231840012819D055
:108C700002280ED000281AD00098019901F096FC25
:108C800080231B06C018EAE70021002202F0B6F894
:108C9000E5E700980199012202F0B0F880231B0655
:108CA000C018DCE70199009801F080FCD7E7009834
:108CB0000199012202F0A2F8D1E7C046D80F493F3E
:108CC000FFFF7F7F00B5104A430083B0011C5B08A3
:108CD000934213DD0D4A934203DDFCF7C3FF03B05B
:108CE00000BD694601F088FA01231A1C02405200B7
:108CF00001999A1A009802F0FBF8F0E7002101228E
:108D000002F0F6F8EBE7C046DA0F493FFFFF7F7F3E
:108D100008B5E8F745F908BD70B58AB0041C00F045
:108D20009FF8224E0023F356051C013304D0201C6B
:108D3000FFF770FE002802D1281C0AB070BD201C6D
:108D4000FFF718FEFE218905FCF76EFA0028F3D024
:108D500001230093164B201C019300230893FEF778
:108D60003FFE04900591029003911248E8F7C4FB7E
:108D70000023F35606900791022B0DD0684602F0AF
:108D80000FFA002808D0089B002B0AD106980799F3
:108D9000FEF778FE051CCFE702F0BEFA2123036040
:108DA000F1E702F0B9FA089B0360EFE7EA00002060
:108DB0005C9B0200809B020070B58AB0041C00F02E
:108DC000B9F9224E0023F356051C013304D0201CB0
:108DD000FFF720FE002802D1281C0AB070BD201C1D
:108DE000FFF7C8FDFE218905FCF71EFA0028F3D025
:108DF00001230093164B201C019300230893FEF7D8
:108E0000EFFD04900591029003911248E8F774FB7E
:108E10000023F35606900791022B0DD0684602F00E
:108E2000BFF9002808D0089B002B0AD106980799A3
:108E3000FEF728FE051CCFE702F06EFA212303603F
:108E4000F1E702F069FA089B0360EFE7EA0000200F
:108E5000649B0200809B020008B500F0BFFA08BDC9
:108E6000F8B5FE224300041C5B089205934211D022
:108E700009DCA04A934212DC8C229205934200DD69
:108E800081E09D4805E0211CFCF7ECFE011CFCF78D
:108E9000DBFBF8BD002800DCCAE00020F9E7002871
:108EA00000DAC7E0FE20211C8005FCF7DBFEFC2178
:108EB0008905FCF7ADFD041C01F01AFB8F49061C67
:108EC000050B201CFCF7A4FD8D49FCF751FA211C71
:108ED000FCF79EFD8B49FCF7C5FE211CFCF798FDB5
:108EE0008949FCF745FA211CFCF792FD8749FCF7FC
:108EF000B9FE211CFCF78CFD8549FCF739FA211CD1
:108F0000FCF786FD8349071C201CFCF781FD824984
:108F1000FCF7A8FE211CFCF77BFD8049FCF728FA32
:108F2000211CFCF775FD7E49FCF79CFE211CFCF71B
:108F30006FFDFE218905FCF71BFA011C381CFCF7AC
:108F400083FB311CFCF764FD2D03071C291C281C26
:108F5000FCF75EFD011C201CFCF784FE291C041C90
:108F6000301CFCF705FA011C201CFCF76DFB011CF2
:108F7000381CFCF7FDF9011C281CFCF7F9F9011C51
:108F8000FCF7F6F985E7211CFCF742FD5B49051C5F
:108F9000FCF73EFD5A49FCF7EBF9291CFCF738FDBC
:108FA0005849FCF75FFE291CFCF732FD5649FCF7D7
:108FB000DFF9291CFCF72CFD5449FCF753FE291C52
:108FC000FCF726FD5249FCF7D3F9291CFCF720FDDC
:108FD0005049061C281CFCF71BFD4F49FCF742FEBC
:108FE000291CFCF715FD4D49FCF7C2F9291CFCF7BB
:108FF0000FFD4B49FCF736FE291CFCF709FDFE214D
:109000008905FCF7B5F9011C301CFCF71DFB011CA0
:10901000201CFCF7FDFC011C4248FCF723FE011C50
:10902000201CFCF71FFE011C3F48FCF71BFE30E72D
:109030003E482EE7FE218905FCF79AF9FC218905B7
:10904000FCF7E6FC2D49041CFCF7E2FC2C49FCF77C
:109050008FF9211CFCF7DCFC2A49FCF703FE211CDC
:10906000FCF7D6FC2849FCF783F9211CFCF7D0FC5F
:109070002649FCF7F7FD211CFCF7CAFC2449FCF744
:1090800077F9211CFCF7C4FC061C201C01F030FA07
:109090002049051C201CFCF7BBFC1F49FCF7E2FD26
:1090A000211CFCF7B5FC1D49FCF762F9211CFCF7FB
:1090B000AFFC1B49FCF7D6FD211CFCF7A9FCFE21E7
:1090C0008905FCF755F9011C301CFCF7BDFA291C79
:1090D000FCF79EFC1349FCF7C5FD011C281CFCF79E
:1090E00047F9011CFCF744F9011C1148FCF7BAFDD3
:1090F000CFE6C046FFFFFF3EDB0FC93F08EF113848
:10910000047F4F3A4611243DA80A4E3E90B0A63E39
:10911000ABAA2A3E2EC69D3D6133303F2D570140FC
:1091200039D119406821A233DA0FC93FDB0F49401A
:10913000DA0F4940F0B54E4645465746E0B4FE23A7
:109140004500041C061C6D089B059D4200D1C8E02B
:1091500000DDA5E08F4B9D420FDC8F4B9D4200DD73
:10916000CCE08E49FCF704F9FE218905FCF75CF898
:10917000031C201C002B00D098E0201CFFF7FAFBFA
:10918000011CFE208005FCF76DFDFC218905FCF724
:109190003FFC8349041CFCF73BFC8249FCF7E8F8E0
:1091A000211CFCF735FC8049FCF75CFD211CFCF719
:1091B0002FFC7E49FCF7DCF8211CFCF729FC7C49DC
:1091C000FCF750FD211CFCF723FC7A49FCF7D0F892
:1091D000211CFCF71DFC78498046201CFCF718FC7C
:1091E0007649FCF73FFD211CFCF712FC7449FCF7A3
:1091F000BFF8211CFCF70CFC7249FCF733FD211C65
:10920000FCF706FCFE218905FCF7B2F88146201C1C
:1092100001F06EF96C4B071C9D424CDC391C050BB0
:10922000FCF7A6F8494682464046FCF70DFA011CB9
:109230005046FCF7EDFB2D038046291C281CFCF74B
:10924000E7FB011C201CFCF70DFD291C041C381C2D
:10925000FCF78EF8011C201CFCF7F6F9011CFCF74A
:1092600087F8011C5948FCF7FDFC011C4046FCF73F
:10927000F9FC291C041C281CFCF77AF8011C544832
:10928000FCF7F0FC011C201CFCF7ECFC011C504816
:10929000FCF7E8FC002E09DC80231B06C01805E063
:1092A000211CFCF7DFFC011CFCF7CEF91CBC90462E
:1092B0009946A246F0BD49464046FCF7C5F9011C57
:1092C000381CFCF7A5FB391CFCF752F8011CFCF715
:1092D0004FF84049FCF74CF8011C3F48FCF7C2FC32
:1092E000D8E73D49FCF794FB3849051C201CFCF7E6
:1092F0008FFB011C281CFCF73BF8D7E7211CFCF76F
:1093000087FB2749051CFCF783FB2649FCF730F84F
:10931000291CFCF77DFB2449FCF7A4FC291CFCF765
:1093200077FB2249FCF724F8291CFCF771FB204944
:10933000FCF798FC291CFCF76BFB1E49FCF718F89E
:10934000291CFCF765FB1C49061C281CFCF760FB6C
:109350001A49FCF787FC291CFCF75AFB1849FCF753
:1093600007F8291CFCF754FB1649FCF77BFC291C69
:10937000FCF74EFBFE218905FBF7FAFF011C301CB0
:10938000FCF762F9011C201CFCF742FB211CFBF7D7
:10939000EFFF8BE7FFFFFF3EFFFFFF31CAF249718E
:1093A00008EF1138047F4F3A4611243DA80A4E3E7B
:1093B00090B0A63EABAA2A3E2EC69D3D6133303FFB
:1093C0002D57014039D119409999793F2EBD3BB3B2
:1093D000DB0F493F2EBD3B33DB0FC93FF8B5FF2202
:1093E0004F464646031C4800C0B44008D205904290
:1093F00015DC5C006408944211DCFE26B605B1421F
:1094000044D08E1702273740DE0F3E43B046002C73
:109410000DD1022E38D0032E2ED1344803E0081C83
:10942000191CFBF7A5FF0CBC90469946F8BD002817
:109430001ED090422ED0944222D0201AC0153C2833
:109440001CDC00293CDB181CFCF7FEF8FFF792FA45
:10945000FFF7E4F84746012F2ED0022F24D0002F2B
:10946000E1D02349FBF784FF2249FCF7FBFBDAE755
:10947000002B07DB2048D6E7181CD4E71E48E9E795
:10948000002BF7DA1D48CEE71A48CCE7181CFFF787
:10949000C5F8C8E7844217D0022EF5D0032EBCD001
:1094A000012E19D00020BEE71149FBF761FF011C16
:1094B0001048FCF7D7FBB6E7802212068018B2E707
:1094C0003C30C0DA0020C5E7022E0CD0032E08D0B5
:1094D000012E04D00A48A6E780200006A3E7094829
:1094E000A1E709489FE709489DE7C046DB0F49C04F
:1094F0002EBDBB33DB0F4940DB0FC93FDB0FC9BFBC
:10950000DB0F493FDB0F49BFE4CB16C0E4CB16406D
:10951000F8B5FF224F4646464300C0B4041C5B0822
:10952000D205934272D8C60F934200D175E0684AC3
:10953000904200DD90E0002800DA85E0654A934221
:1095400000D86EE0644A934200D99FE0634BB500B7
:10955000E958201CFCF786FB614B81460120801BEB
:10956000801BEF5880464846391CFCF77BFB041CE7
:10957000211C201CFCF74CFA5A49051CFCF748FA40
:109580005949FCF76FFB291CFCF742FA5749FBF7D6
:10959000EFFE291CFCF73CFA5549FCF763FB291C3C
:1095A000FCF736FA5349FBF7E3FE291CFCF730FAC7
:1095B000011C201CFCF756FB4346051C291C201CE3
:1095C000002B4ED0FCF724FA041C8020291CC00577
:1095D000FCF748FB011C201CFCF736F8011C381C6A
:1095E000FCF740FB4946FCF73DFB011CFE208005D3
:1095F000FCF738FB43467D3365DA43466433DB05CD
:10960000D82118180905FCF703FA02E0211CFBF722
:10961000AFFE0CBC90469946F8BD002EF9D0002054
:10962000F7E7354A934214D83449201CFBF7A0FED3
:10963000FE218905FBF7F8FD00280AD0FE21201C39
:109640008905FBF795FEE4E72D4A934200D875E7BC
:10965000E5E7002398468BE72848011CFCF7D8F97A
:10966000D7E7FCF7D5F98021061CC905281CFCF7B3
:10967000F9FA011C301CFBF7E7FF211CFCF7F2FA9A
:10968000011CFE208005FCF7EDFAC2E71D49201CF5
:10969000FCF7BEF91C4BB200D158FBF769FEFCF792
:1096A00057FC8046FCF774FC1849051CFCF7B0F920
:1096B000011C201CFCF7D6FA15498146281CFCF732
:1096C000A7F9071C4FE74346DC052018A1E7C04671
:1096D0001772B1421872B13E9115853FA49B0200EA
:1096E0009C9B02004CBB31330EEADD3555B38A3802
:1096F000610B363BABAA2A3EFFFF7F31CAF24971AC
:10970000B5F1CF423BAAB83F949B02008071313F34
:10971000D1F71737F8B54B005B083FD0C70FFF07ED
:109720003B4A3E1C4640964238DCFF22D20593421B
:1097300034DC9E4237DB3CD0364A96423EDC7E2209
:1097400034025242002C03DD013A6400002CFBDCA1
:109750003048834241DC7E251C026D42002C02DB36
:10976000013D6400FCD5101C7E3030DB7602802485
:10977000760A24043443281C7E3022DB4902480A3E
:10978000802109040143521B002A0DD0631A640092
:10979000002B01DB0DD05C00013AF5E7FCF738F94E
:1097A000011CFBF751FFF8BD611A00D5211C0029EF
:1097B00016D1FF0F184BBF00F858F4E7F2157F3AA7
:1097C000C6E77E214942491B8B40191CDBE77E24FA
:1097D0006442A41AA640341CCDE7DD157F3DC2E7E4
:1097E0000C4B994203DC4900013D9942FBDD2B1CE7
:1097F0007E3306DB094B7F35C8183843ED05284317
:10980000D1E77E204042401B0141081C3843CAE793
:10981000FFFF7F7FFFFF7F00AC9B0200000080FF07
:10982000F8B5011C5F4656464D464446F0B44B0021
:1098300000D192E0002800DAB3E0994B984200DDB5
:10984000B6E0984A0023904206DC081C9821C9051E
:10985000FCF7DEF819235B42C7157F3FFF18400273
:10986000914B440AE21880231B04FE20134080051C
:10987000DA154340181CFE2120438905D719FCF74F
:10988000F1F9231C0F335B02051C5B0A0F2B6FDD04
:109890008021C905FBF76CFD011C281CFBF7D4FED9
:1098A0008146381CFCF774FB494682464846FCF763
:1098B000AFF87E4B80461B1941469B46FCF7A8F843
:1098C0007B49061CFCF7A4F87A49FBF751FD311CD3
:1098D000FCF79EF87849FBF74BFD311CFCF798F834
:1098E0007649FBF745FD4146FCF792F874498046FE
:1098F000301CFCF78DF87349FBF73AFD311CFCF77F
:1099000087F87149FBF734FD311CFCF781F8011C25
:109910004046FBF72DFD061C6C485B46041B1C43B0
:10992000002C00DC90E0FC218905281CFCF770F875
:10993000291CFCF76DF8041C002F57D1311CFBF7D4
:1099400017FD4946FCF764F8011C201CFCF78AF956
:10995000011C281CFCF786F904E0CC20000600213D
:10996000FBF772FE3CBC90469946A246AB46F8BD5A
:109970000021FBF73FFC00281ED00020002FF1D073
:10998000381CFCF705FB5249041CFCF741F851490F
:10999000051C201CFCF73CF8011C281CFBF7E8FC0C
:1099A000E0E7081CFCF75EF90021FBF74DFED9E764
:1099B000081CFBF7DDFCD5E7291C281CFCF728F860
:1099C0004549041C281CFCF723F8011CFC208005D9
:1099D000FCF748F9011C201CFCF71AF8041C002FA6
:1099E00025D1281C211CFCF73DF9BBE7384950461E
:1099F000FCF70EF8311C071C201CFBF7B9FC49468C
:109A0000FCF706F83349061C5046FCF701F8011C28
:109A1000301CFBF7ADFC011C201CFCF723F9291CB2
:109A2000FCF720F9011C381CFCF71CF99AE7381CDC
:109A3000FCF7AEFA2649061CFBF7EAFF2549071C8E
:109A4000301CFBF7E5FFE6E7002F1CD0504620490D
:109A5000FBF7DEFF311C041C281CFCF703F9494608
:109A6000FBF7D6FF1B49061C5046FBF7D1FF011C34
:109A7000301CFCF7F7F8291CFCF7F4F8011C201C3B
:109A8000FCF7F0F86EE7311C281CFCF7EBF84946B0
:109A9000FBF7BEFF011C281CFCF7E4F862E7C04698
:109AA000FFFF7F7FFFFF7F0020FB4A00305CCFFF7E
:109AB0009788173E25333A3E2549923EABAA2A3F66
:109AC0004FD01C3E298E633ECDCCCC3E88C23500A3
:109AD0008071313FD1F71737ABAAAA3EF0B55F4688
:109AE00056464D464446F0B44E0087B0071C0C1C49
:109AF0008946760811D043005D08FF238246DB05C6
:109B00009D4204DD5D4801F047FB011C07E09E42D9
:109B10000DDDFE239B059D42F4D1FE218905081C25
:109B200007B03CBC90469946A246AB46F0BD00212A
:109B30000091002862DBFF23DB059E4253D0FE2309
:109B40009B059E426FD08023DB05994500D17FE0C5
:109B5000FC239B05381C994518D0FEF70BFF011C10
:109B6000002D1AD14A46002A00DA80E05346002B25
:109B7000D5DA434A081CAB18009D2B4370D0009DDA
:109B8000012DCCD1802212068918C8E75146002940
:109B9000E3DB00F0ADFC011CC1E7BA00FE23920834
:109BA0009B059A42DED0FB0F013B0193019A009B7B
:109BB000134353D09A23DB059E426DDD314B9D420A
:109BC00004DC4B46002B08DB0021A8E72E4B9D420E
:109BD00000DCC2E24D46002DF6DD2C48011CFBF7EF
:109BE00017FF011C9BE7FE239B059D4295D028DDB6
:109BF0004B46211C002B00DB91E7E5E7244B9E42FE
:109C00001CDC244B9E429ADD9622F315D31A321C9B
:109C10001A41111C9940B14291D101231A400223EB
:109C20009B1A00938BE74B46391C002B00DB76E731
:109C3000FE208005FBF708FD011C70E70222009260
:109C400079E74D46002DBFDA80221206A11866E79B
:109C5000391C381CFBF7DCFE011C60E7381C391C82
:109C6000FCF700F8011CFBF7EFFC011C57E7FE2096
:109C70008005FBF7E9FC011C78E7C046809B0200E9
:109C8000000080C0F7FF7F3F0700803FCAF24971A4
:109C9000FFFF7F4BFFFF7F3FF24A0023954206DC28
:109CA0009721C905FBF7B4FE1823051C5B42EA1592
:109CB0007F3AD21805926B02FE225B0A92051A4384
:109CC0009246E94A934200DCB1E1E84A934200DC63
:109CD0003EE2059DE6490135002205958A449146FC
:109CE00000239B000293029DE24B5046EB58D34663
:109CF000191C9846FBF7B6FF414603905046FBF708
:109D000037FB011CFE208005FBF79EFC04900499A4
:109D10000398FBF77DFE514680234A109B051343B1
:109D20008022D2029B18060B99443603071C494631
:109D3000301CFBF76DFE011C0398FBF793FF4146B7
:109D400082464846FBF78EFF011C5846FBF78AFF08
:109D5000011C301CFBF75CFE011C5046FBF782FF28
:109D60000499FBF755FE391C8346381CFBF750FE5F
:109D700080464146FBF74CFEBF4981464046FBF713
:109D800047FEBE49FBF7F4FA4146FBF741FEBC49EA
:109D9000FBF7EEFA4146FBF73BFEBA49FBF7E8FA60
:109DA0004146FBF735FEB849FBF7E2FA4146FBF7BF
:109DB0002FFEB649FBF7DCFA011C4846FBF728FEEC
:109DC000311C8046381CFBF7D3FA5946FBF720FEBE
:109DD0004146FBF7CDFA311C8146301CFBF718FEDB
:109DE000AB498246FBF7C4FA4946FBF7C1FA000BC0
:109DF000000380464146301CFBF70AFE4146061C24
:109E00005846FBF705FEA24983464046FBF72AFF6A
:109E10005146FBF727FF011C4846FBF723FF391C7F
:109E2000FBF7F6FD011C5846FBF7A2FA81464946AE
:109E3000301CFBF79DFA070B3F03381C9549FBF7D5
:109E4000E7FD95498046381CFBF7E2FD311C824650
:109E5000381CFBF707FF011C4846FBF703FF8F493F
:109E6000FBF7D6FD011C5046FBF782FA8C4BE958F4
:109E7000FBF77EFA071C0598FCF78AF8894B8146A8
:109E8000EB58391C9A464046FBF772FA5146FBF7ED
:109E90006FFA4946FBF76CFA060B36034946301C4D
:109EA000FBF7E0FE5146FBF7DDFE4146FBF7DAFE2D
:109EB000011C381CFBF7D6FE009D019B013D81462D
:109EC0001D4300D0AFE0784DA846250B2D03291C7B
:109ED000201CFBF7C7FE311CFBF79AFD4946071C07
:109EE000201CFBF795FD011C381CFBF741FA291CCF
:109EF0008146301CFBF78CFD041C8246211C484621
:109F0000FBF736FA4600051C071C7608002800DC23
:109F100007E18623DB059E4200DD9AE000D189E05F
:109F2000FC239B059E4200DDD4E0002293460026E0
:109F30003F0B3F03381C5D49FBF76AFD5146051C8A
:109F4000381CFBF78FFE011C4846FBF78BFE584977
:109F5000FBF75EFD5749041C381CFBF759FD011C3B
:109F6000201CFBF705FA071C391C281CFBF700FA1C
:109F7000291C041CFBF776FE011C381CFBF772FE43
:109F8000211C071C201CFBF743FD4B49051CFBF75C
:109F90003FFD4A49FBF766FE291CFBF739FD48499E
:109FA000FBF7E6F9291CFBF733FD4649FBF75AFEA0
:109FB000291CFBF72DFD4449FBF7DAF9291CFBF7B7
:109FC00027FD011C201CFBF74DFE051C291C201C35
:109FD000FBF71EFD80218146C905281CFBF742FEC8
:109FE000011C4846FBF730FB391C051C201CFBF705
:109FF0000FFD391CFBF7BCF9011C281CFBF732FED6
:10A00000211CFBF72FFE011CFE208005FBF72AFE1A
:10A010005B461918CB15002B00DCD9E04046FBF756
:10A02000F7FC011C7BE5FE21890588464DE70023EE
:10A03000994656E625494846FBF79AF9211C82467F
:10A04000281CFBF70FFE011C5046FBF7EDF800281B
:10A0500040D01F494046FBF7DBFC1D49FBF7D8FC0D
:10A06000011C5CE5FFFF7F0071C41C00D6B35D00DE
:10A07000000080FFC49B020042F1533E55326C3E0B
:10A0800005A38B3EABAAAA3EB76DDB3E9A99193F5A
:10A09000000040400038763FA0C39D364F38763FE1
:10A0A000BC9B0200B49B0200000080BF0072313FE5
:10A0B0001872313F8CBEBF354CBB31330EEADD35F3
:10A0C00055B38A38610B363BABAA2A3E3CAA3833DB
:10A0D000CAF24971F6158020331C00047E3B021C35
:10A0E0001A41D3195A00120E111C3C4D7F390D41F3
:10A0F000291C1D1C5B025B0A96261843B21A8D436D
:10A10000061C291C1641002F60DB201CFBF7AAFD52
:10A11000824651464846FBF72BF9F105071C8B4652
:10A1200006E72F4B9E420ADC00D0F9E6211CFBF724
:10A1300099FD011C4846FBF76DF80028CAD0294953
:10A140004046FBF765FC2749FBF762FC011CE6E48F
:10A1500080239B0399460123C3E5FE218905FBF774
:10A1600081FD2149061CFBF753FC2049051C301CCE
:10A17000FBF74EFC311C071C301CFBF749FCFA2195
:10A1800081468905301CFBF743FC011C1848FBF78E
:10A1900069FD311CFBF73CFC011CFC208005FBF732
:10A1A00061FD011C4846FBF733FC1249FBF730FC0C
:10A1B000011C381CFBF756FD071C391C281CFBF73B
:10A1C000D7F8060B3603301C291C6FE676429CE755
:10A1D000311CFEF7D1FC011C20E7C046FFFF7F00C9
:10A1E000000016436042A20D00AAB83F70A5EC36ED
:10A1F000ABAAAA3E3BAAB83FF0B556464D464446E8
:10A200005F46F0B442005608AB4A89B0031C0C1CF0
:10A21000051C964268DDA94A96421ADCA849002B23
:10A2200000DCFEE0FBF71EFD0F23321C9A43A54B1A
:10A23000051C9A426AD0A449FBF714FD011C20605A
:10A24000281CFBF70FFDA049FBF70CFD6060012007
:10A250004EE09E4A96426BDD9D4A96424FDCF715D2
:10A26000863FFB05F61A301CFBF772FEFBF790FEEB
:10A27000011C0590301CFBF7F5FC8721C905FBF795
:10A28000C7FB8046FBF764FEFBF782FE061C0690C8
:10A29000311C4046FBF7E6FC8721C905FBF7B8FBFC
:10A2A00000210790FAF7A6FF002800D1D3E0301C68
:10A2B0000021FAF79FFF431E984102231B1A022236
:10A2C0000092844A05A80192211C3A1C00F036FA3B
:10A2D000002D0DDA22688021090653186268236078
:10A2E00053186360404203E0002320604B6000206D
:10A2F00009B03CBC90469946A246AB46F0BD191C3D
:10A30000FBF7B0FC606020600020F1E77249FBF7CA
:10A31000A9FC7249051CFBF7A5FC011C2060281C48
:10A32000FBF7A0FC6D49FBF79DFC60600120DFE7B7
:10A33000FEF720FB6A498046FBF76AFBFC21890592
:10A34000FBF716F8FBF704FE071CFBF721FE5C4940
:10A350008146FBF75DFB011C4046FBF783FC5A4935
:10A3600080464846FBF754FB824640461F2F22DCBE
:10A37000FF23321C9A43791E5A4B8900CB589A42CC
:10A3800019D05146FBF76EFC834620605946404683
:10A39000FBF768FC5146FBF765FC031C6060381C4A
:10A3A000002DA5DA802109060E1C5E445B1826608C
:10A3B000636078429CE75146FBF754FCFF22C30DD3
:10A3C000F615134083460296F31A082B41DD4249E5
:10A3D0004846FBF71DFB061C311C4046FBF742FCC0
:10A3E000039003994046FBF73DFC311CFBF73AFC18
:10A3F0003A49061C4846FBF70BFB311CFBF732FCC5
:10A40000824651460398FBF72DFCFF22C30D0299AB
:10A4100013408346CB1A192B32DC039B20609846ED
:10A42000B4E7FAF7A5FF0F23321C9A43254B051C0E
:10A430009A4212D02449FAF79BFF011C2060281C85
:10A44000FBF710FC2049FAF793FF606001204042BF
:10A450004EE720609AE7032331E71F49FAF788FFA8
:10A460001E49051CFAF784FF011C2060281CFBF71D
:10A47000F9FB1A49FAF77CFF60600120404237E798
:10A4800019494846FBF7C4FA061C311C0398FBF730
:10A49000E9FB804641460398FBF7E4FB311CFBF7E0
:10A4A000E1FB1249061C4846FBF7B2FA311CFBF7E8
:10A4B000D9FB8246404664E7D80F493FE3CB1640BC
:10A4C000800FC93FD00FC93F43443537800F494300
:10A4D000FFFF7F7F4C9C02000044353708A3852E88
:10A4E00084F9223FCC9B020000A3852E32318D24BB
:10A4F0002C49420070B5031C041C52088A423CD807
:10A50000011C002A37D0002841DB2749C0158A42A8
:10A510000BD880210904214240D100225B00013286
:10A520000B42FBD001218A1A80185B025A0A011CD7
:10A5300080231B047F391343CA0726D48022481086
:10A540005B001921002600255204AC189C4202DC55
:10A55000A5181B1BB61801395B0052080029F4D15D
:10A56000002B02D001233340F618FC2376109B0504
:10A57000F618C1058919081C70BD211CFBF748FAA3
:10A58000211CFAF7F5FE011CF5E75B00D6E7FBF7A7
:10A5900069FB011CFBF758F8011CECE7012280184D
:10A5A000C3E7C046FFFF7F7FFFFF7F00F8B54F4640
:10A5B0004646574BC0B44600051C0F1C76089E4209
:10A5C00048DCFBF7C5FC002800D19EE0291C281CB4
:10A5D000FBF71EFA4F49041CFBF71AFA4E49FAF72B
:10A5E000C7FE211CFBF714FA4C49FBF73BFB211C6F
:10A5F000FBF70EFA4A49FAF7BBFE211CFBF708FAF3
:10A600004849FBF72FFB211CFBF702FA4649FAF7F2
:10A61000AFFE211CFBF7FCF98046FC21201C8905BC
:10A62000FBF7F6F94146061C201CFBF7F1F9391C33
:10A63000041C281CFBF7ECF9011C201CFBF712FB87
:10A64000011C301CFBF70EFB011CFE208005FBF7F4
:10A6500009FB52E0291CFBF7DBF92E49041CFBF730
:10A66000D7F92D49FAF784FE211CFBF7D1F92B49C4
:10A67000FBF7F8FA211CFBF7CBF92949FAF778FE2A
:10A68000211CFBF7C5F92749FBF7ECFA211CFBF766
:10A69000BFF92549FAF76CFE211CFBF7B9F9234BEA
:10A6A00080469E42B9DD224B9E422ADCFF231B06D8
:10A6B000F618FE208005311CFBF7D4FA8146FC21F8
:10A6C000201C8905FBF7A4F9311CFBF7CBFA4146A6
:10A6D000061C201CFBF79CF9391C041C281CFBF7EA
:10A6E00097F9011C201CFBF7BDFA011C301CFBF77D
:10A6F000B9FA011C4846FBF7B5FA0CBC90469946DE
:10A70000F8BD0C4B0C4E9946D9E7FE208005F4E7C6
:10A71000FFFFFF314ED747ADF6740F317CF2933413
:10A72000010DD037610BB63AABAA2A3D9999993EF3
:10A730000000483F0000383F0000903EF0B556460C
:10A740004D4644465F46F0B4DFB0689C0C93C14B65
:10A750000A91A100C958D31E0791D917490F0C9C23
:10A76000CB18DB100B93013C0494DB430B9CDB17F1
:10A770001C4082460498E3430B94DB00251A079C97
:10A780009B180693071919D4699CAB00E4187F192C
:10A79000A0460137002622AC08E041468859FBF765
:10A7A000F7FB0135A0510436BD4207D0002DF4DA85
:10A7B00000200135A0510436BD42F7D1079C002C82
:10A7C00000DAFCE2079B0C9C0133A7009B005EA80B
:10A7D0009846C319F43B00214AAC99463B1C8B4672
:10A7E000574608949A46049C002C00DA1EE24D4617
:10A7F0005D440024002629683859FBF709F9011C3B
:10A80000301CFAF7B5FD0434061C043D5445F2D162
:10A81000089C042158468B442650C345E3D1534637
:10A82000BA461F1C079C0798A3000DACE418B84655
:10A830000D94834657465C460898A40059460394F5
:10A840000459002926DD5D460EAE013D039AAD0098
:10A85000B24645199244B946EE218905201CFBF702
:10A86000D7F8FBF775FBFBF793FB8721C905071C9E
:10A87000FBF7CEF8011C201CFBF7F4F9FBF768FB93
:10A88000296801C6381CFAF773FD043D041C5645BF
:10A89000E2D14F46201C0699FEF76EF9F821890592
:10A8A000041CFBF7B5F8FEF769F88221C905FBF730
:10A8B000AFF8011C201CFBF7D5F9041CFBF748FB83
:10A8C000061CFBF765FB011C201CFBF7CBF9069C63
:10A8D000051C002C00DC8BE15A46013A92000EA8C0
:10A8E00083580821091B181C0841361888401B1A78
:10A8F0000EA98B500722121B13410593059C002CB7
:10A9000033DD58460136002800DCA0E1039C80229C
:10A910000EAB52001919FF200024944608E0002ACB
:10A9200003D06446A21A1A60012404338B4208D073
:10A930001A68002CF3D0821A1A60043301248B4267
:10A94000F6D1069800280DDD012800D15BE1022830
:10A9500008D15B46013B9B000EA9C9583F220A4023
:10A960000EA8C2500599022976D0281C0021FAF7BA
:10A9700041FC002800D189E05946079C01398C42EE
:10A980000CDC0EA88D0043190D9800221C68043BB6
:10A9900022438342FAD1002A00D0F5E1079B0EA89A
:10A9A000013B9B00C358002B00D006E2079B01220D
:10A9B000023B9B00C318043B596801320029FAD0BE
:10A9C0005B465A440133099293423DDC089C584649
:10A9D0009B00E4180B99131A9B0005930B1C5B4416
:10A9E000A246699C9B000C98E3180393031C5B44EC
:10A9F0009B0022A9C91800228B469146039C231C68
:10AA00004B445868FBF7C4FA5946049C4944086013
:10AA1000002C1CDB0D1C0024002629683859FAF78D
:10AA2000F7FF011C301CFAF7A3FC0434061C043D9C
:10AA30004445F2D1514604310422059C8A46914492
:10AA4000043940C1A145D9D109988346F3E60026CF
:10AA5000F0E7C046649F0200FE20291C8005FBF73A
:10AA600001F9051C002C00D17FE7FE200699800526
:10AA7000FEF782F8011C281CFBF7F4F8051C281CC3
:10AA80000021FAF7B7FB002800D075E7069C281CC8
:10AA90006142FEF771F88721C905D946051CB34606
:10AAA000FAF7CCFB002800D18EE1EE218905281CA5
:10AAB000FAF7AEFFFBF74CFAFBF76AFA8721C905F4
:10AAC000041CFAF7A5FF011C281CFBF7CBF8FBF7C9
:10AAD0003FFA039A0EA9885006984B460830013376
:10AAE0000690201C9D000393FBF732FA0EA94851F3
:10AAF000FE2080050699FEF73FF8039C051C002CFC
:10AB00004EDBA2460120A3008244089C5146E41873
:10AB10008F000EAA7F42D618A146B8460024371CE3
:10AB20004E463859FBF734FA291CFAF771FFEE212B
:10AB300030518905281CFAF76BFF043C051C44457D
:10AB4000EFD136AC079A594600200494AA4CB1467E
:10AB500080460691934658460027002813DB0026BE
:10AB60000027002502E0043645450CDC4B46995988
:10AB7000A059FAF74DFF011C381CFAF7F9FB013513
:10AB8000071CAB45EFDA404604998300CF50012201
:10AB900004235B4290449944C245DCD106998B461C
:10ABA000689C022C00DD87E0002C52DC16D1039C4F
:10ABB000002C00DA1EE136A8A400041935AD0020EF
:10ABC0002168043CFAF7D4FBAC42F9D1059C002C77
:10ABD00002D08021090640180A9C206059460720AF
:10ABE00008405FB03CBC90469946A246AB46F0BDDB
:10ABF000069C002C11D15B46013B9B000EA8C3585C
:10AC00001B1205937AE65B46013B9B000EA9C958CF
:10AC10007F220A400EA8C250A4E6FC218905FAF75B
:10AC20000DFB00280CD1002405949EE6089C04210D
:10AC3000584600268B442650C34500D0D3E5EEE5A8
:10AC40000224584605940136002800DD5EE6002403
:10AC500077E6039C0021002C0DDB039C36A8A300A3
:10AC60000021C41835AD081C2168043CFAF780FBAC
:10AC7000AC42F9D1011C059C0B1C002C02D0802099
:10AC800000060B180A9C36982360FAF7EBFF039C2A
:10AC9000002C08DD039937AC8D00651902CCFAF75A
:10ACA00067FBAC42FAD1059C002C02D0802109063A
:10ACB00040180A9C606091E7689C032C00D08DE7E7
:10ACC000039C002C00DC91E036AC0494039B039CB5
:10ACD000013BA500049C9B00675935A8E418A146D8
:10ACE0008046261CAA4600E0271C3568391C281C13
:10ACF000FAF73EFB041C211C281CFAF7B3FF391C91
:10AD0000FAF736FB043EB06074604645ECD1039C14
:10AD100055460020012C24DD049C4E466759D04640
:10AD200000E0271C3568391C281CFAF721FB041C9D
:10AD3000211C281CFAF796FF391CFAF719FB7060E2
:10AD400004983460043EB042EBD1049C4546261C76
:10AD50006519043600202968043DFAF709FBB5425D
:10AD6000F9D1059C002C38D0369A8024240613197A
:10AD70000A9C80212360049C090663680A9C5B1876
:10AD800040186360A06029E7069C0EA84359083C60
:10AD9000B34603910694002B00D0A9E60A1C013AA1
:10ADA0009300C318211C00E0013A043B5C68039245
:10ADB0000839002CF8D006919AE6012200E60C9C96
:10ADC000A7004AAC08942DE5281CFBF7C1F8039CAA
:10ADD0000EAA10514C4603948AE636990A9C2160CB
:10ADE000049C0A99646888604C60F7E636AC0020E1
:10ADF0000494B6E70020E9E6709F0200F8B5354BF1
:10AE00004F4646464500C0B4041C0F1C90466D08D2
:10AE10009D4205DCFBF79CF8031C201C002B46D050
:10AE2000211C201CFAF7F4FD211C051CFAF7F0FD8B
:10AE30002949061C281CFAF7EBFD2849FAF712FFEE
:10AE4000291CFAF7E5FD2649FAF792FA291CFAF7C8
:10AE5000DFFD2449FAF706FF291CFAF7D9FD22493C
:10AE6000FAF786FA43468146002B24D0FC21890557
:10AE7000381CFAF7CDFD49468046301CFAF7C8FD6C
:10AE8000011C4046FAF7EEFE291CFAF7C1FD391CF9
:10AE9000FAF7E8FE1549051C301CFAF7B9FD011C4C
:10AEA000281CFAF765FA011C201CFAF7DBFE0CBC23
:10AEB00090469946F8BD4946281CFAF7A9FD0B496A
:10AEC000FAF7D0FE311CFAF7A3FD211CFAF750FA6D
:10AED000EDE7C046FFFFFF31D3C92E2F342FD73205
:10AEE0001BEF3836010D50398988083CABAA2A3E41
:10AEF000F0B55F46444656464D46F0B48A4B47008F
:10AF000083B0041C8846924683467F089F4211DC2A
:10AF1000FBF71EF8002823D1534601331F4300D10D
:10AF2000EFE05246012A00D1FBE0211C7F48FAF7EE
:10AF30008BFBB2E07E4B9F4212DD002800DAE9E095
:10AF4000211C7C48FAF78EFE4146041C7A48FAF729
:10AF500089FE011C201CFAF70BFA0023041C9846FA
:10AF6000211C201CFAF754FD061C311CFAF750FD79
:10AF7000211C051C301CFAF74BFD70498146281C2A
:10AF8000FAF746FD6E49FAF7F3F9291CFAF740FD86
:10AF90006C49FAF7EDF9291CFAF73AFD6A49FAF714
:10AFA000E7F9291CFAF734FD6849FAF7E1F9291C99
:10AFB000FAF72EFD6649FAF7DBF966490190281C7D
:10AFC000FAF726FD6449FAF7D3F9291CFAF720FDB0
:10AFD0006249FAF7CDF9291CFAF71AFD6049FAF728
:10AFE000C7F9291CFAF714FD5E49FAF7C1F9291CC3
:10AFF000FAF70EFD5C49FAF7BBF9311CFAF708FDC8
:10B00000011C0198FAF7B4F94946FAF701FD4146E7
:10B01000FAF7AEF9311CFAF7FBFC4146FAF7A8F94A
:10B020005249051C4846FAF7F3FC291CFAF7A0F927
:10B03000061C311C201CFAF79BF93D4B051C9F4256
:10B0400032DC5346012B28D0030B1B03291C374845
:10B050009846FAF7F9FA211C071C050B4046FAF747
:10B0600001FE2D03011C301CFAF7FCFD291CFAF728
:10B07000CFFC291C041C4046FAF7CAFCFE218905B6
:10B08000FAF776F9011C201CFAF772F9391CFAF765
:10B09000BFFC011C281CFAF76BF903B03CBC9046BE
:10B0A0009946A246AB46F0BD5046FAF771FF5A46A4
:10B0B0009317071C022018400123181AFAF768FF9B
:10B0C000291C8046281CFAF7A3FC391C8146281C41
:10B0D000FAF74EF9011C4846FAF7B6FA311CFAF7AE
:10B0E000C1FD011C201CFAF7BDFD011CFAF740F957
:10B0F000011C381CFAF7B6FD011C4046FAF788FC23
:10B10000CBE7201CFDF736FC011CFE208005FAF77A
:10B110009BFAC2E780221206131C43448418984607
:10B120000EE7201CB9E7C046FFFF7F31000080BF5B
:10B130003FA12C3FDA0F493F682122335FAE9BB716
:10B1400045F4A338C8261A3A16696B3BA427B33CCA
:10B150008988083E8453D9377AC09538B937813900
:10B1600048DEBE3A1F37113CD10D5D3DABAAAA3E69
:10B170004B0059087047C0464000C90FC907400836
:10B18000084370474300034A5B0800209A4240414D
:10B190007047C046FFFF7F7F004870470000C07FB8
:10B1A00000207047F0B546464F46C0B4CA0F9046DF
:10B1B0004B004D4A5B0D9E1883B0041C0D1C8C4641
:10B1C000071C132E3BDC002E5CDB484F021C374172
:10B1D0003B1C0B400343994648460B1C002827D0D4
:10B1E0007B081A1C0A4022430027002A0AD0132E8B
:10B1F00000D176E0291C80229943D2020B1C3241F7
:10B2000013439C464046C1003948634641180C68C8
:10B210004D683A1C201C291CFAF766FF009001912A
:10B2200000980199221C2B1CFCF734F8021C0B1C03
:10B23000101C191C03B00CBC90469946F0BD332E6F
:10B240000BDD0B1C8021021CC9008E42F0D1291C91
:10B25000FAF74AFF021C0B1CEAE7264A0126D2181D
:10B260007642D64091460B1C021C0642E0D076087E
:10B270000642C7D08023B443DB0548460341271C60
:10B280001F43BFE74E0076080643021C0B1C002E2E
:10B29000CED00903090B014348420143802000033B
:10B2A000090B0140680C40040B1C03434046C100DD
:10B2B0000F4841180C684D68291C201CFAF714FF30
:10B2C00000900191009801992B1C221CFBF7E2FFD2
:10B2D0000D1C4146021CC80769004908031C0B43AA
:10B2E000A6E780273F0685E701FCFFFFFFFF0F0071
:10B2F00040470200EDFBFFFF38B5051C05480C1C5C
:10B30000131C002804D00220291C221C01F0E8F89C
:10B3100038BDC046E1C40100014B18687047C04603
:10B32000BC000020084B10B5041C002B02D00021EB
:10B3300001F02EF9054B1868836A002B00D098475E
:10B34000201C07F0A3FBC04691C50100FC9F020032
:10B3500070B5051C0C1E01D1002049E0002804D066
:10B360008269002A01D100F0F9F8224B9C4201D1F8
:10B370006C6808E0204B9C4201D1AC6803E01F4B95
:10B380009C4200D1EC680C22A35E002BE4D0281C68
:10B39000211C08F0B7FC236B061C002B06D0281CD0
:10B3A000216A9847002801DA01267642A3891A0605
:10B3B00003D5281C216900F0F3FA616B002908D03D
:10B3C000231C4433994202D0281C00F0E9FA0023E0
:10B3D0006363A16C002904D0281C00F0E1FA00236B
:10B3E000A36408F02EFD0023A38108F02BFD301C80
:10B3F00070BDC0469C9F0200BC9F0200DC9F020003
:10B4000008B5034B011C1868FFF7A2FF08BDC04632
:10B41000BC0000200A6938B5051C0C1C002A01D1AB
:10B4200000201CE0002804D08369002B01D100F02B
:10B4300095F80B4B9C4201D16C6808E0094B9C428B
:10B4400001D1AC6803E0084B9C4200D1EC680C22AF
:10B45000A35E002BE4D0281C211C08F053FC38BD4F
:10B460009C9F0200BC9F0200DC9F020008B5011EE9
:10B4700005D1054B0549186808F005FD03E0044BAC
:10B480001868FFF7C7FF08BDFC9F020015B4010054
:10B49000BC00002038B5051C0C1C002804D08369B2
:10B4A000002B01D100F05AF80E4B9C4201D16C6880
:10B4B00008E00D4B9C4201D1AC6803E00B4B9C4271
:10B4C00000D1EC686368013B6360002B04DA281C40
:10B4D000211C00F007FD03E023685A1C2260187845
:10B4E00038BDC0469C9F0200BC9F0200DC9F02004A
:10B4F00008B5034B011C1868FFF7CCFF08BDC04618
:10B50000BC00002008B5024908F0BDFC08BDC046DB
:10B5100051B30100002310B5041C03604360836035
:10B5200081814366C281036143618361191C0822E2
:10B530005C3008F005FD054B24626362044BA36296
:10B54000044BE362044B236310BDC04609C10100F4
:10B5500031C1010069C10100F5400200836913B5E2
:10B56000041C002B27D18364C3640365124B134A68
:10B570001B688262984201D101238361201C00F084
:10B580001FF86060201C00F01BF8A060201C00F079
:10B5900017F80421E06000226068FFF7BBFFA06895
:10B5A00009210122FFF7B6FFE06812210222FFF70E
:10B5B000B1FF0123A36113BDFC9F020005B501008B
:10B5C000F8B51D4B071C1E68B269002A02D1301C59
:10B5D000FFF7C4FF4836B4687368013B05D40C22FA
:10B5E000A55E002D10D06834F7E73368002B06D134
:10B5F000381C042108F00FFC3060002801D03668A8
:10B60000E9E70C233B6016E001235B42E381201C49
:10B610000123A38165662560A5606560256165617C
:10B62000A5615C30291C082208F08AFC6563A563CB
:10B63000A564E564201CF8BDFC9F020038B5074BEB
:10B64000074C1D1CE41AA410002C04D0013CA300DC
:10B65000EB589847F8E708F0C3FE38BDFC0000201F
:10B6600000010020F7B50F1C111C01AA051C08F0F1
:10B670007AFD061E01D1002427E0281CFFF7A0FF59
:10B68000041EF8D0DB23281C391C019A5B0000F053
:10B690002DFB002806DA002508F0D3FBA58108F071
:10B6A000D1FBE8E70A4BE08163620A4BA681A36203
:10B6B000094B2462E362094B2363F30505D5281C7B
:10B6C000211C0022022308F0BEFB201CFEBDC04648
:10B6D00009C1010031C1010069C10100F54002004A
:10B6E00008B50A1C0349031C0868191CFFF7BAFFB8
:10B6F00008BDC046BC00002070B5051C0E1C141C03
:10B70000002804D08369002B01D1FFF727FF0A4BE3
:10B710009C4201D16C6808E0084B9C4201D1AC68A6
:10B7200003E0074B9C4200D1EC68281C311C221C12
:10B7300000F00AFB70BDC0469C9F0200BC9F020047
:10B74000DC9F020008B50A1C0349031C0868191C89
:10B75000FFF7D2FF08BDC046BC000020F7B5051CAE
:10B760000C1C01921E1C002804D08269002A01D101
:10B77000FFF7F4FE414B9C4201D16C6808E0404B5E
:10B780009C4201D1AC6803E03E4B9C4200D1EC6886
:10B79000A28984235B001A409A4203D1281C211CF1
:10B7A000FFF738FEE36A0093002B01D11D2331E03F
:10B7B000012E05D0022E31D01623002E2AD12DE0E5
:10B7C000281C211CFFF726FEA389802252011A4063
:10B7D00001D0606D06E0331C281C216A009EB04732
:10B7E000421C18D0A3895E0707D56268636B801A74
:10B7F000002B0AD0266C801B07E01A0705D52368AA
:10B80000002B02D026699B1BC018019E361801969A
:10B81000002603E02B6001277F422DE02269002AE9
:10B8200003D1281C211C00F057F8281C211CFFF70D
:10B83000F1FD071EEFD1331C281C216A019A009EDE
:10B84000B0470130E7D0616B002908D0231C443396
:10B85000994202D0281C00F0A3F8002363632269F8
:10B86000094B2260A28900211340201C6160A38142
:10B870005C30082208F064FB381CFEBD9C9F02006F
:10B88000BC9F0200DC9F0200DFF7FFFF70B50E4B8C
:10B890000E4D0024ED1AAD101E1CAC4204D0A300C6
:10B8A000F35898470134F8E708F094FD084B094D28
:10B8B0000024ED1AAD101E1CAC4204D0A300F358B6
:10B8C00098470134F8E770BDEC000020EC00002040
:10B8D000EC000020FC000020F0B58B8991B0051C25
:10B8E0000C1C9A0725D40E23C95E002906DAA78905
:10B8F00080231F400FD0002740260EE001AA00F051
:10B90000C9FE0028F3DB029BF0273F02184A1F40C4
:10B91000BF187B425F418026F600281C311C00F0D6
:10B9200087F800280CD1A3899A051FD4022213435B
:10B93000A381231C4733236023610123636115E046
:10B940000C4B8022AB62A38920601343A38120614A
:10B950006661002F0AD00E23E15E281C00F0ACFEC9
:10B96000002803D0A38901221343A38111B0F0BDA5
:10B9700000E0FFFF05B5010008B5034B011C186886
:10B9800000F056F808BDC046BC00002008B5034BC7
:10B99000011C186800F004F808BDC046BC00002077
:10B9A00030B5002940D004390B68002B00DAC918E3
:10B9B0001E4A1368141C002B02D14B60116033E047
:10B9C00099420FD208680A189A4205D11368526842
:10B9D000C01808604A6000E04B60216024E08A42A1
:10B9E00003D8131C5A68002AF9D11D685C198C42CF
:10B9F0000BD10968691858181960904214D114685D
:10BA00005268091919605A600EE08C4202D90C2361
:10BA1000036009E008680C18944203D11468526866
:10BA2000001908604A60596030BDC046782D00207A
:10BA300070B50323CD1C9D430835061C0C2D01D287
:10BA40000C2505E0002D03DA0C233360002040E0D4
:10BA50008D42F9D31F4B1C681A1C211C002913D0DE
:10BA60000868431B0DD40B2B02D90B60CC181EE0C9
:10BA70008C4202D1636813601AE0486860600C1C55
:10BA800016E00C1C4968E9E7134C2068002803D134
:10BA9000301C00F057FA2060301C291C00F052FACC
:10BAA000431CD1D0C41C03239C4384420AD125608B
:10BAB000201C0B300722231D9043C31A09D05A4281
:10BAC000E25006E0211A301C00F03CFA0130EED1C1
:10BAD000BAE770BD782D0020742D0020F0B59FB01E
:10BAE000061C0F1C03920593002804D081690029CD
:10BAF00001D1FFF733FD754B9F4201D1776808E014
:10BB0000734B9F4201D1B76803E0724B9F4200D153
:10BB1000F768BB891A070AD53B69002B07D006AD29
:10BB200000236B6120236B763023AB763BE0301C27
:10BB3000391C00F063FC0028F1D001204042C2E033
:10BB4000059A111D12680591002A76DB09920134CD
:10BB500023782E2B00D181E021785F48032208F062
:10BB6000B3F9002807D05C492A68431A402098405E
:10BB70001043286001342178631C5848062203933F
:10BB8000297608F0A1F9002800D18AE0544B002B57
:10BB90007ED1059B072207339343083305936A69D7
:10BBA000049953186B61039C2378002B04D10399EB
:10BBB000611A029110D003E0252BF8D00134F3E78D
:10BBC000301C391C039A029B08F0D7F9013075D05C
:10BBD0006A69029953186B612378002B6ED0012299
:10BBE00052426A606A4600235B3201342B60EB608C
:10BBF000AB601370AB6521783A48052208F064F910
:10BC0000002808D0374A0134831A012098402B6855
:10BC100018432860EFE72B68D90603D56A46202130
:10BC20005B3211701A0703D56A462B215B32117003
:10BC300022782A2A84D0099B05E05242EA60022237
:10BC400013432B6083E72278303A092A04D80A216B
:10BC50004B4301349B18F6E7099379E763782A2B65
:10BC600009D1059B02341A1D1B680592002B0DDAC1
:10BC700001235B420AE0013400232278303A092A8A
:10BC800004D80A214B4301349B18F6E7079363E776
:10BC900005AB0093301C291C3A1C134B00E000BF7D
:10BCA00007E005AB0093301C291C3A1C0E4B00F03A
:10BCB000D1FF04900499013100D070E7BB895A0686
:10BCC00000D53AE70B981FB0F0BDC0469C9F02001C
:10BCD000BC9F0200DC9F0200080303000C0303006A
:10BCE00000000000020303007B3F020038B5084C4F
:10BCF000051C00202060081C111C1A1CF5F750FEC2
:10BD0000431C03D12368002B00D02B6038BDC046F4
:10BD1000C42F00200FB40B4B13B51C68002C05D0AA
:10BD2000A369002B02D1201CFFF718FC05ABA1680A
:10BD3000201C049A0193FFF7D1FE16BC08BC04B086
:10BD40001847C046BC00002070B5051C0E1C141C12
:10BD5000002804D08269002A01D1FFF7FFFB154BB0
:10BD60009C4201D16C6808E0134B9C4201D1AC6845
:10BD700003E0124B9C4200D1EC68A368013BA36036
:10BD8000002B10DAA269934207DB23681E70236838
:10BD900019780A290AD1281C01E0281C311C221C10
:10BDA00000F0C0FA05E02268167023685A1C226071
:10BDB000187870BD9C9F0200BC9F0200DC9F0200AF
:10BDC00008B5034B011C186808F0E9F808BDC04627
:10BDD000BC000020F8B5051C0C1C002804D08169AB
:10BDE000002901D1FFF7BAFB394B9C4201D16C68A5
:10BDF00008E0384B9C4201D1AC6803E0364B9C42D2
:10BE000000D1EC68A2890023636093B299065CD4E8
:10BE1000590717D4D90602D409232B6052E008260B
:10BE200033420AD0281C211CFFF7F4FA00284CD119
:10BE3000A389A060B343A381A061A3890422134313
:10BE4000A38112E0616B00290FD0231C4433994277
:10BE500002D0281CFFF7A4FD236C00206063636000
:10BE6000834202D0E36B236031E02169002903D1D2
:10BE7000281C211CFFF730FDA789BEB2B3070FD0E5
:10BE80000123A381154B1649186807F0E0FF092329
:10BE9000A7811E409E4203D1281C211C07F032FFBF
:10BEA0002269281C63692260216A656AA847031C0D
:10BEB0006060002083420ADCA289834201D12023F2
:10BEC00001E0606040231A43A28101204042F8BD96
:10BED0009C9F0200BC9F0200DC9F0200FC9F0200AE
:10BEE0006140020038B5051C0C1C002804D0836991
:10BEF000002B01D1FFF732FB0F4B9C4201D16C6844
:10BF000008E00E4B9C4201D1AC6803E00C4B9C4214
:10BF100000D1EC68281C211CFFF75CFF002807D12A
:10BF20006368013B636023685A1C2260187801E053
:10BF30000120404238BDC0469C9F0200BC9F0200C9
:10BF4000DC9F020038B5074C0023051C081C236049
:10BF5000F5F71EFE431C03D12368002B00D02B6095
:10BF600038BDC046C42F0020F7B51E1C3C4B041C36
:10BF70001D680F1C0192002D05D0AA69002A02D16C
:10BF8000281CFFF7EBFA374B9C4201D16C6808E0A4
:10BF9000354B9C4201D1AC6803E0344B9C4200D14C
:10BFA000EC68019B022B57D8002E55DB281C211C66
:10BFB000FFF730FA00236360A361A3891A0603D553
:10BFC000281C2169FFF7ECFCA38983229343A381FA
:10BFD000019B022B13D0002F25D1002E01D18026EA
:10BFE000F600301CFFF7C8FC071E18D18020C000E7
:10BFF000FFF7C2FC071E10D10120404200E00020E4
:10C00000A38902221343A3810023A360231C473387
:10C01000236023610123636120E08026F600A38969
:10C0200080221343A381019A012A04D1A3891343D7
:10C03000A3817342A3610E4B0020AB62A3892760EA
:10C04000276166611A0709D5032213405A425341FA
:10C050005B421E40A66001E001204042FEBDC0469A
:10C06000BC0000209C9F0200BC9F0200DC9F0200DD
:10C0700005B501000EB400B59CB01DAB04CB822207
:10C0800002A992008A810A4A02908A604A610122CA
:10C090005242CA81074A086110681D9A019300F054
:10C0A00091FB029A002313701CB008BC03B0184720
:10C0B000FFFFFF7FBC0000200EB430B59CB01FAD69
:10C0C00008CD812302AC9B00A3810290069008F06A
:10C0D0002DF80B4B6060636200236363A36401234C
:10C0E0005B42E381074B6061211C18681F9A2B1C7F
:10C0F000019500F057FC1CB030BC08BC03B01847D9
:10C10000F1400200BC00002038B50C1C0E25495F30
:10C1100001F01AF8002803DB626D1318636503E071
:10C12000A289024B1340A38138BDC046FFEFFFFF39
:10C13000F8B51E1C8B89051C0C1C171CDA0505D5CF
:10C140000E23C95E0022022300F0C8FAA289054B23
:10C15000281C1340A3810E22A15E331C3A1C00F060
:10C1600039F9F8BDFFEFFFFF38B50C1C0E25495F0C
:10C1700000F0B4FAA389421C03D1054A1340A381FD
:10C1800004E0802252011343A381606538BDC0469C
:10C19000FFEFFFFFF0B51D1C424B87B01B680590F9
:10C1A0000293039101920B1C1C78029F5E1C3A19AA
:10C1B000517808220A4001D0331CF5E72D2C04D118
:10C1C00001279E1C5C78009704E000922B2C01D183
:10C1D0005C789E1C10232A1C9A4311D1302C08D164
:10C1E000327820218A43582A07D174781D1C0236E0
:10C1F00006E0002D04D10A2502E0002D00D108251B
:10C20000009F291C7B427B4180273F06FF1A381C78
:10C21000F8F778FF381C0491291CF8F72FFF00234A
:10C22000021C181C029F391949784F0701D5303C70
:10C2300007E003270F4017D05721012F00D13721E6
:10C24000641AAC4210DA591C0BD0904207D802D1C4
:10C25000049FBC4203DC68430123201801E0012352
:10C260005B4234780136DDE7009F591C0BD18020FA
:10C270007B427B410006059FC01A22233B60019F41
:10C28000002F09D10BE0002F00D04042019F002F6A
:10C2900005D0039A002B00D0721E019F3A6007B0B0
:10C2A000F0BDC046C0000020F7B50B1C4D6B4433F9
:10C2B0000C1C9D421BD18026F600311CFFF7B8FBF9
:10C2C000002802D10120404225E0231C6063A663C0
:10C2D00046331A78104BC254231C45331A780F4B3F
:10C2E000C2542A780E4BC254C018206012E08E6BE4
:10C2F000291C73001A1C019307F06CFF051EE1D086
:10C300008719381C291C321C07F0F8FD019B276097
:10C310006563A3630020FEBDFF030000FE03000071
:10C32000FD03000070B5051C0E1C141C002804D071
:10C330008269002A01D1FFF711F9234B9C4201D1F8
:10C340006C6808E0214B9C4201D1AC6803E0204BB3
:10C350009C4200D1EC68A369A360A3891A070AD59F
:10C360002369002B07D022682369F6B2D01A6269CC
:10C3700090420FDB08E0281C211C00F03FF8002849
:10C38000F1D0012040421DE0281C211CFFF742F89B
:10C390000028F6D1A3680130013BA36023685A1C32
:10C3A00022601E706369984205D0A389301CDA07A9
:10C3B00008D50A2E06D1281C211CFFF72BF80028CF
:10C3C000DFD1301C70BDC0469C9F0200BC9F0200A4
:10C3D000DC9F020038B5084C051C00202060081CBA
:10C3E000111C1A1CF5F75EFB431C03D12368002BBC
:10C3F00000D02B6038BDC046C42F0020344B70B530
:10C400001D68061C0C1C002D05D0A969002902D14D
:10C41000281CFFF7A3F82F4B9C4201D16C6808E061
:10C420002D4B9C4201D1AC6803E02C4B9C4200D1C7
:10C43000EC68A28993B2190721D4D90605D409233F
:10C44000336040231A43A2813FE05A0713D5616B42
:10C45000002908D0231C4433994202D0301CFFF736
:10C460009FFA00236363A38924229343A3810023BB
:10C47000636023692360A38908221343A381216990
:10C4800000290BD1A389A02292001A4080239B008F
:10C490009A4203D0301C211CFFF71EFAA389012207
:10C4A0001A4005D061690022A2604A42A26103E0FD
:10C4B000990700D46269A26022690020824206D1F5
:10C4C000190604D540221343A3810120404270BDC8
:10C4D000BC0000209C9F0200BC9F0200DC9F020069
:10C4E000F7B5284D061C2C680191171C0093002CF1
:10C4F00001D1254C2C6061681F2912DD234B002BD4
:10C5000002D1012040423CE08C20FFF735FA041EA6
:10C51000F7D02A6800230260021C8832436028603A
:10C520001360002E25D0251C8835286800280ED1E0
:10C53000164B002BE5D084204000FFF71DFA0028A1
:10C54000DFD0031C0022FC335A609A6028606268C6
:10C5500001219300C31880C39140FC300A1C41683C
:10C56000114341600099D967022E02D183681A43B2
:10C570008260636801995A1C02339B00626000204C
:10C580001951FEBD082E00207C2D002079B9010034
:10C59000F0B587B005900491334F3C68002C61D012
:10C5A000231C88331B680193636801985D1E013367
:10C5B0009B00AE00E31886190293002D3BDB049923
:10C5C000002907D0019A002A2FD0331C80331B6822
:10C5D0008B422AD162680298013A0368954201D1E0
:10C5E000656002E0029900220A60002B1DD062689B
:10C5F00001980392002806D0011CFC3101224868F2
:10C60000AA40104201D1984708E08968114203D13D
:10C6100005983168984701E0306898470399626847
:10C620009142B9D13B68A342B6D10298013D04388A
:10C63000043E0290C1E70D4B002B13D061682368C4
:10C6400000290CD1002B0AD0019A3B60002A02D0AD
:10C65000101CFFF79BF9201CFFF798F99DE7271C9A
:10C660001C1C9BE707B0F0BD082E00208DB901000F
:10C6700038B5074C0023051C081C2360F5F7FCF9AE
:10C68000431C03D12368002B00D02B6038BDC0466B
:10C69000C42F002038B5074C0023051C081C111CB2
:10C6A000236006F0D6F9431C03D12368002B00D089
:10C6B0002B6038BDC42F002038B5074C0023051C63
:10C6C000081C2360F5F73CFA431C03D12368002BB8
:10C6D00000D02B6038BDC046C42F002038B5084CB0
:10C6E000051C00202060081C111C1A1CF5F73CFAE0
:10C6F000431C03D12368002B00D02B6038BDC046FB
:10C70000C42F0020F0B58D6885B0071C0C1C039267
:10C710000193AB4245D390228B89D20013423DD086
:10C7200062690326564309692068F20F401A961978
:10C730000290021C0198013212187610964200D223
:10C74000161C381C5A050FD5311CFFF771F9051E50
:10C7500013D0029A216907F0D1FBA289184B13402C
:10C7600080221343A38111E0321C07F033FD051E24
:10C770000CD1381C2169FFF713F90C233B60A38906
:10C78000402213430120A381404217E0029B256110
:10C79000ED1825606661019DF61AA6600198A84211
:10C7A00000D2019D2A1C2068039907F0B0FBA26803
:10C7B0000020531BA36023685D19256005B0F0BD00
:10C7C0007FFBFFFFF0B59FB0039005938B890E1C94
:10C7D000171C19060FD53269002A0CD14021FFF72A
:10C7E00027F930603061002803D103990C230B60D6
:10C7F000C9E04023736106AD00236B6120236B7693
:10C800003023AB763C1C2378002B03D1E21B029231
:10C8100011D003E0252BF9D00134F4E70398311C43
:10C820003A1C029BFFF76EFF013000D1A6E0696958
:10C83000029A8B186B612378002B00D19EE00122B5
:10C8400052426A606A4600235B3201342B60EB601F
:10C85000AB601370AB654E4F2178381C052207F092
:10C8600033FB002807D0C71B2B680120B8401843B2
:10C8700028600134EFE72B68D90603D56A462021EA
:10C880005B3211701A0703D56A462B215B32117097
:10C8900022782A2A01D0099B0EE0059A111D126800
:10C8A0000591002A01DB099204E05242EA6002226B
:10C8B00013432B60013409E02278303A092A04D866
:10C8C0000A214B4301349B18F6E7099323782E2B5A
:10C8D00018D163782A2B09D1059B02341A1D1B68D5
:10C8E0000592002B0DDA01235B420AE0013400239C
:10C8F0002278303A092A04D80A214B4301349B1884
:10C90000F6E70793234F2178381C032207F0DCFA5F
:10C91000002806D0C71B2B684020B8401843286069
:10C92000013421781C480622671C297607F0CCFACE
:10C93000002812D0194B002B06D1059B0722073384
:10C9400093430833059314E005AB00930398291C27
:10C95000321C134B00E000BF07E005AB00930398C7
:10C96000291C321C0E4B00F075F90490049901311A
:10C9700004D06A69049953186B6143E7B3895A0676
:10C9800001D40B9801E0012040421FB0F0BDC04629
:10C9900002030300080303000C030300000000006F
:10C9A00005C70100F0B5A54C071CA5440193002361
:10C9B00000924693A24A4793BE235B000C1C43A9F6
:10C9C000CA50A04AC02303A85B004890CA50009AEE
:10C9D0001578002D00D128E19B4E306843195A7814
:10C9E000082313401FD0616800290FDD23683068D9
:10C9F0001A7882185278110711D5479A01330132FB
:10CA0000479262682360013A6260ECE7C0235B00F2
:10CA100043AAD358381C211C98470028E6D0009E12
:10CA200001360096D3E7009E0136252D4CD10098A3
:10CA30004593439343782A2B03D11023061C439339
:10CA40000236351C29780B1C303B092B07D8459A38
:10CA50000A235343303B591845910135F2E77B4E89
:10CA60000322301C07F030FA002806D0861B439BB7
:10CA70000120B0401843439001356E1C2D78672D7E
:10CA80000FD8652D77D25B2D51D005D8002D00D160
:10CA9000CDE0252D18D070E0632D54D0642D3DD00D
:10CAA0006BE0702D2FD007D86E2D52D038D8692D5D
:10CAB00063D10023449338E0752D2FD0782D26D0F4
:10CAC000732D5AD102233CE0606800280DDD2368F5
:10CAD0001A78AA4200D0A8E0013362682360479B1D
:10CAE000013A0133626047939BE7C02343A95B008F
:10CAF000CB58381C211C98470028E8D046980028BD
:10CB000000D08EE093E0439A20231343439343984D
:10CB100080239B0003434393102302E00A2300E099
:10CB20000823449304236E2D0BDC032309E0311CFE
:10CB300003A807F0A1FA439940230B434393061C33
:10CB4000012349931DE0439A402313434393002359
:10CB5000F7E74399CB0600D563E7019B479AC807DF
:10CB600004D5191D01911B681A805AE7191D0191FE
:10CB70001B681A6055E70523E3E7032349930A235B
:10CB800044936168002903DD439A520614D51BE0E3
:10CB9000C02343A85B00C358211C381C98470028B9
:10CBA000F2D0ABE7479A013247926268013A62607D
:10CBB000002A13DD01332360236823491A780968AA
:10CBC0008A1852781007EDD4499B022B10DC381CD0
:10CBD00043A9221C01AB00F055F91CE0C02343A976
:10CBE0005B00CB58381C211C98470028E4D085E70F
:10CBF000042B06DC381C43A9221C01AB00F0A6F96B
:10CC000009E0134B002B00D10BE7381C43A9221C71
:10CC100001AB00E000BF012807D0022800D000E7E8
:10CC20006CE7A389590604D501E0469801E001208C
:10CC30004042A5239B009D44F0BDC0466CFDFFFF14
:10CC4000214202009B420200C000002008030300B2
:10CC500000000000F0B50D1C8BB043350793059024
:10CC6000069204950A7E0C1C109B6E2A00D1A8E047
:10CC700011D8632A22D009D8002A00D1B1E0582A5D
:10CC800000D0C1E045310A707C4D4FE0642A1DD0D0
:10CC9000692A1BD0B8E0732A00D1A6E009D86F2A10
:10CCA0002AD0702A00D0AFE00E68202232430A60FA
:10CCB00037E0752A20D0782A33D0A5E01A680D1CF9
:10CCC000111D1960136842352B70A0E021681A68A5
:10CCD0000E0603D5111D1960166805E04806F9D542
:10CCE000111D19600021565E644B002E3BDA049D35
:10CCF0002D2276422A7036E021681A680E0603D586
:10CD0000111D1960166804E04806F9D5111D168832
:10CD100019605A4B227E039308276F2A1ED00A27D8
:10CD20001CE0221C78214532554D1170196822688B
:10CD3000081D03951860160601D50E6802E050061E
:10CD4000FBD50E88D10702D520231A432260102775
:10CD5000002E03D1226820239A432260231C002244
:10CD600043331A7001E003930A276368A360002B22
:10CD700003DB2568042295432560002E02D1049D23
:10CD8000002B0ED0049D301C391CF8F7BBF903981A
:10CD9000013D435C301C2B70391CF8F76FF9061EFF
:10CDA000F1D1082F09D12168C90706D56268236926
:10CDB0009A4202DC013D30232B70049E731B2361D9
:10CDC0002AE008681A684969050606D4460604D5AB
:10CDD000101D18601368198003E0101D1860136897
:10CDE000196000232361049D16E01A68111D196063
:10CDF0001568281C07F09AF963682061984200D9E9
:10CE000023612069606004E0251C42352A700123FB
:10CE10002361049E00233370079E05980096211C11
:10CE200009AA069B07F058FA013002D101204042BE
:10CE300021E02A1C059806992369079DA84701301F
:10CE4000F4D02668B60705D4099BE068984212DA48
:10CE5000181C10E00025E0680999431A9D42F3DA96
:10CE6000221C0598069919320123079EB04701300C
:10CE7000DCD00135EFE70BB0F0BDC0461404030071
:10CE800025040300F7B5151C8A6801900C1C002AC4
:10CE900006D18A69511E8A41524201210A43A26089
:10CEA0002268D20603D41A68111D1960176800267B
:10CEB000A06900281DD123680136DB0603D42A6847
:10CEC00013783B7001372A686B6801322A60A268C8
:10CED000013B013A6B60A260002A25D0002BE7DC01
:10CEE000C0235B00E3580198291C98470028DFD035
:10CEF0001AE0012808D12A6813786269D35C002BF4
:10CF0000D9D1002E1FD00FE0022802D0002E09D068
:10CF10000AE02A6813780C4A1268D3185B781A075B
:10CF2000C9D5F3E701280ED022681023134006D19B
:10CF3000E2680132E260A269002A00D03B702369F6
:10CF400000209E192661FEBDC0000020F0B5151C12
:10CF50008BB0774A0490029307ABC1CAC1C38869FA
:10CF60000C1C032802D1734E059601E0724F059701
:10CF7000A3680026AE22591E03965200914205D99D
:10CF80005E3BFF3B03935E23FF33A3602068D02307
:10CF9000271C1B011C3703430197009723600027C0
:10CFA00007AABB0098582A681178022206F08CFF65
:10CFB00000283AD0012F0DD16368002B06D1082339
:10CFC0002668636080239B00334323605B4B2068AB
:10CFD00003400EE0022F0DD12368C021C90080223A
:10CFE00019409200914223D11022626080225200A7
:10CFF00013432360A3685A1EA260002B15D02B6830
:10D0000000995A1C2A601B78009E0B706B680136D1
:10D01000013B6B600096002B07DCC0235B00E358EC
:10D020000498291C9847002843D10137032FB7D112
:10D030006268002A01D10A23636063681021C91A5B
:10D040003F4B6069C91807F017F8009E0027A368D6
:10D05000002B2FD02A6861691078095C002929D03B
:10D06000216830280AD1080508D50399013700291D
:10D070000AD0013901330391A36005E0314B194017
:10D0800021601378337001366B68013B6B60002BB5
:10D0900003DD2B6801332B6007E0C0235B00E358FE
:10D0A0000498291C9847002804D1A368013BA36079
:10D0B000CDE700272268D2050DD5019B9E4207D9F6
:10D0C000BE23013E5B003178E35804982A1C984740
:10D0D000019DAE4228D02068102202401CD132703F
:10D0E0006368059D04980199A847029D22682B68F2
:10D0F000910601D51A1D09E0D50705D5029D1A1D17
:10D100002A601B68188004E0029D1A1D2A601B68B3
:10D110001860E3680133E360019D0020761BF71976
:10D120002669F719276100E001200BB0F0BDC04669
:10D1300000A0020095C1010071D10100FFFAFFFFBC
:10D1400036040300FFF6FFFF38B5084C051C00202D
:10D150002060081C111C1A1CF4F7CEFC431C03D1E0
:10D160002368002B00D02B6038BDC046C42F0020A0
:10D17000F0B51D1C3B4B87B01B68059002930491D2
:10D18000171C0B1C02991C785E1C0A195178082286
:10D190000A4001D0331CF5E72D2C04D101229E1C3E
:10D1A0005C78019204E001922B2C01D15C789E1CEA
:10D1B00010232A1C9A4311D1302C08D13278202117
:10D1C0008A43582A07D174781D1C023606E0002DC8
:10D1D00004D10A2502E0002D00D108250120291CD8
:10D1E0004042F7F74BFF039001204042291CF7F71C
:10D1F00089FF00238C46181C02990A19527851079E
:10D2000001D5303C07E00321114017D057220129F6
:10D2100000D13722A41AAC4210DA002B09DB039AA2
:10D22000904206D801D1644503DC684301232018ED
:10D2300001E001235B4234780136DDE7002B04DA9C
:10D24000059922220A60012002E0019A002A00D0FA
:10D250004042002F04D0049A002B00D0721E3A6086
:10D2600007B0F0BDC000002008B5F1F7C1FFF8F726
:10D270006FFE02F07AF908BD08B5F1F7B9FFFBF7C8
:10D280007DFBF8F765FE02F070F908BD08B5F1F70F
:10D29000AFFFFBF7E5FAF8F75BFE02F066F908BDB1
:10D2A00010B50278031C303A092A0ED800230B600F
:10D2B000031C0A680A2454431A780133303AA2182E
:10D2C0000A601A78303A092AF3D9181A10BDF7B54E
:10D2D0001E1C00900192994217D3CC1A089B002B78
:10D2E00002DD271C002400E00027009B01991D1986
:10D2F000281C321C06F0F3FD002804D0BC4204D0E8
:10D30000089BE418F1E7281C00E00020FEBDF8B5FA
:10D31000061C1020151C0F1C03F024FF041C0660C3
:10D320008560002F0FD0291C381CF1F703F86060CE
:10D33000681C03F017FF391CE0602A1C061C06F06D
:10D34000DDFD00237355201CF8BD13B50C1C012A0C
:10D3500009D101A9E4F712FC019B206063606223FC
:10D36000A360002006E000230B604B6001235B42BA
:10D370008B60012016BD08B501220023E4F75EFC96
:10D3800008BD08B5012252420023E4F757FC08BD4E
:10D3900008B50122131CE4F751FC08BD08B50122B1
:10D3A00052420123E4F74AFC08BD08B5031C0A1CDD
:10D3B0000220191CE4F786FD08BD08B5031C0A1CF1
:10D3C0000020191CE4F77EFD08BD08B5031C0A1CEB
:10D3D0000120191CE4F776FD08BDF0B50C1C95B0D2
:10D3E000042803D001235B42069309E0C868F1F7E3
:10D3F0009BFE0690002800D187E0069A002AF1DB08
:10D400002068F1F7A7FD061C6068F1F7A3FD051E73
:10D41000B54201D0606806E0A068F1F79BFD089076
:10D42000A84202D0A068E4F7B3FA0DA92068E4F797
:10D43000A5FB0EA909906068E4F7A0FB0FA90B906B
:10D44000A068E4F79BFB0E9B0D9A0A90002693427E
:10D450005BD80E9B0D9F002B0BD1002E04D0301CEF
:10D460000A990F9A06F04AFD0F9A0123039204933A
:10D4700002E0002204920392099D049B069A9342C3
:10D4800034D0002F32D00E9B281C07930123009329
:10D49000391C0B9A079BFFF71AFF0590002825D02F
:10D4A000079A53425341059AD2180592571B002EF2
:10D4B00005D0039B291CF0183A1C06F01FFD039AA7
:10D4C000BF18002E04D0F0190A990F9A06F016FD25
:10D4D0000F9B059AFF180E9B0397D518099A0D9B71
:10D4E000D718049A7F1B01320492C6E7002E05D09C
:10D4F000039A291CB0183A1C06F000FD039BD919A9
:10D50000002E09D1049A002A01D1206808E010A851
:10D5100003F011FF129E9CE7089810A9E4F7BEFAE9
:10D5200015B0F0BD08B50122E4F7B0FD08BD08B59F
:10D5300001225242E4F7AAFD08BDF0B589B0071CEC
:10D540000D1C081C03A9E4F719FB0399061C04A889
:10D5500003F0F1FE069B00240193039B9C4205D23D
:10D56000305DB847019B18550134F6E7281CF1F7E8
:10D57000F1FC04A9E4F792FA09B0F0BD13B5041C5C
:10D5800001A94068E4F7FAFAA368019A934206D227
:10D59000C05C01334000A3600123184300E0002079
:10D5A00016BDF7B5061C30200D1C171C019303F0A7
:10D5B000EBFD041C06708560C760072E18D8301C70
:10D5C000F7F73EFD04060C0E10121406F4230EE0CD
:10D5D0002B786A780A3B1B02134308E0F52306E028
:10D5E000F62304E0F72302E0F82300E0F9232361A7
:10D5F000019B202063760423E38403F0B3FDE06203
:10D60000201CFEBD10B5041CC06A03F0E1FD201C07
:10D6100003F0DEFD10BD30B5048D021C0023A342D3
:10D6200007D2D56AD800281845688D4202D0013348
:10D63000F5E7002030BD70B5041C0E1C151CFFF76B
:10D64000EAFF002801D0002318E0E18C238D8B42F3
:10D6500008D30631C900E06A03F0A9FDE38CE0625B
:10D660000633E384238DE06A5A1CDB00C0180023D4
:10D670002285037043704380466001232B7070BD88
:10D6800008B54368002B01D0181CFAE7FFF7C3FF69
:10D6900008BD406838B50D1C00280AD04468002C2D
:10D6A00006D0291CFFF7B7FF002802D1201CF5E7A0
:10D6B000201C38BD73B544680E1C6368002B12D063
:10D6C0006D460735201C311C2A1CFFF7B4FF2B7850
:10D6D000002B03D0042303706468EEE70378022B69
:10D6E00001D10323037073BD4068704741607047E8
:10D6F00010B50023C25C002A06D0CC5C002C03D0FD
:10D70000A24210D10133F5E7CB5C0024A34207D13C
:10D710000124002A04D0101CEFF758FD4440E4B265
:10D720000120204000E0002010BD10B5021C03685D
:10D7300000200133591E0978C4017F20084049B2F6
:10D7400020430029F5DB136010BD884203D0007828
:10D750004342584100E001207047037842780A3B79
:10D760001B02134302300B607047838BC26A013384
:10D770009BB28383918C994200D29384704738B5D1
:10D78000041C0D1C101C191C2268049BFFF709FFC8
:10D79000E16AA36AAD004160E85038BD13B5041CCE
:10D7A000081C01A9FFF7D9FF206B019904F04CFE7A
:10D7B00013BDF0B587B0051C0C1C04920593002B1B
:10D7C00003DD0B7E082213430B76049AE283EA6A98
:10D7D0001378002B06D1286B211C049A059B05F0B9
:10D7E0000BF833E00026371CEB6A1A8D964223DAD9
:10D7F000DB6AF2009B1803931B78033B012B19D8BB
:10D8000000230293029A238D9A4213DA029AD300DC
:10D81000E26AD3181A78042A09D1039A5B6851681E
:10D82000994204D15288286B04F0E9FC0137029B2D
:10D830000133E6E70136D7E7002FCCD0059B286BF4
:10D840000093211C3A1C049B04F0ECFF07B0F0BDD0
:10D8500073B51D1C0B781A32061C93420ED1081C9E
:10D8600001A901F017FB019B041E9C4209D0301C4A
:10D87000211CA847201C01F003FBF4E7002B00D07B
:10D88000A84773BD1FB50368041C002B0CD10029E9
:10D890000AD00B78192B07D9081C03AB01A902AADF
:10D8A00001F01FFB029B23601FBD38B5051C081C3F
:10D8B0000C1C01F0E5FA011C281CE6F72FF9281CC6
:10D8C000211CE6F72BF938BD10B5041CE6F726F944
:10D8D000206B04F0DBFD10BD10B5041CE6F71EF94B
:10D8E000206B04F00AFE10BD38B5051C141CA142C3
:10D8F00004D0281CE6F712F9011CF8E738BDF0B592
:10D90000041C85B0081C0D1C171C01F0B9FA01F0AD
:10D91000BCFA03A901F092FA6379061C012B08D125
:10D92000E26A201C537E039900933A1C2B1CFFF7DC
:10D9300026FF039A201C9300A26A99580022131C08
:10D94000FFF737FF301C01F09BFA011C201CE6F7A3
:10D95000E5F8206B04F070FE0022206B0121131CFF
:10D9600004F07DFF05B0F0BD38B5041C0D1E9542D6
:10D9700004D1006B0F21F3F71DFF25E00B78A82BD6
:10D980000DD1006B0F21F3F715FF281C01F0BDFA34
:10D99000002819D1281C01F078FA011C0CE0A92BF1
:10D9A00010D1081C01F071FA011C201CE6F7B6F832
:10D9B0000378011CAA2B07D0201CE6F7AFF8206BD8
:10D9C000032103E0E6F7AAF8206B022104F0EDFE44
:10D9D00038BD70B50E1C151C041C0F21006BF3F72D
:10D9E000E9FE311C2A1C201CFFF7BEFF70BD38B5B4
:10D9F000151C041CE6F792F801F047FA2A1C011CDA
:10DA0000201CFFF7B1FF38BDF8B5051C161C1F1C04
:10DA1000002903D0E6F782F8012400E00C1CBE4286
:10DA200006D0311C281CE6F779F80134061CF6E70D
:10DA3000286B211C04F06EFEF8BD10B50C1C131CE5
:10DA40000021221CFFF7E0FF10BD10B5041CE6F713
:10DA500065F8206B0B2104F03AFE10BDF8B5051CEB
:10DA6000171CE6F75BF8041CBC4213D0A11C281C51
:10DA70006678E6F753F80721041C286B312E06D090
:10DA80000821342E03D00921332E00D00A2104F0BE
:10DA90001EFEE9E7F8BDF8B5051C161CE6F73EF8D2
:10DAA000041CB4420DD0A11C281C6778E6F736F898
:10DAB0000521041C286B2F2F00D0062104F007FE3F
:10DAC000EFE7F8BDF8B5051C161CE6F727F8041CAF
:10DAD000B4420DD0A11C281C6778E6F71FF803217B
:10DAE000041C286B372F00D0042104F0F0FDEFE771
:10DAF000F8BDF8B5051C161C1F1CE6F70FF8041C32
:10DB0000B44209D0211C281CE6F708F8391C041C73
:10DB1000286B04F0DCFDF3E7F8BD08B50223FFF73E
:10DB2000E8FF08BD08B50123FFF7E3FF08BD08B50E
:10DB30000023FFF7DEFF08BD10B5041CE5F7EEFF7C
:10DB4000206B062104F0A8FD10BDF7B5066901930E
:10DB5000731C041C0D1C171C0361BD420CD0291C36
:10DB6000201CE5F7DBFF051EBD42F6D0206B0199B6
:10DB7000321C04F016FDF0E7311C206B04F0C7FBEB
:10DB8000F7BD08B50023FFF7E0FF08BD08B5012386
:10DB9000FFF7DBFF08BDF0B5041C85B00D1C081CA9
:10DBA000111C01F061F9291C0290201CE5F7B6FF59
:10DBB000029A061C032A07DD226901230393131C22
:10DBC00001330192236102E00023039301930127B3
:10DBD000029A7B1C934246DA3378012B18D1707875
:10DBE000B11C36380B2811D8F7F72AFA0610211085
:10DBF000101010100A0C080E192519E01B2517E04B
:10DC00001C2515E01D2513E01E2511E01F250FE042
:10DC10002225812B06D0301C01F077F9232500281E
:10DC200000D02025301C01F02BF9011C00E01A2542
:10DC3000201CE5F773FF029A0237061C974205DAAB
:10DC4000206B04F046FC206B04F079FC206B291C4F
:10DC500004F03DFD029B9F42BADA206B0021019A3D
:10DC600004F09FFCB4E7039B002B18D02569206BC0
:10DC70006B1C2361291C04F077FC206B019904F0D4
:10DC800046FB0121206B04F03EFB206B04F040FCBE
:10DC9000206B04F032FC206B291C04F038FB05B02B
:10DCA000F0BDF7B5041C0D1C171C914203D3111CC9
:10DCB000E5F734FF41E00669731C03610B78702BB4
:10DCC00015D1081C01F0E1F8011C201CE5F726FF26
:10DCD000311C0190206B04F075FC201C019900227E
:10DCE000E6F71CF8281C01F0CBF8051C09E0E5F765
:10DCF00015FF311C051C206B04F064FC206B04F044
:10DD0000FCFB201CFFF731FD3A1C291C201CFFF7EF
:10DD1000C8FF206B04F0ACFC206B0F21F3F74AFD29
:10DD2000206B311C04F0F3FA206B04F057FCA38B3A
:10DD3000206B013BA38304F074FCF7BD13B5041CF6
:10DD4000019101A8552101F0B4F80199021C201C91
:10DD5000FFF7A7FF13BD7FB5041C081C03A9151C02
:10DD600001F06CF86379061C012B06D10095201C8C
:10DD700003990722331CFFF702FD206B04F07CFBA4
:10DD8000039A201C9300A26A9D580022131C291C90
:10DD9000FFF70FFD2969206B04F034FB301C01F004
:10DDA0006FF80378011CB43B581E834100225B428C
:10DDB0001940201CA2710223E6F778FA286904B002
:10DDC00070BD10B5C36A041C5A7EFFF7C4FF011C66
:10DDD000201CE5F72FFD10BD08B59142924111407E
:10DDE0000022131CE6F762FA08BDF0B5051C85B0E9
:10DDF0000E1C171CBE4233D0301C01F041F8041E2B
:10DE0000BC4225D03378A22B22D10378A02B1FD17E
:10DE1000301C01F03AF80190201C01F076F8002641
:10DE2000B04203D1201C01F030F8061C03A9019870
:10DE3000FFF793FC286B039904F012FB281C311C9C
:10DE400001220023E6F732FA201C01F019F803E062
:10DE5000281C311CE5F762FE0023061CAB71C9E7E4
:10DE600005B0F0BDF0B5056985B003936B1C041CCB
:10DE700003610F1C006B291C161C04F0C6FB201C40
:10DE8000FFF773FC002E0DD1206B032104F03BFA49
:10DE9000391C201CE5F742FE0321206B494204F0A7
:10DEA00032FA07E00A9B201C0093391C321C039BAA
:10DEB000E6F740FB206B04F0DBFB206B0F21F3F750
:10DEC00079FC206B291C04F022FA0B99201CE5F741
:10DED00025FEA38B206B013BA38304F0A2FB05B0BE
:10DEE000F0BDF0B5061C87B0081C0D1C00F0C8FF83
:10DEF000039003780222191C914369290AD1512108
:10DF000003A800F0D6FF0022031C0092301C291C3D
:10DF1000039A15E0682B20D104A900F0BBFF512122
:10DF2000059005A800F0C5FF041C00F0A9FF049BA4
:10DF3000059F984207D10094301C291C3A1C231CD1
:10DF4000E6F7F8FA11E0201C00F09AFF0094019027
:10DF5000291C301C3A1C231C05E00023019000936F
:10DF6000301C291C1A1CFFF77DFF07B0F0BD08B557
:10DF700016221723E6F7EEFC08BD08B50E220F2384
:10DF8000E6F7E8FC08BDF8B5041C0D1C081C111CC4
:10DF9000161CFFF7DAFB002802D0206B002139E0C5
:10DFA0002B789A2B30D1281C00F06FFF051C00F055
:10DFB00067FF03781A1C6332D2B2012A13D800F02B
:10DFC00064FF291C071C201CE5F7A8FD201C391C38
:10DFD000321CFFF789FC311C381C246B00F044FF15
:10DFE000411C201C16E0201C291CBD2B03D1032240
:10DFF000FFF785FC10E0E5F791FD011C201CE5F71B
:10E000008DFD206B022105E0291C201CE5F786FD13
:10E01000206B012104F08BFBF8BDF8B5041C0D1C2E
:10E02000081C111C161CFFF790FB071E04D00021D2
:10E03000201C0A1C0B1C14E02B789A2B1FD1281CC7
:10E0400000F023FF051C00F01BFF03781A1C63324D
:10E05000D2B2012A08D800F018FF291C021C201C8B
:10E06000331CFFF7D1FC0EE0201CBD2B04D1291C72
:10E070000622FFF744FC06E0391C2A1CF0E7201CAE
:10E08000291CE5F74BFDF8BD38B50D1CC18A041CF1
:10E09000002908D0828A002A05D1006B04F03AFBDF
:10E0A000206B04F0C7F9291CE28AA38A201CFFF721
:10E0B00080FB38BD10B5C36A041C5A7EE6F770FDBC
:10E0C000011C201CE5F7B6FB10BD38B54C78051CCB
:10E0D0000231E5F723FD286B03212F2C03D0042107
:10E0E000302C00D0052104F0D7FA38BD38B5041C17
:10E0F0000D1C081C111CFFF728FB002802D0206B08
:10E10000002116E02B784A2B0DD1281C00F0BDFE13
:10E11000011C201CE5F702FD011C201CE5F7FEFC9C
:10E12000206B022105E0291C201CE5F7F7FC206B81
:10E13000012104F0B6FB38BDF0B5061C87B00D1CFC
:10E14000141C002901D101211FE00B78002201924B
:10E15000562B0CD1081C00F098FE051C00F090FE18
:10E16000211CFFF7FAFA002DEDD0012301932B7843
:10E17000002BE8D00A3B281C0F2B0BD805A9FFF772
:10E18000ECFA019A0599002A00D12160306804F068
:10E19000CEF854E002A900F07DFE019B051C002B87
:10E1A00002D1211CFFF7D9FA01242F1C6442029AE4
:10E1B00097420AD0381C05A9FFF7CFFA071C05982B
:10E1C00003F0FCFB01342418F1E7201C03A903F041
:10E1D000CAFB2F1C041C029A974215D0AF4202D9E9
:10E1E0002E2323700134381C04A9FFF7B6FA05A9C1
:10E1F000071C049803F0ECFB059A011C201C05F099
:10E200007DFE059BE418E6E7039803F0B7FB011CCD
:10E21000306804F08CF8019B002B10D0281C00F013
:10E220002FFE041C029A944209D005A9201CFFF776
:10E2300094FA0599041C306804F006F9F2E707B077
:10E24000F0BD37B5041C0D1C006B002104F093F8E1
:10E25000206B0F21F3F7AEFA201C291C01AA3030E5
:10E26000FFF76AFF201C0199E5F7E4FA37BD08B50E
:10E2700002780021012A03D1417810394B425941DB
:10E280000123002907D10B1C032A04D100F0E6FD6D
:10E29000031C581E8341181C08BD08B502780021D4
:10E2A000012A03D141780E394B42594101230029FB
:10E2B00006D10B1C032A03D100F0D0FD4342434199
:10E2C000181C08BDF0B5041C85B0081C0E1C151CDC
:10E2D0001F1CFFF7E2FF002853D1301CFFF7C7FFD8
:10E2E000002857D13378192B68D9301C03A900F0C6
:10E2F000D1FD337801907B2B20D1002D22D12669CE
:10E30000731C2361019800F0BBFD039A904208D072
:10E3100001226A40201C0199331CFFF7D3FF0190B2
:10E32000F0E72A1C01993B1C201CFFF7CBFF311C96
:10E33000051C206B03F0EBFF281C4AE07C2B0FD15F
:10E34000002DDCD1019B039A934207D0201C019938
:10E350002A1C3B1CFFF7B6FF0190F3E7181C38E0BE
:10E360007E2B07D101226A40201C01993B1CFFF73C
:10E37000A9FF2EE0962B21D1301C00F0C6FD00280D
:10E3800002D0002D16D107E0301C00F07EFD03788E
:10E390009A2B06D1002D0DD0206B391C04F0E4F827
:10E3A00008E0301C00F071FD2A1C011C3B1C201CE5
:10E3B000FFF788FF301C00F063FD0AE0311C201CD1
:10E3C000E5F7ACFB291C061C3A1C206B04F0D8F8BE
:10E3D000301C05B0F0BDF0B587B0041C0392081CDA
:10E3E0001D1C00281AD1201C0399E5F797FBE26A4F
:10E3F000206B1378032B04D10C99023104F0A4F99B
:10E4000058E0042B04D10C99023104F0C1F951E019
:10E4100004F055FA206B04F070F84BE0037805A97E
:10E42000BE2B0ED100F036FD0022011C2B1C201C3F
:10E43000FFF748FF059A831A5A1E93415B42184022
:10E44000CFE700F027FD00F01BFD029000F018FD63
:10E45000011C201CE5F762FB2569071CAB1C23612E
:10E460006E1C206B04F0E8F8206B311C03F04FFFAA
:10E47000206B291C04F0EAF8201C02990022E5F721
:10E480004DFC059B039AF91A4B1E994149423940AC
:10E490000C9F331C0137201C0097FFF79CFF206B5B
:10E4A000311C04F061F8206B291C03F030FF206B55
:10E4B00004F0D8F807B0F0BDF7B5041C081C0F1C19
:10E4C00000F0DEFC00F0E1FC25690022AB1C011C21
:10E4D0002361201C2B1CFFF7F5FE6E1C391C0190DC
:10E4E000201CE5F71BFB311C206B04F03DF8291CB8
:10E4F000206B03F00CFF0121206B494203F003FF66
:10E500000199201CE5F70AFB311C206B03F0FFFE8C
:10E51000F7BDF8B50569161C6B1C012203612B1CA5
:10E52000041CFFF7CFFE3521071C206B03F012FE01
:10E53000311C381CFFF709F9061E09D1391C201CB3
:10E54000E5F7ECFA206B0121321C331C04F087F94B
:10E55000206B012104F0A5F9291C206B03F0D7FEE4
:10E56000F8BDF0B589B00792028B07690492438B1E
:10E570007E1C0593C28BBB1C06920361838B0783B1
:10E58000C3834683041C081C0D1C00F079FC019019
:10E5900000F076FC0390281CFFF77FFE00281ED1B8
:10E5A0002369281C029301332361FFF760FE0028D2
:10E5B00003D1206B311C03F0D7FF206B029903F0CD
:10E5C000A6FE0199201CE5F7A9FA206B311C03F087
:10E5D0009EFE201C291C0122029BFFF773FE049A59
:10E5E000059B2283069A6383E283039B079A9342E7
:10E5F00003D0201C191CE5F791FA206B391C03F09D
:10E6000086FE09B0F0BDF0B5041C85B00292226907
:10E61000081C131C0133236103910192FFF73DFE97
:10E62000061C0398002E06D000F02AFC039000F090
:10E6300027FC03902FE025696B1C2361FFF717FE71
:10E64000321C03992B1C071C201CFFF73BFE011CEE
:10E650000390201CE5F762FA061C0390002F60D19E
:10E660000299FFF772F8002809D1206B03F046FEEB
:10E6700000280CD1206B019903F076FF07E0301CD5
:10E6800000F0FEFB0299FFF760F80028EDD0206B48
:10E69000291C03F03CFE039B029A934241D003A83D
:10E6A000482100F006FC071C0398B84232D000F065
:10E6B000ECFB0390FFF7F1FD051C0398002D06D03D
:10E6C00000F0DEFB039000F0DBFB0390ECE7266933
:10E6D000731C2361FFF7CBFD331C009003992A1CA8
:10E6E000201CFFF7EFFD011C0390201CE5F716FA34
:10E6F000009B0390002B14D1206B03F0FFFD00283A
:10E7000003D1206B019903F02FFF206B311C03F024
:10E71000FEFDC9E7029A974203D0201C391CE5F799
:10E72000FDF9206B019903F0F2FD05B0F0BD0B7807
:10E7300010B50A3B4C781B022343913B5C4263417A
:10E740008371FFF7D1F810BDF0B587B001910B7858
:10E75000041C0D1C012B01D0532B02D10595002563
:10E7600009E00026502B20D1081C00F08EFB0590FC
:10E7700000F086FB051C05A8392100F09AFB002655
:10E78000071C0598B84210D002780023012A03D153
:10E7900043784A3B5A425341002B01D0013600E0F6
:10E7A000033600F06DFB0590EBE7019800F068FB85
:10E7B000019003780027012B03D14778313F7B423A
:10E7C0005F41206B311C002F13D003F0D4FD206B70
:10E7D000022103F017FE206B012103F09BFF201C98
:10E7E0003030291C05AAFFF7A7FC206B03F0B8FD09
:10E7F00047E003F0C0FD01A83E2100F05AFB019E56
:10E800000090009B9E420FD2301C00F03EFB05A9F9
:10E81000FEF7A3FF206B059903F0F4FD301C00F018
:10E820002FFB0137061CECE7206B391C03F072FF4D
:10E83000201C291C303002AAFFF77EFC019D009BA2
:10E840009D421BD2281C03A900F024FB04A9FEF75B
:10E8500084FF0499051C206B03F076FD039B9D4209
:10E8600002D1201C049906E0281C05A9FEF775FFBB
:10E870000599051C201CE4F7DDFFE0E7206B03F0A1
:10E880003CFE07B0F0BD10B5041C0430E6F726FDD1
:10E890006068E1F759FF00F068FE10BD10B5041C78
:10E8A0000430E6F71BFD606804F0F0FB00F05DFE4D
:10E8B00010BD10B5041C0430E6F710FD606804F0CC
:10E8C000E8FB00F052FE10BD10B5041C0430E6F762
:10E8D00005FD606804F0E0FB00F047FE10BDF7B5F1
:10E8E0001E1C0127002A02D1431EF6187F42002277
:10E8F0000023002906D00023F3560025DC0F002357
:10E900006242AB41002181420BD01C02337800945B
:10E91000150E14021A1C009B22432B43F6190131D9
:10E92000F1E7101C191C03B0F0BD13B5041C0193D2
:10E93000002905D1101C01A9221C05F0DFFA09E00D
:10E9400001AB1918031C013B04D3081BC05C1070F9
:10E950000132F8E713BD38B5041C0D1C181C512CEE
:10E960002AD00ED8482C1FD004D8002C1AD0422C04
:10E9700018D035E04C2C31D0502C2FD0492C2FD131
:10E980002CE0682C10D006D8642C20D0662C19D02E
:10E99000622C25D106E06C2C20D0712C07D0692C7C
:10E9A0001ED11BE0A8541BE05200505318E0D300C6
:10E9B000CB18C11718605960D200AD182860C01775
:10E9C00068600DE09400F7F7E3FA605108E0D200C8
:10E9D0008D18F8F7C7FF2860696001E09200505178
:10E9E00038BD0020704700207047704738B50D1CB7
:10E9F000041CF0F7AFFA291C036A0422201C984774
:10EA000038BD70B50E1C151C041CF0F7A3FA311CA0
:10EA1000036A2A1C201C984770BD38B50D1C041CC5
:10EA2000F0F798FA291C036A0022201C984738BD89
:10EA3000816808B5002909D00139816001234900A6
:10EA4000194304224068F0F701FD00E0081C08BDEE
:10EA50007FB5061C0024081C111C01221D1C0094FB
:10EA6000131CE8F749FC2868282102AAEDF7F4FCFA
:10EA7000029BA34205D0201C211C02AA02F0BFFB6E
:10EA80000DE00C2002F06EFB06602B68041C436056
:10EA90002868F0F7C5FCF0F747FBA060201C04B025
:10EAA00070BD1FB54868012201A9F0F703FD029B64
:10EAB000019A013BD3180020934204D31978000235
:10EAC0000843013BF8E700F06BFD05B000BD0028EE
:10EAD00003DAFF23DB05C01801E0C00DC0059C234D
:10EAE000DB05834280414042704730B510228DB033
:10EAF00006920A22009200220B1C051C019202922F
:10EB0000039206A907AA08AC05A80594E7F760F8E0
:10EB1000011C281C03F099F90598A04201D002F0CD
:10EB200057FB0DB030BD10B5041C4160002901D168
:10EB3000816003E0C80002F027FBA0602268072381
:10EB4000134023600123237010BD10B50468CB006F
:10EB500041600721214019430723016019430170D7
:10EB6000826010BD037810B5041C9A0702D4806837
:10EB700002F02EFB2268002363600723134023600A
:10EB800010BD037810B5041C990702D4806802F008
:10EB90001FFB216807220A40012122600A4302214B
:10EBA00000238A4363602270A36010BD10B5401833
:10EBB0007F24431E14401C700C1A1C19002C05DD08
:10EBC0008024D2096442013B1443F4E710BD10B520
:10EBD000021C036800201978C4017F20084049B254
:10EBE000001901330029F6DB136010BD13B5421C78
:10EBF000019202780C1C031C082A10D8101CF6F78E
:10EC00001FFA1D100E0508080E0E0A0005330193A9
:10EC100014E00333FBE701A8FFF7D9FF0EE0192A40
:10EC200001D80233F3E701A8FFF7D1FF01A8FFF7EE
:10EC3000CEFF002C02D0019B18180190019816BD40
:10EC400010B50C1C022102F0E0FB230A0A3303700A
:10EC5000447010BDF8B51D1C0378041C0F1C161C55
:10EC6000002B26D1436882689A4210D30C214B4373
:10EC7000191CC031C068012202F0A6FA002802D196
:10EC80000123237015E06368E06010336360A268BD
:10EC9000E368511CA1600C214A433F029B183A0AC9
:10ECA000DF783F0617431F6032785D60DA70069A9E
:10ECB0009A60F8BD10B50C1C052102F0A6FB0323D9
:10ECC000037000230133C4542412042BFAD110BD65
:10ECD00070B5161C8269041C00235D1CD20901D08A
:10ECE0002B1CFAE70233081C191C02F08EFB0823C8
:10ECF0000370291C0130A269FFF758FF6569A369F9
:10ED0000AB4206D30835A900E06902F050FA65610C
:10ED1000E061A369E269591C9B00A1619E5070BD2E
:10ED2000F0B5046A89B0221C403203921578071CA2
:10ED30000E1C082D08D1A16CE06CEFF74DFB011CF7
:10ED4000301CFFF77DFF69E0092D0DD10022E06C3A
:10ED5000A16C231CEFF72EFA021CC3070ED541103D
:10ED6000301CFFF7A7FF59E00A2D0CD1E06CA16C15
:10ED7000012200940023E1F70FFB021C381C311C18
:10ED8000FFF7A6FF4AE02B1C0B3B012B3FD804A842
:10ED9000A16C02F0B9FAA26C04A8E16C02F093FA3B
:10EDA000201C02F032FF039A1378AB42F3D00B3BE6
:10EDB000012B2AD9059906980A2902D8EFF70CFBEE
:10EDC00001E0EFF7D3FA041E0CD0301C032102F04F
:10EDD0001CFB0B3D6B1E9D4104354470240A0570DD
:10EDE00084700EE0069805990B2D03D1221CE2F7E2
:10EDF00089FE01E0E2F79EFE021C311C381CFFF781
:10EE000067FF04A802F0AAFA0BE000200AE0081C41
:10EE1000022102F0FAFA012303704570201C02F06F
:10EE2000F4FE012009B0F0BD13B50130019001A836
:10EE30000C1CFFF7CCFE2060019816BD10B5002316
:10EE40000B60C2185478DA009440221C0C6801331D
:10EE500022430A60042BF4D1053010BD07B501A987
:10EE6000FFF7ECFF01980EBD38B50D1C0024A84239
:10EE700004D201210134FFF7B9FEF8E7201C38BDA8
:10EE800008B50121FFF7B2FE08BD08B50021FFF764
:10EE9000ADFE08BD13B50130019001A80C1CFFF7B1
:10EEA00096FE01A8FFF793FE019B18182060181C1E
:10EEB00016BD13B5041C00680378002B02D1013085
:10EEC00020600DE0192B02D91A318B4203D00121A9
:10EED000FFF78CFE04E001A9FFF7DCFF206001983A
:10EEE00016BD37B51C1C431C0193037801A81A3BBF
:10EEF0000B60151CFFF76BFE286001A8FFF767FE8B
:10EF0000019A10182060101C3EBD07B501A9FFF73B
:10EF1000C1FF019BC01A43425841C0B20EBD10B59B
:10EF20008068002804D0446802F052F9201CF8E7F9
:10EF300010BD08B50222E7F77BFB08BD08B501222A
:10EF4000E7F776FB08BD73B5041C01A94068E2F73A
:10EF500015FEA368019A93420DD2C518281C02F031
:10EF600005FB461B311C281C0122E2F7CBFDA368E0
:10EF70009E19A66000E0002076BDF0B50A6887B053
:10EF8000071C05910068111C0192E1F70DFD059A1F
:10EF90003B68041C1568181C211C0493F6F762FEDC
:10EFA000291CF6F751FB0021061C201CF6F722F95C
:10EFB000002805D00024002D27DA8024240624E030
:10EFC0006B4601221A720021201CF6F719F9431E24
:10EFD00098416B461A7A404202401A72281C00215E
:10EFE000F6F70EF9431E98416B461B7A5840C0B2A3
:10EFF00000280AD0201C291CF6F7BAF9FE21041CAF
:10F000008905301CF6F72EFE061C301C0021F6F791
:10F01000F1F8002809D0291C0498F6F715FB002503
:10F02000002816DA80252D0613E0301CF9F7A6FC1F
:10F03000051C291C301CF6F715FEFC218905F6F786
:10F04000F3F8002805D0FE21281C8905F6F790F971
:10F05000051C059A3D60146007B0F0BD08B5FF239C
:10F06000DB05C91803239943E7F78AFF08BDF8B504
:10F07000161C4E43071C1D1C0024AC4209D00698E8
:10F08000391C321C04F03AFF069B01349B1906938D
:10F09000F3E7F8BDF7B5B0CA00200191011C00F0FC
:10F0A0008CFD061C002F0ADA013DAC4211DC019AEE
:10F0B000AB00D158301CE9F7A7FFED19F5E7AC42DA
:10F0C00007DA019AA300D158301CE9F79DFFE41933
:10F0D000F5E7301CFEBD70B5049C061C151C081C11
:10F0E0001B2E03D10022A5422DD10EE0192E07D0F0
:10F0F0001C2E0AD1251C181C141C0B1C1D2604E0F8
:10F10000251C181C141C0B1C1A26221EAA4200D9EE
:10F110002A1C191C04F0E3FE1B2E03D1424242417B
:10F12000D2B210E000280DDB012200280BD1A5424D
:10F1300003D0A5424041C2B205E01A3E721E96417C
:10F14000F2B200E00022101C70BDF7B50024071CCD
:10F150000E1C0192251CB44209D0A300F858019955
:10F16000EFF790FF431E98412D180134F3E76D002F
:10F1700001202843FEBD13B50023041C0093081C86
:10F18000111C1A1CE8F7B8F8042001F0EBFF04602A
:10F1900016BDF7B5061C406800281AD00021EFF70D
:10F1A00035FA0024051C73689C4211D2A200B318E2
:10F1B00098680192EDF71CFA071E04D1281C02F092
:10F1C00034FC381C05E0019A0134AB189860EAE77A
:10F1D000281CFEBDF7B56F4607373A1C051C0C1CF2
:10F1E000FEF729FA3B78061C002B12D0281C211CA4
:10F1F000FEF74FFA00280AD00378023B022B06D80C
:10F2000004233370281C211CFEF754FA01E000236C
:10F210003370F7BD37B56D4607352A1C041CFEF761
:10F220000AFA29782278002905D0002A01D0072A75
:10F2300007D1002206E0013A052A04D80278002A04
:10F2400001D10222027037BD70B5051C0E1C101CC6
:10F25000191C1C1CFEF7DFF90378002B01D1B368E1
:10F2600002E0012B04D1F368281C211C984708E018
:10F270004288022B01D1336800E07368281C211CEE
:10F28000984770BD38B5051C242001F07DFF041C93
:10F290004561A80001F066FFA061201C38BD10B5D3
:10F2A000041C002902D0C06801F092FFA06901F09F
:10F2B0008FFF201C01F08CFF10BD38B5041C0D1E03
:10F2C000012D07D1436901219A004942806904F068
:10F2D00037FE07E0022905D1406801F043FF63686B
:10F2E000E060A36000232560636038BD70478068DC
:10F2F0007047C06870470368012B03D84268836970
:10F300008900CA50704742684B42013A511819406F
:10F310004160704770B504684368012C02D85B18DF
:10F3200043600CE0CE18C5684660022C07D1EB188C
:10F33000C9188B4203D01A70120A0133F9E770BD65
:10F34000026810B54368012A03D8023343601030C5
:10F3500003E0C2689C1C4460D0180170090A417027
:10F3600010BD036A10B5041C002B04D0B0210902A3
:10F370001943FFF7E5FFE369BD2109021943201C8A
:10F38000FFF7DEFF10BD30B504684368012C03D8D9
:10F3900004334360103003E0C4681D1D4560E0186D
:10F3A00001708270090A120A4170C27030BD08B53E
:10F3B0001143DB001943FFF7C3FF08BD08B5072A57
:10F3C00001D8D20003E0083AD20040231A430729AB
:10F3D00002D90839802319430A438C21C9011143FA
:10F3E000FFF7AEFF08BD38B583698900CD58436883
:10F3F000E021ED1A043D2B055B0D0902041C1943A5
:10F40000FFF79EFF23680120022B07D1ED0AED02D2
:10F4100004D080231B01ED186842684138BD70B5E7
:10F42000041C8069920015586268AD1A043D68108A
:10F43000002B15D1D0231B020902FF2619433040AF
:10F440000143201CFFF77CFF22680123181C022ABD
:10F450001FD1B5431DD00135FF356842684118E022
:10F46000F0231B02890119438023AA12DB001340F9
:10F470008022920119432B031540802212020005BD
:10F480009B0E000D2A4302431943201CFFF77BFF0C
:10F49000012070BD38B583698900CD584368F021DB
:10F4A000ED1A043D6B025B0D09021943F8226B1043
:10F4B0009BB21202041C1A43FFF765FF2368012068
:10F4C000022B07D1AD0DAD0504D08023DB03ED1871
:10F4D0006842684138BDF0B587B004920EAA127830
:10F4E0001D1D05920FAA12780F1C0392061C0D9A7F
:10F4F000281C0C99039BECF78DFC3A68041E94427F
:10F5000003D901F02FFE30603C603468039B0D9AF4
:10F5100000930194281C0C99059B01F028FD049A86
:10F520001060201C07B0F0BD08B5043001F0C3FC2A
:10F5300008BD0123184203D01841C043C00F04E0A6
:10F540000079C007C00F4340D8B2704773B50D1C97
:10F55000041CE7F78DFF0123061C009304302B1CCD
:10F56000221C01F09FF9301C76BD08B543001A1C1F
:10F57000424002D40120184302E0C117FFF7E6FF22
:10F5800008BD73B50D1C041CE7F772FF0023061CB1
:10F59000009304302B1C221C01F084F9301C76BD32
:10F5A00008B5830F03D140000123184302E0002176
:10F5B000FFF7E7FF08BDF0B585B0041C0F1C161C53
:10F5C0000393E7F755FF039B051C00932168331C49
:10F5D0003A1C043001F0EEF9236818182060281C4A
:10F5E00005B0F0BD08B5C30701D5401002E00430F6
:10F5F00001F04EFC08BD08B5C30703D54010F6F76F
:10F60000C7FC02E0043001F094FC08BD806870473C
:10F61000F0B50E1C0179171CC9078288C90F87B085
:10F62000C9B2051C1C1C5208C3880091301C391C2F
:10F63000E7F762FE2B79DA070AD5B200A21803A811
:10F64000391CFFF782FAAB68301C211C03AA15E0B5
:10F65000AA88AB685208032A12DCE9888A420FD1D3
:10F66000012A05D0022A06D0002A06D198470AE0CE
:10F670002068984707E003CC04E007CC984702E0F5
:10F68000301C211C984707B0F0BDF7B51C1C43681F
:10F690000027061C0D1C081C0097111C1A1CE7F7FC
:10F6A0002BFEB36801261E43BD4201D1B04725E0C1
:10F6B000012D04D12068E8F7E3F9B0471EE0022DE0
:10F6C0000AD12068E8F7DCF9051C6068E8F7D8F98A
:10F6D000011C281CB04711E0381C032D0ED12068F6
:10F6E000E8F7CEF9071C6068E8F7CAF9051CA068BE
:10F6F000E8F7C6F9291C021C381CB047012340005A
:10F700001843FEBD07B5019001A8FEF70EF801A849
:10F71000FEF70BF80EBD10B5131CC4680022A047FD
:10F7200010BD08B500210A1CFFF7F5FF08BD07B59D
:10F73000019101AA0121FFF7EEFF0EBD08B5E8F720
:10F74000D3FA08BD08B5EFF705FCE8F715FB08BDCF
:10F7500038B5041C0D1CFFF7F5FF002803D0201C52
:10F76000EFF7F8FB041C291C201CEBF7B3FF38BD96
:10F7700008B54069FFF7CEFD08BD08B54069FFF741
:10F78000C2FD08BD038870B50469032B09D1C568A3
:10F790000023AB4205D09E00A659964208D0013303
:10F7A000F7E78B004069E250FFF7A5FD012000E07C
:10F7B000002070BD38B5041C21800D1C42608360A0
:10F7C000032905D1C36800219A00006904F0B8FB41
:10F7D000043D691E8D410221491B6069FFF76DFDE3
:10F7E00060690021E7F71EFE38BD7FB5041C406943
:10F7F000FFF7B7FD6069FFF779FD2388042B15D16A
:10F800006069FFF776FD6368051C60695E69FFF754
:10F810006EFD002162680091528B031C01920291DF
:10F820000391301C05212A1CEDF77EFD7FBD38B504
:10F83000051C182001F096FC041CC560A80001F00E
:10F8400091FC2061281CFFF71DFD6061201C38BD64
:10F8500010B5041C006901F0BBFC60690021FFF7D2
:10F860001EFD201C01F0B4FC10BD026813783E2B75
:10F8700005D83C2B05D2212B07D13E2301E0402B9C
:10F8800003D101320260181C00E040207047F7B538
:10F890000668051C741C20780194EDF7A3FCA71BD7
:10F8A000031C01340028F6D12868391C0A22EEF71F
:10F8B00081FC019A40102A60FEBDF7B5E2F7BEFD5B
:10F8C00000906846FFF7D1FF0025061C009B01242D
:10F8D0001A78002A29D001941878EDF783FC231CAC
:10F8E000002803D06846FFF7D2FF031C00990A786E
:10F8F000732A01D01F1C12E00127002F11D0002B0A
:10F9000006D1009A301C117801AAE5F7FFFC031C10
:10F91000019A013F541E6519524215405D1900239A
:10F92000EBE7009B01330093D0E768002043FEBD66
:10F93000F0B589B00D1CE2F781FD029002A8FFF737
:10F9400094FF029A019004920026049B1C78002CDC
:10F9500012D0201CEDF746FC0124002807D004A893
:10F96000FFF795FF049A1378732B00D0041C049BB7
:10F97000361901330493E8E7211C301CEEF746FEEC
:10F980000122071C05A9281CEFF794FD059A039294
:10F99000B44231D2029B01251878EDF723FC0028F0
:10F9A00003D002A8FFF773FF051C029A1378732B8C
:10F9B00004D06419A300FB1800930BE0291C0398E2
:10F9C000E2F7B8F8039B5D19A31C9B000395D8517F
:10F9D00001340DE0002D0BD0029A0198117803AA92
:10F9E000E0F7B6FB009AAB00D31A9860013DF1E74F
:10F9F000029B01330293CBE7381C09B0F0BD08B578
:10FA0000E9F7B2F8EFF7FEFDE9F7ECF80028F9DBCB
:10FA100008BD10B50C1CF5F7D5FB081E02DA002C4A
:10FA200004DC04E0002902D0002C00DA001910BD2B
:10FA300008B5002804DB002906DACB43C01803E030
:10FA4000002901DB401A0130F5F766FB08BD42686A
:10FA5000836891688B4206D2D26899008A58013334
:10FA60008360101C00E000207047F0B585B0009066
:10FA70000E1C171C0393EBF785FA009AB24255D27D
:10FA8000009D3168043D002F01D1019103E0381C35
:10FA900001F0ADFB0190341C291D0291A1420FD24F
:10FAA0006968002F03D0381C01F0A1FB011C019AEA
:10FAB0001920ECF7DDFD039A904201D1029DEBE79E
:10FAC000029B043C9C4213D921680A1C002F03D0DE
:10FAD000381C01F08CFB021C01991920ECF7C8FDC1
:10FAE00003998842ECD06B6822686A602360E5E77E
:10FAF0006B683168696033600299009B0835E21ACF
:10FB0000731A9B10013B92109A4207DA0098211C4D
:10FB10003A1C039BFFF7A9FF0095AEE7311C281C98
:10FB20003A1C039BFFF7A1FF261CA6E705B0F0BD1A
:10FB300008B50B1C0968021CC8688968E7F77AFBDE
:10FB400008BD38B5041C081CECF704FD051C281C76
:10FB5000ECF74EFD011C201C002902D0E9F754FAF5
:10FB6000F5E738BD08B5031C0A1CC0689968FFF7A3
:10FB7000ECFA08BD38B5051C102001F0F3FA291C79
:10FB8000041CE9F791FB201C38BD73B500240D1C43
:10FB90001E1C081C0094111C0123221CE7F7ACFB5F
:10FBA000A54203D1281CFFF7E5FF05E0201CFFF765
:10FBB000E1FF3168FFF7C5FF76BD38B5051C0C1CA9
:10FBC000FFF7D8FF0023AD009C4206D0AB4204D023
:10FBD000E258C168CA500433F8E738BD08B5031CC1
:10FBE000D9688068FFF7E9FF08BD8368C0680B60CB
:10FBF000106070478160704738B5041C0B1C151CE1
:10FC0000A1681A1C00680023EFF76CFBE368800012
:10FC1000C55038BD07B511216A46ECF71DFC0098A8
:10FC2000431E9841C0B20EBDF0B5570089B07F1891
:10FC30000131041C161C00930191042F0DD8836818
:10FC4000BA00009904A8039304F058F96068019978
:10FC5000321C03ABECF78AFB16E00137BF00381CFF
:10FC600001F080FAA368051C3A1F08C0009904F04F
:10FC700045F960680199321C2B1CECF777FB041CDA
:10FC8000281C01F0A5FA201C09B0F0BD027905235B
:10FC9000D10700D483795B000120184370470279B3
:10FCA0000523D10700D443795B0001201843704736
:10FCB0000423591A01238B40191C021C0023D05C19
:10FCC000084003D10133052BF9D100E00120704732
:10FCD00010B50421041CFFF7EBFF031C0420002BCC
:10FCE00007D1201C0321FFF7E3FF434243410320D8
:10FCF000C01A10BD05235A435118182903D10079A1
:10FD00000007C00F08E0CB08C01843790720014066
:10FD1000181C084101231840704783795A43511831
:10FD20004B08C018C379042289001140181C0841EF
:10FD30000F231840704710B58479624351188C0026
:10FD40004908401804222240C179F024144121407E
:10FD500093400A1C1A43C27110BD08B583794279D9
:10FD600000215A4301325210073004F0E9F808BD6F
:10FD700010B50379DC0705D5FFF7BCFF092358430D
:10FD8000C0B201E0FFF7C9FF10BDF0B587B0029225
:10FD9000DF430C9AFF171F40D343DB171A40009034
:10FDA0000191381C111C0492E9F75CFD0299009A3C
:10FDB000CB43DB171940137903900198DB07C44349
:10FDC000DB0FE417DBB2059104400521002B00D1C5
:10FDD000917901980E1CC219914200DD161C05256F
:10FDE000002B01D100994D79029A049813189D4275
:10FDF00000DD1D1C331B9F4204DC0599049A6B1A1D
:10FE00009A4204DD0398FFF7A8FF00E00134B442F2
:10FE100011DA059FAF42F9DA3A1C0098211CFFF76E
:10FE2000A7FF031C0198211A02983A1A0398FFF7BA
:10FE300082FF0137EEE7039807B0F0BDF0B54868E0
:10FE400085B00C1C0F68EFF76FF9061CA068EFF780
:10FE50006BF9051CE068EFF767F903902069EFF78D
:10FE600063F9311C00902A1C381C039BFFF78DFF9F
:10FE700005B0F0BD436873B5041C18695A68A168E1
:10FE8000002808DD10790525C60700D495790020E3
:10FE9000A94218DA01E0002810DB1579DB6805209B
:10FEA000EE0700D450790090101C0022FFF76DFF80
:10FEB0006368A2681B69D318A36004E0DD68684228
:10FEC0008142EADC002076BD02790523D10700D407
:10FED0008379181C704702790523D10700D4437930
:10FEE000181C7047F7B50379061CDA0703D4437969
:10FEF0008779009301E005270097381C0099E9F7FE
:10FF0000B1FC00250190009A954211DA0024BC4210
:10FF10000CDA211C2A1C301CFFF72AFF211C031CB1
:10FF20002A1C0198FFF707FF0134F0E70135EAE7E3
:10FF30000198FEBD08B5FFF7D5FF08BDF7B50379F9
:10FF4000061CDA0703D443798779009301E005277B
:10FF50000097381C0099E9F785FC00250190009A6C
:10FF6000954212DA0024BC420DDA211C2A1C301CF6
:10FF7000FFF7FEFE09231B1A211C01982A1CFFF71C
:10FF8000DAFE0134EFE70135E9E70198FEBD08B577
:10FF9000FFF7D4FF08BDF0B5037987B00390DA0707
:10FFA00003D443798479009301E0052400946342EB
:10FFB0008B4200DA0B1CA34200DD231CDA43D2176C
:10FFC0001A40E11805920491A14200DD04945B42BD
:10FFD0000193019ADB43DB171A40201C0099019220
:10FFE000E9F740FC0026029001998E4201DB059E54
:10FFF0000EE00025009B9D4207DA2A1C0298311C66
:020000040002F8
:100000000023FFF798FE0135F4E70136ECE70136EF
:100010000199059A8B1A9F19049B9E4211DA0025BB
:10002000009A9542F3DA2A1C0398311CFFF7A0FED0
:100030002A1C031C391C0298FFF77DFE0135EFE7EF
:100040000137A7420BDA002500998D42F8DA2A1C05
:100050000298391C0023FFF76EFE0135F4E7029881
:1000600007B0F0BD10B5041C081CEFF75DF8011CCB
:10007000201CFFF790FF10BD10B5041C081CEFF703
:1000800053F84142201CFFF786FF10BDC16802698A
:10009000F8B5041C914202D1037D052B4AD0A0681B
:1000A0000121FFF778FF227D637D061CA0609A4244
:1000B00016D2E07DE9F7FAFB0025071C237D7A5D67
:1000C0000421CB1A1A41131C012213400922534365
:1000D000301C2A1C0135FFF72EFE052DEED124E041
:1000E0009A4222D1E36821695A1CE2608A4206D111
:1000F0002023E375052363750023237515E05878E5
:10010000E075E9F7D3FBA17D051C002904D0FF238E
:1001100023750523637508E0FFF7CAFD404220758B
:10012000281CFFF7D5FD01306075237D301C01339D
:10013000237500E00020F8BDF0B5037987B0039087
:10014000DA0702D48779447901E005273C1C634231
:100150008B4200DA0B1CA34200DD231CDA43D217CA
:100160001A40E11805920491A14200DD04945B421B
:100170000193019ADB43DB171A40381C211C0192C2
:10018000E9F770FB00260290019B9E4201DB059E71
:100190000DE00025BD4207DA291C0298321C00231D
:1001A000FFF7C9FD0135F5E70136EDE701360199A5
:1001B000059A8B1A9B190093049B9E4212DA002524
:1001C000BD42F3DA291C0398321CFFF7D1FD291C2C
:1001D000031C009A0298FFF7AEFD0135F0E7009985
:1001E00001310091009AA2420ADA0025BD42F6DAF6
:1001F000291C0298009A0023FFF79DFD0135F5E7C1
:10020000029807B0F0BD10B5041C081CEEF78CFF77
:10021000011C201CFFF790FF10BD10B5041C081C2A
:10022000EEF782FF4142201CFFF786FF10BDF8B5B4
:10023000E9F73CFB071C0520011CE9F713FB00252F
:10024000061C00243A5D04235B1B1A41131C012287
:10025000134009225343301C221C291C0134FFF790
:100260006AFD052CEED10135052DEAD1301CF8BD13
:10027000F8B548680C1C0F68EEF756FF061CA0681E
:10028000EEF752FF051CE068EEF74EFF311C031C31
:100290002A1C381CE9F7BAFDF8BD10B5041C04305F
:1002A000EAF70EFC606802F0C8FFFFF75EF910BDC8
:1002B00010B5041C0430EAF703FC606802F0C0FFCC
:1002C000FFF753F910BD10B5041C0430EAF7F8FB32
:1002D000606802F0B8FFFFF748F910BD38B500219B
:1002E000051C0320EEF792F9041C281DEAF7E8FB31
:1002F000686802F0A2FFFFF738F9A060686802F0B2
:100300009FFFFFF732F9E060686802F09CFFFFF79B
:100310002CF92061201C38BD8368C268934203D247
:100320005A1C8260187801E001204042704703683F
:1003300010B5041C002B02D0406800F049FF201CBF
:1003400000F046FF10BD08B580684008FFF70DF9C2
:1003500008BD70B5146801291DD91025211C03782A
:10036000A94314D1302B16D141782026831C314368
:10037000782901D1156027E0002C24D16F2901D103
:10038000082102E0622908D1022111601CE0082C3A
:1003900006D0022C0DD0002C15D10A23136012E0D8
:1003A000302B10D1437820221A43031C6F2A0BD123
:1003B00007E0302B07D1437820221A43031C622A1E
:1003C00002D1831C00E0031C181A70BD10B588B060
:1003D00003AB01A922240022039004940691102467
:1003E0000168181C0192029205941A74EAF7DAFD6A
:1003F000019808B010BD70B5141C126886B0051CB9
:100400000E1C002A0AD101A841608260291C012229
:100410000195C4600274EAF7C5FD1AE0806B0028FC
:1004200017D001F09EFA6568F60006213143002DD1
:1004300006D10222E5F7D0FC00280AD0256008E0AA
:100440000122E5F7C9FC002803D06368436000235C
:10045000236006B070BDF0B5141C1268051C8BB08B
:100460000E1CCB000430002A28D10621194301912B
:10047000E5F7B2FC002801D040681DE005AB07900D
:1004800018742968181C059506960894EAF78AFDE1
:100490002768002F23D1202E21D002AA281C20213A
:1004A000EBF7DAFF029A002A19D0019B0120391CD0
:1004B00002AA049300F0A3FE206010E06568062104
:1004C0001943002D05D10222E5F786FC002806D04D
:1004D00003E00122E5F780FC4560002323600BB0B8
:1004E000F0BD37B5041C1D1C081C0023111C012283
:1004F0000093131CE6F700FF082000F033FE2D6880
:10050000456004603EBDF0B589B0041C0F1C03A813
:100510002C21002381600125161C216801AA037487
:10052000019302934560C2600394EAF73BFD019B8F
:10053000281C042B08D12069EEF70CFD2269C36A40
:10054000391C101C321C984709B0F0BD70B588B03A
:10055000051C182303A80024436001AE2423296846
:100560008360C6600474019474600395EAF71AFD11
:100570000198A0420ED0042807D12869EEF7EAFCC2
:100580002A69436A101C984704E0201C211C321C75
:1005900000F035FE08B070BD08B5FFF717FF431E29
:1005A0009841C0B208BD13B5081C1C1C111C0023C7
:1005B00002220093131CE6F79FFE03CCEBF77CF8B6
:1005C00016BD10B50C1CEEF7C5FC211CEBF7B2F8FC
:1005D00010BD38B50D1C041CEEF7BCFC291CEBF754
:1005E00079F8002800D0206938BDF0B5071C1C0937
:1005F000002094421BD26000121B0918141C3D1CE1
:10060000002C0DD00E88012C02D948880004064326
:100610000F201840C6402E80013C02350231EFE722
:100620005300FF18023F388843425841101AF0BD6A
:10063000F0B5059C059E141B0022A446141C002E38
:1006400008D08D5A9F5A013EEF193C198452240C50
:100650000232F4E7059B62465D00431949191E1CEE
:10066000002A07D00D88013A2C1934800231240C5D
:100670000236F5E761464A009B18002C02D00122A1
:100680001A800233181A4010F0BDF0B5059C121BF9
:10069000271C0024251C002F0AD00E5B013FB44606
:1006A000AC441D5B6646751B05532D140234F2E7FE
:1006B000059B5E008719131C8E193C1C002B07D06C
:1006C0003188013B6D18258002362D140234F5E780
:1006D0005200BA18023A824203D20232101A401073
:1006E000F0BD1388002BF5D0F7E710B5041E05D038
:1006F000806800F06DFD201C00F06AFD10BD38B56B
:10070000041C0D1E012D00D80225A068002803D06E
:1007100022689308AB420CD223789A0709D4690067
:1007200000F045FD2268AB00032515401D43A06085
:10073000256038BD38B5051C0C2000F013FD01788C
:100740002A78012399431A400B1C13430222934336
:1007500003702968041C88082168032382000B4069
:10076000134323606B686360AB68002B01D1A36007
:1007700009E0400000F0F6FCA06029688A085200F9
:10078000A96803F0BBFB201C38BD10B501249942B9
:1007900014D314D84B00C018D218002908D002383E
:1007A000023A04881388E31A04D405D10139F4E726
:1007B0000C1C04E0012401E0012400E06442201C40
:1007C00010BD38B5041C0D1C0221FFF798FF2378DB
:1007D0000122002D03DA13432370694202E09343A0
:1007E0002370291C00236360002907D063685A1C0A
:1007F0006260A2685B009952090CF5E738BD027887
:10080000FC2313400370026803231340036000239A
:1008100043608360704708B5002805D003789A07C5
:1008200002D4806800F0D4FC08BD38B5051C0C1C4F
:100830004968FFF764FF29782278012399431A4019
:100840000B1C13432B706368A8686B606368A16816
:100850005A0003F053FB38BD08B5002901D14160AF
:1008600001E0FFF7AEFF08BD38B50D1C041CFFF713
:10087000C6FF291C201CFFF7EFFF38BD38B50478F0
:100880000125AC4302252C43047005689400032223
:100890002A4022430260002281604260191CFFF757
:1008A000DBFF38BDF8B51D1C06AB1F78061C042104
:1008B000141CFFF724FF33780122002F07D0002DEE
:1008C00005DA1343337000236242AB4103E09343E4
:1008D0003370221C2B1C00217160111C19430CD099
:1008E00071681C04481C7060B06849000A52100C02
:1008F000190C221C02430B1CEFE7F8BD0378F7B577
:100900000E1C0121F20F8B4374001343240E03705D
:10091000631EDBB2051CFD2B02D900236B6048E08F
:10092000231C7F3BF9D4002B02D1FFF74AFF40E0A4
:10093000221C6F3AD117090F8A1812117602019200
:10094000720A802636041643162B05DC96231C1BE0
:100950000027E6403C1C09E00F221340963C1F1C78
:10096000E3171B0F173F1C19174024110199281C6E
:10097000FFF7C5FE0199620069600092002C03D068
:10098000A868002103F0DCFA002F08D0331CA96806
:10099000009ABB408B521023DF1BFE4001346300E2
:1009A000019A944205D0A9680134CE52360C023324
:1009B000F6E7F7BDF0B5041C0D1C8818D10085B012
:1009C000090902900131201C1F1CFFF798FE2378B3
:1009D0000122002F01D0134300E093432370002332
:1009E00063602B1C029FBB420DD219780A1C303A5F
:1009F000092A0DD9113A192A01D80A3208E00A1C2D
:100A0000613A192A02D9581B05B0F0BD0A1C573AA1
:100A10000A9FBA42F7D26068A668844692B20090F4
:100A2000311C009F002F0BD00A9F0888BFB247439C
:100A30000098BA1801380A800090120C0231F0E7D1
:100A4000604641007118002A01D00A800231891BDA
:100A5000491061600133C5E7406843425841C0B264
:100A600070470B1C416810B5021C002903D15C685B
:100A7000081C002C11D014781878E407C007E40F84
:100A8000C00FE4B2C0B2001B07D190689A685B68DF
:100A9000FFF77BFE002C00D0404210BD10B5041EB5
:100AA0008C4201D0FFF7C1FE2378012293432370CB
:100AB00010BD10B5041E8C4201D0FFF7B6FE22789F
:100AC0000123D107C90F591A19409A430A432270CA
:100AD00010BD7FB5041E8C4201D0FFF7A6FE6268F0
:100AE000002A0BD1201C0121FFF709FEA268012377
:100AF0001380227863601343237021E021786D46D0
:100B00000E35CB070BD5012399432170A1682B80AB
:100B1000081C00932B1CFFF7B8FD606010E0511C0F
:100B2000201CFFF7ECFDA16801262E802B1C0096EF
:100B3000081C6268FFF77CFD237860601E43267006
:100B40007FBDF0B50D1C496887B0041C171C002937
:100B500001D0002A03D1291CFFF767FE4EE0FFF702
:100B6000CEFDA9686A683B1CA068FFF73EFD606087
:100B70002B782178DB07021CDB0F0120DBB28143DD
:100B800019432170002B39D06E4669683809163632
:100B90000023039033800291029883420CD0039982
:100BA0008B4209D0A9685800415A002902D001237C
:100BB000338001E00133EFE7039B029883420DD2BB
:100BC0000398AB684100C95A0F231F400123181C2A
:100BD000B840071C013F0F4200D033803388002B00
:100BE0000CD0A1680123002A02D10B80636005E0CC
:100BF0000093081C331CFFF71BFD606007B0F0BDBD
:100C000073B5151C061C0C1C8868926849686B68D3
:100C1000FFF7BBFD002802DA231C2C1C1D1C2278C8
:100C20002B78D207DB07D20FDB0FD2B2DBB26168C1
:100C30009A420CD1301C0131FFF761FDAB686D6841
:100C4000A1686268B0680095FFF7F2FC0AE0301C0A
:100C5000FFF755FDAB686D68A1686268B0680095E4
:100C6000FFF713FD317870602278012399431A4011
:100C70000B1C1343337073BDF7B5161C051C0C1CFD
:100C80008868926849687368FFF77FFD002801DB78
:100C9000002703E0231C0127341C1E1C2278337814
:100CA000D207DB07D20FDB0FD2B2DBB261689A4208
:100CB0000CD0281C0131FFF722FDB3687668A168CB
:100CC0006268A8680096FFF7B3FC0AE0281CFFF7EB
:100CD00016FDB3687668A1686268A8680096FFF799
:100CE000D4FC686021782A780123002F03D0C9073B
:100CF000C90F0123591A19409A430A432A70F7BDB4
:100D0000F0B5041C48688BB00E1C151C002802D0DE
:100D10005168002902D10023636075E0A64207D123
:100D2000301CFFF707FD071CB5420AD1051C08E07F
:100D30000027A24206D1101CFFF7FCFC051C071C73
:100D400000E03E1C73686A68201CD118FFF7D7FCCE
:100D50002068002182085200A06803F0F1F8A16821
:100D6000B268059173680792059A0693A8685B00BC
:100D70006968D2185B42944602900491089300225D
:100D800008980499031C6344002929D00698079AFF
:100D9000039000210398002811D018884018029968
:100DA0000190098810880232414301984018188048
:100DB0000990010C0398023301380390EAE7624678
:100DC000002901D011800232059B04980299D21AA1
:100DD0000138023102235210049002919C44CFE763
:100DE000626030782978C007C907C00FC90FC0B248
:100DF000C9B223780122884201D1934300E0134312
:100E00002370381CFFF771FC0BB0F0BD70B5141CDB
:100E10004A68061C002A02D02378DA0702D500238C
:100E2000736034E06368002B03D10121FFF7C9FC34
:100E30002DE0081CFFF77EFC051C201CFFF77AFC48
:100E40000121041C301CFFF7BCFC6368002B11D08F
:100E5000A2681388DA0704D5301C311C2A1CFFF75E
:100E60004FFFA1686268081C0123FFF7BEFB6060AA
:100E7000002806D1281CFFF738FC201CFFF735FCA2
:100E800005E0281C291C2A1CFFF73AFFDDE770BD8E
:100E900010B58168031C406842008A1800208A420D
:100EA00004D9023A148800042043F8E71B78DA07D3
:100EB00000D5404210BDF0B59C4685B01D1C0029F0
:100EC00000D09D188368476801930024012302978E
:100ED0000393261C029F002F29D0019F24043B88E6
:100EE00010361C43072E1BDD0778A3B2FF0706D57B
:100EF000FF279F43039BFF18BBB21F0A03970029DC
:100F000004D06F1E3B70674506D110E02B706F1C3C
:100F10006546AB189F420AD0083E240A3D1CE1E713
:100F2000019F029B0237013B01970293D2E705B074
:100F3000F0BD4268F8B586685500041C751900209C
:100F4000B5420DD98F21C905F4F762FD023D071C9A
:100F50002888F5F71DF8011C381CF4F709FAEFE7AB
:100F60002378DA0702D580231B06C018F8BDF0B538
:100F70008BB0099310AB1B78119F061C0491141CB5
:100F80000893002F03D00B1C023B1E2B02D900201C
:100F9000387085E04368002B11D1002A08D03B1C33
:100FA00022781D1C002A04D01A7001340133F7E79F
:100FB0003D1C30232B7000236B7001356FE05B000C
:100FC000181C039300F0CEF8B168039A029002F067
:100FD00095FF059701970299039A891806910D1CB0
:100FE0000021029B023D9D420DD32B880A041A4327
:100FF0000499101C0792F4F741F804992880079887
:10100000F4F780F8EDE73031392902D9099B3A3BF2
:10101000C918019D019A029B0135117006998B42F6
:1010200004D21A88002A03D10233F7E7012300E033
:101030000023089A002A09D005996A1A032A05D1C3
:10104000019D0899019A023551700595002B01D137
:101050000195C0E7029800F0BBF8002C0CD0201CD2
:1010600003F064F82B1C20181D1CA04204D9013881
:1010700002781A700133F7E73378DA0702D52D23A7
:101080002B7001356B1E3A1C9A4206D211781878E3
:10109000013B107059700132F6E700232B70E81BFA
:1010A0000BB0F0BD08B54068F2F718FFFEF75DFA27
:1010B00008BD08B54068F2F783FFFEF756FA08BD91
:1010C000F7B54268041C900000F04CF80025061C9F
:1010D00061688D4210D2AB000193E318D868EBF73A
:1010E00087FA071E04D1301C00F072F8381C08E0A3
:1010F000019A0135B050EBE7A0680022331CEBF7F2
:1011000035F9FEBD10B5081C141C111CEEF792FA3F
:10111000201C10BD0020F8B50D1C161C1C1C8242A2
:1011200017D0EEF763FA002804D10B2301202360C7
:1011300040420EE06C1CAE19EEF764FA631E271CE9
:101140001870B44204D0EEF751FA01340028F3D1FC
:10115000781BF8BD08B50979012349001943EBF75D
:1011600087FA08BD10B50021041CEEF747FD0028E2
:1011700004D1002C02D0201CEBF78EFF10BD08B567
:101180000021EEF73BFD08BD38B5041CFFF7EAFF70
:10119000051E05D1002C03D0201CEBF77DFF05E0D8
:1011A000281C0021221C02F0CBFE281C38BD10B5E3
:1011B00001220C1CEEF722FE002804D1002C02D0E4
:1011C000201CEBF769FF10BD08B5EEF717FE08BD50
:1011D00008B5EEF79BFD08BD08B5E6F7A5FB08BD11
:1011E00008B500210A1C0B1CEBF7C0F808BD07B5B9
:1011F0000022019101AB0121EBF7B8F80EBD38B523
:101200005468131C621E94410D1C1A682118A40016
:101210001B1B0833101C2A1CEBF7A8F838BD07B5B8
:101220006A46EBF74BF901990098002901D0E8F7DD
:101230000BFB0EBDF8B5FEF7E9F900F092FB0024B8
:10124000051C6B689C421AD2A968E6008B59002BDA
:1012500003D01A1F511E8A4100E01A1CD1070CD579
:10126000DF08381C00F0AFFB03785F2B05D0AA68BD
:10127000381C96197168EAF7E5FF0134E1E7F8BD1B
:10128000436870B5C9180368041C0125994218D930
:10129000057BAD07ED0F13D10723403199430E1C99
:1012A00008368068311CFFF782FF0123002803D134
:1012B000227B1343237304E02660A0601D1C00E022
:1012C0000025281C70BD037B70B5041C0E1C151C6A
:1012D000DA0703D5237B9A0706D414E0291CFFF70D
:1012E000CFFF002805D1F5E763682568AB420AD235
:1012F000ED1AA3686268311C98182A1C02F007FED8
:1013000063685D19656070BD10B5041C002900D1CB
:101310000121002363602160081CFFF723FF0122E5
:10132000A060237B002801D1134302E093430222F3
:101330009343237310BD38B50D1C041C0131FFF716
:10134000E3FF656038BD00234360037B82600122B8
:10135000934302221343016003737047037B10B56C
:10136000041C9A0702D48068FFF732FF0023A360B1
:1013700010BD10B51020FFF7F5FE041E02D010219D
:10138000FFF7C2FF201C10BD10B5041E08D0037B60
:101390009A0702D48068FFF71BFF201CFFF718FF95
:1013A00010BD00234360037B012293430373704706
:1013B000007BC007C00FC0B27047037BDA0701D4BF
:1013C000806800E000207047027B0023D10700D432
:1013D0004368181C704738B5037B041C0D1C9A0722
:1013E00011D403688068C918FFF7E1FE002804D112
:1013F000237B01221343237306E02368A060ED18CA
:101400002560C01800E0002038BD38B5037B041CFF
:101410000D1CDA0701D5002008E0FFF731FF002896
:10142000F9D06368A068ED186560C01838BD38B59C
:10143000037B041CDB07DD0F002B01D0002008E03C
:101440000121FFF71DFF0028F8D0A2686368D5547A
:10145000A06838BD10B50C1C0121FFF7D6FF00288D
:1014600000D0047010BD38B5051C081C0C1C02F01F
:101470005DFE211C021C281CFFF725FF38BDF8B5B6
:10148000037B041C161CDA0701D5002018E047680E
:101490000D1EBD4200D93D1C002E0FD0201C311C5A
:1014A000FFF7EEFE0028F0D0A168A81908187A1BF3
:1014B000491902F02CFD63689E196660A068401906
:1014C000F8BD10B5141C0122FFF7D9FF002800D089
:1014D000047010BD10B5141C0122FFF7D0FF0028C6
:1014E00000D0047010BD027BD207D20FD2B2002A06
:1014F00006D14368994201D9426001E0591A41601E
:10150000704770B5151C027B041C0B1CD10711D44D
:10151000426893420ED25E19964201D3436009E0BD
:101520008168D21AC818521B891902F0F0FC63684E
:101530005D1B656070BD10B503787F22191C914357
:1015400012D013404022134202D093435208FAE7CC
:10155000013002783F21141C8C43802C04D19B0164
:101560000A4001301343F4E7181C10BD0130037822
:101570003F229343802BF9D0704710B5002381425E
:1015800008D901390A783F24A243803A541EA24167
:101590009B18F4E7181C10BD10B5031C411800205F
:1015A0008B4208D21A783F24A243803A541EA241AB
:1015B00080180133F4E710BD10B5041CEBF72AFEC8
:1015C000031C201C002B00D0203010BD10B5041CC3
:1015D000EBF72CFE031C201C002B00D0203810BD84
:1015E0003038092802D9202398430738704710B5AE
:1015F00044680C6081681160C068186010BD08B54F
:101600001020FFF7C1FD0378072293430122134303
:10161000037008BD037810B55B07041C5B0F052B36
:1016200006D0081CA368111C6268E6F793FA05E06F
:1016300002686168D002400DE6F7BCFA23889A067A
:1016400001D5E9F7E9FA10BD38B5141C8022520023
:101650000A400D1C111E01D021686268FFF7DAFFF5
:101660000223EA091A409A40E9B2A218EDF7E6F817
:1016700038BD1FB5041C0122081C01A9EDF71AFF93
:10168000029A201C0199ECF749F804B010BD13B57B
:10169000041C4068EAF7ACFF00280BD0A368019057
:1016A0005A1CA2605B00012213430220694600938A
:1016B000ECF7ACFF16BDF8B5071C0C201D1C0E1C6A
:1016C000FFF750FD0760041C2868EAF743FF6060DD
:1016D000012E03D96868EDF727FD00E00020A06027
:1016E000201CF8BD10B518C96210E10701D581585A
:1016F000CB588018984710BDF0B585B00290081CF3
:101700000391FEF7E1FB05220192042800DC019021
:101710000398FEF7E0FB0525042800DC051C0027E4
:10172000029E0097009A019B9A421DDA0024AC4267
:101730000BDA221C03980099FEF71AFB3319187173
:10174000012383401F430134F1E7EB43DB172B40B8
:10175000052B04D0F218002111710133F8E7009B2A
:10176000053601330093DDE7019A0523D143C917FC
:1017700011404B43029AD3180433052908D00022A4
:101780001A705A709A70DA701A7101310533F4E7E1
:10179000029B1F8505B0F0BD37B5051C081C111C48
:1017A00000221C1C131CE8F743FB0023011C0093C0
:1017B000281C7822231CECF705F937BD70B5051CF1
:1017C000081C161CEDF7B0FC041C301CEDF7ACFC3B
:1017D000211C021C281CECF737FA01234000184397
:1017E00070BD0B68F0B58668DC00B3420DD2C568E9
:1017F0002A191568002D02D0043D6F1EBD41083422
:101800000133EF07F1D50B6000E00022101CF0BDA2
:10181000011C08B540680831FFF7E3FF002800D03D
:10182000006808BD13B5011C041C0C318068FFF76B
:10183000D8FF002810D02379012B0AD0022B0AD020
:10184000036869460093406801900220ECF7DEFED1
:1018500002E0006800E0406816BD10B50C680B1C83
:10186000043449680022032800D19A68201C01230F
:10187000ECF7DAFA10BD10B50C680B1C043449689B
:101880000022032800D19A68201C0223ECF7CCFA2E
:1018900010BD10B50C680B1C0434496800220328E5
:1018A00000D19A68201C0023ECF7BEFA10BD08B5E1
:1018B0000B7A012B07D100231F2805D14968ECF7CB
:1018C000FDFA031C00E00023181C08BD38B5051CF8
:1018D0001020FFF747FC291C041CECF7E5FB201C3B
:1018E00038BD38B5051C8068FFF7F0FF29686B68C4
:1018F00001604168DA080723D2000B4013434360BC
:1019000029790279012319409A430A4302218A4323
:1019100002712A79041CCA4013409A0003790421F9
:101920008B4313430371AB68E968DA00C06802F0C7
:10193000E5FA201C38BD4068C008704738B5151C52
:10194000041C01220430E4F747FA4560201C38BD2E
:1019500010B50022041C02230430ECF765FA201CA9
:1019600010BD0430704738B5051C03300C1CFFF760
:10197000F9FB206045702068023038BDF8B5467824
:10198000871C041C311C381CECF7F0FC051E0BD125
:10199000311C381CECF7CEFCA6192070B570201C49
:1019A000ECF7A2FC051C02E0201CFFF711FC281C30
:1019B000F8BD08B5ECF786FC007808BD08B5ECF773
:1019C00081FC407808BD08B5ECF77CFC023008BD0E
:1019D00010B50C1CECF776FC43780230236010BD88
:1019E0004268836851688B4206D2991C89008A58E4
:1019F00001338360101C00E00020704708B50B1C09
:101A00000968021C081C08304968E5F713FC08BD8A
:101A100008B5031C0A1C08305968FDF796FB08BD81
:101A2000436808300B601060704708B5FFF7D0FBC3
:101A300008BDF0B585688BB0161C02934A19730077
:101A4000041CD0185B180F1C01920393052814D8AE
:101A5000AD00211C2A1C0C3105A802F04FFA05AB81
:101A60005819039B02999A0002F048FA606801999C
:101A7000321C05ABEAF77AFC1DE08000FFF772FB31
:101A8000A368211C9A000C31051C02F037FAA268E9
:101A9000039B900002999A00281802F02FFAA1687F
:101AA00060687918321C2B1CEAF760FC041C281CA7
:101AB000FFF78EFB201C0BB0F0BD036910B5041CB2
:101AC0005A1C2ED00A2B05D1C3690133C3610123EF
:101AD000036207E0026A092B02D10732D208D20062
:101AE000013222626369A269236162616068A3684E
:101AF00098472269A0610D2A09D10A2323616369ED
:101B00000A2B04D16061A26860689047A061A36954
:101B1000013306D163695A1C03D00A2B01D00A2372
:101B2000A36110BD10B5041E0ED0C368002B01D0F8
:101B300040689847201C4430FFF710FC606BFFF7AB
:101B400047FB201CFFF744FB10BDF7B5071C5420D2
:101B50000E1C01921D1CFFF712FB041E04D1002D68
:101B600051D0301CA8471DE0019901230022C56017
:101B70000A25C36103620363076081604262826277
:101B80004660C5621420FFF7FAFA271C44376063E9
:101B90002021381CFFF7B8FB636B002B04D1201CFD
:101BA000FFF7C0FF00202FE0381CFFF701FC0028E2
:101BB000F5D1616B019B0880301C98470199206129
:101BC000301C8847019B6061301C98472269A061E6
:101BD000511C04D06369591C06D10D2A01D125611D
:101BE0000BE00A2A04D108E0013006D10D2B01D107
:101BF000656102E00A2B00D0A561201C0121ECF7F1
:101C000035FE201C00E0281CFEBD08B50021ECF7C5
:101C10002DFE08BD704708B5EDF79CF94068FFF749
:101C2000D2FE08BD08B5830702D0FDF79EFC07E091
:101C3000002803DB40000123184301E0FDF7B0FC5E
:101C400008BD70B5041C0E1C151CEDF783F9C36AA2
:101C5000002B07D0201C311C2A1C984743425841B6
:101C6000C0B200E0181C70BD022803D14900012059
:101C7000084300E0002070477FB56846EDF76CFF31
:101C8000029801234000184307B000BD7FB56846A5
:101C9000EDF762FF019801234000184307B000BD33
:101CA00010B5041C02F042FA011C201CEDF7C2FC26
:101CB00010BD08B5EAF74EFC08BD08B5031C0A1CA8
:101CC0000C20191CEAF7D4FC08BD38B50124A04249
:101CD00000D04C680868EAF73DFC051C281CEAF7B0
:101CE00087FC021E05D0211C0520EAF7C1FC041C5C
:101CF000F4E7201C38BD08B5011C0220EAF7D6FA2B
:101D000008BD08B51A23EEF717FB08BD08B519235F
:101D1000EEF712FB08BD10B50C1C626809680228BA
:101D200001D10B2005E00B20EAF7A2FCA268011C00
:101D30000A20EAF79DFC10BD73B51D1C061C00238C
:101D4000081C111C02220093131CE5F7D5FA0C2085
:101D5000FFF708FA06602B68041C43606868EAF71E
:101D6000F9FBA060201C76BDC26810B5031C002AD8
:101D700005DD40689968884208DB00200CE00020FF
:101D8000824209D05C6899688C4205DD59688A18DE
:101D900048005A600123184310BD08B582684368A3
:101DA000C168D01A4018002901DD013800E0013077
:101DB000F3F7B2F9C343DB17184008BDF0B50027AD
:101DC00085B003901D1C081C03230E1C0097111CDA
:101DD0000122E5F791FA1020FFF7C4F9039B041CD8
:101DE000036001234760C36028689E4203D1EDF77A
:101DF0009BF9A0600CE0EDF797F960606868EDF77B
:101E000093F9A060032E03D1A868EDF78DF9E06087
:101E1000201C05B0F0BD136810B5141C002B0DD1AB
:101E2000CD2901D1406806E09D2901D1806802E0FA
:101E30009C2903D1C068FDF798FB206010BD08B550
:101E4000081C111CEDF704FC08BD70B5061C081C2D
:101E50000D1C02F06BF9041E03D009CE291C221CB4
:101E60009847201C70BDF0B58BB0029312AB1B7865
:101E70006E4603936B46071C0C1C17332736002A4B
:101E800001D100220EE0002903DA2D221A704C4203
:101E900018E0119A920701D52B2203E0119A5207FC
:101EA000EFD520221A70002C0CD130236D463370F0
:101EB000273519E0337006AB351E9D4214D9013E1B
:101EC000002C11D0201C0299F3F71CF9201C0D1CCA
:101ED0000299F3F7D3F82B1C041C3033092DE9DDEC
:101EE000109B0A3BEB18E5E7119B6946402417312C
:101EF0001C400B78002C0FD00024A34213D0039A6F
:101F0000119B009201220192381CEEF713FE139BE5
:101F1000041C013B139306E0002B04D006AA954253
:101F200001D9013D2B700AAB5A1B039B381C00934F
:101F3000139B291C0193119BEEF7FCFD20180BB09D
:101F4000F0BDF0B58DB01E1C12AB1B78071C0393BF
:101F5000141C2B23B20702D47307DB0F5B01149A06
:101F600004AD00920193081C231C291C2022E4F7D5
:101F700043FDC343041CDB171C40F30507D5631C5A
:101F80001F2B04D825222A550022EA541C1C40226B
:101F9000002332409A4211D02A782F2A11D80122E8
:101FA000291C01920093381CEEF7C4FD139A694670
:101FB000013A051C1392013C113104E0291C151C47
:101FC00001E0291C1D1C039B139A00930192381CED
:101FD000221C331CEEF7AEFD28180DB0F0BD0EB478
:101FE00003B503AA08CA191C0192EEF717FF02B045
:101FF00008BC03B0184738B500220D1C041C017939
:102000004020E3F783F9E3682B60A3685843237902
:102010006860AB60002038BD416838B5C268031CF9
:102020008868824208D29C68551C0879A218C96841
:10203000DD60E3F78DF900E0002038BD7FB50025B5
:10204000081C1C1C0E1C0223111C00950122E5F724
:1020500053F9206803A9E0F707FA0078012E03D1AD
:10206000291CEFF70DF902E06168EFF791F904B070
:1020700070BD73B501AD0E1C2B1C1C1C7F231340BF
:102080002370D209631E002AF7D169460531091B66
:10209000B047231C021C9D4207D01E788021494274
:1020A0003143117001330132F5E72B782C1B0355B6
:1020B00073BD0378012B09D04368C9188368416058
:1020C0005A8C914200DD5984002343707047027896
:1020D000C369032A03D85B18C361343003E0C26AC2
:1020E000C918C161D018704710B50C1C0121FFF749
:1020F000EEFF047010BD10B50278436A032A03D8BE
:102100005B184362343005E0046A1A19C46ACB18BC
:102110004362A01810BD10B50C1C0121FFF7EBFFA6
:10212000047010BD38B50121151C041CFFF7C1FF58
:102130002A1C201C1B21EFF705FA38BD38B50D1CF1
:10214000041C0121FFF7B5FF2A1C201C1C21EFF7FE
:10215000F9F938BD38B50D1C041C0121FFF7A9FFA2
:102160002A1C201C1D21EFF7EDF938BD38B50121DF
:10217000151C041C4942FFF79CFF2A1C201C23212C
:10218000EFF7E0F938BD38B50D1C0121041C4942B8
:10219000FFF78FFF2A1C201C2421EFF7D3F938BD4D
:1021A00038B50D1C0121041C4942FFF782FF2A1C8F
:1021B000201C2521EFF7C6F938BD08B52821EFF717
:1021C000C1F908BD08B52921EFF7BCF908BD38B53C
:1021D0000D1C041C0021FFF76CFF2A1C201C2A2167
:1021E000EFF7B0F938BD38B50D1C041C0021FFF71E
:1021F00060FF2A1C201C2B21EFF7A4F938BD38B54D
:102200000121141C051CFFF754FF0F2C05D8503C6E
:10221000E1B2281CFFF77FFF04E0281C1A21221CD2
:10222000EFF790F938BD012138B54942141C051C5F
:10223000FFF73FFF0F2C05D8403CE1B2281CFFF709
:102240006AFF04E0281C2221221CEFF77BF938BD2D
:1022500038B5041C151CFFF75EFF636A03220333C5
:1022600093436362201C0421FFF745FF056038BDDE
:1022700038B503780D1C0024032B07D9416A0324C9
:102280006442641A816992005358E4180321FFF7ED
:1022900032FF4470240A0570847038BDF8B5069E7C
:1022A000171C079AC91A1D1C7300041C3602C91A90
:1022B000002A04D00239FFF7FCFE013701E0FFF7E6
:1022C000F8FE2A1CF9B23243201CEFF73BF9F8BDA7
:1022D00008B53C20FEF758FF08BD10B5041C41614D
:1022E0008800FEF73FFFA06110BD10B5041C806997
:1022F000FEF76EFF201CFEF76BFF10BD4078431EFB
:102300009841C0B27047436859184160704738B56A
:10231000041C0D1C0021FFF7CCFE2378012B05D0F7
:10232000032B03D8626AA369AD00EA5038BD38B503
:102330000D1C0121041C4942FFF7BBFE2A1C201C76
:102340006821EFF7FFF838BD38B50D1C041C0121DA
:10235000FFF7AFFE2A1C201C6921EFF7F3F838BD08
:1023600010B50121041C4942FFF7A3FE201C6A217D
:10237000FFF7D1FE10BDF7B50D1C0121071CFFF7BB
:1023800098FE2B1C10333F2B05D8803DE9B2381C3A
:10239000FFF7C1FE35E0381C142101AEFFF7BBFE8C
:1023A000331C1C1CEAB27F23ED119C46691C1340B0
:1023B0002370631E0129F4D8211C4020013505D16A
:1023C000024209D11C1C191C634604E0024203D0DE
:1023D0001C1C013900230B7069460531091B381C90
:1023E000FFF789FE231C021C9E4207D01D78802126
:1023F00049422943117001330132F5E73378341B28
:102400000355F7BD38B50D1C041C0121FFF751FE23
:102410002A1C201C1621EFF795F838BD38B50D1C85
:10242000041C0121FFF745FE2A1C201C1721FFF781
:102430000FFF38BD10B50121041CFFF73AFE201C28
:102440001821FFF768FE10BD38B50D1C041C0021D3
:10245000FFF72FFE2A1C201C1E21EFF773F838BD52
:1024600038B50D1C041C0121FFF723FE2A1C201C7B
:102470001F21EFF767F838BD10B50121041CFFF7E5
:1024800018FE201C2021FFF746FE10BD10B50121CB
:10249000041C4942FFF70DFE201C2121FFF73BFEE3
:1024A00010BD38B50D1C0221041C4942FFF701FE86
:1024B0002A1C201C2621EFF745F838BD10B5032152
:1024C000041C4942FFF7F5FD201C2721FFF723FEDE
:1024D00010BD10B50121041CFFF7EBFD201C3021BD
:1024E000FFF719FE10BD10B50221041CFFF7E1FD36
:1024F000201C3121FFF70FFE10BD10B50121041C77
:102500004942FFF7D6FD201C3221FFF704FE10BD23
:1025100010B50021041CFFF7CCFD201C3321FFF770
:10252000FAFD10BD38B5041C0D1CFFF783FF201CFD
:10253000FFF7EEFF291C201CFFF7B3FF38BD10B5D5
:102540000021041CFFF7B5FD201C3421FFF7E3FD3B
:1025500010BD10B5041CFFF76DFF201CFFF7EFFF47
:10256000201CFFF7ABFF10BD38B50D1C041C00216B
:10257000FFF79FFD2A1C201C3521EEF7F1FF38BD27
:1025800070B50E1C0121041C4942151CFFF791FD7A
:10259000201C3621002E00D137212A1CEEF7E0FF47
:1025A00070BD70B50E1C0121041C4942151CFFF7BB
:1025B00080FD201C3821002E00D139212A1CEEF785
:1025C000CFFF70BD38B50D1C041C0421FFF771FD51
:1025D0002A1C201C3D21FFF74BFE38BD10B50421FD
:1025E000041C4942FFF765FD201C3E21FFF793FDC7
:1025F00010BD38B50D1C041C0021FFF75AFD2A1C24
:10260000201C3F21FFF734FE38BD38B50D1C041CDB
:102610000021FFF74EFD2A1C201C4021FFF728FE59
:1026200038BD10B50121041C4942FFF742FD201CB2
:102630004121FFF770FD10BD10B50021041CFFF70C
:1026400038FD201C4221FFF766FD10BD38B50D1C7A
:10265000041C0121FFF72DFD2A1C201C4321FFF73C
:1026600007FE38BD08B501214942FFF722FD08BD2C
:1026700010B50021041CFFF71CFD201C4421FFF7AE
:102680004AFD10BD10B50021041CFFF712FD201CEF
:102690004521FFF740FD10BD38B50D1C041C00217D
:1026A000062D0CD1FFF705FD201CD021FFF733FDCF
:1026B000201C0021FFF7FDFC201C472104E0303DD9
:1026C000FFF7F7FCE9B2201CFFF725FD38BD70B518
:1026D000051C0C1E222C03D0232904D0002604E064
:1026E00001261F2401E0012620240121281C494243
:1026F0002A3CFFF7DEFCE1B2281CFFF70CFD002EA0
:1027000007D0281C0021FFF7D4FC281C4721FFF725
:1027100002FD70BD38B50C1C0121051C091BFFF71B
:10272000C8FC281C5021221CEEF70CFF38BD38B520
:102730000C1C0121051C091BFFF7BBFC281C5121A7
:10274000221CEEF7FFFE38BD38B50D1C0121041C1C
:102750004942FFF7AEFC2A1C201C5221EEF7F2FE84
:1027600038BD38B50D1C041C0121FFF7A2FC2A1C42
:10277000201C5321EEF7E6FE38BD10B50221041CE3
:102780004942FFF796FC201C5421FFF7C4FC10BD02
:1027900038B50D1C0221041C4942FFF78AFC2A1C93
:1027A000201C5521EEF7CEFE38BD38B50C1C01219A
:1027B000051C091BFFF77DFC281C5821221CEEF785
:1027C000C1FE38BD38B5051C0C1C0139FFF771FC82
:1027D000281C5921221CEEF7B5FE38BD70B50D1C22
:1027E000161C8918041CFFF764FC32022A43201CC3
:1027F0005A21EEF7A7FE70BD38B51A430D1C041C14
:102800000121002A05D1FFF754FC6A69201C6021D0
:1028100005E04942FFF74DFC6A69201C6121FFF782
:1028200017FD38BD70B50E1C0499041C0B43D5B2BE
:10283000002B07D10121891AFFF73BFC7269201C8C
:10284000622105E0D143FFF734FC7269201C63214B
:10285000FFF7FEFC291C201CFFF75DFC70BD13B5C3
:102860000C1C0092019300216422231CFFF716FD2B
:1028700013BD13B50C1C012100920193494266223D
:10288000231CFFF70BFD13BD10B501214942041CA9
:10289000FFF70FFC01236370201C5B21FFF73BFC5B
:1028A00010BD38B5051C0C1C4942FFF702FC281C62
:1028B0000221FFF720FC5C230370447038BD10B583
:1028C0000021041CFFF7F5FBA36804211A7E201CDD
:1028D0000A431A765D21FFF71EFC10BD012110B5D9
:1028E0004942041CFFF7E5FBA36804211A7E201C63
:1028F0000A431A765E21FFF70EFC10BD43680633CB
:10290000436070474368053B436070470020704751
:10291000F8B5061C0D1C8F180C1CBC4208D00134E5
:102920003368621E11785B6A301C98470130F4D11D
:10293000601BF8BDF8B5061C0D1C0C1C8F18BC42A2
:1029400005D03368301C9B6A9847431C01D1601B3B
:10295000F8BD20700134F2E7002070470020704776
:10296000002070470020704710B5041CEEF7A2FF4E
:10297000201C01F0B9F9201C10BD38B50D1C041C39
:102980004069F8F773FD281C6169F8F7DBFE38BD74
:1029900010B5041C4069F8F769FD606900F082F821
:1029A00010BD4368426910B5D118041C00F000FA4C
:1029B000E36A002B04D1A369002B07D0984705E0F8
:1029C000A069002802D0211C1C31984710BD10B509
:1029D000041C00F0F5F90023A361E36210BD10B5FB
:1029E000041CEEF7ABFF201C01F07EF9201C10BD8B
:1029F00038B50D1C041C00F0E3F96561206900F096
:102A00009BF94119201C00F0D3F938BD036870B55B
:102A10001B6900210122041C9847051C431C0ED091
:102A2000236800211B690222201C98472368061C8A
:102A30001B69201C291C00229847301CFFE770BD31
:102A400010B5041CEEF788FF201C01F04DF9201C86
:102A500010BD08B5022804D880239B014B600020DC
:102A600005E0F8F759FC092303600120404208BD46
:102A700008B50120F8F756FC7047704708B5FFF716
:102A8000FCFFFFF7F9FFEFF7EDFC08BD08B50028E4
:102A900000D1FEE700F0A8F8FBE708B5002101F03F
:102AA0001EFB08BD08B5F8F723FD08BD10B50023CF
:102AB000036043600A78041C2F2A15D14A789A4291
:102AC00012D0481C2060191C23681A782F2A02D1C2
:102AD0000133236005E0002A03D001330131236074
:102AE000F2E7EFF7D1FA6060201C10BD0068704774
:102AF000406808B5002805D000F053F9013843427A
:102B00005841C0B208BD10B5041CFFF7F1FF002802
:102B100000D0606810BD406808B5002804D000F0FF
:102B200040F943425841C0B208BD10B5041CFFF73C
:102B3000F2FF002803D06068002800D0043810BDE0
:102B40004068431E9841C0B2704708B518235943E6
:102B500008314018011D4B69002B04D14368002B3C
:102B600006D0984704E04068002801D00431984717
:102B700008BD38B50D1C041C0430EFF723F9E563DC
:102B800038BD08B5043000F0FCF808BD10B50B1CCA
:102B9000041C111C0430002B08D018224A430832B0
:102BA000A41863600023A361012200E01A1CEFF760
:102BB000C7F910BD08B5043000F0D6F808BD10B54F
:102BC00004300C1CEFF702FA201C10BD10B5041CD9
:102BD000EFF720F8201C01F087F8201C10BD0FB47F
:102BE000012008B5F8F79EFB00B599B068460321AF
:102BF00000F028F906A8022100F024F90CA8012110
:102C000000F020F912A8102100F01CF9039B019A92
:102C100096201A60079A0A9B1A600D9A109B1A60F8
:102C2000139A159B1A6000F01BF8049B019A9620DA
:102C30001A60079A099B1A600D9A0F9B1A60139AE3
:102C4000169B1A6000F00CF8E0E738B5041CDDF7BD
:102C5000F7FC051CDDF7F4FC401BA042FAD338BD9D
:102C600008B5FA239B005843FFF7EFFF08BD38B5BE
:102C70000368041C1B680D1C984763681D6038BD01
:102C800038B50368041CDB68984763685A68236892
:102C9000002A02D19B68984714E05B681568984742
:102CA00063682D1A002D08DC5A68916859601B680A
:102CB000002BEAD050689847E7E75B6822681868FD
:102CC0001369984738BDF8B50D1C72B64B600A60A1
:102CD000416800234C68002C05D02768D61B02D41D
:102CE000231CA468F7E7002B05D103684D601B691E
:102CF000101C984700E09D60AC6062B6F8BD08B556
:102D000072B6426853688B420FD19B685360026869
:102D1000002B02D1936898470CE018681369984714
:102D200008E09A688A4203D0131C002BF9D101E015
:102D30008968996062B608BD08B503685B68984702
:102D400008BD2F23C046C046C046C046C046C04648
:102D5000C046C046C046C046C046C046C046C04643
:102D6000013B002BEED1704703681A1CFC32D1687E
:102D70000129FAD10021D160A322D2009858C0B213
:102D800070470368FC33D8680138434258417047A4
:102D900010B5041CEFF74CF9201C00F0A5FF201C17
:102DA00010BD007B704708B503689B68984708BD55
:102DB00008B50A1C031C011D0069FFF784FF08BD4C
:102DC00008B5011C04310069FFF799FF08BD10B573
:102DD000041CEFF78BF9201C00F086FF201C10BDAF
:102DE00070B50D1C041C161CEFF798F9013507D0BF
:102DF000201C002100F031F8201C311C00F027F8C5
:102E000070BD08B50322FFF7EBFF08BD08B5FFF75B
:102E1000E7FF08BD70B50D1C041C161CEFF77EF90A
:102E200001350ED06368002E01D0E26800E022690F
:102E3000201C0121136000F010F8201C002100F07C
:102E400006F870BD08B50022FFF7E4FF08BD08B51D
:102E5000007840B200F00EF808BD002901D0012929
:102E600007D100228256A023C132FF329200DB0537
:102E7000D1507047A023DB058000C018E023DB00A1
:102E8000C25810B50C24A243C250C2588900114345
:102E9000C15010BD704770470020704710B5041C2A
:102EA000EFF7DCF9201CF1F721F9201C10BD10B55B
:102EB000041CEFF755FA201CF1F718F9201C10BD7F
:102EC0000523C046C046C046C046C046C046C046B0
:102ED000C046C046C046C046C046C046C046013B8C
:102EE000002BEED1704710B5041CF1F7C1FA002396
:102EF000201C237510BD10B518C96210E10701D55B
:102F00008158CB588018984710BD021C00239800A8
:102F10001018A8300068002801D00133F7E72A33E1
:102F20009B0099507047021C002398001018D03065
:102F30000068002801D00133F7E734339B00995033
:102F400070478079012318407047C068431E98413C
:102F5000704738B58388041C590708D59A0631D4C0
:102F6000DD0604D52169626900F01BFC2AE0042219
:102F70001343A380A388990705D5A06821696269D6
:102F800000F03DFC09E020696169DA0703D5E268D9
:102F9000A368984701E0A568A847A388D9060ED57D
:102FA000A06900280BD0231C021C103322CA22C3A4
:102FB0008268A261F1F79AF8F0F774F9DAE704226F
:102FC0009343A38038BD031C72B6C068002807D0A5
:102FD0008268DA60002A00D11A61DA8A013ADA825C
:102FE00062B670478068002801D0C069FBE770476F
:102FF000F7B50122041C0D1C0769EFF75DFD0028E1
:103000001FD1E38A092B1CD86B4606CD06C30C20C2
:10301000F1F748F80099019A051C00F075F872B6AE
:10302000002F03D1E368AB60E56002E0B968A960F6
:10303000BD60AA68002A00D12561E38A0133E382DA
:1030400062B6F7BD07B5009169460192FFF7D0FF60
:1030500007BD38B5051CFFF7C5FF281CFFF7B3FFF8
:10306000041E0BD0211C0022281CEFF725FD201C7C
:10307000F1F73CF8F0F7F4F80028EED138BDC36B57
:10308000C06A1B681840431E984170472223C05EE7
:1030900070472423C05E70472623C05E704707B583
:1030A0001621425E1021435ED318DA0FD3185B104D
:1030B00083831823C25E1221435ED318DA0FD3181C
:1030C0005B10C3831A23C25E1421435E8188D31828
:1030D000DA0FD3185B108279038402239A43012309
:1030E0001A43827168460322EFF7B6FF07BD807965
:1030F0000123184070478079022318407047837974
:10310000012293438371704737B5041C00910192EB
:103110006D46EFF783FF231C06CD06C30023201C5A
:10312000A3603EBD72B601650B68002B03D14365F9
:103130008365086007E05A6D002A01D0131CFAE786
:1031400058658365426562B67047026D002A12D0E9
:1031500072B6826D436D002A01D0536501E0026DA5
:103160001360436D002B01D0826D9A650023436587
:103170008365036562B6704708B50B1C111C1A1CE9
:103180000123F0F743F808BD38B5041CEFF30885B8
:10319000C26B006C551B626C131AAB420CD220350B
:1031A0001F239D43002801D0F0F7A0FF281CF0F753
:1031B00079FF45192064656438BD10B50C1C804743
:1031C000A047F0F703F910BD08B5F0F7FFF808BD08
:1031D00038B5031C141C101C0D1C9847201CA84754
:1031E000F0F7F4F838BD08B5F0F742F8F0F75AF800
:1031F000FAE710B5041C006800F028FB201C10BD85
:10320000002908DB036802201A5E00208A4203DDE1
:103210005918087900E000207047836A80691B68AC
:10322000184043425841704708B5836A82691B6859
:103230001A4201D1F0F7FEF908BD0E23C05E7047B7
:103240001023C05E70471223C05E704752DF704784
:1032500070B5041C161C1D1C03220723F0F7C6FDC5
:10326000201C311C022207231030F0F7BFFD201C68
:10327000291C012207232030F0F7B8FD201C0499F7
:10328000042203233030F0F7B1FD201C05991122F0
:1032900001234030F0F7AAFD201C069905220323E4
:1032A0005030F0F7A3FD201C07990E220123603057
:1032B000F0F79CFD201C08990D2201237030F0F7D7
:1032C00095FD201C0999122201238030F0F78EFD14
:1032D000201C0A990F2201239030F0F787FD201C53
:1032E0000B9906220323A030F0F780FD201C0C99D7
:1032F0001A220123B030F0F779FD201C0D99142219
:103300000123C030F0F772FD201C0E991722012313
:10331000D030F0F76BFD201C0F9916220123E0300E
:10332000F0F764FD201C109915220123F030F0F70E
:103330005DFD601C119910220123FF30F0F756FD4E
:1033400088235B00E018129900220123F0F74EFD5C
:1033500090235B00E01813991E220123F0F746FD2D
:10336000201C70BD10B5041C006800F06FFA201C12
:1033700010BD08B50A1C002100F0E2FD08BD08B52B
:1033800003685A889988981D5143FFF7F2FF08BDDA
:1033900010B50023041CF0F723FA201C10BDF0B573
:1033A00089B007910EA90978071C00680291059061
:1033B0004188002003918A4276DA059CA1888B42DD
:1033C00072DA079E3668069674881619A4468642F5
:1033D0006ADD069CA5885C19844265DD002A04DA52
:1033E00003980496864207DD05E0039EB61A04960C
:1033F000664501DD60460490002B03DA8C4205DD52
:103400000C1C03E0CC1AAC4200DD2C1C0698D11732
:1034100056420630314000254018AB4202DA614680
:103420004D425D430599D643F617063116404519BE
:103430008E19002B02DD039A534300E00023F61897
:10344000029B002B18D00022101CA2422CDA002371
:1034500004998B4206DAE95C002901D0F15401306D
:103460000133F5E7079B39681B68013201935B88DC
:10347000ED184B88F618E8E7029AA2420FDA291CE9
:10348000301C049A00F03AFD079A386812680299D5
:1034900053880131ED1843880291F618ECE7E043B8
:1034A000C01704400498604309B0F0BD10B518C9B6
:1034B0006210E10701D58158CB588018984710BD9C
:1034C00070B5061C6836041C0121301CF0F7FAF9AF
:1034D000231C56331A780132D2B21A70E1790131C5
:1034E0008A4225D100221A70216D251C54350222F2
:1034F0008A5E2B882021934205DA201C19B25030B5
:10350000FFF77EFE011CE2790023301CF0F78EF9F4
:10351000216D2B8802228A5E934207DD231C4833EB
:1035200000221A70201CF0F787FB01E001332B808A
:1035300070BD70B5816D051C5C3502228A5E2B88DA
:10354000061C041C68362021934204DA19B2583054
:10355000FFF756FE011C0022131C301CF0F766F921
:10356000A16D2B8802228A5E934207DD231C48331B
:1035700000221A70201CF0F75FFB01E001332B8062
:1035800070BD73B5041C061C6836251C301C6435E0
:10359000FFF7F5FE0023EA5E211C00230093603153
:1035A000301CFFF7FCFE231C6733002802D11A7879
:1035B000002A07D1662161562A888A182A800122AA
:1035C0001A7005E0231C48331870201CF0F734FBF8
:1035D00073BDF0B5061C663685B0041C0396002149
:1035E000051C7156266E64350022AB5E7288481D3C
:1035F000271C261C821A67376836934202DC3A7809
:10360000002A18D1002B04DD494209B2301CF0F722
:1036100059F90023EA5E211C00230093301C60311D
:10362000FFF7BDFE0123039E3B700022B2562B889C
:10363000D3182B8009E0231C48330022301C1A7059
:10364000FFF79DFE201CF0F7F7FA05B0F0BD38B586
:10365000051C48352A78041C002A2AD0031C4C3348
:1036600019884A30063189B219800088884220D8EA
:1036700000211980022A02D1201CFFF721FF2B789C
:10368000032B02D1201CFFF754FF2B78042B02D10F
:10369000201CFFF776FF2B78052B02D1201CFFF7AB
:1036A00098FF2B78062B04D100232B70201CF0F7F9
:1036B000C3FA38BD10B5031C403114C914C310BD82
:1036C00008B5FA239B005943F0F7BCFC08BD03681A
:1036D00041688022C91A890812060A431A60704795
:1036E00070B58408820702D1002801D138E0013486
:1036F000621C72B608684968884219D20368002BB8
:1037000013DA5B005B089D0045192E68002E01DA74
:103710008D4202D3934208D30DE0760076088025CF
:103720009B192D061D430560EDE79B00C018E3E7DC
:1037300062B6002014E00234A34203D9A4000419A5
:10374000A14204D8026853005B08036006E08021B0
:103750009B1A0906043C0B432360026062B60430E6
:1037600070BDF7B51D1C08AB1B88041C1030161C5F
:103770000F1C0193EFF752FC019A0023278066800B
:10378000A560201CE360A280E361A361FEBD10B5CB
:103790008388041C9A0702D58068F0F7A7FC201CD8
:1037A00010BD7FB58469051C6B4600910192002C09
:1037B00001D001220DE002AC221C03CB03C20C207D
:1037C000F0F770FC0299061C6268FFF79DFCAE6181
:1037D00014E0A168002902D001320C1CF9E7092A83
:1037E0000CDC02AD2A1C03CB03C20C20F0F75AFC00
:1037F0000299061C6A68FFF787FCA6607FBD37B593
:103800000D1C011C131C04C94469101C2A1CA04770
:1038100037BD10B502680C680023A24207D10430FE
:103820000431102200F05BFB43424341DBB2181C21
:1038300010BD03230380704710B5041CF0F704FD8E
:10384000002802D123880233238010BD10B5041C48
:10385000F0F7FAFC002808D12388023B9BB22380B2
:10386000012B02D1201CF0F741FC10BD0289031C82
:103870008A4202D18079012305E0428900208A42F0
:1038800002D198790223184070470289031C8A42AA
:1038900002D18079042305E0428900208A4202D1C6
:1038A00098790823184070470289031C8A4202D184
:1038B0008079102305E0428900208A4202D198795C
:1038C000202318407047038910B58B4207D18379B4
:1038D0000124002A01D0234300E0A34383714389DC
:1038E0008B4207D183790221002A01D00B4300E0EB
:1038F0008B43837110BD038910B58B4207D1837947
:103900000424002A01D0234300E0A34383714389A8
:103910008B4207D183790821002A01D00B4300E0B4
:103920008B43837110BD038910B58B4207D1837916
:103930001024002A01D0234300E0A343837143896C
:103940008B4207D183792021002A01D00B4300E06C
:103950008B43837110BDF0B587B0009107898DB29C
:10396000041CBD4200D147896B465E88022E25D0DB
:10397000052E11D0012E70D1201C291C321CFFF7FE
:10398000A2FF201C391CFFF771FF002865D0A18819
:1039900004A8321C331C0EE0201C291C0122FFF756
:1039A000AAFF201C391CFFF770FF002855D0A18802
:1039B00004A8321C0123EFF74FFB4EE0201C391CFA
:1039C000FFF754FF002816D0321CA188012302A85B
:1039D000EFF742FB201C291CFFF757FFA6880028A1
:1039E0002FD0201C391CFFF750FF002829D004A835
:1039F000311C042228E0201C291CFFF755FF002859
:103A00000FD1201C291CFFF740FF002803D004A879
:103A1000291C042202E004A8291C03220123EFF739
:103A20001BFB201C291C0022FFF74DFF201C291C1A
:103A30000022FFF760FF201C291C0022FFF773FF04
:103A40000BE004A8311C03220123EFF705FB201C27
:103A5000391C0122FFF767FFE3E707B0F0BD70B53F
:103A6000041C161C1D1CF1F71DFAA670201C291C35
:103A7000F1F7ECF9201C70BD38B50D1C0121041CB8
:103A800041560278281CF0F72FFC657038BD40784D
:103A900040B2704708B5F1F7D9F908BD10B5041C5C
:103AA000F0F7B6FC201C00F01FF9201C10BD08B573
:103AB0000430FFF7CCF908BD08B50A1C031C1C3004
:103AC000002905D000229963DA640221012200E076
:103AD0000221F0F75FFE08BD836980681B6818400B
:103AE000431E9841704708B54369011C002B04D15F
:103AF0000368002B06D0984704E00068002801D036
:103B00000431984708BD08B5012903D0022904D122
:103B1000383000E02030FFF7E6FF08BD08B5C36A83
:103B2000011C002B04D18369002B06D0984704E0C8
:103B30008069002801D01C31984708BDF0B585B0D8
:103B40001C1C0AAB1F78051C0E1C0392F0F7A8FC86
:103B500001235F400097231C281C311C039A00F0AE
:103B600080F8201A441EA04105B0F0BDF0B585B024
:103B70001C1C0AAB1F78051C0E1C0392F0F790FC6E
:103B800001235F400097231C281C311C039A00F07E
:103B900024F8201A441EA04105B0F0BD08B5FFF777
:103BA00009F808BD08B5FFF70AF808BD82B0019012
:103BB000C046C046C046C046C046C046C046C046D5
:103BC000C046C046C046C046C046C046019B013BF9
:103BD0000193002BECD102B07047F7B51F1C019286
:103BE0000368B1224910D200995080210122890036
:103BF0005A50191CFC310026CE60051C1A607C1E30
:103C0000019BA64213DA9919281C0022F0F728FE1E
:103C100000280AD0281CF0F71DFF071C281CF0F70D
:103C2000E7FE341C002F1ADA18E00136E7E719190D
:103C3000281C0122F0F714FE002803D0281CF0F7FE
:103C4000D7FE0CE0089B3C1C002B08D029680B1CFD
:103C5000FC339A68002AFAD000229A603C1C201C8F
:103C6000FEBDF8B5171C1E1CB1220368D200491016
:103C700099508022920000259D500122041C9A60D8
:103C8000B54211DA795D201CF0F7D4FD002809D087
:103C9000201CF0F7ADFE201CF0F7DCFE00280EDA49
:103CA000051C0CE00135EBE7069B351C002B06D00C
:103CB000201CF0F7B5FE002801D001256D42281C1C
:103CC000F8BD0023CB565A1C05D0834201D1486869
:103CD00002E00C31F5E7181C704708B5031C081CFE
:103CE000191CF7F709FB08BD08B5002801D0F7F744
:103CF0004DFE08BD08B5011C0020021C031CF8F78E
:103D0000EFFB08BDF7B58B89051C0C1C19075ED4A9
:103D10006268002A02DC276C002F1ADDE76A002F98
:103D200017D000222E682A60802252011A4001D04A
:103D3000626D15E0281C216A0123B847021C411C52
:103D40000ED12B68002B0BD01D2B01D0162B02D1CE
:103D50002E6000205EE0A38940210B43A38159E03F
:103D6000A3895F0706D56168636B521A002B01D0E7
:103D7000276CD21B281C216A0023E76AB847A28956
:103D8000411C06D12B68002B03D01D2B01D0162B14
:103D900019D10023636023692360D70405D5411C32
:103DA00002D12A68002A00D16065616B2E6000296B
:103DB000CFD0231C4433994202D0281CF7F7F0FDE2
:103DC0000020606326E040231A43A28122E0266996
:103DD000002EBED027680022BF1B019726609907DE
:103DE00000D16269A260019F002FB2DD281C216A08
:103DF000321C019BA76AB847002806DCA389402231
:103E000013430120A381404204E0019F36183F1A6A
:103E10000197E8E7FEBD70B54B1E68255D430E1C9B
:103E2000291C7431F7F704FE041E08D0002101603C
:103E300046602A1C0C30A060683200F081F8201C1B
:103E400070BD7047704708B5F7F788FC08BDF7B537
:103E5000041C019148340026002C12D0A568676824
:103E6000013F0CD4AB89012B07D90E22AB5E013385
:103E700003D0281C019B984706436835F0E7246867
:103E8000EAE7301CFEBDF7B5041C071C019148345D
:103E90000026002C16D06268A5680092009A013AAC
:103EA00000920DD4AB89012B08D90E22AB5E0133F1
:103EB00004D0381C291C019B984706436835EDE760
:103EC0002468E6E7301CFEBDC9B28218904204D0D7
:103ED00003788B4202D00130F8E70020704730B5FC
:103EE0000023934208D0C55C0133CC18013C2478F0
:103EF000A542F6D0281B00E0002030BD10B50023FD
:103F0000934203D0CC5CC4540133F9E710BD70B5C3
:103F1000814201D300230CE08C18A042FAD285180C
:103F2000131C013B0BD351426618F65C6918CE5442
:103F3000F7E7934203D0CC5CC4540133F9E770BD7A
:103F4000031C8218934202D019700133FAE77047BC
:103F5000936810B5013B9360002B05DA9469A34286
:103F600008DBCBB20A2B05D01368581C10601970FF
:103F7000C8B201E0F8F7D6F910BDF8B5061C0F1C61
:103F8000141CD518AC4208D02178301C3A1CFFF71D
:103F9000DFFF0134431CF5D100E00020F8BD70B50F
:103FA000051C0E1C002804D08269002A01D1F7F7F5
:103FB000D5FAAC68A3891A0702D52369002B19D159
:103FC000281C211CF8F71AFA002813D001204042BF
:103FD00045E03178002B1BDAA269934211DA281CE4
:103FE000221CF8F79FF9013043425841C0B2002823
:103FF000ECD10136A3683278013BA360002AE8D1F6
:104000000CE023681970236819780A2903D1E6E7C0
:1040100022681170236801332360EAE7002B17DA66
:10402000A269934208DB22680A2313702368197877
:104030000A2911D1281C01E0281C0A21221CF8F7AA
:1040400071F9013043425841C0B2002806D0BDE7A3
:1040500022680A2313702368013323600A2070BD8D
:1040600008B5828909231A400023092A02D1F7F7EB
:10407000FDF9031C181C08BDF0B50B785E2B02D0AF
:104080004C1C002102E08C1C4B7801210022815441
:10409000802501326D00AA42F9D1002B01D1601EAA
:1040A0001CE001277F1AFEB2C654221C1178541C52
:1040B0002D2905D05D290ED000290ED00B1CF2E76A
:1040C00055785D2DFAD09D42F8DB02320133C6549B
:1040D000AB42FBDBEAE7201C00E0101CF0BD08B59A
:1040E0004A424A4180235200DB00F7F73DFF08BDFA
:1040F0000020704708B50E23C95EF8F7B9FA08BD6D
:10410000C9B20378002B03D08B4204D00130F8E70A
:10411000002900D0181C704702780B78002A03D0C1
:10412000013001319A42F7D0D01A70470023C25CA7
:104130000133002AFBD1581E7047031C002010B524
:1041400082420FD01C780878A04201D1012A03D105
:1041500018780B78C01A05E0013A0028F8D001332E
:104160000131EFE710BD0B7830B5722B09D0772BFA
:104170000BD0612B0ED1822401238420A40098400F
:104180001BE00024231C042017E0C024E4000123CA
:10419000082012E01623036000201AE0622D10D0E0
:1041A000782D11D02B2D07D11C25A843102528438D
:1041B0000325AB4302252B4301314D78002DEDD172
:1041C00005E080256D02F6E780252D01F3E7234306
:1041D000136030BDF8B5061C0C1C151C002904D159
:1041E000111CF7F725FC041C18E0002A03D1F7F78F
:1041F000D7FB2C1C12E000F0E3F8A8420ED2301CD2
:10420000291CF7F715FC071E07D0211C2A1CFFF7F5
:1042100075FE301C211CF7F7C3FB3C1C201CF8BDAD
:1042200038B5141C4B1C02D10120404234E0938964
:1042300020229343A381636BCDB26268002B0FD021
:10424000A36B9A4206DA2368013B23601D70636802
:1042500001331FE0211CF8F727F80028F3D0E3E72B
:1042600021692368002909D08B4207D9591E087893
:10427000A84203D10132216062600DE0E363231C98
:10428000443363630323A363231C463322641D70FA
:10429000236001236360281C38BD10B50C1C496BDA
:1042A00000290ED0231C4433994201D0F7F778FB44
:1042B000236C002060636360834202D0E36B236061
:1042C00009E023692022236000236360A389012081
:1042D0001343A381404210BDF7B5151C01930A6931
:1042E0008B68061C0C1C934200DA131C221C2B60EA
:1042F00043321278002A01D001332B6020688006F7
:1043000002D52B6802332B60216806270F401FD08F
:10431000231C43331B785A1E9341226892061FD5F3
:10432000E11840313020C870211C5A1C45310978F1
:10433000A21840320233D17012E0221C301C0199C5
:1043400019320123089FB847013011D0009F01376F
:104350000097E0682968009F431A9F42EDDBD7E78A
:10436000221C301C01994332089FB847013002D10A
:104370000120404223E0206806212B68E2680140CA
:104380000025042903D1D51AEB43DB171D40A26891
:1043900023699A4201DDD31AED1800270097009F88
:1043A000AF420BDA221C301C01991A320123089FFC
:1043B000B8470130DCD0009F0137EFE70020FEBD99
:1043C00004390B68181F002B02DAC8581B18181F75
:1043D00070470000F8B5C046F8BC08BC9E46704760
:1043E000F8B5C046F8BC08BC9E4670470000000007
:1043F0000000000000000000112902000D29020049
:10440000352902005D2902005929020061290200B4
:1044100065290200B518010069290200712A02000D
:10442000712A0200FCFFFFFF00000000D918010004
:10443000E91801000000000000000000000000007A
:104440003D190100DF290200A3290200000000003D
:104450000000000000000000712A0200712A020022
:10446000712A0200712A0200712A0200712A0200D8
:104470000D2A020059190100412A02000000000023
:104480000000000000000000B91B0100C51B010076
:104490000000000000000000712A0200712A0200E2
:1044A000712A0200712A0200712A0200712A020098
:1044B0000D2A0200151C0100CD2B0200FCFFFFFF9E
:1044C00000000000391C0100491C01000000000030
:1044D000000000000000000031200100912D0200CA
:1044E0000000000000000000ED200100CF2D0200C0
:1044F000712A02000000000000000000000000001F
:10450000952E0200972E0200992E0200FD21010037
:104510002122010000000000000000000000000057
:10452000952E0200972E0200992E020015220100FE
:10453000492201000000000000000000000000000F
:10454000952E0200972E0200992E020009220100EA
:104550003522010000000000000000000000000003
:10456000ED2201002D2301009D3B0200A53B02002E
:10457000C0FFFFFF00000000112902000D2902000A
:10458000352902005D290200592902006129020033
:10459000652902001D23010051230100CD440100C3
:1045A000BD440100BCFFFFFF000000000D2301001F
:1045B0003F23010000000000000000000000000098
:1045C00059290100972E0200992E02003929010075
:1045D000452901000000000000000000000000006C
:1045E000952E0200533002004B2F02007D2A01005D
:1045F000892A010000000000000000000000000007
:10460000952E0200612F01007F300200F92C01007D
:10461000052D010000000000000000000000000067
:10462000952E0200293202001B3202009134010053
:104630009D340100000000000000000000000000A8
:10464000952E02005D3701008D360100A136010074
:10465000AD36010000000000000000000000000076
:10466000593C0100972E0200992E0200612301009F
:10467000AF2E02000000000000000000000000005B
:10468000114401009D3A02000000000000000000FB
:104690005D2201009D2E02001D3B02000000000073
:1046A000000000000000000071220100B92201009A
:1046B0009D3B0200A53B0200C0FFFFFF0000000081
:1046C000112902000D290200352902005D2902008E
:1046D000592902006129020065290200A92201006E
:1046E000DD220100CD440100BD440100BCFFFFFFFD
:1046F0000000000099220100CB2201000000000010
:10470000E2652F227F2B7A3C075C143326A6813C7E
:10471000BDCBF07A8807703C075C143326A6913C29
:104720004FBB610567ACDD3F182D4454FB21E93FC9
:104730009BF681D20B73EF3F182D4454FB21F93FB8
:10474000000000000000304300000000000030C303
:10475000E8580200020001006D160000E85802004F
:1047600002000100F1170000E858020002000100F9
:10477000C1000000E858020004000200A917000070
:10478000E85802000200010009010000E858020098
:10479000020001000D190000E858020004000200A8
:1047A000E1180000E85802000200010079D201007F
:1047B000E858020002000100D517000098800200AE
:1047C000E70000001C0000008C480200E8580200CE
:1047D0000200010029180000E85802000200010050
:1047E00045180000E8580200020001008D16000084
:1047F000E85802000200010069D20100E8580200F6
:1048000002000100AD160000E8580200040002009A
:1048100051170000E8580200020001000D180000C6
:10482000E8580200020001008DD20100E4570200A6
:10483000D6000000BC470200E85802000200020057
:104840007D180000E858020002000100C5180000B1
:10485000E8580200020001004D160000E85802006E
:104860000200010019170000E858020002000100D0
:1048700031160000E8580200040002007D17000015
:10488000E858020004000200E91600006E00000073
:10489000B6060000BE06000056F8ADC0C606000011
:1048A000DA0FC9C0CE0600008C4702003E040000AB
:1048B00098470200D606000044480200DE060000C9
:1048C00038480200E60600006C490200EE060000CF
:1048D000D8470200F6060000CC470200FE060000A2
:1048E00014480200060700005C4702000E070000A3
:1048F000B047020016070000744702001E070000C0
:104900002048020026070000744802002E0700001D
:10491000684802003E070000A44702003607000076
:10492000084802006E0700005C480200760700009D
:104930008048020066070000FC47020046070000AE
:10494000E44702004E0700005047020056070000EF
:10495000504802005E070000F04702008607000092
:10496000804702007E07000068470200E858020006
:104970000200010061180000A84B020000000000C6
:104980000000000000000000E858020004000400DD
:1049900083D3010098800200C700000018000000C7
:1049A000344A0200E85802000400020025D5010044
:1049B000E858020002000200CBD30100E8580200D0
:1049C00002000200BBD30100E8580200040004000A
:1049D000C11F0000E8580200020001005121000040
:1049E000E858020006000400DBD30100E85802008A
:1049F0000400040091D30100E85802000200010005
:104A000019220000E858020004000300151E0000EF
:104A1000E85802000300FFFF6D290000E85802007B
:104A200004000200191D0000E85802000200010005
:104A3000E9210000DE050000004B0200E605000051
:104A4000884902007E050000EC490200EE050000E6
:104A50009C4B02009E0500001C4A0200F605000067
:104A6000784B0200FE050000604B020006060000C5
:104A7000044A02000E060000F44A0200A6050000E7
:104A8000904B0200AE050000BC490200B6050000D4
:104A9000B0490200BE050000104A020016060000E0
:104AA000E04902006E050000C84902001E06000031
:104AB000A449020026060000844B02002E060000D6
:104AC000544B020036060000D44902003E060000A6
:104AD0000C4B020046060000284A02004E06000069
:104AE0006C4B020056060000E44B02005E0600001C
:104AF000F8490200E858020004000300791E000093
:104B0000E85802000400040077D30100E8580200CE
:104B100002000100D9210000C8740200D300000087
:104B20000000000000000000000000000000000085
:104B3000000000000000000000000000151C020042
:104B40007DD5010000000000000000000000000012
:104B500000000000E85802000200010041210000AE
:104B6000E85802000200030071300000E85802001B
:104B700002000100F9210000E858020002000300D1
:104B80002D2F0000E8580200040002002FD501007C
:104B9000E858020002000200ABD30100E85802000E
:104BA000040004009DD30100C874020060000000EE
:104BB000992300009D22000000000000000000007A
:104BC0009D2400000000000029220000AD19000013
:104BD000000000004BD301000000000000000000B6
:104BE00094490200E8580200020001000922000076
:104BF000C874020001000000000000000000000076
:104C000000000000000000000000000000000000A4
:104C10000000000000000000000000000000000094
:104C2000000000000000000000000000E457020047
:104C300064000000384C0200988002001F00000051
:104C400003000000484C02006E0000002603000034
:104C50000604000030950200B60200005C800200ED
:104C600000000000E9D80100E9D8010000000000C0
:104C70000000000000000000000000000000000034
:104C8000FD4B000000000000B5E001000000000046
:104C90000000000000000000000000000000000014
:104CA0000000000000000000000000000000000004
:104CB00000000000000000000000000000000000F4
:104CC00000000000000000000000000000000000E4
:104CD00000000000E9D80100000000009941000038
:104CE00000000000000000000000000000000000C4
:104CF000000000003BDA010000000000000000009E
:104D00008D380000E9D801000000000019480000BB
:104D1000F5470000294A0000D9D80100EDE0010064
:104D20000000000000000000000000007D380000CE
:104D300049E7010000000000000000000000000042
:104D40000000000000000000000000000000000063
:104D50000000000000000000000000000000000053
:104D60000000000089470000E94600000000000044
:104D700013E50100000000000000000007E601004C
:104D8000000000000000000063E501001D3F00007E
:104D9000E3DE010000000000000000000000000051
:104DA0000000000000000000000000000000000003
:104DB0003DDD0100000000000000000000000000D8
:104DC0000000000000000000E9D801000000000021
:104DD000B9E401000000000000000000114F0000D5
:104DE000114F00008DDB010083DB0100000000009B
:104DF00039DB010097DB010000000000000000002B
:104E000000000000000000000D3B00002FDB01004F
:104E100025DB01001BDB0100C5DA010000000000FA
:104E200097DA0100000000005DDA010000000000D8
:104E300000000000CBE00100000000002FE70100AF
:104E4000EBDD01004BDA0100000000000000000073
:104E50001BE001000000000087DF0100DD4A0000C8
:104E60000000000000000000000000000000000042
:104E70000000000000000000D9DD0100C9D80100D9
:104E80009DD701003BDA010000000000EFD90100CE
:104E9000D3D9010000000000000000000000000065
:104EA0000000000000000000000000003BDA0100EC
:104EB00000000000ABD8010000000000000000006E
:104EC00000000000C3DD0100000000000000000041
:104ED00000000000000000000000000000000000D2
:104EE00000000000000000000000000000000000C2
:104EF000000000006D4A00000000000000000000FB
:104F000000000000E858020002000100A152000069
:104F1000E85802000200010087E80100E85802009A
:104F2000020001009DE80100E858020002000100B3
:104F3000CD5200007C4F0200C82A00205E0D000008
:104F4000104F0200660D0000E04F02006E0D0000E1
:104F5000044F0200760D0000EC4F02007E0D0000B1
:104F6000284F02002E0D00001C4F0200360D0000DD
:104F7000B84F02003E0D0000D44F0200C87402007A
:104F8000A901000000000000000000000000000077
:104F90000000000000000000000000000000000011
:104FA0000000000000000000000000000000000001
:104FB00000000000C44F0200E85802000200010097
:104FC000B3E80100988002004700000008000000DC
:104FD0003C4F0200E858020002000100C9E801004D
:104FE000E85802000200010085520000E858020063
:104FF00002000100B1520000E85802000200010066
:1050000091550000E85802000200010079550000A7
:10501000E85802000000000065550000E457020057
:105020001701000028500200988002000F010000C4
:105030002100000044500200E85802000000010076
:10504000BD5500006E000000BE0800000E0A000002
:1050500074650200860C000024000020EE0C0000A5
:1050600004000020F60C000010000020260D0000B7
:10507000AC690200560D0000344F02008E0D000096
:105080005C7C02001E1200001C000020C60800000C
:1050900010500200CE08000004500200D6080000A4
:1050A000F84F0200DE0800004C510200E608000044
:1050B000385002006E090000DC760200760900001C
:1050C000607802007E090000747602008609000004
:1050D000207702008E090000D077020096090000B8
:1050E000587802009E090000B4780200A60900006A
:1050F00018770200AE090000C8770200B609000068
:1051000050780200BE09000030770200C609000096
:10511000E8770200CE09000070780200D60900008E
:105120007C760200DE09000028770200E609000014
:10513000E0770200EE0900002C780200F60900007A
:10514000D8770200FE09000068780200E8580200E3
:1051500000000000A9550000E85802000300FFFF0E
:10516000E5550000E45702001F01000080510200D5
:105170006E000000FE080000460000009051020092
:105180009880020017000000020000007051020029
:10519000E85802000000000019580000E85802001A
:1051A00004000200EDE90100E858020006000300D7
:1051B00003EA0100E8580200040002001BEA0100B3
:1051C000C87402008C0000000000000051EA0100D9
:1051D00000000000000000000000000000000000CF
:1051E00000000000151C020031EA01000000000070
:1051F000000000000000000000000000E85802006D
:1052000004000400CD5A000098800200170000003E
:105210000200000068520200C8740200760000001C
:10522000EBEA01001D5B0000000000008D7400002F
:105230007D7500000000000000000000000000007C
:10524000000000000000000000000000000000005E
:1052500008520200E858020004000300A3EA01001B
:10526000C8750200545202006E0300006052020032
:10527000A6040000FC51020000000000070000002E
:10528000130000002B00000059000000B3000000D4
:105290005B01000087020000CD040000F908000057
:1052A00093100000951E00000B380000A16500005F
:1052B0002DB80000D34B01007B530200652B040086
:1052C000CF73070027460D00A59B170021E3290097
:1052D000A72E4A00B8A302005EA10200E0A00200CF
:1052E000C6A3020086A0020046A2020050A202004D
:1052F000A6A2020066A0020020A00200E0A2020016
:1053000030A20200FAA202004EA3020078A102001D
:1053100094A302000CA002006CA40200E2A102000F
:1053200018A302001AA00200F2A2020032A3020097
:10533000C4A002004AA2020006A402007AA302004E
:105340006CA00200E4A0020048A402001CA4020019
:1053500060A00200B4A10200B4A4020090A3020065
:1053600062A10200D8A30200A6A102003EA302008F
:10537000AAA2020044A10200A2A20200EAA0020026
:1053800048A0020044A30200DAA002001AA2020010
:1053900092A2020000A4020026A1020014A00200B2
:1053A0006EA3020068A102005AA2020006A3020036
:1053B0004AA102001EA1020010A20200A0A3020046
:1053C000D4A2020066A4020060A40200B0A0020001
:1053D000AAA00200F6A002009EA002004CA00200BB
:1053E00080A10200E4A3020048A30200A6A30200D9
:1053F00036A0020042A20200CAA00200A0A402003D
:105400008EA1020002A1020072A1020014A40200F7
:1054100066A2020052A10200F4A10200ACA40200A4
:105420007EA40200C4A2020078A00200D2A302005F
:1054300072A00200CCA3020000A20200FCA30200A2
:105440002CA302004EA4020070A202008CA2020053
:10545000ECA302000CA102009AA302002CA10200FE
:105460001EA30200DEA3020086A202008CA402009A
:1054700012A302003CA2020098A202009CA2020019
:105480008AA302005CA30200C0A1020038A30200AC
:1054900056A302007AA2020074A30200D4A1020063
:1054A0002CA00200DAA20200E8A1020016A102006C
:1054B00024A3020044A00200C0A302002EA4020004
:1054C0000CA302007EA0020032A10200C6A10200CD
:1054D00052A00200A4A002000AA20200CEA1020073
:1054E00054A402005AA4020086A10200ACA102004A
:1054F000F8A10200D4A0020026A002001EA2020011
:1055000062A3020068A302008CA0020092A0020025
:1055100098A0020080A20200CEA2020014A2020003
:1055200000A30200EEA10200DAA10200BAA102006B
:105530005AA002007EA3020024A202000CA40200D2
:1055400086A402009EA1020058A10200FCA0020055
:1055500036A2020072A4020078A4020060A2020037
:1055600038A10200B6A00200BEA00200F6A302000D
:1055700084A30200E85802000200030033EF010098
:10558000E8580200020003003DEF0100C874020069
:10559000D300000000000000000000000000000038
:1055A00000000000000000000000000000000000FB
:1055B000151C020047EF0100000000000000000081
:1055C0000000000000000000C8740200920000000B
:1055D0006D6700009D1B00000000000031670000A7
:1055E0009D240000000000002969000015670000EC
:1055F000000000004BD3010000000000000000008C
:10560000C4560200DE050000004B0200E605000063
:10561000884902007E050000EC490200EE0500000A
:105620009C4B02009E0500001C4A0200F60500008B
:10563000784B0200FE050000604B020006060000E9
:10564000044A02000E060000F44A0200A60500000B
:10565000904B0200AE050000BC490200B6050000F8
:10566000B0490200BE050000104A02001606000004
:10567000E04902006E050000C84902001E06000055
:10568000A449020026060000844B02002E060000FA
:10569000544B020036060000D44902003E060000CA
:1056A0000C4B020046060000284A02004E0600008D
:1056B0006C4B020056060000E44B02005E06000040
:1056C000F849020098800200C7000000180000009E
:1056D00004560200E45702005B000000E05602009E
:1056E000988002001700000002000000F05602003F
:1056F0006E000000DE020000DE0200005C96020088
:10570000AEC59D74CA1B0E5A20BCBE4C00401C4640
:105710000000C842000020411FB14F0A9595E624C1
:1057200077CC2B3217B7D1380AD7233CCDCCCC3D20
:10573000C87402006C000000AD6E00000D6F000028
:1057400000000000596E00005DF001000000000044
:105750000000000000000000000000000000000049
:10576000000000000000000000000000C8740200FB
:10577000540000000000000077F10100000000006C
:105780000000000000000000000000000000000019
:105790000000000000000000000000000000000009
:1057A0000000000000000000C87402009900000022
:1057B00000000000AD7200000000000000000000CA
:1057C000000000000000000000000000151C0200A6
:1057D00093F1010000000000000000000000000044
:1057E00000000000C8740200D400000059780000D6
:1057F00000000000000000000000000000000000A9
:1058000069780000000000000000000000000000B7
:105810000000000000000000000000000000000088
:1058200087000000100000002C5802005E000000FD
:105830002C7D020086010000EC9002004E01000069
:10584000CC690200DE020000D456020026030000EC
:105850002C4C02004E080000C4600200B606000096
:105860002C4802009E040000607E02006E080000CA
:10587000C48D0200BE0800001C500200B60D0000DE
:1058800084620200EE08000024630200FE080000AB
:105890006451020006090000DC6A0200AE08000044
:1058A0002C4C0200B6080000C4600200C87402005C
:1058B000D100000000000000000000008BF6010095
:1058C000691C020000000000000000000000000051
:1058D00000000000000000000000000000000000C8
:1058E0000000000000000000C8740200D1000000A9
:1058F000000000000000000011F60100691C020019
:105900000000000000000000000000000000000097
:105910000000000000000000000000000000000087
:1059200000000000C8740200D10000000000000068
:1059300000000000AD790000691C020000000000BA
:105940000000000000000000000000000000000057
:105950000000000000000000000000000000000047
:10596000C874020041000000317C0000D17B0000BF
:10597000000000000000000000000000BD7C0000EE
:105980000000000000000000000000000000000017
:10599000000000004C5B020000000000D08B020001
:1059A00001000000E4590200C87402004E0000002B
:1059B000317C0000D17B00000000000000000000EE
:1059C00000000000BD7C000000000000000000009E
:1059D000000000000000000000000000BC5A0200AF
:1059E00000000000C874020049000000317C000083
:1059F000D17B00000000000000000000000000005B
:105A0000BD7C00000000000000000000000000005D
:105A10000000000000000000BC5A0200000000006E
:105A2000460000000C5C0200C87402004400000044
:105A3000317C0000D17B000000000000000000006D
:105A400000000000BD7C000000000000000000001D
:105A5000000000000000000000000000BC5A02002E
:105A6000000000004C5F0200000000000000000089
:105A7000588C0200D08B020001000000185C02006C
:105A8000C874020050000000317C0000D17B00008F
:105A9000000000000000000000000000BD7C0000CD
:105AA00000000000000000000000000000000000F6
:105AB000000000007C5E020000000000D08B0200AD
:105AC00001000000D45F0200C87402004B00000017
:105AD000317C0000D17B00000000000000000000CD
:105AE00000000000BD7C000000000000000000007D
:105AF0000000000000000000000000004C5B0200FD
:105B000000000000C874020040000000317C00006A
:105B1000D17B000000000000000000000000000039
:105B2000BD7C00000000000000000000000000003C
:105B30000000000000000000745A02000000000095
:105B4000D08B020001000000D05B0200D08B02006D
:105B500001000000145D0200C8740200470000004C
:105B6000317C0000D17B000000000000000000003C
:105B700000000000BD7C00000000000000000000EC
:105B8000000000000000000000000000BC5A0200FD
:105B900000000000C874020045000000317C0000D5
:105BA000D17B0000000000000000000000000000A9
:105BB000BD7C0000000000000000000000000000AC
:105BC0000000000000000000BC5A020000000000BD
:105BD000C874020034000000317C0000D17B00005A
:105BE000000000000000000000000000BD7C00007C
:105BF00000000000000000000000000000000000A5
:105C000000000000BC5A020000000000E85802003A
:105C10000200FFFF1D7C0000C8740200430000006A
:105C2000317C0000D17B000000000000000000007B
:105C300000000000BD7C000000000000000000002B
:105C4000000000000000000000000000BC5A02003C
:105C500000000000C874020032000000317C000027
:105C6000D17B0000000000000000000000000000E8
:105C7000BD7C0000000000000000000000000000EB
:105C80000000000000000000BC5A020000000000FC
:105C9000C87402003F000000317C0000D17B00008E
:105CA000000000000000000000000000BD7C0000BB
:105CB00000000000000000000000000000000000E4
:105CC00000000000085D020000000000C87402002F
:105CD00036000000317C0000D17B00000000000095
:105CE0000000000000000000BD7C0000000000007B
:105CF00000000000000000000000000000000000A4
:105D0000BC5A020000000000D08B0200010000001D
:105D1000105F0200C874020033000000317C0000F4
:105D2000D17B000000000000000000000000000027
:105D3000BD7C00000000000000000000000000002A
:105D4000000000000000000000000000885E02006B
:105D5000C87402003E000000317C0000D17B0000CE
:105D6000000000000000000000000000BD7C0000FA
:105D70000000000000000000000000000000000023
:105D800000000000BC5A020000000000C8740200BD
:105D900035000000317C0000D17B000000000000D5
:105DA0000000000000000000BD7C000000000000BA
:105DB00000000000000000000000000000000000E3
:105DC000BC5A020000000000C87402003800000045
:105DD000317C0000D17B00000000000000000000CA
:105DE00000000000BD7C000000000000000000007A
:105DF000000000000000000000000000BC5A02008B
:105E000000000000C87402004F000000317C000058
:105E1000D17B000000000000000000000000000036
:105E2000BD7C000000000000000000000000000039
:105E30000000000000000000405B020000000000C5
:105E4000C874020046000000317C0000D17B0000D5
:105E5000000000000000000000000000BD7C000009
:105E60000000000000000000000000000000000032
:105E7000000000009C59020000000000D08B0200CE
:105E800001000000A8590200988002000F000000E5
:105E900001000000205A0200C87402004C000000FB
:105EA000317C0000D17B00000000000000000000F9
:105EB00000000000BD7C00000000000000000000A9
:105EC000000000000000000000000000BC5A0200BA
:105ED00000000000C874020048000000317C00008F
:105EE000D17B000000000000000000000000000066
:105EF000BD7C000000000000000000000000000069
:105F00000000000000000000405B020000000000F4
:105F1000C87402004A000000317C0000D17B000000
:105F2000000000000000000000000000BD7C000038
:105F30000000000000000000000000000000000061
:105F400000000000BC5A020000000000C8740200FB
:105F50003D000000317C0000D17B0000000000000B
:105F60000000000000000000BD7C000000000000F8
:105F70000000000000000000000000000000000021
:105F80004C5B020000000000C874020042000000E8
:105F9000317C0000D17B0000000000000000000008
:105FA00000000000BD7C00000000000000000000B8
:105FB000000000000000000000000000745A020011
:105FC00000000000285A020000000000000000004D
:105FD000588C0200C874020039000000317C0000B7
:105FE000D17B000000000000000000000000000065
:105FF000BD7C000000000000000000000000000068
:1060000000000000000000004C5B020000000000E7
:10601000B5F70100EBF701005980000085F701009A
:106020007BF7010071F70100CD800000D08B0200EA
:1060300008000000F0790200487A0200B0790200FE
:1060400080790200707A0200087A0200187A020051
:1060500008790200D08B02000C000000307A0200A8
:10606000B87A020038790200687A0200287A0200C1
:10607000B07A020028790200B8790200107A020092
:10608000A87A020040790200C87902006E00000080
:106090004E08000066080000D060020056080000AC
:1060A000B86002005E080000AC600200E858020020
:1060B0000400020031F90100E85802000200FFFF6D
:1060C000D1850000E457020009010000DC600200F5
:1060D000E858020002000100BBF8010098800200AD
:1060E00027000000040000008C600200F460020041
:1060F00031000000C8740200010000009D8600000D
:10610000000000000000000000000000000000008F
:10611000000000000000000000000000000000007F
:10612000000000000000000000000000000000006F
:1061300098800200DF0000001B00000040610200A8
:10614000C608000048620200DE0D0000A8620200DE
:10615000E60D00009C620200D60D000030620200D5
:10616000C60D000090620200EE0400003C620200D6
:10617000260E0000246E02002E0E000004720200A3
:10618000760E0000A87202005E0E0000006C020095
:10619000560E0000546E02008E0E0000B073020016
:1061A0003E0E0000446B0200160E00002470020038
:1061B0000E0E0000946B02009E0E0000806C020028
:1061C000360E0000087102007E0E00007C72020094
:1061D000860E0000D06C0200FE0D0000547202001A
:1061E0001E0E00003C710200060E0000146E02003C
:1061F000960E0000087402004E0E0000EC730200C0
:10620000460E0000EC7002006E0E0000E471020009
:10621000660E000004700200BE01000002020000D1
:1062200000000000BD0100000202000000000000AC
:10623000E85802000100FFFF51870000E858020003
:1062400000000100ED860000E85802000000000098
:10625000AD860000B6010000030100000000000050
:10626000B901000003000000DC7602009501000087
:106270000100000001000000960100000100000084
:1062800000000000E4570200B60100003061020087
:10629000E85802000100FFFF19880000E8580200DA
:1062A00000000000C9860000E85802000100FFFF5E
:1062B00019870000B7010000020100000000000083
:1062C0007A00000002000000FFFFFFFFB90100009C
:1062D00003000000DC7602009501000001000000D0
:1062E000010000006E000000EE0800004600000003
:1062F0000C630200F6080000186302009880020098
:106300001F00000003000000E4620200E8580200E1
:1063100000000000818F0000E8580200000000002B
:10632000618F0000E45702001D010000FC620200C2
:10633000C87402007B000000D19100008BFB0100BB
:1063400000000000A18F0000DD92000000000000AE
:10635000B59300008D9200000000000000000000D6
:1063600000000000000000003C6402004E05000038
:1063700064640200F6040000C4630200FE0400002E
:10638000706402006E05000088640200760500005B
:106390004C6402007E050000946402008E0500003B
:1063A0005864020026050000D06302008605000044
:1063B000DC630200CE050000A06402009605000028
:1063C0007C640200E858020002000100A99000006D
:1063D000E85802000200020031910000E858020073
:1063E00004000200B1910000C8740200D300000054
:1063F000000000000000000000000000000000009D
:10640000000000000000000000000000151C020059
:106410004FFA010000000000000000000000000032
:1064200000000000B800000003020000387D0200F8
:10643000B900000001020000000000009880020086
:106440005F0000000B0000006C630200E8580200CF
:106450000400020019920000E85802000600030040
:1064600055900000E8580200040002000990000066
:10647000E858020002000100DDFB0100E8580200BC
:106480000300FFFFD1900000E85802000400020062
:1064900065FB0100E85802000400040031FB010024
:1064A000E858020002000100CD8F0000E858020009
:1064B00002000500B9950000C8740200CE0000007B
:1064C000000000000000000029FC010000000000A6
:1064D00000000000000000000000000000000000BC
:1064E00000000000000000000000000000000000AC
:1064F00000000000C8740200D3000000000000008B
:10650000000000000000000000000000000000008B
:106510000000000000000000151C02008D000200B9
:10652000000000000000000000000000000000006B
:10653000E8580200020001008FFF0100E858020045
:10654000080004002D990000E85802000400020031
:1065500079000200E8580200040002006500020011
:106560007465020001000000E85802000800040001
:1065700071020200C874020040010000299A000064
:10658000F99A00000000000000000000A19D00003A
:1065900000000000000000000000000000000000FB
:1065A0000000000000000000000000005868020029
:1065B000C87402009A010000000000000000000002
:1065C00000000000000000000000000000000000CB
:1065D0000000000091980000000000000000000092
:1065E000000000000000000000000000E858020069
:1065F00004000200070202001E0A000004690200F3
:10660000260A00001C6902003E0A0000F868020029
:10661000360A00003C650200460A0000546502008C
:106620004E0A000048650200560A0000EC650200B0
:106630005E0A000068680200FE04000010690200A3
:10664000C60C0000746802002E0A000030650200CB
:10665000AE060000686502006E0A00003079020094
:10666000760A0000D07902007E0A0000807A0200DB
:106670008E0A0000607A0200860A0000707902002B
:10668000960A0000187902009E0A000010790200A4
:10669000A60A000020790200AE0A0000E07A02009B
:1066A000B60A0000F8780200BE0A0000987A0200DC
:1066B000C60A0000387A0200CE0A0000207A0200E2
:1066C000D60A0000587A0200DE0A0000307A020082
:1066D000E60A0000B87A0200EE0A000038790200EB
:1066E000F60A0000687A0200FE0A0000287A02001A
:1066F000060B0000B07A02000E0B000028790200A1
:10670000160B0000B87902001E0B0000107A020080
:10671000260B0000A87A02002E0B00004079020030
:10672000360B0000C87902003E0B0000F079020031
:10673000460B0000487A02004E0B0000B0790200C0
:10674000560B0000807902005E0B0000707A020098
:10675000660B0000087A02006E0B0000187A020037
:10676000760B0000087902007E0B0000407A0200E0
:10677000860B0000E07902008E0B000058790200C1
:10678000960B0000787902009E0B0000D87A020078
:10679000A60B000088790200AE0B0000E879020029
:1067A000B60B0000C0790200BE0B0000D8790200D1
:1067B000C60B000050790200CE0B00006879020081
:1067C000D60B0000C07A0200DE0B0000C87A02007F
:1067D000E60B000048790200EE0B0000007A020090
:1067E000FE0B000054600200F60B00002C6002005B
:1067F000060C0000907902000E0C0000887A02005E
:10680000160C0000F87902001E0C0000787A0200D5
:10681000260C0000D07A02002E0C0000507A0200F4
:10682000360C0000987902003E0C0000907A0200BD
:10683000460C0000A87902004E0C0000007902000E
:10684000560C0000607902005E0C0000A079020086
:10685000660C0000A07A0200988002006702000027
:106860004C000000F8650200E85802000400020035
:106870001B020200E85802000A0005003DFE01006C
:10688000C87402009B01000000000000000000002E
:1068900000000000000000000000000000000000F8
:1068A00000000000D598000000000000000000007B
:1068B000000000000000000000000000C87402009A
:1068C000D3000000000000000000000000000000F5
:1068D00000000000000000000000000000000000B8
:1068E000151C020075FE0100000000000000000001
:1068F0000000000000000000E8580200060003004D
:10690000C1990000E8580200020001008DFC01005E
:10691000E85802000200010035FF0100E8580200BB
:10692000020001009FFC0100E85802000200010083
:10693000DD02020098800200270000000400000031
:106940008C690200E858020002000100B102020056
:10695000C8740200A3010000000000000000000055
:106960000000000000000000000000000000000027
:106970000000000000000000000000000000000017
:106980000000000000000000346902002E0D00002D
:10699000B4690200360D0000446902003E0D00009B
:1069A000C0690200460D000028690200506902001B
:1069B0009C2A0020E8580200020001009B0202000D
:1069C000E858020002000100C7020200E45702007A
:1069D00029000000D8690200988002001F00000012
:1069E00003000000F4690200E85802000000010002
:1069F000F1AA00006E0000004E0100008E070000AA
:106A0000E8690200960700000C6A0200E8580200DC
:106A10000000010029AB0000C8740200D200000091
:106A200000000000000000009DAB0000000000001E
:106A30000000000000000000000000000000000056
:106A40000000000000000000000000000000000046
:106A500000000000E8580200040002006DAD0000D4
:106A6000C8740200D2000000F9AB00000000000072
:106A70000000000000000000000000000000000016
:106A800000000000151C020089AD0000000000009D
:106A90000000000000000000A86A0200E8580200A0
:106AA0000200010099AD0000988002001F00000064
:106AB00003000000C46A0200E85802000400040059
:106AC00039AD0000560500009C6A02005E0500001A
:106AD000546A020066050000B86A0200E45702002A
:106AE00020010000346B020000000000398EE33DFD
:106AF000398E633E398EE33EABAA2A3F721C473F74
:106B00000000803F6E000000060900004600000003
:106B1000286B02000E0900001C6B0200E8580200FE
:106B20000000000075AE0000E85802000000000000
:106B300075AE0000988002001F00000003000000F6
:106B4000046B0200D08B0200120000008E0F0000C8
:106B5000560F000026100000F60F00005E11000026
:106B6000F60F00005E1100001E1100007E110000F3
:106B7000560F0000560F00007E110000F60F0000B7
:106B80003E110000F60F00003E110000161100003B
:106B900026100000D08B020019000000BE0F00007C
:106BA000F60F00008E1000000E10000016110000FD
:106BB0000611000006100000F60F00008E10000005
:106BC0000E1000007E11000076110000061000007B
:106BD000F60F0000EE0F0000CE0E000016110000B0
:106BE000BE0600001E100000BE0E0000B60E000023
:106BF000F60E0000161100007E1100007611000054
:106C0000D08B02001E000000B6100000BE0600007F
:106C1000161100007E1100007E1100001611000008
:106C2000BE0600001E100000560F0000560F0000A8
:106C30001E100000BE060000FE1000007E100000C6
:106C4000A6100000EE100000BE06000016110000A5
:106C50007E1100007E11000016110000BE0600002B
:106C60001E100000560F0000560F00001E100000FE
:106C7000BE0600009E100000FE0F0000161000006F
:106C8000D08B020012000000C60F00006611000049
:106C900056110000761100000E100000DE110000F9
:106CA000D6100000761100000E10000066110000E2
:106CB000E60E0000EE0F0000DE0E00005611000090
:106CC0006E110000E610000056110000E6110000F1
:106CD000D08B02004F000000661000001E0F000065
:106CE000EE110000060F0000060F0000AE0E0000BF
:106CF000060F0000BE110000EE1100001E10000083
:106D00001E100000EE1100001E0F0000CE0F00004C
:106D1000EE110000560F0000560F0000EE110000AB
:106D20001E100000F6100000F60F0000CE0E00004E
:106D3000EE110000A60E0000A60E00008611000055
:106D4000A60E000026110000EE110000BE06000095
:106D5000BE060000EE110000560F00001E0F0000DE
:106D6000EE110000060F0000060F0000EE110000FB
:106D7000CE0F000096100000761000001E0F0000DD
:106D8000EE110000060F0000060F0000AE0E00001E
:106D9000060F0000360F0000EE1100007E1100000B
:106DA0007E110000EE1100001E1000005E0F0000BA
:106DB000EE110000A60E0000A60E0000EE1100006D
:106DC000A60E0000FE0E0000CE1100003E110000D5
:106DD000E60E0000A60E000086110000A60E0000C0
:106DE000DE100000E60E0000A60E00008611000076
:106DF000A60E00001E100000EE1100005E0F000045
:106E00001E100000EE1100005E0F00007E1000005A
:106E10000E120000D08B0200020000003E0F0000A6
:106E2000CE100000D08B02000A000000F611000016
:106E30007E1100007E1100007E1100000E11000086
:106E400006120000161100001611000016110000B5
:106E5000A6100000D08B02006A0000002E11000076
:106E6000861100007E0F000036100000260F000083
:106E7000661000005E0F00002E0F0000060F0000DD
:106E8000660F00001E100000761000005E0F00006C
:106E9000260F00006E0F0000261000001E110000DB
:106EA00086110000261000001E1100005E0F000079
:106EB0001E1000001E0F0000660F00001E0F0000D5
:106EC0002E1000001E1100008E1100002610000080
:106ED0001E1100005E0F0000261000001E0F0000B3
:106EE0005E100000261000001E1000005E0F000063
:106EF0001E0F0000660F00007E100000260F00002D
:106F0000660F0000261000001E1100005E0F00003A
:106F10001E1000005E0F00001E0F0000760F000024
:106F20001E0F0000660F00001E0F0000361100004B
:106F3000861100004E0F000036110000861100007F
:106F4000060F0000660F0000261000001E0F000054
:106F5000C610000026100000BE0600001E11000032
:106F60002E0F0000060F00003611000086110000F1
:106F7000060F00001E110000C610000026100000C1
:106F80005E0F00001E0F00001E1100002610000002
:106F9000BE0600001E1100004E0F0000361100005A
:106FA000861100004E0F000036110000861100000F
:106FB000060F0000060F0000660F000026100000FC
:106FC0001E0F00001E110000861100001E1100009F
:106FD0004E0F0000460F0000AE0E0000060F00002E
:106FE0001E11000086110000060F0000C6100000F0
:106FF00026100000BE0600001E1100002E0F00002B
:10700000660F0000D08B020006000000C6110000D1
:1070100026100000560F0000B6110000460F0000B9
:10702000E60F0000D08B0200300000008E0F000041
:10703000BE0600007E110000A60E0000AE0E00008D
:10704000A60E00007E110000BE0600008E0F00009C
:10705000BE0600007E110000A60E0000AE0E00006D
:10706000A60E00007E110000BE06000016110000F2
:10707000A60E0000960F00001E1000002610000053
:107080001E100000560F0000C60E00008E0F0000FC
:10709000BE0600007E110000A60E0000AE0E00002D
:1070A000A60E00007E110000BE0600007E1100004A
:1070B000060F000046100000161100004E110000DF
:1070C000A60E0000960F0000261000008E0F000094
:1070D000BE0600007E110000BE0600007E1100000A
:1070E00016110000BE0600001E100000D08B02002A
:1070F00005000000C611000016110000BE060000C9
:107100001E100000560F0000D08B02000B00000084
:10711000A60F000006100000F60F00000E10000081
:107120003E1000007610000086100000F60F0000F0
:10713000061000000E0F0000A60F0000D08B02000A
:1071400028000000D60E0000060F0000CE0F000041
:107150001E0F0000EE0E0000EE110000E60E000013
:10716000060F0000CE0F00001E0F0000EE0E000004
:10717000EE110000EE0E0000C61000002610000008
:10718000BE06000016110000BE060000261000001A
:10719000BE060000260F0000CE0F00001E100000EB
:1071A000560F00002E0F0000EE110000460F0000E9
:1071B000CE0F00001E100000560F00002E0F000022
:1071C000EE1100004E0F0000C61000002610000057
:1071D000BE06000016110000BE06000026100000CA
:1071E000BE060000D08B020006000000AE110000B9
:1071F000CE0F0000BE060000D6110000D610000021
:10720000DE110000D08B02001200000056100000BA
:1072100026100000BE060000DE0F0000BE100000B9
:10722000DE0F0000BE100000E60F0000F60F0000A9
:107230001E10000026100000BE060000560F0000C1
:107240001E100000DE100000260F00006E1000006F
:107250000E100000D08B0200080000009E0F0000FE
:10726000EE1100007E10000026100000EE1100005C
:10727000560F0000EE11000046110000D08B0200F6
:1072800009000000BE0F00009E1100001E1100004A
:107290007E110000961100007E110000EE1100002A
:1072A000060F0000AE0F0000D08B0200400000006F
:1072B000B60F0000BE0600007E110000CE0F0000D9
:1072C000BE060000A6110000CE0F0000BE060000A2
:1072D000AE0F0000BE0600007E110000CE0F0000C1
:1072E000BE060000A6110000CE0F0000BE06000082
:1072F000AE0F00001E1000007E1100005E100000A6
:1073000016110000A61100005E100000161100000A
:10731000AE0F00001E1000007E1100005E10000085
:1073200016110000A61100005E10000016110000EA
:10733000160F00004E1000007E1100005E100000CD
:1073400016110000A61100005E10000016110000CA
:10735000160F00004E1000007E1100005E100000AD
:1073600016110000A61100005E10000016110000AA
:10737000AE0F0000BE0600007E110000CE0F000020
:10738000BE060000A6110000CE0F0000BE060000E1
:10739000AE0F0000BE0600007E110000CE0F000000
:1073A000BE060000A6110000CE0F0000BE060000C1
:1073B000D08B02000D000000B60F00001E10000070
:1073C000DE1000007E11000076100000BE060000F6
:1073D0005E110000A60E0000D6100000161100007D
:1073E000D6110000060F0000EE0F0000D08B020047
:1073F00005000000D60F00001E100000BE060000B1
:10740000161100007E110000D08B02000700000062
:10741000AE100000FE1100003E100000FE11000042
:107420008E100000FE110000860F0000C8740200DC
:107430009C010000000000000000000000000000AF
:10744000000000000000000000000000000000003C
:10745000000000000000000000000000000000002C
:107460000000000080740200E858020002000100E1
:1074700095AE0000E85802000200010085AE000051
:1074800098800200270000000400000090740200B1
:10749000FE0C0000B0740200060D000068740200CB
:1074A0000E0D0000BC740200160D00007474020082
:1074B000E858020002000100B5AE0000E8580200E2
:1074C0000200010047030200C87402009600000099
:1074D000F1B000006DB60000FDB20000691C0200B2
:1074E00000000000F70302000000000000000000A0
:1074F000000000000000000000000000000000008C
:10750000000000000000000000000000000000007B
:1075100000000000000000001C0000001D00000032
:10752000000000000000000000000000000000005B
:10753000000000000000000000000000000000004B
:10754000000000000000000000000000000000003B
:10755000000000000000000000000000000000002B
:1075600000000000000000002300000024000000D4
:107570002500000026000000270000000000000099
:10758000140000000000000001000000C8740200A8
:1075900091000000BDB20000A7050200000000003D
:1075A000000000000000000095B000000000000096
:1075B00000000000000000000000000000000000CB
:1075C0000000000000000000C8740200630000001A
:1075D00000000000E30402000000000000000000C2
:1075E000000000000000000000000000000000009B
:1075F000000000000000000000000000000000008B
:1076000000000000C87402008F00000000000000AD
:10761000E304020000000000000000000000000081
:10762000000000000000000000000000000000005A
:10763000000000000000000000000000000000004A
:10764000E858020004000200B9B70000130000006F
:10765000170000000E000000000000000000000005
:107660000000000001000000E858020004000200D1
:10767000C3050200F07702003C2B00208C7702004B
:10768000EC2B00209880020037000000060000006C
:107690008478020036090000F07602002E0900000E
:1076A0008077020046090000387702003E0900009A
:1076B000447802004E090000787802005609000064
:1076C000E47602005E0900000C7702009880020058
:1076D0003F0000000700000094760200F0770200EF
:1076E0001C2B0020E85802000400020071BE0000BC
:1076F000E858020004000200A9BE0000360900009C
:10770000F07602002E09000080770200E85802009F
:10771000020001008DBE00008C7702008C2B00203F
:10772000447702004C2B00208C770200FC2B0020B9
:1077300044770200BC2B0020E8580200040002003D
:1077400029030000C87402002301000000000000AB
:107750000000000000000000000000000000000029
:107760000000000000000000000000000000000019
:10777000000000000000000000000000847602000D
:10778000E858020002000100A5100200C8740200BF
:1077900022010000000000000000000000000000C6
:1077A00000000000000000000000000000000000D9
:1077B00000000000000000000000000000000000C9
:1077C00000000000347802008C7702009C2B00201F
:1077D0008C7702005C2B00208C7702002C2C002080
:1077E0008C7702000C2C00208C770200CC2B002020
:1077F000C874020024010000000000000000000026
:107800000000000000000000000000000000000078
:107810000000000000000000000000000000000068
:107820000000000000000000CC7602008C7702000F
:107830001C2C0020988002001700000002000000AD
:10784000FC760200E858020002000100B3100200BA
:107850008C770200AC2B0020447702006C2B0020B8
:10786000F07702002C2B00208C7702003C2C0020AB
:107870008C770200DC2B0020E85802000400020094
:1078800055BE000036090000F07602002E09000007
:107890008077020046090000387702003E090000A8
:1078A000447802004E090000787802005609000072
:1078B000E47602008C7702007C2B0020C874020062
:1078C0007D000000000000001DBF0000000000005F
:1078D00000000000000000000000000000000000A8
:1078E000151C0200C1100200000000000000000092
:1078F00000000000000000007465020009117CCA4D
:1079000074650200014308A7746502000967140446
:10791000746502000951815F7465020009400155D8
:1079200074650200016003077465020001001042E3
:107930007465020001EA7F477465020001001300CC
:10794000746502000160100074650200097E9DE705
:10795000746502000184D1737465020001AAAAAAA9
:107960007465020001AE7EE774650200095ECABD5F
:107970007465020009400117746502000144454521
:1079800074650200094150CC74650200093FC6F8D5
:107990007465020001FB3BE77465020009E41315FE
:1079A0007465020001EE9362746502000184104761
:1079B0007465020001047D44746502000100102119
:1079C0007465020001A5BCF5746502000142100057
:1079D00074650200014039027465020001317E477E
:1079E00074650200096194F47465020001C02907FE
:1079F0007465020001C455427465020001E678070F
:107A00007465020001C46D47746502000110957130
:107A100074650200010090017465020001447C411C
:107A2000746502000100A222746502000100100CBE
:107A3000746502000184100074650200010A2022AE
:107A4000746502000180A80F74650200011C5311C7
:107A50007465020009FB93BF74650200095111159A
:107A600074650200010080E8746502000100700086
:107A700074650200018454477465020001C47DA747
:107A800074650200014081E8746502000118FFAFCF
:107A90007465020009BFFE5F74650200017F03E5A3
:107AA0007465020001632B077465020001001C006D
:107AB0007465020001001084746502000108110061
:107AC0007465020001B57E427465020009C411F7B5
:107AD0007465020001C07D05746502000180280202
:107AE00074650200010A1045C874020042020000D9
:107AF0000000000000000000000000000000000086
:107B00000000000000000000000000000000000075
:107B10000000000000000000307B020000000000B8
:107B20004C7B0200E858020002000100EDBF00009B
:107B30001511020005110200000000000000000005
:107B4000E85802000300FFFF71BF000098800200A8
:107B50004F00000009000000987B02004502000071
:107B60000200000080250000460200000200000024
:107B7000080000004702000003000000387D0200FA
:107B80009D0000000200000001000000480200000B
:107B900003020000387D020026120000407B020034
:107BA000CE020000247B0200560400009C7E0200EE
:107BB0004E120000847E020056120000907E0200E9
:107BC0005E1200006C7E0200C6040000787E020097
:107BD00066120000030000006E12000005000000A5
:107BE000E87B020001000000C87402005E00000093
:107BF00049C0000065C000000000000009C000008E
:107C0000551102000000000000000000000000000C
:107C10000000000000000000000000000000000064
:107C200000000000E87B020000000000B20100003C
:107C30000201000000000000B3010000020100008A
:107C400000000000B501000001000000000000007D
:107C5000E85802000300FFFF99C00000B47C020056
:107C60000C290020B2010000020100000000000009
:107C7000B40100000301000000000000B501000095
:107C8000010000000000000056040000507C0200CB
:107C9000C6040000987C0200E85802000300FFFFC1
:107CA000F5C00000988002001700000002000000EC
:107CB000887C0200C8740200B001000000000000CF
:107CC00000000000000000000000000000000000B4
:107CD00000000000000000000000000000000000A4
:107CE000000000000000000000000000A47C020072
:107CF000C8740200D1000000000000000000000075
:107D0000A9C3000000000000000000000000000007
:107D10000000000000000000000000000000000063
:107D2000000000000000000000000000E457020016
:107D30000B000000C02E00203C7D0200C874020031
:107D40005500000061D200000000000000000000AB
:107D500045D200000000000000000000000000000C
:107D60000000000000000000000000000000000013
:107D70000000000000000000C8740200D5000000F0
:107D800071D20000000000000000000000000000B0
:107D900000000000000000000000000000000000E3
:107DA00000000000000000000000000000000000D3
:107DB00000000000E858020002000200E5D20000C6
:107DC000C85502000000000008000000C5CB0200FA
:107DD000D08B0200020000004E010000E07D020096
:107DE000D08B020003000000030000000B00000025
:107DF000010000006E0000009E0400002E0800003C
:107E0000407E0200360800002C7E02003E08000082
:107E1000D07D02000E080000C07D0200EE070000C9
:107E20000608000046080000B47D0200D08B020066
:107E3000030000000700000009000000010000002E
:107E4000C855020000000000050000002DBF020020
:107E5000988002003F00000007000000F47D02004F
:107E6000E457020093000000507E0200E858020030
:107E70000400030099D60000E85802000400020044
:107E800073160200E85802000200010055D40000F9
:107E9000E8580200020002006DD30000E85802001A
:107EA000020002001DD50000C87402006800000036
:107EB00000000000B71602000000000000000000F3
:107EC000000000000000000000000000151C02007F
:107ED0008F160200000000000000000000000000FB
:107EE00000000000C87402008D01000000000000C6
:107EF0000000000000000000000000000000000082
:107F00000000000000000000000000000000000071
:107F10000000000000000000000000001C800200C3
:107F2000E85802000300FFFF45DB0000E8580200AC
:107F30000500FFFFE9DA0000E8580200080004002D
:107F400019DC0000E858020006000300BD1702001B
:107F5000E858020002000100C5DB000042010000F9
:107F60000301000000000000930100000201000076
:107F70000000000094010000020200000500000063
:107F8000CD00000002020000FBFFFFFF9501000092
:107F90000102000001000000960100000102000043
:107FA000000000003E0A0000447F0200360A000084
:107FB000387F02008E0C0000D47F0200960C000077
:107FC000207F0200BE0C00002C7F0200F60400009F
:107FD000507F0200E85802000400030045DA000068
:107FE000990100000301000000000000930100005F
:107FF000020000007800000095010000010200006E
:1080000001000000960100000102000000000000D5
:108010004C010000010200000000000098800200F6
:108020003700000006000000A47F0200E8580200AC
:10803000040003005B18020035C0020040C00200CB
:108040004AC00200D08B02000100000098800200AC
:10805000E858020002000100E3180200C8740200A0
:108060005600000095DD000001E100000000000066
:108070009DDC0000BDDE00000000000051E10000BA
:1080800005DD00000000000000000000000000000E
:1080900044800200A4810200C87402006500000050
:1080A00095DD000001E10000000000009DDC000003
:1080B000BDDE00000000000051E1000005DD000011
:1080C00000000000000000000000000000000000B0
:1080D000A4810200E85802000200010065E00000EF
:1080E000C8740200D300000000000000000000007F
:1080F0000000000000000000000000000000000080
:1081000000000000151C0200111802000000000011
:10811000000000000000000000000000E85802001D
:108120000200010075DE0000F6040000108202006B
:10813000FE0400005080020006050000FC810200E1
:108140000E050000708202001605000098810200F2
:108150001E050000D480020026050000588202009F
:108160002E0500001C810200360500002C80020054
:108170003E05000064820200460500000482020001
:10818000CE0000009C510200D6000000A851020061
:10819000DE000000B4510200E858020002000100B5
:1081A000C9DC000098800200770000000E0000008B
:1081B00028810200C8740200D30000000000000003
:1081C00000000000000000000000000000000000AF
:1081D0000000000000000000151C0200251802002D
:1081E000000000000000000000000000000000008F
:1081F000E858020004000300B9E00000C87502005E
:10820000F0810200E85802000200010049E000008D
:10821000E85802000200010021DD0000C8740200DD
:10822000D000000031DD0000000000000000000070
:1082300000000000AF180200000000000000000075
:10824000E5DC00000000000000000000000000006D
:108250000000000000000000E858020004000300D5
:1082600077180200E85802000300FFFF55DF000006
:10827000E858020004000300931802000000000008
:10828000000000000A0000004E020000D8C00200FA
:10829000DBC00200E5C00200E9C00200EDC0020040
:1082A000FFC002000BC1020015C1020022C1020082
:1082B0002DC1020037C1020044C102004FC10200BB
:1082C0005CC1020067C1020072C102007DC10200F0
:1082D0008CC1020097C10200A8C10200B3C1020014
:1082E000C2C10200CEC10200D9C10200E3C1020036
:1082F000EEC10200FCC102000AC2020018C2020064
:1083000022C202002CC2020037C2020041C2020097
:108310004FC2020059C2020064C202006DC20200D4
:1083200076C202007FC2020088C2020091C202002F
:10833000A0C20200AEC20200B9C20200C1C2020065
:10834000CDC20200D5C20200DDC20200E4C20200BA
:10835000EFC20200FAC202000AC302001AC30200FE
:108360002CC302003DC302004EC302005CC30200E6
:1083700067C3020073C3020085C3020099C30200F1
:10838000AEC30200BEC30200CCC30200DFC30200C2
:10839000ECC3020000C402000BC4020019C40200B6
:1083A00027C4020033C4020049C4020053C40200BF
:1083B00063C4020072C4020080C402008DC40200C3
:1083C00099C40200ADC40200BAC40200CEC40200C7
:1083D000DDC40200E4C40200ECC40200F3C40200E5
:1083E000FCC4020007C5020015C502001BC502003F
:1083F00021C5020027C502002EC5020036C50200B5
:108400003CC5020044C502004BC5020057C502002E
:108410005FC502006AC5020070C502007EC5020089
:108420008DC5020094C502009AC50200A3C50200D2
:10843000AFC50200B6C50200BDC50200C6C5020038
:10844000CEC50200DBC50200E5C50200EFC5020093
:10845000F9C5020003C602000AC6020010C60200E7
:1084600016C602001BC6020021C602002EC602006C
:108470003BC6020042C6020048C602004FC60200C8
:1084800058C602005EC6020064C602006AC6020048
:1084900077C602007EC6020084C602008AC60200B9
:1084A00091C6020097C602009EC60200A4C6020042
:1084B000ACC60200B4C60200BBC60200C2C60200BF
:1084C000CDC60200D5C60200DEC60200EDC602001F
:1084D000F3C60200FBC6020001C7020007C7020084
:1084E00012C702001AC7020021C7020029C70200F2
:1084F00031C7020037C702003DC7020043C7020070
:108500004AC7020051C7020059C7020060C70200F3
:108510006BC7020071C7020079C7020080C7020062
:1085200086C7020090C702009DC70200A6C70200CE
:10853000AFC70200B8C70200C0C70200C7C7020029
:10854000CFC70200D7C70200E0C70200E8C7020099
:10855000F1C70200FAC7020001C8020008C8020001
:1085600010C8020019C8020022C802002BC802006D
:1085700031C802003BC8020041C8020048C80200DE
:1085800050C8020059C8020061C802006AC802004F
:1085900077C8020082C802008CC8020098C8020096
:1085A000A5C80200ADC80200B5C80200BFC80200DD
:1085B000C9C80200D3C80200DDC80200E7C8020033
:1085C000F2C80200FAC8020009C9020013C9020079
:1085D0001FC902002AC9020036C9020041C90200AF
:1085E0004AC9020052C9020059C902005DC902000D
:1085F00062C9020069C902006FC9020075C90200A0
:108600007BC9020081C9020087C902008EC902002D
:1086100095C902009CC90200A4C90200ABC90200AE
:10862000B6C90200BDC90200C4C90200CCC902001B
:10863000D7C90200DFC90200E7C90200EFC9020082
:10864000F6C90200FEC9020006CA020010CA0200F2
:108650001ACA020025CA020031CA020054CA020026
:108660005FCA02006ACA020077CA020084CA020016
:1086700090CA02009CCA0200A7CA0200B1CA020046
:10868000B8CA0200C4CA0200CACA0200D1CA0200A3
:10869000DACA0200E5CA0200EDCA0200F6CA020008
:1086A000FFCA020009CB020018CB020029CB02004E
:1086B0003BCB020045CB02004CCB020055CB020065
:1086C00060CB020065CB02006FCB020079CB0200C9
:1086D00082CB02008ECB020099CB0200A5CB020018
:1086E000ACCB0200BACB0200C3CB0200CECB02005F
:1086F000D6CB0200DECB0200E7CB0200F6CB0200B5
:10870000FECB020005CC02000FCC02001DCC020003
:1087100024CC02002FCC020044CC02005FCC02002B
:1087200072CC020081CC020091CC02009FCC0200EE
:10873000AECC0200C2CC0200E3CC0200F0CC0200BE
:10874000FDCC020004CD02000BCD020012CD0200D0
:1087500019CD020020CD020027CD02002ECD02004F
:1087600035CD02003CCD020043CD02004BCD0200CE
:1087700053CD02005BCD020063CD02006BCD020041
:1087800073CD02007BCD020083CD02008BCD0200B1
:108790009BCD0200A3CD0200ABCD0200B3CD020001
:1087A000BCCD0200C5CD0200D1CD0200DDCD02005E
:1087B000EACD0200F8CD020003CE020010CE020086
:1087C0001CCE020024CE020032CE02003ACE0200BD
:1087D00040CE020048CE020053CE02005BCE020023
:1087E00064CE020070CE020078CE020083CE02007A
:1087F00089CE02008FCE020094CE02009ECE0200EF
:10880000A7CE0200B0CE0200B9CE0200C2CE020056
:10881000CBCE0200D4CE0200DDCE0200E6CE0200B6
:10882000EFCE0200F9CE020003CF02000DCF02000E
:1088300018CF020022CF02002DCF020037CF020056
:1088400042CF02004CCF020057CF020062CF02009D
:1088500072CF02007FCF020089CF020099CF0200C1
:10886000A2CF0200B1CF0200BACF0200C0CF0200F7
:10887000D1CF0200E1CF0200EDCF0200F4CF020021
:10888000FDCF020006D0020013D0020020D002006B
:1088900029D0020037D002003ED0020046D00200AC
:1088A00051D002005DD002006BD0020073D00200F4
:1088B0007BD0020085D002008DD0020098D002004B
:1088C000A0D00200B2D00200C3D00200D6D0020075
:1088D000E0D00200E7D00200F0D00200F8D00200A1
:1088E00001D1020008D102000FD1020019D102000B
:1088F00020D1020027D1020035D1020047D1020069
:1089000058D1020063D102006ED102007BD1020077
:1089100089D1020097D10200A7D10200BFD1020085
:10892000CFD10200D7D10200DFD10200E7D102008F
:10893000F4D1020006D2020010D202001AD20200C4
:108940002AD2020036D2020047D202005BD20200D5
:1089500069D202006FD2020076D202007AD20200FF
:1089600080D2020089D2020091D202009DD2020080
:10897000A5D20200ABD20200B2D20200BED20200E7
:10898000CAD20200D0D20200D8D20200E0D2020045
:10899000EAD20200F5D20200FDD2020005D30200A5
:1089A00011D302001FD3020029D3020030D30200EA
:1089B0003CD3020046D302004DD3020053D3020041
:1089C00060D302006BD3020075D3020081D3020092
:1089D0008AD3020095D30200A1D30200ABD30200D8
:1089E000AFD30200B4D30200BBD30200C2D3020053
:1089F000C7D30200CCD30200D3D30200DAD30200E3
:108A0000E0D30200E6D30200ECD30200F2D302006E
:108A1000F6D30200FDD3020002D4020007D4020004
:108A20000ED4020015D402001AD4020021D4020090
:108A300027D402002DD4020031D4020036D4020023
:108A40003CD4020044D402004CD4020053D40200AF
:108A50005AD4020061D4020066D402006DD4020030
:108A600074D4020079D4020080D4020087D40200BA
:108A70008ED4020093D402009AD40200A1D4020042
:108A8000A8D40200AFD40200B5D40200BBD40200C7
:108A9000C1D40200C7D40200CDD40200D1D4020058
:108AA000D6D40200DED40200E5D40200ECD40200E9
:108AB000F1D40200F6D40200FDD4020002D5020077
:108AC00009D5020010D5020016D502001CD50200FF
:108AD00022D5020028D502002ED5020034D502008E
:108AE0003AD5020041D5020046D502004DD502001C
:108AF00052D5020059D502005FD5020065D50200AB
:108B00006BD5020071D5020077D502007DD5020039
:108B100083D502008AD502008ED5020093D50200CB
:108B200099D50200A1D50200A8D50200AFD5020058
:108B3000B6D50200BBD50200C1D50200C7D50200E0
:108B4000CDD50200D3D50200D9D50200DDD5020073
:108B5000E2D50200E9D50200F0D50200F7D5020007
:108B6000FCD5020003D602000AD602000FD602008E
:108B700016D602001CD6020022D6020028D6020019
:108B80002ED6020032D6020039D602003FD60200AD
:108B900045D602004BD602005AD6020061D602002A
:108BA00068D6020073D602007AD6020083D602008D
:108BB0008AD6020094D602009FD60200AAD60200EE
:108BC000B0D60200E858020004000400FD190200BB
:108BD000C87402009500000039E50000B9E7000004
:108BE0000000000091E5000049E6000000000000E0
:108BF00045E70000F1E50000000000000000000073
:108C000000000000000000000C8C020098800200B0
:108C10001700000002000000608C0200C87402000F
:108C2000D300000000000000000000000000000071
:108C30000000000000000000000000000000000034
:108C4000151C0200E11902000000000000000000F5
:108C50000000000000000000D08B020000000000B7
:108C60006E050000708C02007E050000C48B0200BF
:108C7000E858020004000200111A0200C874020041
:108C8000CF0000000000000000000000331A0200C6
:108C900000000000000000000000000000000000D4
:108CA00000000000000000000000000000000000C4
:108CB0000000000000000000E6C40200DFC4020063
:108CC000EEC402003BD702003FD7020042D70200A9
:108CD00049D70200BFBB02004FD702003204030095
:108CE00058D702005CD7020061D7020066D70200A5
:108CF0006DD70200C0A9020075D70200CEAD0200F8
:108D00005ED70200AEB702006FCC020002CC0200B8
:108D10007AD702008FAD020081D70200C1A90200FC
:108D200001D2020096B9020085D70200C4A9020050
:108D3000BAA902007DC802008CD7020092D70200B7
:108D4000988002003F00000007000000808D0200B4
:108D5000E858020000000000D5F40000E8580200C6
:108D6000000000008D1C0200E85802000000000016
:108D7000E9F40000E858020000000000FDF40000E3
:108D80006E0000006E08000076080000D08D020022
:108D90007E080000508D020086080000688D0200E9
:108DA0008E080000748D020096080000B88D020045
:108DB0009E0800005C8D0200E858020000000000E0
:108DC000791C0200E45702000D010000408D0200F2
:108DD000E8580200000000001DF50000C874020001
:108DE000D3000000000000000000000000000000B0
:108DF0000000000000000000000000000000000073
:108E0000151C020015F70000000000000000000023
:108E100000000000000000001C500200B7DD02004E
:108E200038500200E8DD0200F84F02004DDE02007B
:108E300004500200AFDE02004C5102002DDF0200A0
:108E4000AC69020072DF0200B4690200C9DF0200EF
:108E50004469020001E00200C069020039E002003A
:108E600004000020C7E002001000002013E102000F
:108E7000B07402005FE1020068740200A1E1020028
:108E8000BC7402001CE20200747402005BE2020087
:108E9000344F0200A6E20200E04F020049E3020064
:108EA000044F0200D5E30200EC4F020099E40200F7
:108EB000284F020014E502001C4F020077E5020073
:108EC000B84F020023E60200D44F0200CFE60200B2
:108ED000240000207BE70200D47F020099E7020013
:108EE000207F020045E80200507F0200DEE8020019
:108EF0002C7F020009E90200447F02001AEA020006
:108F0000387F0200ABEA0200DC76020034EB02009C
:108F10006078020063EB02007476020092EB0200BC
:108F200020770200C1EB0200D0770200F0EB0200D4
:108F3000587802001FEC0200B47802004EEC0200E8
:108F4000187702007DEC0200C8770200ACEC02004A
:108F500050780200DBEC0200307702000AED0200DC
:108F6000E87702003AED0200707802006AED020034
:108F70007C7602009AED020028770200CAED02001A
:108F8000E0770200FAED02002C7802002AEE0200DF
:108F9000D87702005AEE0200687802008AEE0200DA
:108FA000F0760200BAEE02008077020018EF0200AD
:108FB0003877020062EF020044780200C9EF020035
:108FC0000C7702003DF002005C7C02009BF0020086
:108FD000507C020039F10200987C020084F102000A
:108FE00074650200DAF1020004690200CEF20200A8
:108FF0001C690200F8F20200F868020023F3020084
:109000003C650200B2F30200546502003DF4020028
:10901000486502008EF40200EC650200E1F40200F3
:109020006868020027F502001069020071F502006D
:1090300074680200A4F502003065020059F60200CF
:109040001C000020E4F60200407B020029F7020029
:10905000247B0200BEF702009C7E020026F802007C
:10906000847E020077F80200907E0200A8F80200D9
:109070006C7E0200EBF80200787E02006BF90200C1
:1090800084620200B7F90200A862020006FA020038
:109090009062020075FA02003062020015FB0200C5
:1090A0009C620200A6FB02003C620200FFFB020081
:1090B0004862020029FC02006451020069FC0200BF
:1090C0002463020084FC02001863020008FD020011
:1090D000DC6A020054FD02001C6B02008DFD0200E0
:1090E000E8580200000001008DF70000E45702007C
:1090F00030000000B4940200E858020002000100B1
:1091000021F40000E858020002000100F71C0200F0
:10911000E858020004000300A5060100E858020018
:1091200004000300171D0200E858020004000200BA
:1091300085060100E858020004000200BB1C020082
:10914000E85802000200010001020100E858020094
:109150000200010025030100E8580200020001009E
:109160002D020100E85802000300FFFF0D1D020060
:10917000E85802000300FFFFB9070100E8580200A9
:1091800000000000F9000100E8580200020002009F
:10919000CB1C0200E858020002000100610201003D
:1091A000E858020002000100D5010100E858020061
:1091B0000200010059050100E85802000200010008
:1091C000A5050100E858020002000100251C02006C
:1091D000E85802000200010045020100E8580200C0
:1091E0000000010009070100E85802000200010028
:1091F00011030100E85802000400FFFF050101000F
:1092000026000000F49102003E000000AC64020061
:1092100096000000AC910200F6020000E87B02001C
:1092200006030000A84B0200FE0200009896020010
:109230002E0300009880020046030000A87E020072
:109240005E0300003C9502006603000030570200F8
:10925000B603000018520200DE0300003063020073
:10926000EE030000BC780200A60200006C5702006A
:109270004E0400007895020066040000C051020010
:1092800096040000C85502008E0400008C75020090
:10929000AE040000D08B0200B6040000C8740200C7
:1092A000CE040000A85702001E030000C87502008B
:1092B0007E040000047602008E010000EC600200D3
:1092C000BE0200000C950200C6020000A091020040
:1092D000CE02000040910200E60200005891020018
:1092E0000E030000D09102001603000094910200CA
:1092F00036030000DC9102003E03000034910200BE
:109300004E03000074550200560300008055020011
:1093100076030000109102007E030000DC9402003E
:10932000860300007C9102008E0300002891020059
:1093300096030000049102009E030000E8910200E1
:10934000AE030000C4910200BE0300006876020074
:10935000C603000040760200CE030000F494020031
:10936000D6030000F8900200E6030000009502001A
:10937000F6030000D0940200FE0300006491020096
:109380000E040000A8940200160400004C91020094
:109390002E040000C49402003E0400001C91020050
:1093A00046040000189502005E040000B891020017
:1093B0006E040000E8940200760400007091020040
:1093C00086040000889102009E010000145D0200E6
:1093D000A6010000D05B0200AE0100008C5D02001F
:1093E000B6010000CC5C0200C6010000C85D0200AE
:1093F000CE010000D45F0200EE0100004C5F0200CD
:10940000F6010000505D0200FE010000905C0200C9
:1094100006020000045B02000E0200006059020018
:1094200016020000885F02001E020000185C0200A5
:1094300026020000285A02002E020000945B02005F
:1094400036020000405E02003E020000585B02004F
:1094500046020000D45E02004E020000E459020001
:1094600096010000545C020056020000105F0200EA
:109470005E020000C85A020066020000985E020008
:1094800086020000805A020076020000A8590200FD
:109490007E020000045E0200A6080000E0900200C8
:1094A0002604000058510200E858020002000100A2
:1094B0009D07010098800200AF02000055000000E7
:1094C00000920200E8580200020001000D040100B1
:1094D000E85802000300FFFF031D0200E8580200E5
:1094E00006000300E9060100E8580200020002003D
:1094F000D1050100E858020002000100B31C02007F
:10950000E858020000000000ED000100E8580200E9
:10951000020001007D010100E85802000100FFFF88
:10952000A1040100D08B020001000000D08B0200DA
:10953000E858020004000200FD080100C87402009F
:109540006B00000000000000391D02000000000058
:10955000000000000000000000000000000000000B
:10956000151C0200050A01000000000000000000B8
:109570000000000000000000C87402008900000024
:10958000890A0100BD1D020000000000390A010027
:1095900000000000171E0200BD0A0100690A010058
:1095A00000000000000000000000000000000000BB
:1095B00000000000C8740200D3000000000000009A
:1095C000000000000000000000000000000000009B
:1095D0000000000000000000151C0200691D0200D0
:1095E000000000000000000000000000000000007B
:1095F000000000003F1E02009880020017000000DB
:1096000002000000D4960200E858020004000200A4
:1096100075110100E8580200040002000911010060
:10962000C8740200D3000000000000000000000029
:10963000000000000000000000000000000000002A
:1096400000000000151C02001920020000000000AC
:10965000000000000000000000000000C8740200CC
:109660005B000000F51101003D2002000000000039
:10967000DD100100D91201000000000049140100B2
:10968000DD11010000000000F71F020000000000D3
:1096900000000000F8950200C87402005F0000009E
:1096A000F5110100E514010000000000DD100100CB
:1096B000D91201000000000049140100DD11010071
:1096C00000000000F71F0200000000000000000082
:1096D000F89502004E05000008960200760500008D
:1096E00014960200272202006D2102008721020049
:1096F000A1210200FF210200252102003D210200DC
:1097000055210200BB210200C5210200CF21020029
:10971000E7210200B004000000F00400600900002E
:1097200000D00900C012000000B013008025000026
:10973000005027004038000000003B00004B0000B4
:1097400000A04E008070000000F07500127A00004A
:10975000000080000096000000509D0000E1000025
:1097600000F0EB00002C010000903A0100C2010063
:1097700000E0D7010084030000B0AF0390D00300E5
:10978000000000040008070000705F0700100E00D2
:10979000A4DFBE0E40420F0000000010311D01008A
:1097A000410600008D1D0100B51D01007906000075
:1097B0009C970200CC280020D4300000000000005C
:1097C000A86100002000000050C30000400000001D
:1097D000A086010060000000400D03008000000032
:1097E000801A06008800000000350C009000000080
:1097F000006A1800B000000000D43000D000000063
:1098000000A86100F00000000050C300F800000054
:10981000FFFF000000000000E20400000000000064
:10982000C4090000080000008813000010000000B8
:109830001027000018000000204E0000200000004B
:109840008038010028000000007102003000000094
:1098500000C4090038000000FFFF01000100000003
:10986000ACC52737DE214538DE21C5386E154439B1
:10987000A69BC439A69B443AA69BC43AA69B443BEC
:109880000100000000700040040000000200000021
:10989000007000400800000003000000007000405D
:1098A00010000000040000000070004020000000D4
:1098B00005000000007000404000000006000000AD
:1098C0000070004080000000FF000000FFFFFFFF6D
:1098D0000000000000000000000000000100000087
:1098E0000100000000000000010000000200000074
:1098F0000000000001000000030000000000000064
:109900000100000004000000000000000100000051
:10991000050000000000000001000000060000003B
:10992000000000000100000007000000000000002F
:10993000010000000800000000000000010000001D
:109940000900000000000000010000000A00000003
:1099500000000000010000000B00000000000000FB
:10996000010000000C0000000000000001000000E9
:109970000D00000000000000010000000E000000CB
:1099800000000000010000000F00000000000000C7
:1099900001000000100000000000000001000000B5
:1099A0001100000000000000010000001200000093
:1099B0000000000001000000130000000000000093
:1099C0000100000014000000000000000100000081
:1099D000150000000000000001000000160000005B
:1099E000000000000100000017000000000000005F
:1099F000010000001800000000000000010000004D
:109A00001900000000000000010000001C00000020
:109A100000000000010000001D0000000000000028
:109A2000010000001E000000000000000100000016
:109A3000FF000000FFFFFFFF00000000945701003F
:109A40004657010074570100CE56010074570100BB
:109A50006A57010074570100CE56010046570100B5
:109A6000465701006A570100CE560100C656010054
:109A7000C6560100C65601007A570100385B010046
:109A8000325B0100325B0100285B0100885A010053
:109A9000885A01001E5B0100285B0100885A010002
:109AA0001E5B0100885A0100285B0100865A0100F4
:109AB000865A0100865A0100C05B0100146901004A
:109AC000B0680100F8680100DE670100F868010075
:109AD000EC680100F8680100DE670100B068010071
:109AE000B0680100EC680100DE670100D467010086
:109AF000D4670100D4670100386B0100586F010082
:109B00004671010046710100386F0100226E0100AC
:109B1000226E01002A6F0100386F0100226E0100E1
:109B20002A6F0100226E0100386F0100206E0100D3
:109B3000206E0100206E01004E7101006937AC31CA
:109B400068212233B40F14336821A2333863ED3E09
:109B5000DA0F493F5E987B3FDA0FC93F61636F734D
:109B6000660000006173696E6600000065787066CB
:109B700000000000666D6F64660000006C6F676631
:109B800000000000706F776600000000737172744F
:109B9000660000000000003F000000BFD1F717374B
:109BA000D1F717B78071313F807131BF00000000DD
:109BB000000000800000000000C0153F0000000011
:109BC000DCCFD1350000803F0000C03F000FC93F0F
:109BD000000F494000CB9640000FC9400053FB40A6
:109BE00000CB164100ED2F41000F49410031624189
:109BF00000537B41003A8A4100CB9641005CA3416F
:109C000000EDAF41007EBC41000FC94100A0D5412D
:109C10000031E24100C2EE410053FB4100F2034239
:109C2000003A0A420083104200CB164200141D4243
:109C3000005C234200A5294200ED2F420036364247
:109C4000007E3C4200C74242000F4942A200000091
:109C5000F9000000830000006E0000004E000000CC
:109C6000440000001500000029000000FC00000076
:109C70002700000057000000D1000000F5000000A0
:109C800034000000DD000000C0000000DB00000028
:109C90006200000095000000990000003C000000F8
:109CA000430000009000000041000000FE000000A2
:109CB0005100000063000000AB000000DE00000067
:109CC000BB000000C500000061000000B7000000FC
:109CD000240000006E0000003A0000004200000076
:109CE0004D000000D2000000E0000000060000006F
:109CF000490000002E000000EA00000009000000FA
:109D0000D1000000920000001C000000FE000000D6
:109D10001D000000EB0000001C000000B10000006E
:109D200029000000A70000003E000000E80000003D
:109D30008200000035000000F50000002E00000049
:109D4000BB0000004400000084000000E9000000A7
:109D50009C0000007000000026000000B40000001D
:109D60005F0000007E00000041000000390000009C
:109D700091000000D60000003900000083000000C0
:109D80005300000039000000F40000009C000000B7
:109D9000840000005F0000008B000000BD00000098
:109DA000F9000000280000003B0000001F00000038
:109DB000F800000097000000FF000000DE00000037
:109DC00005000000980000000F000000EF000000F8
:109DD0002F000000110000008B0000005A0000005E
:109DE0000A0000006D0000001F0000006D00000070
:109DF000360000007E000000CF00000027000000B9
:109E0000CB00000009000000B70000004F00000078
:109E1000460000003F000000660000009E000000B9
:109E20005F000000EA0000002D0000007500000047
:109E300027000000BA000000C7000000EB0000008F
:109E4000E5000000F10000007B0000003D00000084
:109E50000700000039000000F70000008A00000041
:109E60005200000092000000EA0000006B000000B9
:109E7000FB0000005F000000B10000001F000000B8
:109E80008D0000005D00000008000000560000008A
:109E9000030000003000000046000000FC0000004D
:109EA0007B0000006B000000AB000000F000000031
:109EB000CF000000BC000000200000009A0000005D
:109EC000F4000000360000001D000000A9000000A2
:109ED000E300000091000000610000005E0000004F
:109EE000E60000001B000000080000006500000004
:109EF00099000000850000005F00000014000000D1
:109F0000A000000068000000400000008D0000007C
:109F1000FF000000D8000000800000004D0000009D
:109F20007300000027000000310000000600000060
:109F3000060000001500000056000000CA000000E6
:109F400073000000A8000000C900000060000000CD
:109F5000E20000007B000000C00000008C00000058
:109F60006B00000004000000070000000900000072
:109F70000000C93F0000F0390000DA370000A233CA
:109F80000000842E0000502B0000C2270000D022C9
:109F90000000C41F0000C61B0000441700000000A2
:109FA00000000000000000000000000000000000B1
:109FB00000000000000000000000000000000000A1
:109FC0000000000000000000000000000000000091
:109FD0000000000000000000000000000000000081
:109FE0000000000000000000000000000000000071
:109FF0000000000000000000000000005C000020E5
:10A00000480403004B0403004E04030010233210E5
:10A010000810113032123320342014331520481028
:10A02000091299200A2089338A20481073143110AC
:10A03000331035103410472620105B20491058206B
:10A0400048305330783285202B21141042222510BD
:10A0500043207F23461094304710972248109830B1
:10A060001F22252020300822072009201B1246200D
:10A070001C20576212106B205531562048107C234B
:10A0800042107D3043100422932005308D128E2023
:10A090008F208E2249105B308F225B20903041222E
:10A0A0001F1043208022812082303F313C20481005
:10A0B0003E333B204810A42320105E20A230A5226E
:10A0C0002E10A630172231101A30492419105B20A7
:10A0D0004910582088224A1008102D222A10933047
:10A0E000023203201C221D2005102A152B202C20B3
:10A0F0002D202F202E20403108104A109E22321091
:10A100005B204C242B10491058204D2060A42410B3
:10A11000143049105E2076132F1030103D10386334
:10A1200042103E20431031621E105B2062316320DA
:10A1300011107D12A5208020A3A51D1091202210B2
:10A140006120A230282218109120371331103820B6
:10A150003E2050225B203D309D2231105B200121AA
:10A16000023023624D10242034241E10352021108B
:10A1700037204D124E2052200E630810113012303D
:10A1800043310810481085138620872088204B27EC
:10A190001D109120221093204910582053309C13F9
:10A1A0009D209E209F202533262048108623421084
:10A1B0009B3043102012212022209612A3209720AA
:10A1C0006D316E203A107E2344108030451082128B
:10A1D000A320832072317420732095235B204910C3
:10A1E0005B2012624D105B20752276207420942231
:10A1F0009520963051324F208723441089204510F6
:10A200005924051006105A20071081126A205B207D
:10A2100039323A2092126A206B202E21A5208A1210
:10A220008C208B2099A5151008109A3049105820C1
:10A230000B625A105B209F225B20A0306822231003
:10A2400069304832492005210510182232100810C3
:10A2500006244C1040208630051035124020362050
:10A26000A212A320A4204F241B10503049105820C4
:10A270005D24201061201A105B2070317220712043
:10A28000906249105B3065316B2066205E12602061
:10A2900061202F2229103030692126106A223110C6
:10A2A0006B202921281007320620271C4E104F1042
:10A2B000501051105310541055105610581057107C
:10A2C0005910521054242D10552049105820913304
:10A2D000922048103B2208103D30741275207720E0
:10A2E0000AA81710081042100C3043100B30491008
:10A2F000582015131620172018200C330D20481055
:10A3000093335B2048103622392040307B120B10EB
:10A310000C1067222610221013220810113063122D
:10A320006420652077237A20783079305B125F20B3
:10A330005C201662081019306E3170206F202612D2
:10A340006A205B202C211610456248105B200D13FB
:10A350000E200F2010206F12371039106C316D2035
:10A360003C108B225B208C308C2249108D303322A4
:10A3700021103F2071122F1030101A6108109833ED
:10A3800095204810A7221E105B206B316C203B10DB
:10A39000223223200F223110133061316220271026
:10A3A0003A124A100D10461847204A204B204C20E4
:10A3B00054200A2099200820001305101C20462054
:10A3C000792232107420031205101B2058125920D4
:10A3D0001C2056225B2057302412A5202520642201
:10A3E00026106320442313105B2045305FA4241003
:10A3F000143049105B20A612A72093205A321B204C
:10A4000030225B20313019624D105B209A6342107C
:10A410009B3043104E235120533052301E182820B9
:10A4200029202A2032204120422044201F207A1C4B
:10A43000081009100A100B100C100D100F1010103E
:10A440000E107C207E207F201D331E204B105C22AE
:10A4500061205D308362481084308433812048104D
:10A460003D62121008103C2240203D30116249101C
:10A470005B20A012A320A120A1624D105B2053639A
:10A480001A10491058209B339C204810661936102A
:10A49000381040103E103F104110221067206820F5
:10A4A0004A252C105B2049105820533052631C1051
:10A4B0004910582021222720242000686C64720053
:10A4C000000000786C647262000000886C6472683E
:10A4D0000000006073747200000000707374726298
:10A4E00000000080737472680000E108E907EE0E56
:10A4F0004D0DDA0B2F0BF70961080000180E8E0CBA
:10A5000000008F0A68090000230020003D0073004E
:10A51000DB00A1011703DC0520090A0D0B0C006309
:10A52000616E277420636F6E7665727420272573C1
:10A5300027206F626A65637420746F2073747220C1
:10A54000696D706C696369746C79005C2563005C8B
:10A550005C005C6E005C72005C74005C78253032DC
:10A560007800737562737472696E67206E6F742001
:10A57000666F756E64006A6F696E206578706563DA
:10A5800074732061206C697374206F662073747219
:10A590002F6279746573206F626A656374732063D8
:10A5A0006F6E73697374656E742077697468207355
:10A5B000656C66206F626A6563740073746172749F
:10A5C0002F656E6420696E646963657300656D70E4
:10A5D000747920736570617261746F72006F6E6C54
:10A5E0007920736C6963657320776974682073746C
:10A5F00065703D312028616B61204E6F6E652920AA
:10A6000061726520737570706F7274656400777223
:10A610006F6E67206E756D626572206F6620617265
:10A6200067756D656E747300696E636F6D706C65D0
:10A63000746520666F726D617400696E636F6D7012
:10A640006C65746520666F726D6174206B6579004E
:10A650006E6F7420656E6F75676820617267756DC7
:10A66000656E747320666F7220666F726D61742000
:10A67000737472696E670025256320726571756950
:10A6800072657320696E74206F7220636861720056
:10A69000696E74656765722072657175697265644B
:10A6A00000756E737570706F7274656420666F727A
:10A6B0006D6174206368617261637465722027251F
:10A6C00063272028307825782920617420696E64FA
:10A6D0006578202564006E6F7420616C6C20617257
:10A6E00067756D656E747320636F6E7665727465E1
:10A6F0006420647572696E6720737472696E672076
:10A70000666F726D617474696E670073696E676CF1
:10A710006520277D2720656E636F756E7465726591
:10A720006420696E20666F726D6174207374726943
:10A730006E670062616420636F6E76657273696F25
:10A740006E2073706563696669657200756E6D6110
:10A75000746368656420277B2720696E20666F72AA
:10A760006D617400657870656374656420273A27AD
:10A7700020616674657220666F726D6174207370FB
:10A78000656369666965720063616E27742073771B
:10A79000697463682066726F6D206175746F6D6196
:10A7A000746963206669656C64206E756D6265729C
:10A7B000696E6720746F206D616E75616C206669CB
:10A7C000656C642073706563696669636174696F41
:10A7D0006E007475706C6520696E646578206F75A5
:10A7E00074206F662072616E6765006174747269AF
:10A7F0006275746573206E6F7420737570706F72FC
:10A80000746564207965740063616E2774207377C2
:10A81000697463682066726F6D206D616E75616C1E
:10A82000206669656C64207370656369666963613D
:10A8300074696F6E20746F206175746F6D617469D7
:10A8400063206669656C64206E756D626572696E01
:10A8500067003C3E3D5E006263646545664667474F
:10A860006E6F7378582500696E76616C6964206636
:10A870006F726D61742073706563696669657200DB
:10A880007369676E206E6F7420616C6C6F7765649E
:10A8900020696E20737472696E6720666F726D61D5
:10A8A0007420737065636966696572007369676EA9
:10A8B000206E6F7420616C6C6F77656420776974AB
:10A8C0006820696E746567657220666F726D617469
:10A8D0002073706563696669657220276327007558
:10A8E0006E6B6E6F776E20666F726D617420636F32
:10A8F0006465202725632720666F72206F626A6572
:10A900006374206F66207479706520272573270093
:10A91000756E6B6E6F776E20666F726D61742063FB
:10A920006F6465202725632720666F72206F626A37
:10A93000656374206F6620747970652027666C6F7C
:10A9400061742700273D2720616C69676E6D656E15
:10A9500074206E6F7420616C6C6F77656420696E13
:10A9600020737472696E6720666F726D61742073F4
:10A97000706563696669657200756E6B6E6F776E80
:10A9800020666F726D617420636F64652027256394
:10A990002720666F72206F626A656374206F66207D
:10A9A00074797065202773747227007273706C69F4
:10A9B00074284E6F6E652C6E29007768696C65008F
:10A9C000666F7200747279000A25730066756E6393
:10A9D00074696F6E2074616B657320256420706FDD
:10A9E000736974696F6E616C20617267756D656EF5
:10A9F0007473206275742025642077657265206702
:10AA00006976656E0066756E6374696F6E20676F38
:10AA100074206D756C7469706C652076616C7565F9
:10AA20007320666F7220617267756D656E74202782
:10AA30002571270066756E6374696F6E20646F659B
:10AA400073206E6F742074616B65206B6579776F0E
:10AA5000726420617267756D656E74730066756EE1
:10AA60006374696F6E206D697373696E67207265B8
:10AA700071756972656420706F736974696F6E6156
:10AA80006C20617267756D656E74202325640066A5
:10AA9000756E6374696F6E206D697373696E67207C
:10AAA0007265717569726564206B6579776F726420
:10AAB00020617267756D656E7420272571270066A9
:10AAC000756E6374696F6E206D697373696E67204C
:10AAD0006B6579776F72642D6F6E6C792061726728
:10AAE000756D656E74001213141615170F0D0E1187
:10AAF00010696E6C696E6520617373656D626C655B
:10AB000072206D75737420626520612066756E63B6
:10AB100074696F6E00657870656374696E67206133
:10AB20006E20617373656D626C657220696E7374FB
:10AB300072756374696F6E00276C6162656C2720A3
:10AB40007265717569726573203120617267756D08
:10AB5000656E74006C6162656C207265646566691F
:10AB60006E65640027616C69676E27207265717578
:10AB700069726573203120617267756D656E74004E
:10AB8000276461746127207265717569726573202D
:10AB90006174206C65617374203220617267756D19
:10ABA000656E747300276461746127207265717526
:10ABB0006972657320696E7465676572206172677A
:10ABC000756D656E7473002A78206D7573742062DC
:10ABD000652061737369676E6D656E742074617250
:10ABE00067657400696E7465726E616C20636F6D69
:10ABF00070696C6572206572726F72006D756C742D
:10AC000069706C65202A7820696E206173736967AA
:10AC10006E6D656E740063616E2774206173736975
:10AC2000676E20746F206C69746572616C0063617B
:10AC30006E27742061737369676E20746F20657866
:10AC40007072657373696F6E00696C6C6567616CB7
:10AC50002065787072657373696F6E20666F7220FD
:10AC60006175676D656E7465642061737369676E85
:10AC70006D656E7400737570657228292063616C50
:10AC80006C2063616E6E6F742066696E64207365FC
:10AC90006C660063616E27742068617665206D754F
:10ACA0006C7469706C65202A780063616E2774206B
:10ACB00068617665206D756C7469706C65202A2AF0
:10ACC00078004C4853206F66206B6579776F72640B
:10ACD00020617267206D75737420626520616E203B
:10ACE0006964006E6F6E2D6B6579776F7264206199
:10ACF0007267206166746572206B6579776F726424
:10AD000020617267006E6F6E2D64656661756C748C
:10AD100020617267756D656E7420666F6C6C6F77FD
:10AD2000732064656661756C7420617267756D650A
:10AD30006E740064656661756C7420276578636560
:10AD400070743A27206D757374206265206C61738E
:10AD5000740063616E2774206465636C61726520A2
:10AD60006E6F6E6C6F63616C20696E206F757465B9
:10AD70007220636F6465006964656E7469666965F5
:10AD800072207265646566696E6564206173206E09
:10AD90006F6E6C6F63616C006E6F2062696E6469C8
:10ADA0006E6720666F72206E6F6E6C6F63616C20D1
:10ADB000666F756E64006964656E74696669657254
:10ADC000207265646566696E656420617320676CD6
:10ADD0006F62616C0027636F6E74696E7565272002
:10ADE0006F757473696465206C6F6F700027627291
:10ADF00065616B27206F757473696465206C6F6F74
:10AE0000700063616E27742064656C6574652065ED
:10AE1000787072657373696F6E006E616D65207214
:10AE2000657573656420666F7220617267756D6504
:10AE30006E74002772657475726E27206F75747357
:10AE40006964652066756E6374696F6E0027796941
:10AE5000656C6427206F7574736964652066756E10
:10AE60006374696F6E00657870656374696E6720DE
:10AE70006B65793A76616C756520666F72206469DE
:10AE80006374696F6E61727900696E76616C696472
:10AE9000206D6963726F707974686F6E206465638A
:10AEA0006F7261746F72000100000000000000000A
:10AEB0000000000000000000000000000000000092
:10AEC0000000000000000000000000000000000082
:10AED0000000000000000000000000000000000072
:10AEE000000000000000000000010000000000025F
:10AEF0000400000400000404080004000000000036
:10AF00000000000000000000000100080004000232
:10AF1000040000040000000008010101010101011A
:10AF20000101010101010101010101010101010111
:10AF30000101010101010101010101010101010101
:10AF400001010101010101010101010101010101F1
:10AF500001010101010101010101010101010101E1
:10AF600001020401010401010404080104010101BA
:10AF700001010101010101010101010101080104B7
:10AF800001020401010401010101080100000000A7
:10AF90000002040000040000040408000400000093
:10AFA0000000000000000000000000010008000494
:10AFB00000020400000400000000086C696E6520B7
:10AFC00025752000257120004D656D6F72794572E1
:10AFD000726F723A206C6578657220636F756C646D
:10AFE000206E6F7420616C6C6F63617465206D6599
:10AFF0006D6F727900736F6674207265626F6F7423
:10B000000D0A00726177205245504C3B2043545248
:10B010004C2D4220746F20657869740D0A004F4BE7
:10B0200000044D656D6F72794572726F720A04008B
:10B030004D6963726F507974686F6E2076312E356A
:10B040002D3135302D6734366463633830206F6EB0
:10B0500020323031352D31312D31373B206D696350
:10B06000726F3A6269742077697468206E5246354F
:10B07000313832320D0A0054797065202268656CCF
:10B080007028292220666F72206D6F726520696EAC
:10B09000666F726D6174696F6E2E0D0A003E3E3EE2
:10B0A00020000D0A7061737465206D6F64653B202C
:10B0B0004374726C2D4320746F2063616E63656C02
:10B0C0002C204374726C2D4420746F2066696E6965
:10B0D00073680D0A3D3D3D20002E2E2E2000636F2B
:10B0E000756C64206E6F74206F70656E2066696C7D
:10B0F00065202725732720666F7220726561646959
:10B100006E670A000000010102020202030303034A
:10B1100003030303040404040404040404040404F3
:10B120000404040405030000000000000000706136
:10B130007273657220636F756C64206E6F7420612A
:10B140006C6C6F6361746520656E6F756768206DE8
:10B15000656D6F727900756E65787065637465648E
:10B1600020696E64656E7400756E696E64656E74D8
:10B1700020646F6573206E6F74206D617463682046
:10B18000616E79206F7574657220696E64656E7486
:10B190006174696F6E206C6576656C0063616E6EBC
:10B1A0006F74206D697820627974657320616E64B4
:10B1B000206E6F6E6279746573206C69746572615C
:10B1C0006C7300696E76616C69642073796E74616A
:10B1D0007800252E2A73005C7525303478005C5584
:10B1E0002530387800737472696E6720696E6469FF
:10B1F000636573206D75737420626520696E746574
:10B20000676572732C206E6F7420257300737472DF
:10B21000696E6720696E646578206F7574206F664B
:10B220002072616E6765006469766973696F6E206C
:10B230006279207A65726F006F626A656374206E4E
:10B240006F7420696E2073657175656E6365006645
:10B25000756E6374696F6E206D697373696E6720B4
:10B26000256420726571756972656420706F7369F9
:10B2700074696F6E616C20617267756D656E747351
:10B280000066756E6374696F6E20657870656374AF
:10B290006564206174206D6F737420256420617271
:10B2A00067756D656E74732C20676F74202564005C
:10B2B0002725712720617267756D656E7420726530
:10B2C00071756972656400657874726120706F735E
:10B2D0006974696F6E616C20617267756D656E74FB
:10B2E0007320676976656E006578747261206B659E
:10B2F00079776F726420617267756D656E74732003
:10B30000676976656E0063616E277420636F6E7681
:10B3100065727420696E6620746F20696E740063B4
:10B32000616E277420636F6E76657274204E614E75
:10B3300020746F20696E74006F766572666C6F772B
:10B3400020636F6E76657274696E67206C6F6E67CE
:10B3500020696E7420746F206D616368696E65206A
:10B36000776F7264006E65676174697665207368D3
:10B3700069667420636F756E74003C6D6F64756CE4
:10B380006520272571273E0004656F72086C736C79
:10B390000C6C73721061737214616463187362636E
:10B3A0001C726F7220747374246E656728636D70ED
:10B3B0002C636D6E306F7272346D756C38626963B8
:10B3C0003C6D766E006571016E65026373036363A5
:10B3D000046D6905706C0676730776630868690901
:10B3E0006C730A67650B6C740C67740D6C652725AC
:10B3F00073272065787065637473206174206D6FA6
:10B400007374207225640027257327206578706582
:10B4100063747320612072656769737465720027B5
:10B420002573272065787065637473207B72302CD8
:10B430002072312C202E2E2E7D002725732720658B
:10B4400078706563747320616E20696E74656765DA
:10B4500072002725732720696E7465676572203036
:10B4600078257820646F6573206E6F742066697428
:10B4700020696E206D61736B203078257800272558
:10B48000732720657870656374732061206C616236
:10B49000656C006C6162656C2027257127206E6FDA
:10B4A0007420646566696E65640063616E206F6E0A
:10B4B0006C79206861766520757020746F20342067
:10B4C000706172616D657465727320746F20546869
:10B4D000756D6220617373656D626C790070617265
:10B4E000616D6574657273206D757374206265207B
:10B4F00072656769737465727320696E2073657114
:10B5000075656E636520723020746F207233006E33
:10B510006F700077666900756E737570706F727406
:10B520006564205468756D6220696E73747275630A
:10B5300074696F6E2027257327207769746820252A
:10B540006420617267756D656E747300626C006271
:10B550007800637073696400637073696500707567
:10B560007368006D6F7600616E645F00636D7000DC
:10B57000737562002725732720657870656374737F
:10B5800020616E2061646472657373206F6620743D
:10B59000686520666F726D205B612C20625D006CB7
:10B5A000736C006C737200617372006272616E631F
:10B5B00068206E6F7420696E2072616E676500008E
:10B5C00072300001723100027232000372330004E3
:10B5D00072340005723500067236000772370008B3
:10B5E000723800097239000A7231300B7231310C35
:10B5F0007231320D7231330E7231340F7231350ABD
:10B60000736C000B6670000D7370000E6C72000F8F
:10B610007063002C200025713D004D6963726F50EE
:10B620007974686F6E206F6E20746865206D696331
:10B63000726F3A6269742069732062726F7567680D
:10B640007420746F20796F752062793A0A44616DB5
:10B6500069656E20502E2047656F7267652C204DFE
:10B6600061747468657720456C73652C2041626253
:10B6700069652042726F6F6B7320616E64204E6942
:10B6800063686F6C617320482E20546F6C6C657218
:10B690007665792E0A00546865205A656E206F66BB
:10B6A000204D6963726F507974686F6E2C206279D7
:10B6B000204E6963686F6C617320482E546F6C6C08
:10B6C00065727665790A0A436F64652C0A4861637E
:10B6D0006B2069742C0A4C657373206973206D6F3D
:10B6E00072652C0A4B6565702069742073696D70F2
:10B6F0006C652C0A536D616C6C2069732062656106
:10B7000075746966756C2C0A0A42652062726176EE
:10B71000652120427265616B207468696E677321D0
:10B72000204C6561726E20616E64206861766520D0
:10B7300066756E210A4578707265737320796F752E
:10B740007273656C662077697468204D6963726FE7
:10B75000507974686F6E2E0A0A486170707920689B
:10B7600061636B696E6721203A2D290A00706F7042
:10B770002066726F6D20656D707479206C697374CA
:10B78000006E6F206D6F64756C65206E616D656411
:10B7900020272573270063616E6E6F7420706572B9
:10B7A000666F726D2072656C617469766520696D73
:10B7B000706F7274006E6F206D6F64756C65206EB3
:10B7C000616D65642027257127005F5F696E69746C
:10B7D0005F5F2E7079005468697320696D616765D9
:10B7E0002063616E6E6F74206265206D6F646966A0
:10B7F0006965642E2054727920636F7079696E6771
:10B800002069742066697273742E00696E646578AD
:10B810002063616E6E6F74206265206E656761746F
:10B82000697665006272696768746E657373206F0C
:10B830007574206F6620626F756E64732E00696E7A
:10B8400064657820746F6F206C6172676500496D64
:10B8500061676528000A2020202000270A20202078
:10B860002027003031323334353637383900556EC1
:10B870006578706563746564206368617261637480
:10B88000657220696E20496D61676520646566692F
:10B890006E6974696F6E2E00696D61676520646101
:10B8A000746120697320696E636F727265637420BE
:10B8B00073697A6500496D61676528292074616B39
:10B8C0006573203020746F203320617267756D6559
:10B8D0006E747300496D6167652873292074616B0C
:10B8E0006573206120737472696E672E00427269FD
:10B8F0006768746E657373206D756C7469706C69BC
:10B900006572206D757374206E6F74206265206E91
:10B91000656761746976652E00496D61676573209E
:10B920006D757374206265207468652073616D6540
:10B930002073697A652E006C6F63616C207661728A
:10B940006961626C65207265666572656E636564C7
:10B95000206265666F72652061737369676E6D65DD
:10B960006E74006279746520636F6465206E6F7415
:10B9700020696D706C656D656E746564004E6F2036
:10B9800061637469766520657863657074696F6E4C
:10B9900020746F20726572616973650073746163EE
:10B9A0006B3A202575206F7574206F662025640A18
:10B9B000007173747220706F6F6C3A206E5F706FDD
:10B9C0006F6C3D25752C206E5F717374723D25750B
:10B9D0002C206E5F7374725F646174615F6279744E
:10B9E00065733D25752C206E5F746F74616C5F62AA
:10B9F000797465733D25750A003C67656E657261F3
:10BA0000746F72206F626A65637420272571272026
:10BA100061742025703E0063616E27742073656E2B
:10BA200064206E6F6E2D4E6F6E652076616C75654D
:10BA300020746F2061206A7573742D737461727441
:10BA400065642067656E657261746F720067656E0C
:10BA5000657261746F722069676E6F7265642047EA
:10BA6000656E657261746F7245786974003C636CD1
:10BA700061737320272571273E003C2573206F6278
:10BA80006A6563742061742025703E003C73757094
:10BA900065723A200063616E6E6F74206372656137
:10BAA0007465202725712720696E7374616E636544
:10BAB00073005F5F696E69745F5F28292073686F28
:10BAC000756C642072657475726E204E6F6E652C95
:10BAD000206E6F7420272573270027257327206F7A
:10BAE000626A656374206973206E6F742063616C91
:10BAF0006C61626C65007479706520272571272060
:10BB00006973206E6F7420616E2061636365707469
:10BB100061626C6520626173652074797065006D87
:10BB2000756C7469706C65206261736573206861FF
:10BB3000766520696E7374616E6365206C61792D22
:10BB40006F757420636F6E666C69637400747970CE
:10BB5000652074616B65732031206F722033206122
:10BB60007267756D656E7473006973737562636C6B
:10BB70006173732829206172672032206D75737498
:10BB8000206265206120636C617373206F72206195
:10BB9000207475706C65206F6620636C61737365CB
:10BBA00073006973737562636C6173732829206114
:10BBB00072672031206D7573742062652061206387
:10BBC0006C617373000000010102020202030303AF
:10BBD000030303030304040404040404040404042A
:10BBE0000404040404056269676E756D20616E6467
:10BBF0002077697468206E65676174697665206175
:10BC0000726773006269676E756D206F7220776965
:10BC10007468206E65676174697665206172677308
:10BC2000006269676E756D20786F7220776974683D
:10BC3000206E65676174697665206172677300764E
:10BC4000616C7565206D7573742062652030206F9E
:10BC50007220310076616C7565206D757374206299
:10BC600065206265747765656E203020616E6420A2
:10BC70003130323300657870656374696E672061B6
:10BC80002070696E004932432072656164206661EC
:10BC9000696C65642077697468206572726F7220C0
:10BCA000636F6465202564004932432077726974AC
:10BCB00065206661696C65642077697468206572C7
:10BCC000726F7220636F6465202564006E616D651C
:10BCD0002027257127206973206E6F7420646566A4
:10BCE000696E656400756E737570706F72746564EB
:10BCF000207479706520666F722025713A2027259F
:10BD0000732700617267756D656E742068617320BA
:10BD100077726F6E67207479706500747970652032
:10BD20006F626A656374202725712720686173201C
:10BD30006E6F206174747269627574652027257155
:10BD4000270027257327206F626A65637420686166
:10BD500073206E6F20617474726962757465202738
:10BD60002571270027257327206F626A6563742079
:10BD70006973206E6F74206974657261626C65000E
:10BD800027257327206F626A656374206973206EAC
:10BD90006F7420616E206974657261746F720075D2
:10BDA0006E737570706F72746564207479706573EA
:10BDB00020666F722025713A20272573272C2027B3
:10BDC000257327006E656564206D6F726520746849
:10BDD000616E2025642076616C75657320746F2018
:10BDE000756E7061636B00746F6F206D616E79208A
:10BDF00076616C75657320746F20756E7061636B0E
:10BE00002028657870656374656420256429006561
:10BE10007863657074696F6E73206D7573742064D8
:10BE200065726976652066726F6D20426173654543
:10BE30007863657074696F6E0063616E6E6F7420F5
:10BE4000696D706F7274206E616D65202571006D73
:10BE5000656D6F727920616C6C6F636174696F6E70
:10BE6000206661696C65642C206865617020697367
:10BE7000206C6F636B6564006D656D6F7279206116
:10BE80006C6C6F636174696F6E206661696C656468
:10BE90002C20616C6C6F636174696E67202575205E
:10BEA0006279746573000000000000000000000368
:10BEB0000303030300000000000000000000000076
:10BEC0000000000000000301010101010101010166
:10BED00001010101010145454545454545454545AA
:10BEE00001010101010101595959595959191919EA
:10BEF00019191919191919191919191919191919B2
:10BF00001901010101010169696969696929292921
:10BF10002929292929292929292929292929292991
:10BF2000290101010100736C6963652800332E3417
:10BF30002E30004F7065726174696F6E206E6F7481
:10BF400020737570706F72746564006F7574206F04
:10BF500066206D656D6F7279004F7574206F662075
:10BF60006D656D6F727900657870656374696E6771
:10BF700020616E20696D616765206F72206120739A
:10BF80007472696E672E00696E646578206F7574CF
:10BF9000206F6620626F756E64732E0000000402CD
:10BFA000020402000002040404000202000404036C
:10BFB0000100000103030300010102030304020165
:10BFC0000103010403010003000004010102000059
:10BFD0000302285B005D2900257128007B003C7668
:10BFE000616C75653E00706F706974656D28293AE3
:10BFF0002064696374696F6E61727920697320656A
:10C000006D7074790064696374696F6E6172792010
:10C010007570646174652073657175656E63652004
:10C02000686173207468652077726F6E67206C6535
:10C030006E67746800646963745F6974656D73002A
:10C04000646963745F6B65797300646963745F76B8
:10C05000616C75657300696E7428292061726720B0
:10C0600032206D757374206265203E3D2032206160
:10C070006E64203C3D20333600696E76616C6964E5
:10C080002073796E74617820666F7220696E7465B2
:10C090006765722077697468206261736520256422
:10C0A00000636F6D706C65782076616C75657320C8
:10C0B0006E6F7420737570706F7274656400696E52
:10C0C00076616C69642073796E74617820666F7232
:10C0D000206E756D62657200000000050000512839
:10C0E0002573290A008F012A00FA015F00420F5FC1
:10C0F0005F6275696C645F636C6173735F5F002B73
:10C10000095F5F636C6173735F5F002D075F5F643E
:10C110006F635F5F00380A5F5F696D706F72745F95
:10C120005F005F085F5F696E69745F5F0079075F3A
:10C130005F6E65775F5F007B0A5F5F6C6F63616C4A
:10C14000735F5F008E085F5F6D61696E5F5F00FF08
:10C150000A5F5F6D6F64756C655F5F00E2085F5F2B
:10C160006E616D655F5F00F7085F5F686173685FB0
:10C170005F0002085F5F6E6578745F5F006B0C5F45
:10C180005F7175616C6E616D655F5F00C8085F5FB0
:10C19000706174685F5F00010E5F5F7265706C5F55
:10C1A0007072696E745F5F002B085F5F626F6F6C07
:10C1B0005F5F00C60C5F5F636F6E7461696E735F73
:10C1C0005F006D095F5F656E7465725F5F004508B3
:10C1D0005F5F657869745F5F00E2075F5F6C656E43
:10C1E0005F5F00CF085F5F697465725F5F00260B59
:10C1F0005F5F6765746974656D5F5F00320B5F5FD9
:10C200007365746974656D5F5F00FD0B5F5F6465E6
:10C210006C6974656D5F5F00C4075F5F6164645F34
:10C220005F0021075F5F7375625F5F0010085F5FEB
:10C23000726570725F5F00D0075F5F7374725F5FDB
:10C2400000400B5F5F676574617474725F5F0068C4
:10C25000075F5F64656C5F5F00A7085F5F63616C89
:10C260006C5F5F005D065F5F6C745F5F00B6065FCA
:10C270005F67745F5F0071065F5F65715F5F00CC31
:10C28000065F5F6C655F5F00A7065F5F67655F5F66
:10C2900000610C5F5F72657665727365645F5F0055
:10C2A0000B0B6D6963726F707974686F6E00220892
:10C2B00062797465636F646500C005636F6E737443
:10C2C00000430961736D5F7468756D620043056CAE
:10C2D0006162656C00A805616C69676E0015046495
:10C2E00061746100F7086275696C74696E7300F0BF
:10C2F00008456C6C697073697300EA0D53746F7054
:10C30000497465726174696F6E00070D42617365EF
:10C31000457863657074696F6E002D0F41726974A2
:10C32000686D657469634572726F7200970E417330
:10C3300073657274696F6E4572726F7200210E417F
:10C3400074747269627574654572726F72001D0B48
:10C350004275666665724572726F72009108454F4C
:10C36000464572726F7200F20945786365707469B0
:10C370006F6E005B0F46696C654578697374734531
:10C3800072726F7200781146696C654E6F74466FF9
:10C39000756E644572726F72000112466C6F617443
:10C3A000696E67506F696E744572726F7200160D18
:10C3B00047656E657261746F724578697400200B11
:10C3C000496D706F72744572726F72005C10496EC5
:10C3D00064656E746174696F6E4572726F7200830A
:10C3E0000A496E6465784572726F7200AF114B65D1
:10C3F00079626F617264496E7465727275707400EF
:10C40000EA084B65794572726F7200FF0B4C6F6FD3
:10C410006B75704572726F7200DC0B4D656D6F72DB
:10C42000794572726F7200BA094E616D654572721C
:10C430006F7200C6134E6F74496D706C656D656EDA
:10C440007465644572726F7200A1074F5345727232
:10C450006F7200810D4F766572666C6F77457272F0
:10C460006F7200610C52756E74696D654572726F02
:10C470007200940B53796E7461784572726F72001A
:10C48000200A53797374656D4578697400250954E1
:10C490007970654572726F72009911556E626F7591
:10C4A0006E644C6F63616C4572726F7200960A56CF
:10C4B000616C75654572726F7200B6115A65726F64
:10C4C0004469766973696F6E4572726F7200220CEF
:10C4D000556E69636F64654572726F72006F044ECA
:10C4E0006F6E6500380546616C7365001304547205
:10C4F00075650090066F626A6563740017084E6F79
:10C500006E655479706500F00B4F726465726564F6
:10C5100044696374009503616273004403616C6C49
:10C52000001303616E7900C20461726773007C05B9
:10C53000617272617900E00362696E0058057B3AAE
:10C5400023627D00EB04626F6F6C00760962797480
:10C55000656172726179005C056279746573000DC2
:10C560000863616C6C61626C6500DC036368720077
:10C57000B40B636C6173736D6574686F64003F0C1A
:10C580005F636F6C6C656374696F6E73003F046406
:10C5900069637400FA0364697200B8066469766DB1
:10C5A0006F64007109656E756D6572617465009BDD
:10C5B000046576616C001E04657865630025066677
:10C5C000696C746572003505666C6F617400350ABC
:10C5D00066726F6D5F627974657300C0076765741A
:10C5E0006174747200D40773657461747472009D11
:10C5F00007676C6F62616C73008C076861736174AC
:10C60000747200B70468617368007003686578002D
:10C610007B032523780028026964001603696E7481
:10C6200000B60A6973696E7374616E636500B50A5A
:10C630006973737562636C617373008F04697465E9
:10C64000720062036C656E0027046C697374003BB2
:10C65000066C6F63616C7300B9036D617000B103A8
:10C660006D617800AF036D696E001E0A6E616D65C5
:10C67000647475706C650042046E65787400FD0327
:10C680006F6374006C0325236F00D1046F70656EB7
:10C69000001C036F726400880470617468002D03CD
:10C6A000706F770054057072696E74001A057261BC
:10C6B0006E676500B7047265616400D004726570CE
:10C6C0007200A108726576657273656400E7057291
:10C6D0006F756E64005E06736F7274656400620C41
:10C6E0007374617469636D6574686F64002E03739D
:10C6F000756D00C4057375706572005003737472B4
:10C7000000BC0373797300D808746F5F6279746535
:10C710007300FD057475706C65009D047479706517
:10C72000004E0576616C75650098057772697465D1
:10C7300000E6037A6970002303736570000A0365DD
:10C740006E6400570473746570009D0473746F7099
:10C75000007C05636C65617200E004636F707900B2
:10C76000370866726F6D6B657973003303676574A4
:10C7700000E3056974656D730001046B65797300EE
:10C780002A03706F7000BF07706F706974656D0069
:10C790006C0A73657464656661756C7400B40675C3
:10C7A0007064617465007D0676616C756573006BFD
:10C7B00006617070656E64003305636C6F736500AD
:10C7C000B90473656E6400B3057468726F7700A670
:10C7D00005636F756E74006306657874656E64003A
:10C7E0007B05696E64657800630672656D6F7665BA
:10C7F000001206696E7365727400BF04736F727401
:10C8000000A7046A6F696E0029057374726970006D
:10C81000E5066C7374726970003B0672737472691A
:10C8200070002606666F726D61740032036B657965
:10C830000025077265766572736500440361646460
:10C8400000010466696E6400D2057266696E640058
:10C85000E90672696E64657800B70573706C697477
:10C8600000A5067273706C697400740A7374617247
:10C87000747377697468001B08656E6473776974F4
:10C88000680049077265706C6163650087097061B3
:10C8900072746974696F6E00150A727061727469DE
:10C8A00074696F6E00C6056C6F7765720027057539
:10C8B00070706572005B076973737061636500EB8C
:10C8C000076973616C70686100A8076973646967C0
:10C8D000697400DD076973757070657200FC076923
:10C8E000736C6F7765720025086974657261626C9C
:10C8F00065008505737461727400970C626F756EC4
:10C90000645F6D6574686F64007407636C6F737542
:10C910007265002D09646963745F76696577002725
:10C920000866756E6374696F6E00960967656E655B
:10C930007261746F720047086974657261746F7216
:10C9400000BF066D6F64756C6500B505736C696337
:10C95000650035046D61746800C00165001C0270DB
:10C96000690021047371727400C803657870002136
:10C97000036C6F67007A03636F7300B10373696EB2
:10C9800000FE0374616E001B0461636F730050044A
:10C990006173696E001F046174616E00CD0561747E
:10C9A000616E320006046365696C003308636F7062
:10C9B000797369676E0093046661627300E50466CB
:10C9C0006D6F64007D05666C6F6F7200A6086973F9
:10C9D00066696E697465003E056973696E66009EDE
:10C9E0000569736E616E005B057472756E63002578
:10C9F000046D6F6466001C05667265787000400502
:10CA00006C64657870000207646567726565730021
:10CA1000870772616469616E7300D1086D656D5F2F
:10CA2000696E666F00B009717374725F696E666FCC
:10CA30000073206D6178696D756D20726563757224
:10CA400073696F6E206465707468206578636565CE
:10CA500064656400BD083C6D6F64756C653E008064
:10CA6000083C6C616D6264613E00D40A3C6C697381
:10CA700074636F6D703E00CC0A3C64696374636FCD
:10CA80006D703E0054093C736574636F6D703E00B9
:10CA900034093C67656E657870723E0052083C73DD
:10CAA0007472696E673E00E3073C737464696E3E9E
:10CAB00000C70461726776006109627974656F72FC
:10CAC00064657200E90362696700850465786974CA
:10CAD0000089066C6974746C65003A08706C617446
:10CAE000666F726D002105737464696E00080673C9
:10CAF00074646F757400A30673746465727200BF0A
:10CB00000776657273696F6E006E0C766572736975
:10CB10006F6E5F696E666F00170E696D706C656D84
:10CB2000656E746174696F6E001C0F7072696E744B
:10CB30005F657863657074696F6E0047077573741D
:10CB40007275637400BC047061636B000706756ED8
:10CB50007061636B004D0863616C6373697A650093
:10CB600061026763009B07636F6C6C65637400917F
:10CB70000764697361626C65000406656E61626CCE
:10CB800065009A096973656E61626C656400CB0823
:10CB90006D656D5F667265650052096D656D5F61FB
:10CBA0006C6C6F6300940468656C7000E00B636FDD
:10CBB0006C6C656374696F6E7300120673747275C2
:10CBC000637400C0086D6963726F62697400100558
:10CBD000726573657400EA05736C65657000BE0666
:10CBE00072616E646F6D00C80C72756E6E696E67EF
:10CBF0005F74696D6500D00570616E696300A304A0
:10CC000074686973006307617574686F727300F10B
:10CC10000B616E7469677261766974790055046C92
:10CC20006F7665002C0862616461626F6F6D00CD84
:10CC3000124D6963726F4269744469676974616C0B
:10CC400050696E0007184D6963726F426974416ED6
:10CC5000616C6F674469676974616C50696E0052FA
:10CC6000104D6963726F426974546F7563685069DF
:10CC70006E00920C726561645F6469676974616CCF
:10CC800000FD0D77726974655F6469676974616C32
:10CC900000620B726561645F616E616C6F67002D8D
:10CCA0000C77726974655F616E616C6F6700081163
:10CCB0007365745F616E616C6F675F706572696FD9
:10CCC0006400EE1E7365745F616E616C6F675F7008
:10CCD0006572696F645F6D6963726F7365636F6EB0
:10CCE000647300040A69735F746F75636865640038
:10CCF000E60A4D6963726F426974494F000204701D
:10CD0000696E3000030470696E3100010470696E51
:10CD10003200010470696E3300060470696E3400DD
:10CD2000070470696E3500040470696E36000504EE
:10CD300070696E37000A0470696E38000B04706900
:10CD40006E3900530570696E313000520570696E9E
:10CD5000313100510570696E313200500570696ED5
:10CD6000313300570570696E313400560570696EB5
:10CD7000313500550570696E3136005A0570696E9F
:10CD8000313900300570696E323000870D4D6963AE
:10CD9000726F426974496D616765006205496D6132
:10CDA0006765004205696D61676500230577696401
:10CDB000746800FA0668656967687400B706696E8A
:10CDC0007665727400B0097365745F706978656C1C
:10CDD00000A4096765745F706978656C00A10A73C7
:10CDE000686966745F6C65667400BA0B736869661F
:10CDF000745F726967687400DF0873686966745FDE
:10CE0000757000480A73686966745F646F776E00B6
:10CE1000E2096D6F6E6F7370616365000F054845C1
:10CE200041525400CF0B48454152545F534D414C41
:10CE30004C0015054841505059009303534144009C
:10CE40009B05534D494C4500A608434F4E4655534C
:10CE50004544002605414E475259000B0641534CAC
:10CE60004545500088095355525052495345440096
:10CE7000C60553494C4C59003008464142554C4F69
:10CE800055530005034D4548000A03594553000416
:10CE9000024E4F006E07434C4F434B313200DC06CD
:10CEA000434C4F434B3100DF06434C4F434B320062
:10CEB000DE06434C4F434B3300D906434C4F434BA4
:10CEC0003400D806434C4F434B3500DB06434C4FF0
:10CED000434B3600DA06434C4F434B3700D50643ED
:10CEE0004C4F434B3800D406434C4F434B39006CF6
:10CEF00007434C4F434B3130006D07434C4F434B7E
:10CF0000313100ED074152524F575F4E00C8084182
:10CF100052524F575F4E4500E6074152524F575FFE
:10CF20004500B5084152524F575F534500F0074145
:10CF300052524F575F5300A7084152524F575F5309
:10CF40005700F4074152524F575F5700DA084152D9
:10CF5000524F575F4E5700EB08545249414E474CD1
:10CF600045008F0D545249414E474C455F4C454654
:10CF70005400510A4348455353424F41524400A183
:10CF8000074449414D4F4E4400610D4449414D4FC6
:10CF90004E445F534D414C4C008406535155415211
:10CFA0004500840C5351554152455F534D414C4C03
:10CFB00000EB06524142424954005E03434F570082
:10CFC000AB0E4D555349435F43524F54434845546C
:10CFD000006C0D4D555349435F51554156455253D1
:10CFE0000033095049544348464F524B00E204581D
:10CFF0004D41530055065041434D414E00B4065437
:10D00000415247455400F10A414C4C5F4152524F46
:10D01000575300C00A414C4C5F434C4F434B5300A5
:10D02000450654534849525400270B524F4C4C4527
:10D0300052534B415445003C044455434B00A10519
:10D04000484F55534500C808544F52544F49534513
:10D05000005609425554544552464C5900E90B5369
:10D060005449434B46494755524500C20547484F2E
:10D07000535400980553574F5244007D0747495277
:10D0800041464645004805534B554C4C00C9085590
:10D090004D4252454C4C41009705534E414B450083
:10D0A0005A0F4D6963726F426974446973706C61A1
:10D0B0007900910E7365745F6272696768746E655A
:10D0C0007373009E107365745F646973706C61792B
:10D0D0005F6D6F6465001F07646973706C61790030
:10D0E000860473686F770028067363726F6C6C0038
:10D0F000500564656C617900B80673747269646583
:10D10000008E04776169740039046C6F6F70003EA3
:10D1100007616E696D617465000B0463726F700066
:10D1200098047465787400F60B536C696365644900
:10D130006D61676500BD0F5363726F6C6C696E67DC
:10D14000537472696E6700160E4D6963726F42699F
:10D1500074427574746F6E00ED08627574746F6E4E
:10D160005F6100EE08627574746F6E5F6200E60ABC
:10D1700069735F7072657373656400F90B7761732F
:10D180005F7072657373656400FD0B6765745F7033
:10D19000726573736573009E0D72657365745F705D
:10D1A000726573736573005B154D6963726F4269D5
:10D1B00074416363656C65726F6D65746572001EA2
:10D1C0000D616363656C65726F6D657465720034C3
:10D1D000056765745F780035056765745F790036AB
:10D1E000056765745F7A00F40A6765745F76616C41
:10D1F00075657300100F4D6963726F426974436FF8
:10D200006D70617373005507636F6D7061737300A8
:10D210002D0768656164696E6700230D69735F633C
:10D22000616C6962726174656400020963616C69B2
:10D23000627261746500220E69735F63616C69627A
:10D24000726174696E67004911636C6561725F6336
:10D25000616C6962726174696F6E00B80B4D6963CD
:10D26000726F426974493243005D0369326300B6EC
:10D27000046164647200CB016E0074036275660021
:10D28000F2067265706561740004056D75736963FB
:10D2900000A1096672657175656E6379008305701A
:10D2A0006974636800F20370696E002104706C6138
:10D2B00079009B097365745F74656D706F008F09E9
:10D2C0006765745F74656D706F00DA0362706D007E
:10D2D00043057469636B73009F05424144445900E0
:10D2E0009D0742415F44494E4700FC084249525461
:10D2F0004844415900C805424C554553005905431F
:10D300004841534500FC0944414441444144554D82
:10D3100000480B454E5445525441494E4552004237
:10D320000746554E4552414C00D30446554E4B00DE
:10D33000AA094A554D505F444F574E00FD074A55C4
:10D340004D505F5550003D044E59414E006B034F08
:10D35000444500970A504F5745525F444F574E007F
:10D360000108504F5745525F5550003A07505245FB
:10D370004C55444500EB0950554E43484C494E45E9
:10D3800000B106505954484F4E00C70852494E4705
:10D39000544F4E4500640957415741574157414149
:10D3A00000170757454444494E4700C401610067D0
:10D3B000026123002C0461233A31002E0461233AD8
:10D3C000330076026132007002613400BB046134C4
:10D3D0003A3100B90461343A33000F03613A310045
:10D3E0000C03613A32000A03613A34000B03613ADC
:10D3F0003500C7016200DE0462323A3100940262F5
:10D4000033009302623400D80462343A3100DB0402
:10D4100062343A32009202623500D90462353A3100
:10D42000000C03623A31000F03623A3200C6016316
:10D4300000A502632300700363233500BB0563234B
:10D44000353A3100B8056323353A32006E04632360
:10D450003A3100670463233A3800FC0463323A32FD
:10D4600000B5026333007C0463333A33007B04630A
:10D47000333A3400B202633400F90463343A3100C1
:10D48000FB0463343A3300FC0463343A3400B302DF
:10D49000633500780463353A31007B0463353A32F2
:10D4A000007A0463353A33007D0463353A34000D65
:10D4B00003633A31000E03633A32000F03633A33D9
:10D4C000000803633A34000403633A3800C101647E
:10D4D00000C202642300FF056423353A32000A04C7
:10D4E00064233A32000B0464233A3300D2026433DB
:10D4F00000D5026434001E0464343A3100D402645E
:10D5000035001F0464353A31001C0464353A32009A
:10D510000A03643A31000903643A32000803643AAA
:10D5200033000F03643A34000E03643A35000D03F0
:10D53000643A36000303643A3800BA0465333A3378
:10D5400000F4026534003F0465343A3100F50265A9
:10D5500035003F0465363A33000B03653A31000865
:10D5600003653A32000903653A33000E03653A3425
:10D57000000F03653A35000C03653A360002036577
:10D580003A3800E00465623A3800C30166000102DF
:10D59000662300350366233500FD056623353A32E0
:10D5A000004B0466233A3100480466233A320042B5
:10D5B0000466233A380011026632000803663A31E5
:10D5C000000B03663A32000A03663A33000D036625
:10D5D0003A34000103663A3800C20167002102674D
:10D5E0002300EA0467233A3100E80467233A330052
:10D5F000FA0467333A310036026734007D04673439
:10D600003A31007E0467343A32003702673500FC55
:10D610000467353A31000903673A31000A03673A73
:10D6200032000B03673A33000103673A3800D70131
:10D630007200CB0472343A32001C03723A31001F7C
:10D6400003723A32001E03723A3300320C4D6963A2
:10D65000726F426974554152540077047561727457
:10D66000001F04696E697400F50862617564726177
:10D6700074650049046269747300420670617269DE
:10D68000747900410470696E730076077265616495
:10D69000616C6C00F908726561646C696E65004BC1
:10D6A0000872656164696E746F006A034F444400D8
:10D6B000DD044556454E002C00424344454647484C
:10D6C000494B4C3D363E3758383F39573150325927
:10D6D0002F4E304F5A3A543B553351345235533C08
:10D6E000564D404128295B5D7B7D2C3A3B407E3C7A
:10D6F000653D633C653D3E653D633E653D2A653D58
:10D70000632A653D2B653D2D653D653E26653D7C67
:10D71000653D2F653D632F653D25653D5E653D3D5E
:10D72000653D21453D00756E69636F6465206E61DE
:10D730006D65206573636170657300616E6400617F
:10D74000730061737365727400627265616B00636C
:10D750006F6E74696E75650064656C00656C6966F2
:10D7600000656C7365006578636570740066696E4A
:10D77000616C6C790066726F6D006C616D626461E2
:10D78000006E6F740072657475726E007969656CF5
:10D7900064005F5F64656275675F5F003C25713E92
:10D7A0000054726163656261636B20286D6F7374EE
:10D7B00020726563656E742063616C6C206C6173AC
:10D7C00074293A0A00202046696C652022257122BE
:10D7D0002C206C696E65202564002C20696E202544
:10D7E000710A0063616E277420636F6E76657274D0
:10D7F00020257320746F20696E740063616E277436
:10D8000020636F6E7665727420257320746F2066B6
:10D810006C6F6174006F626A6563742027257327DB
:10D82000206973206E6F742061207475706C6520A0
:10D830006F72206C697374007265717565737465BD
:10D8400064206C656E67746820256420627574209E
:10D850006F626A65637420686173206C656E6774BB
:10D860006820256400257120696E646963657320F2
:10D870006D75737420626520696E74656765727377
:10D880002C206E6F7420257300257120696E6465ED
:10D8900078206F7574206F662072616E6765006F07
:10D8A000626A656374206F6620747970652027252D
:10D8B000732720686173206E6F206C656E282900C5
:10D8C00027257327206F626A65637420646F657310
:10D8D000206E6F7420737570706F72742069746538
:10D8E0006D2064656C6574696F6E00272573272051
:10D8F0006F626A656374206973206E6F742073753C
:10D900006273637269707461626C650027257327A6
:10D91000206F626A65637420646F6573206E6F7434
:10D9200020737570706F7274206974656D206173F7
:10D930007369676E6D656E74006F626A65637420EB
:10D9400077697468206275666665722070726F749C
:10D950006F636F6C20726571756972656400080889
:10D960000808080808080020202020202020200087
:10D9700057656C636F6D6520746F204D6963726FBE
:10D98000507974686F6E206F6E20746865206D69C1
:10D9900063726F3A626974210A0A5472792074685A
:10D9A00065736520636F6D6D616E64733A0A202044
:10D9B000646973706C61792E7363726F6C6C282765
:10D9C00048656C6C6F27290A202072756E6E696E2F
:10D9D000675F74696D6528290A2020736C6565701E
:10D9E0002831303030290A2020627574746F6E5FE0
:10D9F000612E69735F7072657373656428290A57B5
:10DA000068617420646F20746865736520636F6D4E
:10DA10006D616E647320646F3F2043616E20796F87
:10DA20007520696D70726F7665207468656D3F2032
:10DA300048494E543A2075736520746865207570A6
:10DA400020616E6420646F776E0A6172726F772056
:10DA50006B65797320746F2067657420796F7572B8
:10DA600020636F6D6D616E6420686973746F727985
:10DA70002E205072657373207468652054414220D3
:10DA80006B657920746F206175746F2D636F6D7095
:10DA90006C6574650A756E66696E69736865642085
:10DAA000776F7264732028736F2027646927206260
:10DAB00065636F6D65732027646973706C61792786
:10DAC00020616674657220796F752070726573735A
:10DAD00020544142292E2054686573650A74726986
:10DAE000636B7320736176652061206C6F74206FA7
:10DAF0006620747970696E6720616E64206C6F6F48
:10DB00006B20636F6F6C210A0A4578706C6F7265C9
:10DB10003A0A54797065202768656C7028736F6DB8
:10DB2000657468696E67292720746F2066696E6462
:10DB3000206F75742061626F75742069742E205493
:10DB4000797065202764697228736F6D65746869E0
:10DB50006E67292720746F2073656520776861746C
:10DB60000A69742063616E20646F2E205479706599
:10DB7000202764697228292720746F207365652027
:10DB800077686174207374756666206973206176A6
:10DB900061696C61626C652E20466F7220676F6FE1
:10DBA000646E6573732073616B652C0A646F6E27F6
:10DBB0007420747970652027696D706F7274207499
:10DBC000686973272E0A0A436F6E74726F6C206344
:10DBD0006F6D6D616E64733A0A20204354524C2D70
:10DBE0004320202020202020202D2D2073746F70B2
:10DBF00020612072756E6E696E672070726F677239
:10DC0000616D0A20204354524C2D442020202020B6
:10DC10002020202D2D206F6E206120626C616E6BA4
:10DC2000206C696E652C20646F206120736F6674B0
:10DC3000207265736574206F6620746865206D6955
:10DC400063726F3A6269740A0A417661696C616253
:10DC50006C65206D6F64756C65733A20616E7469D4
:10DC6000677261766974792C2061727261792C20F7
:10DC7000636F6C6C656374696F6E732C2067632CC3
:10DC8000206C6F76652C206D6174682C0A6D696359
:10DC9000726F707974686F6E2C206D757369632C68
:10DCA000207374727563742C207379732C207468DC
:10DCB00069730A0A466F72206D6F726520696E661D
:10DCC0006F726D6174696F6E2061626F7574205040
:10DCD0007974686F6E2C2076697369743A20687461
:10DCE00074703A2F2F707974686F6E2E6F72672F71
:10DCF0000A546F2066696E64206F75742061626FCC
:10DD00007574204D6963726F507974686F6E2C2042
:10DD100076697369743A20687474703A2F2F6D694C
:10DD200063726F707974686F6E2E6F72672F0A500E
:10DD30007974686F6E2F6D6963726F3A62697420CF
:10DD4000646F63756D656E746174696F6E2069735D
:10DD500020686572653A20687474703A2F2F6D6977
:10DD600063726F6269742D6D6963726F7079746824
:10DD70006F6E2E727466642E6F72672F0A004D6983
:10DD800063726F426974416363656C65726F6D6540
:10DD900074657220747970650A006F626A656374D5
:10DDA0002000206973206F662074797065202571CA
:10DDB0000A00202D2D200055736566756C20737444
:10DDC00075666620746F20636F6E74726F6C20745A
:10DDD0006865206D6963726F3A6269742068617268
:10DDE00064776172652E0A00507574206D696372E4
:10DDF0006F3A62697420696E2070616E69632829C8
:10DE0000206D6F646520616E6420646973706C615D
:10DE10007920616E20756E6861707079206661632B
:10DE2000652E0A5072657373207265736574206283
:10DE30007574746F6E20746F2065786974207061DA
:10DE40006E69632829206D6F64652E0A005265741F
:10DE500075726E20612072616E646F6D286E756DD3
:10DE600062657229206265747765656E2030206175
:10DE70006E6420276E756D626572202D2031272E0D
:10DE80000A72616E646F6D28313029207265747575
:10DE9000726E732061206E756D62657220626574AA
:10DEA0007765656E203020616E6420392E0A00503F
:10DEB0007574206D6963726F3A62697420746F20A3
:10DEC000736C6565702874696D652920666F7220B2
:10DED000736F6D65206D696C6C697365636F6E64DB
:10DEE00073202831207365636F6E64203D203130CC
:10DEF0003030206D7329206F662074696D652E0A9D
:10DF0000736C65657028323030302920676976651A
:10DF100073206D6963726F3A6269742061203220E8
:10DF20007365636F6E64206E61702E0A00526574B3
:10DF300075726E2072756E6E696E675F74696D655D
:10DF4000282920696E206D696C6C697365636F6E3A
:10DF500064732073696E6365206D6963726F3A62E2
:10DF600069742773206C6173742072657365742EF5
:10DF70000A00446574656374206D6963726F3A6268
:10DF800069742773206D6F76656D656E7420696E98
:10DF90002033442E0A4974206D6561737572657370
:10DFA0002074696C7420285820616E6420592920DF
:10DFB000616E642075702D646F776E20285A292059
:10DFC0006D6F74696F6E2E0A0052657475726E20E3
:10DFD0006D6963726F3A62697427732074696C7437
:10DFE00020285820616363656C65726174696F6E87
:10DFF0002920696E206D696C6C692D6727732E0A64
:10E000000052657475726E206D6963726F3A626951
:10E010007427732074696C742028592061636365C8
:10E020006C65726174696F6E2920696E206D696C10
:10E030006C692D6727732E0A0052657475726E2005
:10E040006D6963726F3A62697427732075702D640D
:10E050006F776E206D6F74696F6E20285A20616330
:10E0600063656C65726174696F6E2920696E206DDD
:10E07000696C6C692D6727732E0A5A2069732061B9
:10E0800020706F736974697665206E756D62657254
:10E09000207768656E206D6F76696E672075702ECB
:10E0A000204D6F76696E6720646F776E2C205A2042
:10E0B00069732061206E65676174697665206E758D
:10E0C0006D6265722E0A006D6963726F3A626974DF
:10E0D00027732027412720627574746F6E2E205796
:10E0E00068656E20627574746F6E2069732070723B
:10E0F000657373656420646F776E2C2069735F703D
:10E10000726573736564282920697320547275657C
:10E110002E0A006D6963726F3A6269742773202753
:10E12000422720627574746F6E2E205768656E20CA
:10E13000627574746F6E2069732070726573736595
:10E140006420646F776E2C2069735F7072657373DF
:10E150006564282920697320547275652E0A004968
:10E16000662074686520627574746F6E2069732010
:10E170007072657373656420646F776E2C206973A9
:10E180005F70726573736564282920697320547207
:10E1900075652C20656C73652046616C73652E0A6D
:10E1A00000557365207761735F7072657373656482
:10E1B000282920746F206C6561726E206966207456
:10E1C000686520627574746F6E2077617320707259
:10E1D00065737365642073696E6365207468652078
:10E1E0006C6173742074696D650A7761735F707216
:10E1F00065737365642829207761732063616C6C93
:10E2000065642E2052657475726E73205472756544
:10E21000206F722046616C73652E0A00557365206D
:10E220006765745F70726573736573282920746FF6
:10E2300020676574207468652072756E6E696E67FC
:10E2400020746F74616C206F6620627574746F6ED9
:10E2500020707265737365732E0A005573652072A2
:10E26000657365745F7072657373657328292074B4
:10E270006F207265736574207468652072756E6EA8
:10E28000696E6720746F74616C206F6620627574AC
:10E29000746F6E207072657373657320746F207A6B
:10E2A00065726F2E0A00557365206D6963726F3A4F
:10E2B000626974277320636F6D7061737320746F6C
:10E2C0002064657465637420746865206469726590
:10E2D0006374696F6E206974206973206865616476
:10E2E000696E6720696E2E0A54686520636F6D70D1
:10E2F0006173732063616E20646574656374206D5F
:10E3000061676E65746963206669656C64732E0A63
:10E310004974207573657320746865204561727453
:10E32000682773206D61676E65746963206669652F
:10E330006C6420746F206465746563742064697212
:10E34000656374696F6E2E0A004966206D69637299
:10E350006F3A626974277320636F6D706173732005
:10E3600069735F63616C69627261746564282920F6
:10E37000616E642061646A757374656420666F728F
:10E380002061636375726163792C207265747572A4
:10E390006E20547275652E0A496620636F6D706138
:10E3A0007373206861736E2774206265656E2061E7
:10E3B000646A757374656420666F72206163637547
:10E3C000726163792C2072657475726E2046616C7F
:10E3D00073652E0A004966206D6963726F3A62693F
:10E3E0007420697320636F6E66757365642C206397
:10E3F000616C6962726174652829207468652063A4
:10E400006F6D7061737320746F2061646A757374CB
:10E410002074686520697473206163637572616339
:10E42000792E0A5768656E2063616C696272617447
:10E43000696E672C206C696520697420666C617454
:10E4400020616E64207370696E20697420686F7239
:10E45000697A6F6E74616C6C792E20447572696E86
:10E46000672063616C6962726174696F6E2C0A74F3
:10E470007279206E6F7420746F2074696C742074CC
:10E48000686520636F6D7061737320757020616EB5
:10E490006420646F776E2E0A004966206D6963728E
:10E4A0006F3A626974277320636F6D7061737320B4
:10E4B00069735F63616C6962726174696E67282950
:10E4C000206974732061636375726163792C2069BC
:10E4D000742073656E647320547275652E0A4966E4
:10E4E0002069742773206E6F7420627573792063BE
:10E4F000616C6962726174696E67207468696E67C5
:10E50000732C2069742073656E64732046616C738C
:10E51000652E0A005265736574206D6963726F3AE7
:10E52000626974277320636F6D70617373207573F4
:10E53000696E6720636C6561725F63616C696272AA
:10E540006174696F6E282920636F6D6D616E642E32
:10E550000A52756E2063616C696272617465282964
:10E5600020746F20696D70726F76652061636375CA
:10E57000726163792E0A0052657475726E206D6146
:10E58000676E65746963206669656C642064657490
:10E59000656374656420616C6F6E67206D6963727A
:10E5A0006F3A6269742773205820617869732E0A64
:10E5B000557375616C6C792C2074686520636F6D80
:10E5C000706173732072657475726E732074686500
:10E5D0002065617274682773206D61676E65746968
:10E5E00063206669656C6420696E206D6963726F73
:10E5F0002D5465736C6120756E6974732E0A556EA7
:10E600006C6573732E2E2E61207374726F6E67208B
:10E610006D61676E6574206973206E6561726279E1
:10E62000210A0052657475726E206D61676E6574A3
:10E630006963206669656C642064657465637465EC
:10E640006420616C6F6E67206D6963726F3A6269F6
:10E65000742773205920617869732E0A5573756188
:10E660006C6C792C2074686520636F6D70617373B6
:10E670002072657475726E732074686520656172AE
:10E6800074682773206D61676E65746963206669BD
:10E69000656C6420696E206D6963726F2D546573BB
:10E6A0006C6120756E6974732E0A556E6C65737398
:10E6B0002E2E2E61207374726F6E67206D61676EEF
:10E6C0006574206973206E6561726279210A005257
:10E6D000657475726E206D61676E6574696320661E
:10E6E00069656C6420646574656374656420616C3D
:10E6F0006F6E67206D6963726F3A62697427732069
:10E700005A20617869732E0A557375616C6C792C87
:10E710002074686520636F6D706173732072657417
:10E7200075726E73207468652065617274682773F2
:10E73000206D61676E65746963206669656C64202D
:10E74000696E206D6963726F2D5465736C612075FD
:10E750006E6974732E0A556E6C6573732E2E2E615E
:10E76000207374726F6E67206D61676E65742069C7
:10E7700073206E6561726279210A006D6963726F40
:10E780003A626974277320357835204C45442064FB
:10E790006973706C61792E0A005573652073686F18
:10E7A0007728782920746F207072696E74207468DD
:10E7B0006520737472696E67206F7220696D61677E
:10E7C000652027782720746F20746865206469733A
:10E7D000706C61792E205472792073686F772827C6
:10E7E00048692127292E0A5573652073686F772899
:10E7F000732C20692920746F2073686F77207374DD
:10E8000072696E67202773272C206F6E65206368FE
:10E810006172616374657220617420612074696D36
:10E8200065207769746820612064656C6179206F68
:10E83000660A276927206D696C6C697365636F6E62
:10E8400064732E0A00557365207363726F6C6C28B5
:10E85000732920746F207363726F6C6C2074686509
:10E8600020737472696E6720277327206163726F4B
:10E8700073732074686520646973706C61792E0A03
:10E88000557365207363726F6C6C28732C20692933
:10E8900020746F207363726F6C6C20737472696E76
:10E8A0006720277327207769746820612064656C6E
:10E8B0006179206F6620276927206D696C6C697308
:10E8C00065636F6E64732061667465720A65616367
:10E8D00068206368617261637465722E0A00557303
:10E8E0006520636C656172282920746F20636C65F4
:10E8F0006172206D6963726F3A6269742773206474
:10E900006973706C61792E0A0055736520616E69B8
:10E910006D61746528696D672C2064656C61792C64
:10E92000207374726964652C2073746172743D3055
:10E930002C206173796E633D46616C73652C207287
:10E9400065706561743D46616C73652920746F2044
:10E95000616E696D6174650A696D6167652027691B
:10E960006D67272077697468202764656C61792753
:10E97000206D696C6C697365636F6E647320616E82
:10E980006420277374726964652720706978656CE8
:10E9900073206F6666736574206265747765656E53
:10E9A0000A6672616D65732E204F7074696F6E61B7
:10E9B0006C3A2027737461727427206F66667365E2
:10E9C000742066726F6D206C6566742068616E6479
:10E9D00020736964652C20276173796E6327207426
:10E9E0006F2072756E20696E207468650A626163BB
:10E9F0006B67726F756E642C202772657065617429
:10EA00002720746F206C6F6F702074686520616EB2
:10EA1000696D6174696F6E2E0A00557365206765B4
:10EA2000745F706978656C28782C20792920746F60
:10EA30002072657475726E207468652064697370E5
:10EA40006C61792773206272696768746E6573738D
:10EA5000206174204C454420706978656C202878CA
:10EA60002C79292E0A4272696768746E6573732067
:10EA700063616E2062652066726F6D203020284CC5
:10EA80004544206973206F66662920746F20392001
:10EA9000286D6178696D756D204C454420627269FE
:10EAA0006768746E657373292E0A00557365207349
:10EAB00065745F706978656C28782C20792C2062E9
:10EAC0002920746F207365742074686520646973ED
:10EAD000706C6179206174204C45442070697865C0
:10EAE0006C2028782C792920746F206272696768FD
:10EAF000746E657373202762270A776869636820DC
:10EB000063616E2062652073657420626574776549
:10EB1000656E203020286F66662920746F203920AA
:10EB20002866756C6C206272696768746E657373B1
:10EB3000292E0A006D6963726F3A62697427732027
:10EB400070696E2030206F6E2074686520676F6C6E
:10EB500064206564676520636F6E6E6563746F72B1
:10EB60002E0A006D6963726F3A62697427732070B0
:10EB7000696E2031206F6E2074686520676F6C6449
:10EB8000206564676520636F6E6E6563746F722EB7
:10EB90000A006D6963726F3A626974277320706945
:10EBA0006E2032206F6E2074686520676F6C642061
:10EBB0006564676520636F6E6E6563746F722E0A9D
:10EBC000006D6963726F3A62697427732070696EB1
:10EBD0002033206F6E2074686520676F6C64206539
:10EBE00064676520636F6E6E6563746F722E0A00D2
:10EBF0006D6963726F3A62697427732070696E2061
:10EC000034206F6E2074686520676F6C64206564C3
:10EC1000676520636F6E6E6563746F722E0A006D98
:10EC20006963726F3A62697427732070696E203568
:10EC3000206F6E2074686520676F6C642065646760
:10EC40006520636F6E6E6563746F722E0A006D6966
:10EC500063726F3A62697427732070696E20362080
:10EC60006F6E2074686520676F6C642065646765EB
:10EC700020636F6E6E6563746F722E0A006D696338
:10EC8000726F3A62697427732070696E2037206F43
:10EC90006E2074686520676F6C642065646765200A
:10ECA000636F6E6E6563746F722E0A006D696372B6
:10ECB0006F3A62697427732070696E2038206F6E16
:10ECC0002074686520676F6C6420656467652063E5
:10ECD0006F6E6E6563746F722E0A006D6963726F7A
:10ECE0003A62697427732070696E2039206F6E2034
:10ECF00074686520676F6C64206564676520636F66
:10ED00006E6E6563746F722E0A006D6963726F3A7E
:10ED100062697427732070696E203130206F6E2015
:10ED200074686520676F6C64206564676520636F35
:10ED30006E6E6563746F722E0A006D6963726F3A4E
:10ED400062697427732070696E203131206F6E20E4
:10ED500074686520676F6C64206564676520636F05
:10ED60006E6E6563746F722E0A006D6963726F3A1E
:10ED700062697427732070696E203132206F6E20B3
:10ED800074686520676F6C64206564676520636FD5
:10ED90006E6E6563746F722E0A006D6963726F3AEE
:10EDA00062697427732070696E203133206F6E2082
:10EDB00074686520676F6C64206564676520636FA5
:10EDC0006E6E6563746F722E0A006D6963726F3ABE
:10EDD00062697427732070696E203134206F6E2051
:10EDE00074686520676F6C64206564676520636F75
:10EDF0006E6E6563746F722E0A006D6963726F3A8E
:10EE000062697427732070696E203135206F6E201F
:10EE100074686520676F6C64206564676520636F44
:10EE20006E6E6563746F722E0A006D6963726F3A5D
:10EE300062697427732070696E203136206F6E20EE
:10EE400074686520676F6C64206564676520636F14
:10EE50006E6E6563746F722E0A006D6963726F3A2D
:10EE600062697427732070696E203139206F6E20BB
:10EE700074686520676F6C64206564676520636FE4
:10EE80006E6E6563746F722E0A006D6963726F3AFD
:10EE900062697427732070696E203230206F6E2093
:10EEA00074686520676F6C64206564676520636FB4
:10EEB0006E6E6563746F722E0A006D6963726F3ACD
:10EEC0006269742C2077726974655F64696769741C
:10EED000616C2863686F6963652920746F207468AA
:10EEE000652070696E2E20596F75206861766520E7
:10EEF00074776F202763686F696365272076616C7C
:10EF00007565732C0A3020286C6F29206F722031B0
:10EF100020286869292E0A006D6963726F3A626958
:10EF2000742C20726561645F6469676974616C2820
:10EF3000292076616C75652066726F6D2074686536
:10EF40002070696E20617320656974686572203075
:10EF500020286C6F29206F72203120286869292EA3
:10EF60000A006D6963726F3A6269742C2077726966
:10EF700074655F616E616C6F672876616C75652979
:10EF800020746F207468652070696E2E20596F752B
:10EF90002063616E2075736520612077686F6C65F2
:10EFA000206E756D626572206265747765656E0AA4
:10EFB0003020616E642032353520617320746865BD
:10EFC0002076616C75652E0A006D6963726F3A6216
:10EFD00069742C20726561645F616E616C6F672873
:10EFE000292076616C75652066726F6D2074686586
:10EFF0002070696E2E20576F772C20616E616C6FC8
:10F000006720686173206C6F7473206F662076616F
:10F010006C7565730A2830202D2036353533352937
:10F020002E204469676974616C20686173206F6E7B
:10F030006C79203020616E6420312E0A00496620F0
:10F0400070696E2069735F746F75636865642829E1
:10F05000206F6E206D6963726F3A6269742C207242
:10F06000657475726E20547275652E204966206E27
:10F070006F7468696E6720697320746F756368695F
:10F080006E67207468652070696E2C0A72657475ED
:10F09000726E2046616C73652E0A00436F6D6D754C
:10F0A0006E69636174652077697468206F6E65208E
:10F0B0006F72206D6F7265206E616D65642064658E
:10F0C000766963657320636F6E6E65637465642033
:10F0D000746F206D6963726F3A6269742E204561A6
:10F0E0006368206E616D65640A6465766963652096
:10F0F00068617320616E2027616464726573732791
:10F100002C20636F6D6D756E696361746573207516
:10F1100073696E67204932432C20616E6420636FEF
:10F120006E6E6563747320746F2074686520492F58
:10F130004F2070696E732E0A0055736520726561E9
:10F140006428616464726573732C206E2920746F67
:10F15000207265616420276E2720627974657320B0
:10F1600066726F6D207468652064657669636520DA
:10F170007769746820746869732061646472657368
:10F18000732E0A005573652077726974652861646F
:10F1900064726573732C20627566666572292074CB
:10F1A0006F20777269746520746F207468652027FA
:10F1B00062756666657227206F66207468652064D4
:10F1C00065766963652061742074686973202761BE
:10F1D000646472657373272E0A00437265617465F7
:10F1E00020616E6420757365206275696C742D6989
:10F1F0006E20494D4147455320746F2073686F77E7
:10F20000206F6E2074686520646973706C61792E5C
:10F21000205573653A0A496D616765280A202027E1
:10F2200030393039303A270A2020273939393939ED
:10F230003A270A20202739393939393A270A202034
:10F240002730393939303A270A20202730303930F1
:10F25000303A27290A2E2E2E746F206D616B65209F
:10F2600061206E657720357835206865617274207D
:10F27000696D6167652E204E756D626572732067DA
:10F280006F2066726F6D203020286F6666292074AB
:10F290006F20392028627269676874657374292E3B
:10F2A000204E6F74650A74686520636F6C6F6E2002
:10F2B000273A2720746F2073657420746865206571
:10F2C0006E64206F66206120726F772E0A0052658F
:10F2D0007475726E20746865207769647468206F35
:10F2E000662074686520696D61676520696E2070AD
:10F2F0006978656C732E0A0052657475726E20749D
:10F30000686520686569676874206F662074686541
:10F3100020696D61676520696E20706978656C731E
:10F320002E0A00557365206765745F706978656C97
:10F3300028782C20792920746F2072657475726E7C
:10F340002074686520696D61676527732062726942
:10F350006768746E657373206174204C4544207037
:10F360006978656C2028782C79292E0A42726967A1
:10F3700068746E6573732063616E206265206672C7
:10F380006F6D203020284C4544206973206F6666DD
:10F390002920746F203920286D6178696D756D2082
:10F3A0004C4544206272696768746E657373292ED8
:10F3B0000A00557365207365745F706978656C2801
:10F3C000782C20792C20622920746F20736574209A
:10F3D000746865204C454420706978656C202878F5
:10F3E0002C792920696E2074686520696D616765D4
:10F3F00020746F206272696768746E6573730A2780
:10F4000062272077686963682063616E20626520E7
:10F41000736574206265747765656E203020286F8F
:10F4200066662920746F2039202866756C6C20620E
:10F4300072696768746E657373292E0A0055736567
:10F440002073686966745F6C656674286929207426
:10F450006F206D616B65206120636F7079206F662E
:10F460002074686520696D61676520627574206D20
:10F470006F7665642027692720706978656C732032
:10F48000746F20746865206C6566742E0A0055736D
:10F49000652073686966745F726967687428692992
:10F4A00020746F206D616B65206120636F7079201F
:10F4B0006F662074686520696D6167652062757488
:10F4C000206D6F7665642027692720706978656CE8
:10F4D0007320746F0A7468652072696768742E0AF5
:10F4E000005573652073686966745F7570286929B3
:10F4F00020746F206D616B65206120636F707920CF
:10F500006F662074686520696D6167652062757437
:10F51000206D6F7665642027692720706978656C97
:10F52000732075702E0A00557365207368696674C0
:10F530005F646F776E28692920746F206D616B6539
:10F54000206120636F7079206F6620746865206980
:10F550006D61676520627574206D6F766564202724
:10F56000692720706978656C7320646F776E2E0A46
:10F570000055736520636F7079282920746F206DA2
:10F58000616B652061206E6577206578616374200A
:10F59000636F7079206F662074686520696D61679C
:10F5A000652E0A005573652063726F702878312CC0
:10F5B0002079312C2078322C2079322920746F2048
:10F5C0006D616B652061206375742D6F75742063A8
:10F5D0006F7079206F662074686520696D6167655A
:10F5E00020776865726520636F6F7264696E6174FD
:10F5F000650A2878312C793129206973207468656F
:10F6000020746F70206C65667420636F726E657213
:10F61000206F6620746865206375742D6F75742083
:10F620006172656120616E6420636F6F7264696EE0
:10F63000617465202878322C79322920697320740E
:10F6400068650A626F74746F6D20726967687420F0
:10F65000636F726E65722E0A0055736520696E764F
:10F66000657274282920746F206D616B652061209C
:10F670006E6567617469766520636F7079206F6667
:10F680002074686520696D6167652E205768657212
:10F6900065206120706978656C20776173206272E3
:10F6A00069676874206F720A6F6E20696E207468D3
:10F6B00065206F726967696E616C2C2069742069BE
:10F6C000732064696D206F72206F666620696E20FA
:10F6D000746865206E6567617469766520636F7014
:10F6E000792E0A00436F6D6D756E696361746520D4
:10F6F0007769746820612073657269616C20646544
:10F700007669636520636F6E6E65637465642074EB
:10F710006F206D6963726F3A626974277320492F95
:10F720004F2070696E732E0A0055736520696E69EB
:10F7300074282920746F2073657420757020636F9E
:10F740006D6D756E69636174696F6E2E205573659A
:10F750002070696E732030202854582920616E640F
:10F76000203120285258292077697468206120624E
:10F770006175640A72617465206F662039363030B5
:10F780002E0A4F766572726964652074686520641C
:10F79000656661756C747320666F7220276261758F
:10F7A0006472617465272C202770617269747927EF
:10F7B00020616E64202770696E73272E0A004966E7
:10F7C0002074686572652061726520696E636F6D73
:10F7D000696E672063686172616374657273207714
:10F7E000616974696E6720746F206265207265615B
:10F7F000642C20616E7928292077696C6C207265F1
:10F800007475726E20547275652E0A4F7468657235
:10F81000776973652C2072657475726E732046610A
:10F820006C73652E0A005573652072656164282922
:10F8300020746F2072656164206368617261637413
:10F840006572732E0A5573652072656164286E298E
:10F8500020746F20726561642C206174206D6F7359
:10F86000742C20276E27206279746573206F6620C0
:10F87000646174612E0A005573652072656164616C
:10F880006C6C282920746F2072656164206173207C
:10F890006D756368206461746120617320706F739B
:10F8A0007369626C652E0A00557365207265616428
:10F8B0006C696E65282920746F207265616420610F
:10F8C000206C696E65207468617420656E647320B5
:10F8D000776974682061206E65776C696E65206356
:10F8E00068617261637465722E0A005573652072D7
:10F8F000656164696E746F286275662920746F2073
:10F900007265616420627974657320696E746F201A
:10F910007468652062756666657220276275662761
:10F920002E0A5573652072656164696E746F286272
:10F930007566662C206E2920746F20726561642CB8
:10F94000206174206D6F73742C20276E27206E75D4
:10F950006D626572206F6620627974657320696ECE
:10F96000746F2027627566272E0A0055736520770D
:10F9700072697465286275662920746F20777269D0
:10F9800074652074686520627974657320696E20DF
:10F9900062756666657220276275662720746F201F
:10F9A00074686520636F6E6E65637465642064655A
:10F9B000766963652E0A00506C756720696E206158
:10F9C00020737065616B657220776974682063725B
:10F9D0006F636F64696C6520636C69707320616E1E
:10F9E00064206D616B65206D6963726F3A62697442
:10F9F00020676F20626C65657020616E6420626CA8
:10FA00006F6F702E0A00557365207365745F74659F
:10FA10006D706F286E756D6265722C2062706D2935
:10FA200020746F206D616B652061206265617420B8
:10FA30006C617374206120276E756D62657227207A
:10FA40006F66207469636B73206C6F6E6720616EE4
:10FA5000640A706C61796564206174202762706D3E
:10FA60002720626561747320706572206D696E7500
:10FA700074652E0A00557365207069746368286682
:10FA80007265712C206C656E6774682920746F2014
:10FA90006D616B65206D6963726F3A626974207085
:10FAA0006C61792061206E6F746520617420276617
:10FAB00072657127206672657175656E637920665F
:10FAC0006F720A276C656E67746827206D696C6CAD
:10FAD000697365636F6E64732E20452E672E2070E8
:10FAE00069746368283434302C2031303030292058
:10FAF00077696C6C20706C617920636F6E636572DE
:10FB0000742027412720666F722031207365636F50
:10FB10006E642E0A0055736520706C6179286D75CE
:10FB20007369632920746F206D616B65206D696353
:10FB3000726F3A62697420706C617920276D7573F9
:10FB4000696327206C697374206F66206E6F74651B
:10FB5000732E20547279206F7574207468650A6260
:10FB600075696C7420696E206D7573696320746F9C
:10FB70002073656520686F7720697420776F726BDA
:10FB8000732E20452E672E206D757369632E706C61
:10FB90006179286D757369632E50554E43484C4901
:10FBA0004E45292E0A00557365206765745F74659C
:10FBB0006D706F282920746F2072657475726E20C5
:10FBC000746865206E756D626572206F6620746959
:10FBD000636B7320696E2061206265617420616EC1
:10FBE00064206E756D626572206F66206265617457
:10FBF000730A706572206D696E7574652E0A005502
:10FC0000736520746F2073746F7028292074686581
:10FC1000206D757369632074686174206973207046
:10FC20006C6179696E672E0A004966207468696E96
:10FC3000677320676F2077726F6E672C2072657311
:10FC40006574282920746865206D75736963207454
:10FC50006F206974732064656661756C74207365C8
:10FC60007474696E67732E0A005365653A20687470
:10FC700074703A2F2F786B63642E636F6D2F33355A
:10FC8000332F0A00546865205A656E206F66205035
:10FC90007974686F6E20646566696E657320776835
:10FCA000617420697420697320746F20626520502C
:10FCB0007974686F6E69632E20497420776F756C54
:10FCC000646E277420666974206F6E20746869738F
:10FCD0000A64657669636520736F207765277665AA
:10FCE000207772697474656E2061205A656E206F8A
:10FCF00066204D6963726F507974686F6E20696E0B
:10FD000073746561642E0A005573652061757468AB
:10FD10006F7273282920746F2072657665616C207C
:10FD2000746865206E616D6573206F662074686508
:10FD30002070656F706C652077686F2063726561F5
:10FD4000746564207468697320736F667477617278
:10FD5000652E0A00416C6C20796F75206E656564B4
:10FD60002E20557365206C6F76652E62616461622A
:10FD70006F6F6D282920746F207265706561742023
:10FD8000746865206566666563742E0A004865615F
:10FD900072206D7920736F756C20737065616B3A9A
:10FDA0000A546865207665727920696E7374616E95
:10FDB00074207468617420492073617720796F75AD
:10FDC0002C206469640A4D7920686561727420662C
:10FDD0006C7920746F20796F757220736572766903
:10FDE00063652E0A0047433A20746F74616C3A20B1
:10FDF00025752C20757365643A2025752C20667254
:10FE000065653A2025750A00204E6F2E206F66200A
:10FE1000312D626C6F636B733A2025752C20322D67
:10FE2000626C6F636B733A2025752C206D617820AE
:10FE3000626C6B20737A3A2025750A004743206D67
:10FE4000656D6F7279206C61796F75743B20667295
:10FE50006F6D2025703A000A2020202020202028C5
:10FE60002575206C696E657320616C6C2066726507
:10FE70006529000A253035783A2000636872282900
:10FE800020617267206E6F7420696E2072616E67E8
:10FE90006528307831313030303029006172672088
:10FEA000697320616E20656D70747920736571755A
:10FEB000656E6365006F72642829206578706563DC
:10FEC0007465642061206368617261637465722C7B
:10FED0002062757420737472696E67206F66206C7F
:10FEE000656E67746820256420666F756E64006DAA
:10FEF00075737420757365206B6579776F726420F4
:10FF0000617267756D656E7420666F72206B6579BE
:10FF10002066756E6374696F6E00756E65787065C6
:10FF200063746564206B6579776F726420617267B2
:10FF3000756D656E742027257127006C69737420B8
:10FF400072657175697265640063616E27742073F0
:10FF50006574206174747269627574650072616E93
:10FF600067652825642C202564002C202564290041
:10FF7000747275650066616C736500286E756C6CD3
:10FF800029003030303030303030303030303030A8
:10FF90003030002020202020202020202020202061
:10FFA0002020200062797465617272617928620094
:10FFB00061727261792827256327002C205B00621B
:10FFC00061642074797065636F6465004552524FB7
:10FFD000523A20737461636B2073697A65206E6F87
:10FFE00074206261636B20746F207A65726F3B20AE
:10FFF000676F742025640A003A257000772B002F64
:020000040003F7
:10000000737464696E002F737464657272002F7369
:1000100074646F7574007A76677074756F69656162
:100020007A76677074756F6965617A766770740245
:10003000000401080200000402020402000002049D
:10004000040400020200040403010000010303038E
:100050000001010203030402010103010403010082
:1000600003000004010102000003021B1B000E112B
:1000700000000000000000000008080800080A4A0C
:100080004000000A5FEA5FEA0ED92ED36E193244AF
:1000900089330C924C924D0808000000048808082F
:1000A000040804848488000A448A4000048EC480C2
:1000B000000000048800000EC000000000080001DD
:1000C000224488100C9252524C048C84848E1C82E0
:1000D0004C901E1EC244924C06CA525FE21FF01E94
:1000E000C13E02448ED12E1FE24488100ED12ED183
:1000F0002E0ED12EC4880008000800000480048859
:100100000244880482000EC00EC008048244880E97
:10011000D126C0040ED135B36C0C925ED2521C9223
:100120005C925C0ED010100E1C9252525C1ED01CC1
:10013000901E1ED01C90100ED013712E12525ED243
:10014000521C8808081C1FE242524C125498149208
:10015000101010101E113B75B131113935B3710CEF
:100160009252524C1C925C90100C92524C861C92F3
:100170005C92510ED00C825C1FE484848412525233
:10018000524C1131312A44113135BB7112524C920B
:1001900052112A4484841EC488101E0EC808080EFA
:1001A00010080482410EC242424E048A4000000000
:1001B0000000001F0804800000000ED2524F1010F3
:1001C0001C925C000ED0100E02424ED24E0C925C7D
:1001D000900E06C81C88080ED24EC24C10101C92FD
:1001E000520800080808024002424C101498149269
:1001F0000808080806001B75B131001C9252520015
:100200000C92524C001C925C90000ED24EC2000E1A
:10021000D010100006C8049808080EC80700125233
:10022000524F0011312A4400113135BB00124C8C61
:100230009200112A4498001EC4881E06C48C84862D
:10024000080808080818080C881800000C83604E7D
:100250006F20617661696C61626C65204932430090
:1002600050776D4F75742070696E206D6170706984
:100270006E67206661696C65642E20416C6C20613C
:100280007661696C61626C652050574D20636861CE
:100290006E6E656C732061726520696E2075736582
:1002A0002E00636F756C64206E6F742070696E6FC2
:1002B00075740070696E6D6170206D69732D6D616C
:1002C0007463680070696E6D6170206E6F74206673
:1002D0006F756E6420666F722070657269706865F4
:1002E00072616C0070696E6D6170206E6F74206653
:1002F0006F756E6420666F722066756E6374696FC9
:100300006E00232D302B2000686C4C00656667451D
:1003100046470000202020202020202020282828B8
:1003200028282020202020202020202020202020BD
:100330002020202088101010101010101010101005
:100340001010101004040404040404040404101025
:1003500010101010104141414141410101010101C2
:10036000010101010101010101010101010101106E
:100370001010101010424242424242020202020297
:10038000020202020202020202020202020202103F
:10039000101010200000000000000000000000000D
:1003A000000000000000000000000000000000004D
:1003B000000000000000000000000000000000003D
:1003C000000000000000000000000000000000002D
:1003D000000000000000000000000000000000001D
:1003E000000000000000000000000000000000000D
:1003F00000000000000000000000000000000000FD
:1004000000000000000000000000000000000000EC
:10041000000000003031323334353637383941424C
:10042000434445460030313233343536373839614C
:10043000626364656600412D46612D66383930314E
:100440003233343536375D002B2D0030300078588C
:10045000000000001000000000000000017A5200BF
:10046000027C0E011B0C0D001000000018000000A3
:10047000A83CFFFF14000000000000000000000086
:100480004411FD7F01000000000000002C740200F8
:10049000402A0020000000002C740200682A00207E
:1004A00000000000E87A0200E8030000E47E020099
:1004B000000000000000000000000000000000003C
:1004C000000000000000000000000000000000002C
:1004D0000000000000002000E4290020C82F0020B8
:1004E00074000300000000009C9F0200BC9F0200FB
:1004F000DC9F02000000000000000000000000007F
:10050000000000005E020300000000000000000088
:1005100000000000000000000000000000000000DB
:1005200000000000000000000000000000000000CB
:1005300000000000000000000000000000000000BB
:10054000000000005C00002013030300780004009A
:100550000404881301000100010001424243206DA0
:100560006963726F3A626974205B78787878785D35
:100570000004010089150000A9240100693401006C
:08058000193901005D150000AE
:0400000500011FE9EE
:00000001FF
"""
